-- =============================================
-- Gartle Budgeting
-- Version 3.3, April 10, 2023
--
-- Copyright 2019-2023 Gartle LLC
--
-- License: MIT
-- =============================================
GO

SET NOCOUNT ON
GO

CREATE USER budgeting_app WITHOUT LOGIN;
GO

CREATE SCHEMA dbo27 AUTHORIZATION budgeting_app;
GO
CREATE SCHEMA xls27 AUTHORIZATION budgeting_app;
GO

CREATE TABLE [dbo27].[companies] (
      [id] int IDENTITY(1,1) NOT NULL
    , [code] nvarchar(50) NOT NULL
    , [name] nvarchar(100) NOT NULL
    , [default_language] varchar(10) NULL CONSTRAINT [DF_companies_default_language] DEFAULT('en')
    , [sort_order] int NULL
    , [created_by] nvarchar(128) NULL CONSTRAINT [DF_companies_created_by] DEFAULT(user_name())
    , [created_on] datetime NULL CONSTRAINT [DF_companies_created_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , [modified_by] nvarchar(128) NULL CONSTRAINT [DF_companies_modified_by] DEFAULT(user_name())
    , [modified_on] datetime NULL CONSTRAINT [DF_companies_modified_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , CONSTRAINT [PK_companies] PRIMARY KEY ([id])
    , CONSTRAINT [IX_companies_code] UNIQUE ([code])
    , CONSTRAINT [IX_companies_name] UNIQUE ([name])
);
GO

CREATE TABLE [dbo27].[dimensions] (
      [id] tinyint NOT NULL
    , [code] nvarchar(50) NOT NULL
    , [name] nvarchar(100) NOT NULL
    , [created_by] nvarchar(128) NULL CONSTRAINT [DF_dimensions_created_by] DEFAULT(user_name())
    , [created_on] datetime NULL CONSTRAINT [DF_dimensions_created_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , [modified_by] nvarchar(128) NULL CONSTRAINT [DF_dimensions_modified_by] DEFAULT(user_name())
    , [modified_on] datetime NULL CONSTRAINT [DF_dimensions_modified_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , CONSTRAINT [PK_dimensions] PRIMARY KEY ([id])
    , CONSTRAINT [IX_dimensions_code] UNIQUE ([code])
    , CONSTRAINT [IX_dimensions_name] UNIQUE ([name])
);
GO

CREATE TABLE [dbo27].[entry_sides] (
      [id] tinyint NOT NULL
    , [code] nvarchar(50) NOT NULL
    , [name] nvarchar(100) NOT NULL
    , [created_by] nvarchar(128) NULL CONSTRAINT [DF_entry_sides_created_by] DEFAULT(user_name())
    , [created_on] datetime NULL CONSTRAINT [DF_entry_sides_created_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , [modified_by] nvarchar(128) NULL CONSTRAINT [DF_entry_sides_modified_by] DEFAULT(user_name())
    , [modified_on] datetime NULL CONSTRAINT [DF_entry_sides_modified_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , CONSTRAINT [PK_entry_sides] PRIMARY KEY ([id])
    , CONSTRAINT [IX_entry_sides_code] UNIQUE ([code])
    , CONSTRAINT [IX_entry_sides_name] UNIQUE ([name])
);
GO

CREATE TABLE [dbo27].[ledger_account_special_types] (
      [id] tinyint NOT NULL
    , [code] nvarchar(50) NOT NULL
    , [name] nvarchar(100) NOT NULL
    , [created_by] nvarchar(128) NULL CONSTRAINT [DF_ledger_account_special_types_created_by] DEFAULT(user_name())
    , [created_on] datetime NULL CONSTRAINT [DF_ledger_account_special_types_created_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , [modified_by] nvarchar(128) NULL CONSTRAINT [DF_ledger_account_special_types_modified_by] DEFAULT(user_name())
    , [modified_on] datetime NULL CONSTRAINT [DF_ledger_account_special_types_modified_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , CONSTRAINT [PK_ledger_account_special_types] PRIMARY KEY ([id])
    , CONSTRAINT [IX_ledger_account_special_types_code] UNIQUE ([code])
    , CONSTRAINT [IX_ledger_account_special_types_name] UNIQUE ([name])
);
GO

CREATE TABLE [dbo27].[member_types] (
      [id] int NOT NULL
    , [code] nvarchar(50) NOT NULL
    , [name] nvarchar(100) NOT NULL
    , [cf_sign] int NULL
    , [pl_sign] int NULL
    , [asset_sign] int NULL
    , [vat_sign] int NULL
    , [payment_debit_type_id] tinyint NULL
    , [payment_credit_type_id] tinyint NULL
    , [charge_debit_type_id] tinyint NULL
    , [charge_credit_type_id] tinyint NULL
    , [vat_debit_type_id] tinyint NULL
    , [vat_credit_type_id] tinyint NULL
    , [created_by] nvarchar(128) NULL CONSTRAINT [DF_member_types_created_by] DEFAULT(user_name())
    , [created_on] datetime NULL CONSTRAINT [DF_member_types_created_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , [modified_by] nvarchar(128) NULL CONSTRAINT [DF_member_types_modified_by] DEFAULT(user_name())
    , [modified_on] datetime NULL CONSTRAINT [DF_member_types_modified_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , CONSTRAINT [PK_member_types] PRIMARY KEY ([id])
    , CONSTRAINT [IX_member_types_code] UNIQUE ([code])
    , CONSTRAINT [IX_member_types_name] UNIQUE ([name])
);
GO

CREATE TABLE [dbo27].[report_section_total_types] (
      [id] tinyint NOT NULL
    , [code] nvarchar(50) NOT NULL
    , [name] nvarchar(100) NOT NULL
    , [created_by] nvarchar(128) NULL CONSTRAINT [DF_report_section_total_types_created_by] DEFAULT(user_name())
    , [created_on] datetime NULL CONSTRAINT [DF_report_section_total_types_created_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , [modified_by] nvarchar(128) NULL CONSTRAINT [DF_report_section_total_types_modified_by] DEFAULT(user_name())
    , [modified_on] datetime NULL CONSTRAINT [DF_report_section_total_types_modified_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , CONSTRAINT [PK_report_section_total_types] PRIMARY KEY ([id])
    , CONSTRAINT [IX_report_section_total_types_code] UNIQUE ([code])
    , CONSTRAINT [IX_report_section_total_types_name] UNIQUE ([name])
);
GO

CREATE TABLE [dbo27].[report_section_value_types] (
      [id] tinyint NOT NULL
    , [code] nvarchar(50) NOT NULL
    , [name] nvarchar(100) NOT NULL
    , [created_by] nvarchar(128) NULL CONSTRAINT [DF_report_section_value_types_created_by] DEFAULT(user_name())
    , [created_on] datetime NULL CONSTRAINT [DF_report_section_value_types_created_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , [modified_by] nvarchar(128) NULL CONSTRAINT [DF_report_section_value_types_modified_by] DEFAULT(user_name())
    , [modified_on] datetime NULL CONSTRAINT [DF_report_section_value_types_modified_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , CONSTRAINT [PK_report_section_value_types] PRIMARY KEY ([id])
    , CONSTRAINT [IX_report_section_value_types_code] UNIQUE ([code])
    , CONSTRAINT [IX_report_section_value_types_name] UNIQUE ([name])
);
GO

CREATE TABLE [dbo27].[report_types] (
      [id] tinyint NOT NULL
    , [code] nvarchar(50) NOT NULL
    , [name] nvarchar(100) NOT NULL
    , [created_by] nvarchar(128) NULL CONSTRAINT [DF_report_types_created_by] DEFAULT(user_name())
    , [created_on] datetime NULL CONSTRAINT [DF_report_types_created_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , [modified_by] nvarchar(128) NULL CONSTRAINT [DF_report_types_modified_by] DEFAULT(user_name())
    , [modified_on] datetime NULL CONSTRAINT [DF_report_types_modified_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , CONSTRAINT [PK_report_types] PRIMARY KEY ([id])
    , CONSTRAINT [IX_report_types_code] UNIQUE ([code])
    , CONSTRAINT [IX_report_types_name] UNIQUE ([name])
);
GO

CREATE TABLE [dbo27].[translated_tables] (
      [id] tinyint NOT NULL
    , [code] nvarchar(50) NOT NULL
    , [name] nvarchar(100) NOT NULL
    , [created_by] nvarchar(128) NULL CONSTRAINT [DF_translated_tables_created_by] DEFAULT(user_name())
    , [created_on] datetime NULL CONSTRAINT [DF_translated_tables_created_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , [modified_by] nvarchar(128) NULL CONSTRAINT [DF_translated_tables_modified_by] DEFAULT(user_name())
    , [modified_on] datetime NULL CONSTRAINT [DF_translated_tables_modified_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , CONSTRAINT [PK_translated_tables] PRIMARY KEY ([id])
    , CONSTRAINT [IX_translated_tables_code] UNIQUE ([code])
    , CONSTRAINT [IX_translated_tables_name] UNIQUE ([name])
);
GO

CREATE TABLE [dbo27].[actual_closed_periods] (
      [date] date NOT NULL
    , [company_id] int NOT NULL
    , [is_closed] bit NOT NULL
    , [created_by] nvarchar(128) NULL CONSTRAINT [DF_actual_closed_periods_created_by] DEFAULT(user_name())
    , [created_on] datetime NULL CONSTRAINT [DF_actual_closed_periods_created_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , [modified_by] nvarchar(128) NULL CONSTRAINT [DF_actual_closed_periods_modified_by] DEFAULT(user_name())
    , [modified_on] datetime NULL CONSTRAINT [DF_actual_closed_periods_modified_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , CONSTRAINT [PK_actual_closed_periods] PRIMARY KEY ([date], [company_id])
);
GO

ALTER TABLE [dbo27].[actual_closed_periods] ADD CONSTRAINT [FK_actual_closed_periods_companies] FOREIGN KEY ([company_id]) REFERENCES [dbo27].[companies] ([id]);
GO

CREATE TABLE [dbo27].[ledger_account_types] (
      [id] tinyint NOT NULL
    , [code] nvarchar(50) NOT NULL
    , [name] nvarchar(100) NOT NULL
    , [bs_section] tinyint NULL
    , [bs_sign] int NULL
    , [pl_section] tinyint NULL
    , [is_pl] bit NULL
    , [is_da] bit NULL
    , [cf_section] tinyint NULL
    , [specific_type_id] tinyint NULL
    , [created_by] nvarchar(128) NULL CONSTRAINT [DF_ledger_account_types_created_by] DEFAULT(user_name())
    , [created_on] datetime NULL CONSTRAINT [DF_ledger_account_types_created_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , [modified_by] nvarchar(128) NULL CONSTRAINT [DF_ledger_account_types_modified_by] DEFAULT(user_name())
    , [modified_on] datetime NULL CONSTRAINT [DF_ledger_account_types_modified_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , CONSTRAINT [PK_ledger_account_types] PRIMARY KEY ([id])
    , CONSTRAINT [IX_ledger_account_types_code] UNIQUE ([code])
    , CONSTRAINT [IX_ledger_account_types_name] UNIQUE ([name])
);
GO

CREATE INDEX [IX_ledger_account_types_is_pl] ON [dbo27].[ledger_account_types] ([is_pl]);
GO

CREATE INDEX [IX_ledger_account_types_specific_type_id] ON [dbo27].[ledger_account_types] ([specific_type_id]);
GO

ALTER TABLE [dbo27].[ledger_account_types] ADD CONSTRAINT [FK_ledger_account_types_ledger_account_special_types] FOREIGN KEY ([specific_type_id]) REFERENCES [dbo27].[ledger_account_special_types] ([id]) ON UPDATE CASCADE;
GO

CREATE TABLE [dbo27].[report_section_types] (
      [id] tinyint NOT NULL
    , [report_type_id] tinyint NULL
    , [name] nvarchar(100) NOT NULL
    , [total_type_id] tinyint NULL
    , [hide_accounts] bit NULL CONSTRAINT [DF_report_section_types_hide_accounts] DEFAULT((0))
    , [created_by] nvarchar(128) NULL CONSTRAINT [DF_report_section_types_created_by] DEFAULT(user_name())
    , [created_on] datetime NULL CONSTRAINT [DF_report_section_types_created_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , [modified_by] nvarchar(128) NULL CONSTRAINT [DF_report_section_types_modified_by] DEFAULT(user_name())
    , [modified_on] datetime NULL CONSTRAINT [DF_report_section_types_modified_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , CONSTRAINT [PK_report_section_types] PRIMARY KEY ([id])
    , CONSTRAINT [IX_report_section_types_name] UNIQUE ([name])
);
GO

ALTER TABLE [dbo27].[report_section_types] ADD CONSTRAINT [FK_report_section_types_report_section_total_types] FOREIGN KEY ([total_type_id]) REFERENCES [dbo27].[report_section_total_types] ([id]) ON UPDATE CASCADE;
GO

ALTER TABLE [dbo27].[report_section_types] ADD CONSTRAINT [FK_report_section_types_report_types] FOREIGN KEY ([report_type_id]) REFERENCES [dbo27].[report_types] ([id]);
GO

CREATE TABLE [dbo27].[saved_report_types] (
      [id] int IDENTITY(1,1) NOT NULL
    , [company_id] int NOT NULL
    , [code] nvarchar(50) NOT NULL
    , [name] nvarchar(100) NULL
    , [created_by] nvarchar(128) NULL CONSTRAINT [DF_saved_report_types_created_by] DEFAULT(user_name())
    , [created_on] datetime NULL CONSTRAINT [DF_saved_report_types_created_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , [modified_by] nvarchar(128) NULL CONSTRAINT [DF_saved_report_types_modified_by] DEFAULT(user_name())
    , [modified_on] datetime NULL CONSTRAINT [DF_saved_report_types_modified_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , CONSTRAINT [PK_saved_report_types] PRIMARY KEY ([id])
    , CONSTRAINT [IX_saved_report_types_code] UNIQUE ([company_id], [code])
    , CONSTRAINT [IX_saved_report_types_name] UNIQUE ([company_id], [name])
);
GO

ALTER TABLE [dbo27].[saved_report_types] ADD CONSTRAINT [FK_saved_report_types_companies] FOREIGN KEY ([company_id]) REFERENCES [dbo27].[companies] ([id]);
GO

CREATE TABLE [dbo27].[subsidiary_groups] (
      [id] int IDENTITY(1,1) NOT NULL
    , [company_id] int NOT NULL
    , [code] nvarchar(50) NOT NULL
    , [name] nvarchar(100) NOT NULL
    , [created_by] nvarchar(128) NULL CONSTRAINT [DF_subsidiary_groups_created_by] DEFAULT(user_name())
    , [created_on] datetime NULL CONSTRAINT [DF_subsidiary_groups_created_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , [modified_by] nvarchar(128) NULL CONSTRAINT [DF_subsidiary_groups_modified_by] DEFAULT(user_name())
    , [modified_on] datetime NULL CONSTRAINT [DF_subsidiary_groups_modified_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , CONSTRAINT [PK_subsidiary_groups] PRIMARY KEY ([id])
    , CONSTRAINT [IX_subsidiary_groups] UNIQUE ([company_id], [code])
    , CONSTRAINT [IX_subsidiary_groups_name] UNIQUE ([company_id], [name])
);
GO

ALTER TABLE [dbo27].[subsidiary_groups] ADD CONSTRAINT [FK_subsidiary_groups_companies] FOREIGN KEY ([company_id]) REFERENCES [dbo27].[companies] ([id]);
GO

CREATE TABLE [dbo27].[translations] (
      [company_id] int NOT NULL
    , [table_id] tinyint NOT NULL
    , [member_id] int NOT NULL
    , [language] varchar(10) NOT NULL
    , [name] nvarchar(400) NULL
    , [created_by] nvarchar(128) NULL CONSTRAINT [DF_translations_created_by] DEFAULT(user_name())
    , [created_on] datetime NULL CONSTRAINT [DF_translations_created_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , [modified_by] nvarchar(128) NULL CONSTRAINT [DF_translations_modified_by] DEFAULT(user_name())
    , [modified_on] datetime NULL CONSTRAINT [DF_translations_modified_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , CONSTRAINT [PK_translations] PRIMARY KEY ([company_id], [table_id], [member_id], [language])
);
GO

ALTER TABLE [dbo27].[translations] ADD CONSTRAINT [FK_translations_companies] FOREIGN KEY ([company_id]) REFERENCES [dbo27].[companies] ([id]);
GO

ALTER TABLE [dbo27].[translations] ADD CONSTRAINT [FK_translations_translated_tables] FOREIGN KEY ([table_id]) REFERENCES [dbo27].[translated_tables] ([id]) ON DELETE CASCADE ON UPDATE CASCADE;
GO

CREATE TABLE [dbo27].[units] (
      [id] int IDENTITY(1,1) NOT NULL
    , [company_id] int NOT NULL
    , [code] nvarchar(50) NOT NULL
    , [name] nvarchar(100) NOT NULL
    , [sort_order] tinyint NOT NULL
    , [factor] float NOT NULL CONSTRAINT [DF_units_factor] DEFAULT((1))
    , [is_currency] bit NOT NULL CONSTRAINT [DF_units_is_currency] DEFAULT((0))
    , [is_functional_currency] bit NOT NULL CONSTRAINT [DF_units_is_functional_currency] DEFAULT((0))
    , [is_base_currency] bit NOT NULL CONSTRAINT [DF_units_is_base_currency] DEFAULT((0))
    , [is_translatable] bit NULL CONSTRAINT [DF_units_is_translatable] DEFAULT((1))
    , [is_active] bit NOT NULL CONSTRAINT [DF_units_is_active] DEFAULT((1))
    , [created_by] nvarchar(128) NULL CONSTRAINT [DF_units_created_by] DEFAULT(user_name())
    , [created_on] datetime NULL CONSTRAINT [DF_units_created_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , [modified_by] nvarchar(128) NULL CONSTRAINT [DF_units_modified_by] DEFAULT(user_name())
    , [modified_on] datetime NULL CONSTRAINT [DF_units_modified_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , CONSTRAINT [PK_units] PRIMARY KEY ([id])
    , CONSTRAINT [IX_units_code] UNIQUE ([company_id], [code])
    , CONSTRAINT [IX_units_name] UNIQUE ([company_id], [name])
);
GO

ALTER TABLE [dbo27].[units] ADD CONSTRAINT [FK_units_companies] FOREIGN KEY ([company_id]) REFERENCES [dbo27].[companies] ([id]);
GO

CREATE TABLE [dbo27].[users] (
      [id] int IDENTITY(1,1) NOT NULL
    , [company_id] int NOT NULL
    , [username] nvarchar(128) NOT NULL
    , [name] nvarchar(100) NOT NULL
    , [is_admin] bit NOT NULL CONSTRAINT [DF_users_is_admin] DEFAULT((0))
    , [is_default] bit NOT NULL CONSTRAINT [DF_users_is_default] DEFAULT((1))
    , [is_active] bit NOT NULL CONSTRAINT [DF_users_is_active] DEFAULT((0))
    , [created_by] nvarchar(128) NULL CONSTRAINT [DF_users_created_by] DEFAULT(user_name())
    , [created_on] datetime NULL CONSTRAINT [DF_users_created_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , [modified_by] nvarchar(128) NULL CONSTRAINT [DF_users_modified_by] DEFAULT(user_name())
    , [modified_on] datetime NULL CONSTRAINT [DF_users_modified_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , CONSTRAINT [PK_users] PRIMARY KEY ([id])
    , CONSTRAINT [IX_users_name] UNIQUE ([company_id], [name])
    , CONSTRAINT [IX_users_username] UNIQUE ([company_id], [username])
);
GO

ALTER TABLE [dbo27].[users] ADD CONSTRAINT [FK_users_companies] FOREIGN KEY ([company_id]) REFERENCES [dbo27].[companies] ([id]);
GO

CREATE TABLE [dbo27].[vat_rates] (
      [id] int IDENTITY(1,1) NOT NULL
    , [company_id] int NOT NULL
    , [code] nvarchar(50) NOT NULL
    , [name] nvarchar(100) NOT NULL
    , [sort_order] tinyint NOT NULL
    , [factor] float NULL CONSTRAINT [DF_vat_rates_factor] DEFAULT((0))
    , [is_translatable] bit NULL CONSTRAINT [DF_vat_rates_is_translatable] DEFAULT((1))
    , [is_active] bit NOT NULL CONSTRAINT [DF_vat_rates_is_active] DEFAULT((1))
    , [created_by] nvarchar(128) NULL CONSTRAINT [DF_vat_rates_created_by] DEFAULT(user_name())
    , [created_on] datetime NULL CONSTRAINT [DF_vat_rates_created_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , [modified_by] nvarchar(128) NULL CONSTRAINT [DF_vat_rates_modified_by] DEFAULT(user_name())
    , [modified_on] datetime NULL CONSTRAINT [DF_vat_rates_modified_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , CONSTRAINT [PK_vat_rates] PRIMARY KEY ([id])
    , CONSTRAINT [IX_vat_rates_code] UNIQUE ([company_id], [code])
    , CONSTRAINT [IX_vat_rates_name] UNIQUE ([company_id], [name])
);
GO

ALTER TABLE [dbo27].[vat_rates] ADD CONSTRAINT [FK_vat_rates_companies] FOREIGN KEY ([company_id]) REFERENCES [dbo27].[companies] ([id]);
GO

CREATE TABLE [dbo27].[actual_currency_rates] (
      [currency_id] int NOT NULL
    , [date] date NOT NULL
    , [rate] smallmoney NOT NULL
    , [is_checked] bit NOT NULL CONSTRAINT [DF_actual_currency_is_checked] DEFAULT((0))
    , [is_calc_date] AS (case when datepart(day,dateadd(day,(1),[date]))=(1) then (1) else (0) end)
    , [created_by] nvarchar(128) NULL CONSTRAINT [DF_actual_currency_rates_created_by] DEFAULT(user_name())
    , [created_on] datetime NULL CONSTRAINT [DF_actual_currency_rates_created_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , [modified_by] nvarchar(128) NULL CONSTRAINT [DF_actual_currency_rates_modified_by] DEFAULT(user_name())
    , [modified_on] datetime NULL CONSTRAINT [DF_actual_currency_rates_modified_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , CONSTRAINT [PK_actual_currency_rates] PRIMARY KEY ([currency_id], [date])
);
GO

ALTER TABLE [dbo27].[actual_currency_rates] ADD CONSTRAINT [FK_actual_currency_rates_units] FOREIGN KEY ([currency_id]) REFERENCES [dbo27].[units] ([id]) ON DELETE CASCADE ON UPDATE CASCADE;
GO

CREATE TABLE [dbo27].[ledger_accounts] (
      [id] int IDENTITY(1,1) NOT NULL
    , [company_id] int NOT NULL
    , [code] nvarchar(50) NOT NULL
    , [name] nvarchar(100) NOT NULL
    , [parent_id] int NULL
    , [account_type_id] tinyint NULL
    , [subsidiary_group_id] int NULL
    , [closing_child_account_id] int NULL
    , [closing_debit_account_id] int NULL
    , [closing_credit_account_id] int NULL
    , [ref_number] int NULL
    , [is_active] bit NOT NULL CONSTRAINT [DF_ledger_accounts_is_active] DEFAULT((1))
    , [created_by] nvarchar(128) NULL CONSTRAINT [DF_ledger_accounts_created_by] DEFAULT(user_name())
    , [created_on] datetime NULL CONSTRAINT [DF_ledger_accounts_created_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , [modified_by] nvarchar(128) NULL CONSTRAINT [DF_ledger_accounts_modified_by] DEFAULT(user_name())
    , [modified_on] datetime NULL CONSTRAINT [DF_ledger_accounts_modified_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , CONSTRAINT [PK_ledger_accounts] PRIMARY KEY ([id])
    , CONSTRAINT [IX_ledger_accounts_code] UNIQUE ([company_id], [code])
);
GO

CREATE INDEX [IX_ledger_accounts_name] ON [dbo27].[ledger_accounts] ([company_id], [name]);
GO

ALTER TABLE [dbo27].[ledger_accounts] ADD CONSTRAINT [FK_ledger_accounts_companies] FOREIGN KEY ([company_id]) REFERENCES [dbo27].[companies] ([id]);
GO

ALTER TABLE [dbo27].[ledger_accounts] ADD CONSTRAINT [FK_ledger_accounts_ledger_account_types] FOREIGN KEY ([account_type_id]) REFERENCES [dbo27].[ledger_account_types] ([id]) ON UPDATE CASCADE;
GO

ALTER TABLE [dbo27].[ledger_accounts] ADD CONSTRAINT [FK_ledger_accounts_subsidiary_groups] FOREIGN KEY ([subsidiary_group_id]) REFERENCES [dbo27].[subsidiary_groups] ([id]) ON DELETE SET NULL ON UPDATE CASCADE;
GO

CREATE TABLE [dbo27].[report_section_accounts] (
      [id] int IDENTITY(1,1) NOT NULL
    , [account_type_id] tinyint NOT NULL
    , [section_type_id] tinyint NOT NULL
    , [entry_side_id] tinyint NOT NULL
    , [value_type_id] tinyint NOT NULL CONSTRAINT [DF_report_section_accounts_value_type_id] DEFAULT((0))
    , [value_sign] int NULL CONSTRAINT [DF_report_section_accounts_value_sign] DEFAULT((1))
    , [pair_account_type_id] tinyint NULL
    , [created_by] nvarchar(128) NULL CONSTRAINT [DF_report_section_accounts_created_by] DEFAULT(user_name())
    , [created_on] datetime NULL CONSTRAINT [DF_report_section_accounts_created_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , [modified_by] nvarchar(128) NULL CONSTRAINT [DF_report_section_accounts_modified_by] DEFAULT(user_name())
    , [modified_on] datetime NULL CONSTRAINT [DF_report_section_accounts_modified_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , CONSTRAINT [PK_report_section_accounts] PRIMARY KEY ([id])
);
GO

ALTER TABLE [dbo27].[report_section_accounts] ADD CONSTRAINT [FK_report_section_accounts_entry_sides] FOREIGN KEY ([entry_side_id]) REFERENCES [dbo27].[entry_sides] ([id]) ON UPDATE CASCADE;
GO

ALTER TABLE [dbo27].[report_section_accounts] ADD CONSTRAINT [FK_report_section_accounts_ledger_account_types] FOREIGN KEY ([account_type_id]) REFERENCES [dbo27].[ledger_account_types] ([id]) ON UPDATE CASCADE;
GO

ALTER TABLE [dbo27].[report_section_accounts] ADD CONSTRAINT [FK_report_section_accounts_ledger_account_types_pair_account_id] FOREIGN KEY ([pair_account_type_id]) REFERENCES [dbo27].[ledger_account_types] ([id]);
GO

ALTER TABLE [dbo27].[report_section_accounts] ADD CONSTRAINT [FK_report_section_accounts_report_section_types] FOREIGN KEY ([section_type_id]) REFERENCES [dbo27].[report_section_types] ([id]) ON UPDATE CASCADE;
GO

ALTER TABLE [dbo27].[report_section_accounts] ADD CONSTRAINT [FK_report_section_accounts_report_section_value_types] FOREIGN KEY ([value_type_id]) REFERENCES [dbo27].[report_section_value_types] ([id]) ON UPDATE CASCADE;
GO

CREATE TABLE [dbo27].[report_sections] (
      [id] int IDENTITY(1,1) NOT NULL
    , [company_id] int NOT NULL
    , [report_type_id] tinyint NOT NULL
    , [section] int NOT NULL
    , [row_format] int NULL
    , [ref_number] int NULL
    , [code] nvarchar(50) NULL
    , [description] nvarchar(255) NULL
    , [parent_id] int NULL
    , [parent2_id] int NULL
    , [section_type_id] tinyint NULL
    , [inverse_sign] bit NULL CONSTRAINT [DF_report_sections_inverse_sign] DEFAULT((0))
    , [line_factor] AS (case when [inverse_sign]=(1) then (-1) else (1) end)
    , [hide_items] bit NULL
    , [show_line] bit NULL
    , [show_line_before] bit NULL
    , [show_line_after] bit NULL
    , [page_break_before] bit NULL
    , [created_by] nvarchar(128) NULL CONSTRAINT [DF_report_sections_created_by] DEFAULT(user_name())
    , [created_on] datetime NULL CONSTRAINT [DF_report_sections_created_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , [modified_by] nvarchar(128) NULL CONSTRAINT [DF_report_sections_modified_by] DEFAULT(user_name())
    , [modified_on] datetime NULL CONSTRAINT [DF_report_sections_modified_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , CONSTRAINT [PK_report_sections] PRIMARY KEY ([id])
    , CONSTRAINT [IX_report_sections] UNIQUE ([company_id], [report_type_id], [section])
);
GO

CREATE INDEX [IX_report_sections_system_type_id] ON [dbo27].[report_sections] ([section_type_id]);
GO

ALTER TABLE [dbo27].[report_sections] ADD CONSTRAINT [FK_report_sections_companies] FOREIGN KEY ([company_id]) REFERENCES [dbo27].[companies] ([id]);
GO

ALTER TABLE [dbo27].[report_sections] ADD CONSTRAINT [FK_report_sections_report_section_types] FOREIGN KEY ([section_type_id]) REFERENCES [dbo27].[report_section_types] ([id]) ON UPDATE CASCADE;
GO

ALTER TABLE [dbo27].[report_sections] ADD CONSTRAINT [FK_report_sections_report_types] FOREIGN KEY ([report_type_id]) REFERENCES [dbo27].[report_types] ([id]) ON UPDATE CASCADE;
GO

CREATE TABLE [dbo27].[members] (
      [id] int IDENTITY(1,1) NOT NULL
    , [company_id] int NULL
    , [dimension_id] tinyint NOT NULL
    , [sort_order] int NULL
    , [code] nvarchar(50) NOT NULL
    , [name] nvarchar(100) NOT NULL
    , [parent_id] int NULL
    , [start_date] date NULL
    , [unit_id] int NULL
    , [vat_rate_id] int NULL
    , [account_type_id] int NULL
    , [payment_debit_id] int NULL
    , [payment_credit_id] int NULL
    , [charge_debit_id] int NULL
    , [charge_credit_id] int NULL
    , [vat_debit_id] int NULL
    , [vat_credit_id] int NULL
    , [is_charge_net] AS (case when [vat_debit_id] IS NOT NULL AND [vat_credit_id] IS NOT NULL AND ([vat_debit_id]=[charge_debit_id] OR [vat_credit_id]=[charge_credit_id]) then (1) else (0) end)
    , [is_translatable] bit NULL CONSTRAINT [DF_members_is_translatable] DEFAULT((1))
    , [is_active] bit NOT NULL CONSTRAINT [DF_members_is_active] DEFAULT((1))
    , [created_by] nvarchar(128) NULL CONSTRAINT [DF_members_created_by] DEFAULT(user_name())
    , [created_on] datetime NULL CONSTRAINT [DF_members_created_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , [modified_by] nvarchar(128) NULL CONSTRAINT [DF_members_modified_by] DEFAULT(user_name())
    , [modified_on] datetime NULL CONSTRAINT [DF_members_modified_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , CONSTRAINT [PK_members] PRIMARY KEY ([id])
    , CONSTRAINT [IX_members_code] UNIQUE ([company_id], [code])
);
GO

CREATE INDEX [IX_members_name] ON [dbo27].[members] ([company_id], [name]);
GO

ALTER TABLE [dbo27].[members] ADD CONSTRAINT [FK_members_budgeting_account_types] FOREIGN KEY ([account_type_id]) REFERENCES [dbo27].[member_types] ([id]) ON UPDATE CASCADE;
GO

ALTER TABLE [dbo27].[members] ADD CONSTRAINT [FK_members_companies] FOREIGN KEY ([company_id]) REFERENCES [dbo27].[companies] ([id]);
GO

ALTER TABLE [dbo27].[members] ADD CONSTRAINT [FK_members_dimensions] FOREIGN KEY ([dimension_id]) REFERENCES [dbo27].[dimensions] ([id]) ON UPDATE CASCADE;
GO

ALTER TABLE [dbo27].[members] ADD CONSTRAINT [FK_members_ledger_accounts_charge_credit_id] FOREIGN KEY ([charge_credit_id]) REFERENCES [dbo27].[ledger_accounts] ([id]);
GO

ALTER TABLE [dbo27].[members] ADD CONSTRAINT [FK_members_ledger_accounts_charge_debit_id] FOREIGN KEY ([charge_debit_id]) REFERENCES [dbo27].[ledger_accounts] ([id]);
GO

ALTER TABLE [dbo27].[members] ADD CONSTRAINT [FK_members_ledger_accounts_payment_credit_id] FOREIGN KEY ([payment_credit_id]) REFERENCES [dbo27].[ledger_accounts] ([id]);
GO

ALTER TABLE [dbo27].[members] ADD CONSTRAINT [FK_members_ledger_accounts_payment_debit_id] FOREIGN KEY ([payment_debit_id]) REFERENCES [dbo27].[ledger_accounts] ([id]);
GO

ALTER TABLE [dbo27].[members] ADD CONSTRAINT [FK_members_ledger_accounts_vat_credit_id] FOREIGN KEY ([vat_credit_id]) REFERENCES [dbo27].[ledger_accounts] ([id]);
GO

ALTER TABLE [dbo27].[members] ADD CONSTRAINT [FK_members_ledger_accounts_vat_debit_id] FOREIGN KEY ([vat_debit_id]) REFERENCES [dbo27].[ledger_accounts] ([id]);
GO

ALTER TABLE [dbo27].[members] ADD CONSTRAINT [FK_members_tax_rates] FOREIGN KEY ([vat_rate_id]) REFERENCES [dbo27].[vat_rates] ([id]) ON DELETE SET NULL ON UPDATE CASCADE;
GO

ALTER TABLE [dbo27].[members] ADD CONSTRAINT [FK_members_units] FOREIGN KEY ([unit_id]) REFERENCES [dbo27].[units] ([id]) ON DELETE SET NULL ON UPDATE CASCADE;
GO

CREATE TABLE [dbo27].[actual_balances] (
      [id] int IDENTITY(1,1) NOT NULL
    , [account_id] int NOT NULL
    , [subsidiary_account_id] int NULL
    , [balance] money NULL
    , [balance$] money NULL
    , [debit] AS (case when [balance]<(0) then NULL else [balance] end)
    , [credit] AS (case when [balance]<(0) then  -[balance]  end)
    , [debit$] AS (case when [balance$]<(0) then NULL else [balance$] end)
    , [credit$] AS (case when [balance$]<(0) then  -[balance$]  end)
    , [created_by] nvarchar(128) NULL CONSTRAINT [DF_actual_balances_created_by] DEFAULT(user_name())
    , [created_on] datetime NULL CONSTRAINT [DF_actual_balances_created_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , [modified_by] nvarchar(128) NULL CONSTRAINT [DF_actual_balances_modified_by] DEFAULT(user_name())
    , [modified_on] datetime NULL CONSTRAINT [DF_actual_balances_modified_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , CONSTRAINT [PK_actual_balances] PRIMARY KEY ([id])
    , CONSTRAINT [IX_actual_balances] UNIQUE ([account_id], [subsidiary_account_id])
);
GO

ALTER TABLE [dbo27].[actual_balances] ADD CONSTRAINT [FK_actual_balances_ledger_accounts] FOREIGN KEY ([account_id]) REFERENCES [dbo27].[ledger_accounts] ([id]);
GO

ALTER TABLE [dbo27].[actual_balances] ADD CONSTRAINT [FK_actual_balances_subsidiary_accounts] FOREIGN KEY ([subsidiary_account_id]) REFERENCES [dbo27].[members] ([id]) ON UPDATE CASCADE;
GO

CREATE TABLE [dbo27].[budget_balances] (
      [id] int IDENTITY(1,1) NOT NULL
    , [category_id] int NOT NULL
    , [time_id] int NOT NULL
    , [account_id] int NOT NULL
    , [debit] money NULL
    , [credit] money NULL
    , [created_by] nvarchar(128) NULL CONSTRAINT [DF_budget_balances_created_by] DEFAULT(user_name())
    , [created_on] datetime NULL CONSTRAINT [DF_budget_balances_created_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , [modified_by] nvarchar(128) NULL CONSTRAINT [DF_budget_balances_modified_by] DEFAULT(user_name())
    , [modified_on] datetime NULL CONSTRAINT [DF_budget_balances_modified_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , CONSTRAINT [PK_budget_balances] PRIMARY KEY ([id])
    , CONSTRAINT [IX_budget_balances] UNIQUE ([category_id], [time_id], [account_id])
);
GO

ALTER TABLE [dbo27].[budget_balances] ADD CONSTRAINT [FK_budget_balances_ledger_accounts] FOREIGN KEY ([account_id]) REFERENCES [dbo27].[ledger_accounts] ([id]) ON DELETE CASCADE ON UPDATE CASCADE;
GO

ALTER TABLE [dbo27].[budget_balances] ADD CONSTRAINT [FK_budget_balances_members_category_id] FOREIGN KEY ([category_id]) REFERENCES [dbo27].[members] ([id]);
GO

ALTER TABLE [dbo27].[budget_balances] ADD CONSTRAINT [FK_budget_balances_members_time_id] FOREIGN KEY ([time_id]) REFERENCES [dbo27].[members] ([id]);
GO

CREATE TABLE [dbo27].[budget_currency_rates] (
      [category_id] int NOT NULL
    , [time_id] int NOT NULL
    , [unit_id] int NOT NULL
    , [balance00] float NULL
    , [period01] float NULL
    , [balance01] float NULL
    , [period02] float NULL
    , [balance02] float NULL
    , [period03] float NULL
    , [balance03] float NULL
    , [period04] float NULL
    , [balance04] float NULL
    , [period05] float NULL
    , [balance05] float NULL
    , [period06] float NULL
    , [balance06] float NULL
    , [period07] float NULL
    , [balance07] float NULL
    , [period08] float NULL
    , [balance08] float NULL
    , [period09] float NULL
    , [balance09] float NULL
    , [period10] float NULL
    , [balance10] float NULL
    , [period11] float NULL
    , [balance11] float NULL
    , [period12] float NULL
    , [balance12] float NULL
    , [row_formulas] nvarchar(max) NULL
    , [created_by] nvarchar(128) NULL CONSTRAINT [DF_budget_currency_rates_created_by] DEFAULT(user_name())
    , [created_on] datetime NULL CONSTRAINT [DF_budget_currency_rates_created_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , [modified_by] nvarchar(128) NULL CONSTRAINT [DF_budget_currency_rates_modified_by] DEFAULT(user_name())
    , [modified_on] datetime NULL CONSTRAINT [DF_budget_currency_rates_modified_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , CONSTRAINT [PK_budget_currency_rates] PRIMARY KEY ([category_id], [time_id], [unit_id])
);
GO

ALTER TABLE [dbo27].[budget_currency_rates] ADD CONSTRAINT [FK_budget_currency_rates_members_category_id] FOREIGN KEY ([category_id]) REFERENCES [dbo27].[members] ([id]);
GO

ALTER TABLE [dbo27].[budget_currency_rates] ADD CONSTRAINT [FK_budget_currency_rates_members_time_id] FOREIGN KEY ([time_id]) REFERENCES [dbo27].[members] ([id]);
GO

ALTER TABLE [dbo27].[budget_currency_rates] ADD CONSTRAINT [FK_budget_currency_rates_units] FOREIGN KEY ([unit_id]) REFERENCES [dbo27].[units] ([id]);
GO

CREATE TABLE [dbo27].[budget_requests] (
      [id] int IDENTITY(1,1) NOT NULL
    , [entity_id] int NOT NULL
    , [category_id] int NOT NULL
    , [time_id] int NOT NULL
    , [row_index] int NOT NULL
    , [row_format] int NULL
    , [description] nvarchar(255) NULL
    , [account_id] int NULL
    , [subsidiary_account_id] int NULL
    , [region_id] int NULL
    , [product_id] int NULL
    , [vat_rate_id] int NULL
    , [unit_id] int NULL
    , [total_payments] money NULL
    , [total_charges] money NULL
    , [balance00] money NULL
    , [payments01] money NULL
    , [charges01] money NULL
    , [balance01] money NULL
    , [payments02] money NULL
    , [charges02] money NULL
    , [balance02] money NULL
    , [payments03] money NULL
    , [charges03] money NULL
    , [balance03] money NULL
    , [payments04] money NULL
    , [charges04] money NULL
    , [balance04] money NULL
    , [payments05] money NULL
    , [charges05] money NULL
    , [balance05] money NULL
    , [payments06] money NULL
    , [charges06] money NULL
    , [balance06] money NULL
    , [payments07] money NULL
    , [charges07] money NULL
    , [balance07] money NULL
    , [payments08] money NULL
    , [charges08] money NULL
    , [balance08] money NULL
    , [payments09] money NULL
    , [charges09] money NULL
    , [balance09] money NULL
    , [payments10] money NULL
    , [charges10] money NULL
    , [balance10] money NULL
    , [payments11] money NULL
    , [charges11] money NULL
    , [balance11] money NULL
    , [payments12] money NULL
    , [charges12] money NULL
    , [balance12] money NULL
    , [row_formulas] nvarchar(max) NULL
    , [row_comments] nvarchar(max) NULL
    , [transaction_start_time] datetime NULL
    , [is_empty] AS (CONVERT([bit],case when [description] IS NOT NULL OR [account_id] IS NOT NULL OR [subsidiary_account_id] IS NOT NULL OR [region_id] IS NOT NULL OR [product_id] IS NOT NULL OR [vat_rate_id] IS NOT NULL OR [unit_id] IS NOT NULL OR [balance00] IS NOT NULL OR [payments01] IS NOT NULL OR [charges01] IS NOT NULL OR [payments02] IS NOT NULL OR [charges02] IS NOT NULL OR [payments03] IS NOT NULL OR [charges03] IS NOT NULL OR [payments04] IS NOT NULL OR [charges04] IS NOT NULL OR [payments05] IS NOT NULL OR [charges05] IS NOT NULL OR [payments06] IS NOT NULL OR [charges06] IS NOT NULL OR [payments07] IS NOT NULL OR [charges07] IS NOT NULL OR [payments08] IS NOT NULL OR [charges08] IS NOT NULL OR [payments09] IS NOT NULL OR [charges09] IS NOT NULL OR [payments10] IS NOT NULL OR [charges10] IS NOT NULL OR [payments11] IS NOT NULL OR [charges11] IS NOT NULL OR [payments12] IS NOT NULL OR [charges12] IS NOT NULL then (0) else (1) end))
    , [created_by] nvarchar(128) NULL CONSTRAINT [DF_budget_requests_created_by] DEFAULT(user_name())
    , [created_on] datetime NULL CONSTRAINT [DF_budget_requests_created_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , [modified_by] nvarchar(128) NULL CONSTRAINT [DF_budget_requests_modified_by] DEFAULT(user_name())
    , [modified_on] datetime NULL CONSTRAINT [DF_budget_requests_modified_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , CONSTRAINT [PK_budget_requests] PRIMARY KEY ([id])
);
GO

CREATE INDEX [IX_budget_requests] ON [dbo27].[budget_requests] ([category_id], [time_id], [entity_id]);
GO

ALTER TABLE [dbo27].[budget_requests] ADD CONSTRAINT [FK_budget_requests_members_account_id] FOREIGN KEY ([account_id]) REFERENCES [dbo27].[members] ([id]);
GO

ALTER TABLE [dbo27].[budget_requests] ADD CONSTRAINT [FK_budget_requests_members_category_id] FOREIGN KEY ([category_id]) REFERENCES [dbo27].[members] ([id]);
GO

ALTER TABLE [dbo27].[budget_requests] ADD CONSTRAINT [FK_budget_requests_members_entity_id] FOREIGN KEY ([entity_id]) REFERENCES [dbo27].[members] ([id]);
GO

ALTER TABLE [dbo27].[budget_requests] ADD CONSTRAINT [FK_budget_requests_members_product_id] FOREIGN KEY ([product_id]) REFERENCES [dbo27].[members] ([id]);
GO

ALTER TABLE [dbo27].[budget_requests] ADD CONSTRAINT [FK_budget_requests_members_region_id] FOREIGN KEY ([region_id]) REFERENCES [dbo27].[members] ([id]);
GO

ALTER TABLE [dbo27].[budget_requests] ADD CONSTRAINT [FK_budget_requests_members_subaccount_id] FOREIGN KEY ([subsidiary_account_id]) REFERENCES [dbo27].[members] ([id]);
GO

ALTER TABLE [dbo27].[budget_requests] ADD CONSTRAINT [FK_budget_requests_members_time_id] FOREIGN KEY ([time_id]) REFERENCES [dbo27].[members] ([id]);
GO

ALTER TABLE [dbo27].[budget_requests] ADD CONSTRAINT [FK_budget_requests_units] FOREIGN KEY ([unit_id]) REFERENCES [dbo27].[units] ([id]) ON UPDATE CASCADE;
GO

ALTER TABLE [dbo27].[budget_requests] ADD CONSTRAINT [FK_budget_requests_vat_rates] FOREIGN KEY ([vat_rate_id]) REFERENCES [dbo27].[vat_rates] ([id]) ON UPDATE CASCADE;
GO

CREATE TABLE [dbo27].[journals] (
      [id] int IDENTITY(1,1) NOT NULL
    , [company_id] int NOT NULL
    , [month] AS (dateadd(day,(1)-datepart(day,[date]),[date]))
    , [date] date NOT NULL
    , [amount] money NOT NULL
    , [amount$] money NULL
    , [description] nvarchar(255) NULL
    , [debit_account_id] int NULL
    , [debit_subsidiary_account_id] int NULL
    , [credit_account_id] int NULL
    , [credit_subsidiary_account_id] int NULL
    , [entity_id] int NULL
    , [account_id] int NULL
    , [region_id] int NULL
    , [product_id] int NULL
    , [auto_type_id] int NULL CONSTRAINT [DF_journals_auto_type_id] DEFAULT((0))
    , [ref_record_id] int NULL
    , [is_draft] bit NULL CONSTRAINT [DF_journals_is_draft] DEFAULT((0))
    , [created_by] nvarchar(128) NULL CONSTRAINT [DF_journals_created_by] DEFAULT(user_name())
    , [created_on] datetime NULL CONSTRAINT [DF_journals_created_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , [modified_by] nvarchar(128) NULL CONSTRAINT [DF_journals_modified_by] DEFAULT(user_name())
    , [modified_on] datetime NULL CONSTRAINT [DF_journals_modified_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , CONSTRAINT [PK_journals] PRIMARY KEY ([id])
);
GO

CREATE INDEX [IX_journals_date] ON [dbo27].[journals] ([date]);
GO

CREATE INDEX [IX_journals_ref_record_id] ON [dbo27].[journals] ([ref_record_id]);
GO

CREATE INDEX [IX_journals_auto_type_id] ON [dbo27].[journals] ([auto_type_id]);
GO

ALTER TABLE [dbo27].[journals] ADD CONSTRAINT [FK_journals_accounts_credit] FOREIGN KEY ([credit_account_id]) REFERENCES [dbo27].[ledger_accounts] ([id]);
GO

ALTER TABLE [dbo27].[journals] ADD CONSTRAINT [FK_journals_accounts_debit] FOREIGN KEY ([debit_account_id]) REFERENCES [dbo27].[ledger_accounts] ([id]);
GO

ALTER TABLE [dbo27].[journals] ADD CONSTRAINT [FK_journals_companies] FOREIGN KEY ([company_id]) REFERENCES [dbo27].[companies] ([id]);
GO

ALTER TABLE [dbo27].[journals] ADD CONSTRAINT [FK_journals_members_account_id] FOREIGN KEY ([account_id]) REFERENCES [dbo27].[members] ([id]);
GO

ALTER TABLE [dbo27].[journals] ADD CONSTRAINT [FK_journals_members_entity_id] FOREIGN KEY ([entity_id]) REFERENCES [dbo27].[members] ([id]);
GO

ALTER TABLE [dbo27].[journals] ADD CONSTRAINT [FK_journals_members_product_id] FOREIGN KEY ([product_id]) REFERENCES [dbo27].[members] ([id]);
GO

ALTER TABLE [dbo27].[journals] ADD CONSTRAINT [FK_journals_members_region_id] FOREIGN KEY ([region_id]) REFERENCES [dbo27].[members] ([id]);
GO

ALTER TABLE [dbo27].[journals] ADD CONSTRAINT [FK_journals_subsidiary_accounts_credit] FOREIGN KEY ([credit_subsidiary_account_id]) REFERENCES [dbo27].[members] ([id]);
GO

ALTER TABLE [dbo27].[journals] ADD CONSTRAINT [FK_journals_subsidiary_accounts_debit] FOREIGN KEY ([debit_subsidiary_account_id]) REFERENCES [dbo27].[members] ([id]);
GO

CREATE TABLE [dbo27].[member_groups] (
      [member_id] int NOT NULL
    , [group_id] int NOT NULL
    , [created_by] nvarchar(128) NULL CONSTRAINT [DF_member_groups_created_by] DEFAULT(user_name())
    , [created_on] datetime NULL CONSTRAINT [DF_member_groups_created_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , [modified_by] nvarchar(128) NULL CONSTRAINT [DF_member_groups_modified_by] DEFAULT(user_name())
    , [modified_on] datetime NULL CONSTRAINT [DF_member_groups_modified_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , CONSTRAINT [PK_member_groups] PRIMARY KEY ([member_id], [group_id])
);
GO

ALTER TABLE [dbo27].[member_groups] ADD CONSTRAINT [FK_member_groups_members] FOREIGN KEY ([member_id]) REFERENCES [dbo27].[members] ([id]) ON DELETE CASCADE ON UPDATE CASCADE;
GO

ALTER TABLE [dbo27].[member_groups] ADD CONSTRAINT [FK_member_groups_subsidiary_groups] FOREIGN KEY ([group_id]) REFERENCES [dbo27].[subsidiary_groups] ([id]) ON DELETE CASCADE ON UPDATE CASCADE;
GO

CREATE TABLE [dbo27].[member_permissions] (
      [member_id] int NOT NULL
    , [username] nvarchar(128) NOT NULL
    , [select_permission] bit NOT NULL
    , [update_permission] bit NOT NULL
    , [is_inherited] bit NOT NULL
    , [permission] AS (CONVERT([char](1),case when [update_permission]=(1) then case when [is_inherited]=(1) then 'w' else 'W' end when [select_permission]=(1) then case when [is_inherited]=(1) then 'r' else 'R' end when [select_permission]=(0) then case when [is_inherited]=(1) then 'd' else 'D' end else '?' end))
    , [created_by] nvarchar(128) NULL CONSTRAINT [DF_member_permissions_created_by] DEFAULT(user_name())
    , [created_on] datetime NULL CONSTRAINT [DF_member_permissions_created_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , [modified_by] nvarchar(128) NULL CONSTRAINT [DF_member_permissions_modified_by] DEFAULT(user_name())
    , [modified_on] datetime NULL CONSTRAINT [DF_member_permissions_modified_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , CONSTRAINT [PK_member_permissions] PRIMARY KEY ([member_id], [username])
);
GO

ALTER TABLE [dbo27].[member_permissions] ADD CONSTRAINT [FK_member_permissions_members_member_id] FOREIGN KEY ([member_id]) REFERENCES [dbo27].[members] ([id]) ON DELETE CASCADE ON UPDATE CASCADE;
GO

CREATE TABLE [dbo27].[member_relations] (
      [member_id] int NOT NULL
    , [partner_id] int NOT NULL
    , [select_permission] bit NULL
    , [update_permission] bit NULL
    , [permission] AS (CONVERT([char](1),case when [update_permission]=(1) then 'W' when [select_permission]=(1) then 'R' when [select_permission]=(0) then 'D' else '?' end))
    , [created_by] nvarchar(128) NULL CONSTRAINT [DF_member_relations_created_by] DEFAULT(user_name())
    , [created_on] datetime NULL CONSTRAINT [DF_member_relations_created_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , [modified_by] nvarchar(128) NULL CONSTRAINT [DF_member_relations_modified_by] DEFAULT(user_name())
    , [modified_on] datetime NULL CONSTRAINT [DF_member_relations_modified_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , CONSTRAINT [PK_member_relations] PRIMARY KEY ([member_id], [partner_id])
);
GO

ALTER TABLE [dbo27].[member_relations] ADD CONSTRAINT [FK_member_relations_members_member_id] FOREIGN KEY ([member_id]) REFERENCES [dbo27].[members] ([id]);
GO

ALTER TABLE [dbo27].[member_relations] ADD CONSTRAINT [FK_member_relations_members_partner_id] FOREIGN KEY ([partner_id]) REFERENCES [dbo27].[members] ([id]);
GO

CREATE TABLE [dbo27].[saved_reports] (
      [type_id] int NOT NULL
    , [category_id] int NOT NULL
    , [time_id] int NOT NULL
    , [row_index] int NOT NULL
    , [id1] nvarchar(50) NULL
    , [id2] int NULL
    , [ref_number] int NULL
    , [account] nvarchar(50) NULL
    , [report] int NULL
    , [page_break] int NULL
    , [row_level] int NULL
    , [row_format] int NULL
    , [hide] int NULL
    , [zero] int NULL
    , [code1] nvarchar(50) NULL
    , [code2] nvarchar(50) NULL
    , [code] nvarchar(50) NULL
    , [description] nvarchar(255) NULL
    , [data00] float NULL
    , [data01] float NULL
    , [data02] float NULL
    , [data03] float NULL
    , [data04] float NULL
    , [data05] float NULL
    , [data06] float NULL
    , [data07] float NULL
    , [data08] float NULL
    , [data09] float NULL
    , [data10] float NULL
    , [data11] float NULL
    , [data12] float NULL
    , [transaction_start_time] datetime NULL
    , [created_by] nvarchar(128) NULL CONSTRAINT [DF_saved_reports_created_by] DEFAULT(user_name())
    , [created_on] datetime NULL CONSTRAINT [DF_saved_reports_created_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , [modified_by] nvarchar(128) NULL CONSTRAINT [DF_saved_reports_modified_by] DEFAULT(user_name())
    , [modified_on] datetime NULL CONSTRAINT [DF_saved_reports_modified_on] DEFAULT(CONVERT([datetime2](0),getdate()))
    , CONSTRAINT [PK_saved_reports] PRIMARY KEY ([type_id], [category_id], [time_id], [row_index])
);
GO

ALTER TABLE [dbo27].[saved_reports] ADD CONSTRAINT [FK_saved_reports_members_category_id] FOREIGN KEY ([category_id]) REFERENCES [dbo27].[members] ([id]);
GO

ALTER TABLE [dbo27].[saved_reports] ADD CONSTRAINT [FK_saved_reports_members_time_id] FOREIGN KEY ([time_id]) REFERENCES [dbo27].[members] ([id]);
GO

ALTER TABLE [dbo27].[saved_reports] ADD CONSTRAINT [FK_saved_reports_saved_report_types] FOREIGN KEY ([type_id]) REFERENCES [dbo27].[saved_report_types] ([id]) ON UPDATE CASCADE;
GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Returns the translated string
-- =============================================

CREATE FUNCTION [dbo27].[get_translated_string]
(
    @string nvarchar(128) = NULL
    , @data_language varchar(10) = NULL
)
RETURNS nvarchar(128)
AS
BEGIN

RETURN COALESCE((
    SELECT
        COALESCE(TRANSLATED_DESC, TRANSLATED_NAME)
    FROM
        xls.translations
    WHERE
        TABLE_SCHEMA = 'dbo27' AND TABLE_NAME = 'strings'
        AND COLUMN_NAME = @string AND LANGUAGE_NAME = COALESCE(@data_language, 'en')
    ), @string)

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Checks that the record is empty
-- =============================================

CREATE FUNCTION [dbo27].[is_request_row_empty]
(
    @category_id int = NULL
    , @time_id int = NULL
    , @entity_id int = NULL
    , @row_format int = NULL
    , @description nvarchar(255) = NULL
    , @account_id int = NULL
    , @subsidiary_account_id int = NULL
    , @region_id int = NULL
    , @product_id int = NULL
    , @vat_rate_id tinyint = NULL
    , @unit_id tinyint = NULL
    , @total_payments money = NULL, @total_charges money = NULL, @balance00 money = NULL
    , @payments01 money = NULL, @charges01 money = NULL, @balance01 money = NULL
    , @payments02 money = NULL, @charges02 money = NULL, @balance02 money = NULL
    , @payments03 money = NULL, @charges03 money = NULL, @balance03 money = NULL
    , @payments04 money = NULL, @charges04 money = NULL, @balance04 money = NULL
    , @payments05 money = NULL, @charges05 money = NULL, @balance05 money = NULL
    , @payments06 money = NULL, @charges06 money = NULL, @balance06 money = NULL
    , @payments07 money = NULL, @charges07 money = NULL, @balance07 money = NULL
    , @payments08 money = NULL, @charges08 money = NULL, @balance08 money = NULL
    , @payments09 money = NULL, @charges09 money = NULL, @balance09 money = NULL
    , @payments10 money = NULL, @charges10 money = NULL, @balance10 money = NULL
    , @payments11 money = NULL, @charges11 money = NULL, @balance11 money = NULL
    , @payments12 money = NULL, @charges12 money = NULL, @balance12 money = NULL
)
RETURNS bit
AS
BEGIN

RETURN CAST(CASE WHEN @row_format IS NOT NULL OR @description IS NOT NULL OR @account_id IS NOT NULL OR @subsidiary_account_id IS NOT NULL OR @region_id IS NOT NULL OR @product_id IS NOT NULL OR @vat_rate_id IS NOT NULL OR @unit_id IS NOT NULL OR @balance00 IS NOT NULL OR @payments01 IS NOT NULL OR @charges01 IS NOT NULL OR @payments02 IS NOT NULL OR @charges02 IS NOT NULL OR @payments03 IS NOT NULL OR @charges03 IS NOT NULL OR @payments04 IS NOT NULL OR @charges04 IS NOT NULL OR @payments05 IS NOT NULL OR @charges05 IS NOT NULL OR @payments06 IS NOT NULL OR @charges06 IS NOT NULL OR @payments07 IS NOT NULL OR @charges07 IS NOT NULL OR @payments08 IS NOT NULL OR @charges08 IS NOT NULL OR @payments09 IS NOT NULL OR @charges09 IS NOT NULL OR @payments10 IS NOT NULL OR @charges10 IS NOT NULL OR @payments11 IS NOT NULL OR @charges11 IS NOT NULL OR @payments12 IS NOT NULL OR @charges12 IS NOT NULL THEN 0 ELSE 1 END AS bit)

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: The view defines automatic handlers
-- =============================================

CREATE VIEW [xls27].[xl_automatic_handlers]
AS

SELECT
    t.TABLE_SCHEMA
    , t.TABLE_NAME
    , t.COLUMN_NAME
    , 'DoNotSave' AS EVENT_NAME
    , CAST(NULL AS nvarchar) AS HANDLER_SCHEMA
    , CAST(NULL AS nvarchar) AS HANDLER_NAME
    , 'ATTRIBUTE' AS HANDLER_TYPE
    , CAST(NULL AS nvarchar) AS HANDLER_CODE
    , CAST(NULL AS nvarchar) AS TARGET_WORKSHEET
    , CAST(NULL AS int) AS MENU_ORDER
    , CAST(NULL AS bit) AS EDIT_PARAMETERS
FROM
    INFORMATION_SCHEMA.COLUMNS t
WHERE
    t.COLUMN_NAME IN ('created_by', 'created_on', 'modified_by', 'modified_on')

UNION ALL
SELECT
    p.SPECIFIC_SCHEMA AS TABLE_SCHEMA
    , p.SPECIFIC_NAME AS TABLE_NAME
    , t.COLUMN_NAME
    , 'DefaultValue' AS EVENT_NAME
    , CAST(NULL AS nvarchar) AS HANDLER_SCHEMA
    , CAST(NULL AS nvarchar) AS HANDLER_NAME
    , 'ATTRIBUTE' AS HANDLER_TYPE
    , t.HANDLER_CODE
    , CAST(NULL AS nvarchar) AS TARGET_WORKSHEET
    , CAST(NULL AS int) AS MENU_ORDER
    , CAST(NULL AS bit) AS EDIT_PARAMETERS
FROM
    (
        SELECT
            TOP 1
            'company_id' AS COLUMN_NAME
            , CAST(company_id AS nvarchar) AS HANDLER_CODE
        FROM
            dbo27.users u
        WHERE
            u.is_default = 1
            AND u.username = USER_NAME()
        UNION ALL
        SELECT
            TOP 1
            'category_id' AS COLUMN_NAME
            , CAST(m.id AS nvarchar) AS HANDLER_CODE
        FROM
            dbo27.members m
            INNER JOIN (
                SELECT TOP 1 company_id FROM dbo27.users u WHERE u.is_default = 1 AND u.username = USER_NAME()
            ) c ON c.company_id = m.company_id
        WHERE
            m.dimension_id = 3
            AND m.is_active = 1
        ORDER BY
            m.sort_order
            , m.id
        UNION ALL
        SELECT
            TOP 1
            'time_id' AS COLUMN_NAME
            , CAST(m.id AS nvarchar) AS HANDLER_CODE
        FROM
            dbo27.members m
            INNER JOIN (
                SELECT TOP 1 company_id FROM dbo27.users u WHERE u.is_default = 1 AND u.username = USER_NAME()
            ) c ON c.company_id = m.company_id
        WHERE
            m.dimension_id = 2
            AND m.is_active = 1
        ORDER BY
            m.sort_order
            , m.id
        UNION ALL
        SELECT
            TOP 1
            'entity_id' AS COLUMN_NAME
            , CAST(m.id AS nvarchar) AS HANDLER_CODE
        FROM
            dbo27.members m
            INNER JOIN (
                SELECT TOP 1 company_id, u.username FROM dbo27.users u WHERE u.is_default = 1 AND u.username = USER_NAME()
            ) c ON c.company_id = m.company_id
            LEFT OUTER JOIN dbo27.member_permissions mp ON mp.member_id = m.id AND mp.username = c.username
        WHERE
            m.dimension_id = 4
            AND m.is_active = 1
        ORDER BY
            mp.update_permission DESC
            , mp.select_permission DESC
            , m.sort_order
            , m.id
        UNION ALL
        SELECT 'year' AS COLUMN_NAME, CAST(YEAR(GETDATE()) AS nvarchar) AS HANDLER_CODE
        UNION ALL
        SELECT 'start_year' AS COLUMN_NAME, CAST(YEAR(GETDATE()) AS nvarchar) AS HANDLER_CODE
        UNION ALL
        SELECT 'end_year' AS COLUMN_NAME, CAST(YEAR(GETDATE()) AS nvarchar) AS HANDLER_CODE
    ) t
    INNER JOIN (
        SELECT
            p.SPECIFIC_SCHEMA
            , p.SPECIFIC_NAME
            , SUBSTRING(p.PARAMETER_NAME, 2, 100) AS PARAMETER_NAME
        FROM
            INFORMATION_SCHEMA.PARAMETERS p
        WHERE
            p.SPECIFIC_SCHEMA = 'xls27'
            AND p.SPECIFIC_NAME LIKE 'usp_%'
            AND NOT RIGHT(p.SPECIFIC_NAME, 7) IN ('_insert', '_update', '_delete', '_change')
            AND (NOT p.PARAMETER_NAME = '@entity_id' OR p.SPECIFIC_NAME IN ('usp_budget_request1', 'usp_budget_request2'))
            AND NOT p.SPECIFIC_NAME IN ('usp_saved_report_types')
    ) p ON p.PARAMETER_NAME = t.COLUMN_NAME


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: The view selects Actions menu handlers for online help
-- =============================================

CREATE VIEW [xls27].[xl_online_help_handlers]
AS

SELECT
    t.TABLE_SCHEMA
    , t.TABLE_NAME
    , CAST(NULL AS nvarchar(128)) AS COLUMN_NAME
    , 'Actions' AS EVENT_NAME
    , t.TABLE_SCHEMA AS HANDLER_SCHEMA
    , CASE WHEN v.menu_order = 90 THEN 'MenuSeparator90' ELSE 'Online Database Help - ' + t.TABLE_SCHEMA + '.' + t.TABLE_NAME END AS HANDLER_NAME
    , CASE WHEN v.menu_order = 90 THEN 'MENUSEPARATOR' ELSE 'HTTP' END AS HANDLER_TYPE
    , CASE WHEN v.menu_order = 90 THEN NULL ELSE CASE
        WHEN t.TABLE_TYPE = 'BASE TABLE' THEN REPLACE(t.URL, '.htm', '-tables.htm')
        WHEN t.TABLE_TYPE = 'VIEW' THEN REPLACE(t.URL, '.htm', '-views.htm')
        WHEN t.TABLE_TYPE = 'PROCEDURE' THEN REPLACE(t.URL, '.htm', '-procedures.htm')
        WHEN t.TABLE_TYPE = 'FUNCTION' THEN REPLACE(t.URL, '.htm', '-functions.htm')
        ELSE t.URL
        END + '#' + REPLACE(t.TABLE_SCHEMA, ' ', '') + '.' + REPLACE(t.TABLE_NAME, ' ', '') END HANDLER_CODE
    , CAST(NULL AS nvarchar) AS TARGET_WORKSHEET
    , v.menu_order AS MENU_ORDER
    , CAST(NULL AS bit) AS EDIT_PARAMETERS
FROM
    (
        SELECT
            t.TABLE_SCHEMA
            , t.TABLE_NAME
            , t.TABLE_TYPE
            , 'https://www.savetodb.com/help/budgeting-application.htm' AS URL
        FROM
            INFORMATION_SCHEMA.TABLES t
        WHERE
            t.TABLE_SCHEMA IN ('dbo27', 'xls27')
        UNION ALL
        SELECT
            t.ROUTINE_SCHEMA AS TABLE_SCHEMA
            , t.ROUTINE_NAME AS TABLE_NAME
            , t.ROUTINE_TYPE AS TABLE_TYPE
            , 'https://www.savetodb.com/help/budgeting-application.htm' AS URL
        FROM
            INFORMATION_SCHEMA.ROUTINES t
        WHERE
            t.ROUTINE_SCHEMA IN ('dbo27', 'xls27')
            AND t.ROUTINE_TYPE IN ('PROCEDURE')
            AND NOT t.ROUTINE_NAME LIKE 'xl_%'
            AND NOT t.ROUTINE_NAME LIKE 'usp_import_%'
            AND NOT t.ROUTINE_NAME LIKE 'usp_export_%'
            AND NOT t.ROUTINE_NAME LIKE '%_change'
            AND NOT t.ROUTINE_NAME LIKE '%_insert'
            AND NOT t.ROUTINE_NAME LIKE '%_update'
            AND NOT t.ROUTINE_NAME LIKE '%_delete'
    ) t
    CROSS JOIN (VALUES (90), (91)) v(menu_order)
WHERE
    t.URL IS NOT NULL


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: The view selects admin objects for the ribbon query list
-- =============================================

CREATE VIEW [xls27].[xl_query_list_admin]
AS

SELECT
    r.SPECIFIC_SCHEMA AS TABLE_SCHEMA
    , r.SPECIFIC_NAME AS TABLE_NAME
    , 'PROCEDURE' AS TABLE_TYPE
    , CAST(NULL AS nvarchar(max)) AS TABLE_CODE
    , CAST(NULL AS nvarchar(max)) AS INSERT_PROCEDURE
    , CAST(NULL AS nvarchar(max)) AS UPDATE_PROCEDURE
    , CAST(NULL AS nvarchar(max)) AS DELETE_PROCEDURE
    , CAST(NULL AS nvarchar(50)) AS PROCEDURE_TYPE
FROM
    INFORMATION_SCHEMA.ROUTINES r
WHERE
    r.SPECIFIC_NAME IN (
        'usp_companies'
        , 'usp_users'
        , 'usp_member_permissions'
        , 'usp_actual_closed_periods'
        , 'usp_budget_closed_periods'
        --, 'usp_database_permissions'
        --, 'usp_object_permissions'
        --, 'usp_principal_permissions'
        , 'usp_role_members'
        )


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: The view selects setup objects for the ribbon query list
-- =============================================

CREATE VIEW [xls27].[xl_query_list_setup]
AS

SELECT
    r.SPECIFIC_SCHEMA AS TABLE_SCHEMA
    , r.SPECIFIC_NAME AS TABLE_NAME
    , 'PROCEDURE' AS TABLE_TYPE
    , CAST(NULL AS nvarchar(max)) AS TABLE_CODE
    , CAST(NULL AS nvarchar(max)) AS INSERT_PROCEDURE
    , CAST(NULL AS nvarchar(max)) AS UPDATE_PROCEDURE
    , CAST(NULL AS nvarchar(max)) AS DELETE_PROCEDURE
    , CAST(NULL AS nvarchar(50)) AS PROCEDURE_TYPE
FROM
    INFORMATION_SCHEMA.ROUTINES r
WHERE
    r.SPECIFIC_SCHEMA = 'xls27'
    AND r.SPECIFIC_NAME IN (
        'usp_actual_balances'
        , 'usp_actual_closed_periods'
        , 'usp_actual_currency_rates'
        , 'usp_budget_balances'
        , 'usp_budget_closed_periods'
        , 'usp_budget_currency_rates'
        , 'usp_budgeting_accounts'
        , 'usp_ledger_accounts'
        , 'usp_member_relations'
        , 'usp_members'
        , 'usp_report_sections'
        , 'usp_saved_report_types'
        , 'usp_subsidiary_accounts'
        , 'usp_subsidiary_groups'
        , 'usp_translation_elements'
        , 'usp_translations'
        , 'usp_units'
        , 'usp_vat_rates'
        )


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Selects SQL commands to insert actual balances
-- =============================================

CREATE PROCEDURE [dbo27].[usp_export_actual_balances]
    @company nvarchar(50) = NULL
AS
BEGIN

SET NOCOUNT ON;

WITH cte(part, r, command) AS (
    SELECT
        1 AS part
        , ROW_NUMBER() OVER (ORDER BY c.code, a.code) AS r
        , 'EXEC dbo27.usp_import_actual_balances ' +
               + COALESCE('N''' + REPLACE(c.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(a.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(m.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE(CAST(t.balance AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(t.balance$ AS nvarchar), 'NULL')
        + ';' AS command
    FROM
        dbo27.actual_balances t
        INNER JOIN dbo27.ledger_accounts a ON a.id = t.account_id
        LEFT OUTER JOIN dbo27.members m ON m.id = t.subsidiary_account_id
        INNER JOIN dbo27.users u ON u.company_id = a.company_id AND u.username = USER_NAME() AND u.is_active = 1 AND u.is_admin = 1
        INNER JOIN dbo27.companies c ON c.id = a.company_id AND c.code = COALESCE(@company, c.code)
)
SELECT
    command
FROM
    cte
ORDER BY
    part
    , r

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Selects SQL commands to insert actual closed periods
-- =============================================

CREATE PROCEDURE [dbo27].[usp_export_actual_closed_periods]
    @company nvarchar(50) = NULL
AS
BEGIN

SET NOCOUNT ON;

WITH cte(part, r, command) AS (
    SELECT
        1 AS part
        , ROW_NUMBER() OVER (ORDER BY c.code, r.date) AS r
        , 'EXEC dbo27.usp_import_actual_closed_periods '
               + COALESCE('N''' + REPLACE(c.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + CONVERT(nvarchar, r.date, 120) + '''', 'NULL')
        + ', ' + COALESCE(CAST(CAST(r.is_closed AS tinyint) AS nvarchar), 'NULL')
        + ';' AS command
    FROM
        dbo27.actual_closed_periods r
        INNER JOIN dbo27.users u ON u.company_id = r.company_id AND u.username = USER_NAME() AND u.is_active = 1 AND u.is_admin = 1
        INNER JOIN dbo27.companies c ON c.id = r.company_id AND c.code = COALESCE(@company, c.code)
)
SELECT
    command
FROM
    cte
ORDER BY
    part
    , r

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Selects SQL commands to insert actual currency rates
-- =============================================

CREATE PROCEDURE [dbo27].[usp_export_actual_currency_rates]
    @company nvarchar(50) = NULL
AS
BEGIN

SET NOCOUNT ON;

WITH cte(part, r, command) AS (
    SELECT
        1 AS part
        , ROW_NUMBER() OVER (ORDER BY c.code, t.code, r.date) AS r
        , 'EXEC dbo27.usp_import_actual_currency_rates '
               + COALESCE('N''' + REPLACE(c.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(t.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + CONVERT(nvarchar, r.date, 120) + '''', 'NULL')
        + ', ' + COALESCE(CASE WHEN CAST(CAST(r.rate AS nvarchar) AS float) = r.rate THEN CAST(r.rate AS nvarchar) ELSE STR(r.rate, 20, 10) END, 'NULL')
        + ', ' + COALESCE(CAST(CAST(r.is_checked AS tinyint) AS nvarchar), 'NULL')
        + ';' AS command
    FROM
        dbo27.actual_currency_rates r
        INNER JOIN dbo27.units t ON t.id = r.currency_id
        INNER JOIN dbo27.users u ON u.company_id = t.company_id AND u.username = USER_NAME() AND u.is_active = 1 AND u.is_admin = 1
        INNER JOIN dbo27.companies c ON c.id = t.company_id AND c.code = COALESCE(@company, c.code)
)
SELECT
    command
FROM
    cte
ORDER BY
    part
    , r

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Selects SQL commands to insert budget balances
-- =============================================

CREATE PROCEDURE [dbo27].[usp_export_budget_balances]
    @company nvarchar(50) = NULL
AS
BEGIN

SET NOCOUNT ON;

WITH cte(part, r, command) AS (
    SELECT
        1 AS part
        , ROW_NUMBER() OVER (ORDER BY c.code, m1.code, m2.code, a.code) AS r
        , 'EXEC dbo27.usp_import_budget_balances ' +
               + COALESCE('N''' + REPLACE(c.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(m1.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(m2.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(a.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE(CAST(t.debit AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(t.credit AS nvarchar), 'NULL')
        + ';' AS command
    FROM
        dbo27.budget_balances t
        INNER JOIN dbo27.members m1 ON m1.id = t.category_id
        INNER JOIN dbo27.members m2 ON m2.id = t.time_id
        INNER JOIN dbo27.ledger_accounts a ON a.id = t.account_id
        INNER JOIN dbo27.users u ON u.company_id = m1.company_id AND u.username = USER_NAME() AND u.is_active = 1 AND u.is_admin = 1
        INNER JOIN dbo27.companies c ON c.id = m1.company_id AND c.code = COALESCE(@company, c.code)
)
SELECT
    command
FROM
    cte
ORDER BY
    part
    , r

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Selects SQL commands to insert budget currency rates
-- =============================================

CREATE PROCEDURE [dbo27].[usp_export_budget_currency_rates]
    @company nvarchar(50) = NULL
AS
BEGIN

SET NOCOUNT ON;

WITH cte(part, r, command) AS (
    SELECT
        1 AS part
        , ROW_NUMBER() OVER (ORDER BY c.code, m1.code, m2.code, t.code) AS r
        , 'EXEC dbo27.usp_import_budget_currency_rates '
               + COALESCE('N''' + REPLACE(c.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(m1.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(m2.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(t.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE(CAST(balance00 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(period01 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(balance01 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(period02 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(balance02 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(period03 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(balance03 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(period04 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(balance04 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(period05 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(balance05 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(period06 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(balance06 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(period07 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(balance07 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(period08 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(balance08 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(period09 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(balance09 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(period10 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(balance10 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(period11 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(balance11 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(period12 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(balance12 AS nvarchar), 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(r.row_formulas, '''', '''''') + '''', 'NULL')
        + ';' AS command
    FROM
        dbo27.budget_currency_rates r
        INNER JOIN dbo27.members m1 ON m1.id = r.category_id
        INNER JOIN dbo27.members m2 ON m2.id = r.time_id
        INNER JOIN dbo27.units t ON t.id = r.unit_id
        INNER JOIN dbo27.users u ON u.company_id = m1.company_id AND u.username = USER_NAME() AND u.is_active = 1 AND u.is_admin = 1
        INNER JOIN dbo27.companies c ON c.id = m1.company_id AND c.code = COALESCE(@company, c.code)
)
SELECT
    command
FROM
    cte
ORDER BY
    part
    , r

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Selects SQL commands to insert budget requests
-- =============================================

CREATE PROCEDURE [dbo27].[usp_export_budget_requests]
    @company nvarchar(50) = NULL
AS
BEGIN

SET NOCOUNT ON;

WITH cte(part, r, command) AS (
    SELECT
        1 AS part
        , ROW_NUMBER() OVER (ORDER BY c.code, m2.code, m3.code, m1.code, d.row_index) AS r
        , 'EXEC dbo27.usp_import_budget_requests ' +
               + COALESCE('N''' + REPLACE(c.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(m1.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(m2.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(m3.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE(CAST(d.row_index AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(d.row_format AS nvarchar), 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(d.description, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(m4.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(m5.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(m6.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(m7.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(t.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(n.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE(CAST(d.total_payments AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(d.total_charges AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(d.balance00 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(d.payments01 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(d.charges01 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(d.balance01 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(d.payments02 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(d.charges02 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(d.balance02 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(d.payments03 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(d.charges03 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(d.balance03 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(d.payments04 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(d.charges04 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(d.balance04 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(d.payments05 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(d.charges05 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(d.balance05 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(d.payments06 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(d.charges06 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(d.balance06 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(d.payments07 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(d.charges07 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(d.balance07 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(d.payments08 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(d.charges08 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(d.balance08 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(d.payments09 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(d.charges09 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(d.balance09 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(d.payments10 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(d.charges10 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(d.balance10 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(d.payments11 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(d.charges11 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(d.balance11 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(d.payments12 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(d.charges12 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(d.balance12 AS nvarchar), 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(row_formulas, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('''' + CONVERT(nvarchar, [transaction_start_time], 120) + '''', 'NULL')
        + ';' AS command
    FROM
        dbo27.budget_requests d
        INNER JOIN dbo27.members m1 ON m1.id = d.[entity_id]
        INNER JOIN dbo27.members m2 ON m2.id = d.category_id
        INNER JOIN dbo27.members m3 ON m3.id = d.time_id
        LEFT OUTER JOIN dbo27.members m4 ON m4.id = d.account_id
        LEFT OUTER JOIN dbo27.members m5 ON m5.id = d.subsidiary_account_id
        LEFT OUTER JOIN dbo27.members m6 ON m6.id = d.region_id
        LEFT OUTER JOIN dbo27.members m7 ON m7.id = d.product_id
        LEFT OUTER JOIN dbo27.vat_rates t ON t.id = d.vat_rate_id
        LEFT OUTER JOIN dbo27.units n ON n.id = d.unit_id
        INNER JOIN dbo27.users u ON u.company_id = m1.company_id AND u.username = USER_NAME() AND u.is_active = 1 AND u.is_admin = 1
        INNER JOIN dbo27.companies c ON c.id = m1.company_id
    WHERE
        c.code = COALESCE(@company, c.code)
)
SELECT
    command
FROM
    cte
ORDER BY
    part
    , r

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Selects SQL commands to insert companies
-- =============================================

CREATE PROCEDURE [dbo27].[usp_export_companies]
    @company nvarchar(50) = NULL
AS
BEGIN

SET NOCOUNT ON;

WITH cte(part, r, command) AS (
    SELECT
        1 AS part
        , ROW_NUMBER() OVER (ORDER BY c.code) AS r
        , 'EXEC dbo27.usp_import_companies ' +
               + COALESCE('N''' + REPLACE(c.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(c.name, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(c.default_language, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE(CAST(c.sort_order AS nvarchar), 'NULL')
        + ';' AS command
    FROM
        dbo27.companies c
        INNER JOIN dbo27.users u ON u.company_id = c.id AND u.username = USER_NAME() AND u.is_active = 1 AND u.is_admin = 1
    WHERE
        c.code = COALESCE(@company, c.code)
)
SELECT
    command
FROM
    cte
ORDER BY
    part
    , r

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Selects SQL commands to insert journal records
-- =============================================

CREATE PROCEDURE [dbo27].[usp_export_journals]
    @company nvarchar(50) = NULL
AS
BEGIN

SET NOCOUNT ON;

WITH cte(part, r, command) AS (
    SELECT
        1 AS part
        , ROW_NUMBER() OVER (ORDER BY c.code, t.date, t.id) AS r
        , 'EXEC dbo27.usp_import_journals ' +
               + COALESCE('N''' + REPLACE(c.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + CONVERT(nvarchar, t.date, 120) + '''', 'NULL')
        + ', ' + COALESCE(CAST(t.amount AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(t.amount$ AS nvarchar), 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(t.description, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(da.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(ca.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(ds.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(cs.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(m1.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(m2.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(m3.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(m4.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE(CAST(t.ref_record_id AS nvarchar), 'NULL')
        + ';' AS command
    FROM
        dbo27.journals t
        LEFT OUTER JOIN dbo27.ledger_accounts da ON da.id = t.debit_account_id
        LEFT OUTER JOIN dbo27.ledger_accounts ca ON ca.id = t.credit_account_id
        LEFT OUTER JOIN dbo27.members ds ON ds.id = t.debit_subsidiary_account_id
        LEFT OUTER JOIN dbo27.members cs ON cs.id = t.credit_subsidiary_account_id
        LEFT OUTER JOIN dbo27.members m1 ON m1.id = t.entity_id
        LEFT OUTER JOIN dbo27.members m2 ON m2.id = t.account_id
        LEFT OUTER JOIN dbo27.members m3 ON m3.id = t.region_id
        LEFT OUTER JOIN dbo27.members m4 ON m4.id = t.product_id
        INNER JOIN dbo27.users u ON u.company_id = t.company_id AND u.username = USER_NAME() AND u.is_active = 1 AND u.is_admin = 1
        INNER JOIN dbo27.companies c ON c.id = t.company_id AND c.code = COALESCE(@company, c.code)
    WHERE
        t.auto_type_id = 0
)
SELECT
    command
FROM
    cte
ORDER BY
    part
    , r

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Selects SQL commands to update ledger account properties
-- =============================================

CREATE PROCEDURE [dbo27].[usp_export_ledger_account_properties]
    @company nvarchar(50) = NULL
AS
BEGIN

SET NOCOUNT ON;

WITH cte(part, r, command) AS (
    SELECT
        1 AS part
        , ROW_NUMBER() OVER (ORDER BY c.code, m.code) AS r
        , 'EXEC dbo27.usp_import_ledger_account_properties '
               + COALESCE('N''' + REPLACE(c.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(m.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(p.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(t.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(g.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(c1.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(c2.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(c3.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE(CAST(m.ref_number AS nvarchar), 'NULL')
        + ';' AS command
    FROM
        dbo27.ledger_accounts m
        LEFT OUTER JOIN dbo27.ledger_account_types t ON t.id = m.account_type_id
        LEFT OUTER JOIN dbo27.ledger_accounts p ON p.id = m.parent_id
        LEFT OUTER JOIN dbo27.subsidiary_groups g ON g.id = m.subsidiary_group_id
        LEFT OUTER JOIN dbo27.ledger_accounts c1 ON c1.id = m.closing_child_account_id
        LEFT OUTER JOIN dbo27.ledger_accounts c2 ON c2.id = m.closing_debit_account_id
        LEFT OUTER JOIN dbo27.ledger_accounts c3 ON c3.id = m.closing_credit_account_id
        INNER JOIN dbo27.users u ON u.company_id = m.company_id AND u.username = USER_NAME() AND u.is_active = 1 AND u.is_admin = 1
        INNER JOIN dbo27.companies c ON c.id = m.company_id
    WHERE
        c.code = COALESCE(@company, c.code)
        AND (
            m.parent_id IS NOT NULL
            OR m.account_type_id IS NOT NULL
            OR m.subsidiary_group_id IS NOT NULL
            OR m.closing_child_account_id IS NOT NULL
            OR m.closing_debit_account_id IS NOT NULL
            OR m.closing_credit_account_id IS NOT NULL
            OR m.ref_number IS NOT NULL
        )
)
SELECT
    command
FROM
    cte
ORDER BY
    part
    , r

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Selects SQL commands to insert accounts
-- =============================================

CREATE PROCEDURE [dbo27].[usp_export_ledger_accounts]
    @company nvarchar(50) = NULL
AS
BEGIN

SET NOCOUNT ON;

WITH cte(part, r, command) AS (
    SELECT
        1 AS part
        , ROW_NUMBER() OVER (ORDER BY c.code, m.code) AS r
        , 'EXEC dbo27.usp_import_ledger_accounts ' +
               + COALESCE('N''' + REPLACE(c.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(m.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(m.name, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE(CAST(CAST(m.is_active AS tinyint) AS nvarchar), 'NULL')
        + ';' AS command
    FROM
        dbo27.ledger_accounts m
        INNER JOIN dbo27.users u ON u.company_id = m.company_id AND u.username = USER_NAME() AND u.is_active = 1 AND u.is_admin = 1
        INNER JOIN dbo27.companies c ON c.id = m.company_id
    WHERE
        c.code = COALESCE(@company, c.code)
)
SELECT
    command
FROM
    cte
ORDER BY
    part
    , r

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Selects SQL commands to insert member groups
-- =============================================

CREATE PROCEDURE [dbo27].[usp_export_member_groups]
    @company nvarchar(50) = NULL
AS
BEGIN

SET NOCOUNT ON;

WITH cte(part, r, command) AS (
    SELECT
        4 AS part
        , ROW_NUMBER() OVER (ORDER BY c.code, m.dimension_id, m.sort_order, m.code, p.code) AS r
        , 'EXEC dbo27.usp_import_member_groups '
               + COALESCE('N''' + REPLACE(c.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(m.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(p.code, '''', '''''') + '''', 'NULL')
        + ';' AS command
    FROM
        dbo27.member_groups mp
        INNER JOIN dbo27.members m ON m.id = mp.member_id
        INNER JOIN dbo27.subsidiary_groups p ON p.id = mp.group_id
        INNER JOIN dbo27.users u ON u.company_id = m.company_id AND u.username = USER_NAME() AND u.is_active = 1 AND u.is_admin = 1
        INNER JOIN dbo27.companies c ON c.id = m.company_id
    WHERE
        c.code = COALESCE(@company, c.code)
)
SELECT
    command
FROM
    cte
ORDER BY
    part
    , r

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Selects SQL commands to insert member permissions
-- =============================================

CREATE PROCEDURE [dbo27].[usp_export_member_permissions]
    @company nvarchar(50) = NULL
AS
BEGIN

SET NOCOUNT ON;

WITH cte(part, r, command) AS (
    SELECT
        5 AS part
        , ROW_NUMBER() OVER (ORDER BY c.code, mp.username, m.dimension_id, m.sort_order, m.code) AS r
        , 'EXEC dbo27.usp_import_member_permissions '
               + COALESCE('N''' + REPLACE(c.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(m.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(mp.username, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE(CAST(mp.select_permission AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(mp.update_permission AS nvarchar), 'NULL')
        + ';' AS command
    FROM
        dbo27.member_permissions mp
        INNER JOIN dbo27.members m ON m.id = mp.member_id
        INNER JOIN dbo27.users u ON u.company_id = m.company_id AND u.username = USER_NAME() AND u.is_active = 1 AND u.is_admin = 1
        INNER JOIN dbo27.companies c ON c.id = m.company_id
    WHERE
        c.code = COALESCE(@company, c.code)
        AND mp.is_inherited = 0
)
SELECT
    command
FROM
    cte
ORDER BY
    part
    , r

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Selects SQL commands to update member properties
-- =============================================

CREATE PROCEDURE [dbo27].[usp_export_member_properties]
    @company nvarchar(50) = NULL
AS
BEGIN

SET NOCOUNT ON;

WITH cte(part, r, command) AS (
    SELECT
        1 AS part
        , ROW_NUMBER() OVER (ORDER BY c.code, m.dimension_id, m.sort_order, m.code) AS r
        , 'EXEC dbo27.usp_import_member_properties '
               + COALESCE('N''' + REPLACE(c.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(m.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(p.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(n.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(r.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(t.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(d1.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(c1.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(d2.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(c2.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(d3.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(c3.code, '''', '''''') + '''', 'NULL')
        + ';' AS command
    FROM
        dbo27.members m
        LEFT OUTER JOIN dbo27.members p ON p.id = m.parent_id
        LEFT OUTER JOIN dbo27.units n ON n.id = m.unit_id
        LEFT OUTER JOIN dbo27.vat_rates r ON r.id = m.vat_rate_id
        LEFT OUTER JOIN dbo27.member_types t ON t.id = m.account_type_id
        LEFT OUTER JOIN dbo27.ledger_accounts d1 ON d1.id = m.payment_debit_id
        LEFT OUTER JOIN dbo27.ledger_accounts c1 ON c1.id = m.payment_credit_id
        LEFT OUTER JOIN dbo27.ledger_accounts d2 ON d2.id = m.charge_debit_id
        LEFT OUTER JOIN dbo27.ledger_accounts c2 ON c2.id = m.charge_credit_id
        LEFT OUTER JOIN dbo27.ledger_accounts d3 ON d3.id = m.vat_debit_id
        LEFT OUTER JOIN dbo27.ledger_accounts c3 ON c3.id = m.vat_credit_id
        INNER JOIN dbo27.users u ON u.company_id = m.company_id AND u.username = USER_NAME() AND u.is_active = 1 AND u.is_admin = 1
        INNER JOIN dbo27.companies c ON c.id = m.company_id
    WHERE
        c.code = COALESCE(@company, c.code)
        AND (
            m.payment_debit_id IS NOT NULL
            OR m.payment_credit_id IS NOT NULL
            OR m.charge_debit_id IS NOT NULL
            OR m.charge_credit_id IS NOT NULL
            OR m.vat_debit_id IS NOT NULL
            OR m.vat_credit_id IS NOT NULL
            OR t.id IS NOT NULL
            OR n.id IS NOT NULL
        )
)
SELECT
    command
FROM
    cte
ORDER BY
    part
    , r

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Selects SQL commands to insert member relations
-- =============================================

CREATE PROCEDURE [dbo27].[usp_export_member_relations]
    @company nvarchar(50) = NULL
AS
BEGIN

SET NOCOUNT ON;

WITH cte(part, r, command) AS (
    SELECT
        4 AS part
        , ROW_NUMBER() OVER (ORDER BY c.code, m.dimension_id, p.sort_order, p.code, m.sort_order, m.code) AS r
        , 'EXEC dbo27.usp_import_member_relations '
               + COALESCE('N''' + REPLACE(c.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(m.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(p.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE(CAST(mp.select_permission AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(mp.update_permission AS nvarchar), 'NULL')
        + ';' AS command
    FROM
        dbo27.member_relations mp
        INNER JOIN dbo27.members m ON m.id = mp.member_id
        INNER JOIN dbo27.members p ON p.id = mp.partner_id
        INNER JOIN dbo27.users u ON u.company_id = m.company_id AND u.username = USER_NAME() AND u.is_active = 1 AND u.is_admin = 1
        INNER JOIN dbo27.companies c ON c.id = m.company_id
    WHERE
        c.code = COALESCE(@company, c.code)
)
SELECT
    command
FROM
    cte
ORDER BY
    part
    , r

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Selects SQL commands to insert members
-- =============================================

CREATE PROCEDURE [dbo27].[usp_export_members]
    @company nvarchar(50) = NULL
AS
BEGIN

SET NOCOUNT ON;

WITH cte(part, r, command) AS (
    SELECT
        1 AS part
        , ROW_NUMBER() OVER (ORDER BY c.code, m.dimension_id, m.sort_order, m.code) AS r
        , 'EXEC dbo27.usp_import_members ' +
               + COALESCE('N''' + REPLACE(c.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE(CAST(m.dimension_id AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(m.sort_order AS nvarchar), 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(m.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(m.name, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE(CAST(CAST(m.is_translatable AS tinyint) AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(CAST(m.is_active AS tinyint) AS nvarchar), 'NULL')
        + ';' AS command
    FROM
        dbo27.members m
        INNER JOIN dbo27.users u ON u.company_id = m.company_id AND u.username = USER_NAME() AND u.is_active = 1 AND u.is_admin = 1
        INNER JOIN dbo27.companies c ON c.id = m.company_id
    WHERE
        c.code = COALESCE(@company, c.code)
)
SELECT
    command
FROM
    cte
ORDER BY
    part
    , r

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Selects SQL commands to insert report_sections
-- =============================================

CREATE PROCEDURE [dbo27].[usp_export_report_section_properties]
    @company nvarchar(50) = NULL
AS
BEGIN

SET NOCOUNT ON;

WITH cte(part, r, command) AS (
    SELECT
        2 AS part
        , ROW_NUMBER() OVER (ORDER BY c.code, m.report_type_id, m.section) AS r
        , 'EXEC dbo27.usp_import_report_section_properties '
               + COALESCE('N''' + REPLACE(c.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE(CAST(m.report_type_id AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(m.section AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(p1.section AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(p2.section AS nvarchar), 'NULL')
        + ';' AS command
    FROM
        dbo27.report_sections m
        LEFT OUTER JOIN dbo27.report_sections p1 ON p1.id = m.parent_id
        LEFT OUTER JOIN dbo27.report_sections p2 ON p2.id = m.parent2_id
        INNER JOIN dbo27.users u ON u.company_id = m.company_id AND u.username = USER_NAME() AND u.is_active = 1 AND u.is_admin = 1
        INNER JOIN dbo27.companies c ON c.id = m.company_id
    WHERE
        c.code = COALESCE(@company, c.code)
        AND (
            m.parent_id IS NOT NULL
            OR m.parent2_id IS NOT NULL
        )
)
SELECT
    command
FROM
    cte
ORDER BY
    part
    , r

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Selects SQL commands to insert translations of report_sections
-- =============================================

CREATE PROCEDURE [dbo27].[usp_export_report_section_translations]
    @company nvarchar(50) = NULL
    , @language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

;WITH cte(part, r, command) AS (
    SELECT
        1 AS part
        , ROW_NUMBER() OVER(ORDER BY c.code, t.language, m.report_type_id, m.section) AS r
        , 'EXEC dbo27.usp_import_report_section_translations '
        + 'N''' + REPLACE(c.code, '''', '''''') + ''''
        + ', ' + COALESCE(CAST(m.report_type_id AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(m.section AS nvarchar), 'NULL')
        + ', N''' + REPLACE(t.language, '''', '''''') + ''''
        + ', N''' + REPLACE(t.name, '''', '''''') + ''''
        + ';' AS command
    FROM
        dbo27.report_sections m
        INNER JOIN dbo27.translations t ON t.company_id = m.company_id AND t.table_id = 9 AND t.member_id = m.id
        INNER JOIN dbo27.translated_tables tt ON tt.id = t.table_id
        INNER JOIN dbo27.users u ON u.company_id = t.company_id AND u.username = USER_NAME()
        INNER JOIN dbo27.companies c ON c.id = t.company_id
    WHERE
        c.code = COALESCE(@company, c.code)
        AND t.language = COALESCE(@language, t.language)
        AND t.name IS NOT NULL
)
SELECT
    command
FROM
    cte
ORDER BY
    part
    , r

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Selects SQL commands to insert report_sections
-- =============================================

CREATE PROCEDURE [dbo27].[usp_export_report_sections]
    @company nvarchar(50) = NULL
AS
BEGIN

SET NOCOUNT ON;

WITH cte(part, r, command) AS (
    SELECT
        1 AS part
        , ROW_NUMBER() OVER (ORDER BY c.code, m.report_type_id, m.section) AS r
        , 'EXEC dbo27.usp_import_report_sections ' +
               + COALESCE('N''' + REPLACE(c.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE(CAST(m.report_type_id AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(m.section AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(m.row_format AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(m.ref_number AS nvarchar), 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(m.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(m.description, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE(CAST(m.section_type_id AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(CAST(m.inverse_sign AS tinyint) AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(CAST(m.hide_items AS tinyint) AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(CAST(m.show_line AS tinyint) AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(CAST(m.show_line_before AS tinyint) AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(CAST(m.show_line_after AS tinyint) AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(CAST(m.page_break_before AS tinyint) AS nvarchar), 'NULL')
        + ';' AS command
    FROM
        dbo27.report_sections m
        INNER JOIN dbo27.users u ON u.company_id = m.company_id AND u.username = USER_NAME() AND u.is_active = 1 AND u.is_admin = 1
        INNER JOIN dbo27.companies c ON c.id = m.company_id
    WHERE
        c.code = COALESCE(@company, c.code)
)
SELECT
    command
FROM
    cte
ORDER BY
    part
    , r

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Selects SQL commands to insert saved_report_types
-- =============================================

CREATE PROCEDURE [dbo27].[usp_export_saved_report_types]
    @company nvarchar(50) = NULL
AS
BEGIN

SET NOCOUNT ON;

WITH cte(part, r, command) AS (
    SELECT
        1 AS part
        , ROW_NUMBER() OVER (ORDER BY c.code, t.code) AS r
        , 'EXEC dbo27.usp_import_saved_report_types ' +
               + COALESCE('N''' + REPLACE(c.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(t.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(t.name, '''', '''''') + '''', 'NULL')
        + ';' AS command
    FROM
        dbo27.saved_report_types t
        INNER JOIN dbo27.users u ON u.company_id = t.company_id AND u.username = USER_NAME()
        INNER JOIN dbo27.companies c ON c.id = t.company_id
    WHERE
        c.code = COALESCE(@company, c.code)
)
SELECT
    command
FROM
    cte
ORDER BY
    part
    , r

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Selects SQL commands to insert budget reports
-- =============================================

CREATE PROCEDURE [dbo27].[usp_export_saved_reports]
    @company nvarchar(50) = NULL
AS
BEGIN

SET NOCOUNT ON;

WITH cte(part, r, command) AS (
    SELECT
        1 AS part
        , ROW_NUMBER() OVER (ORDER BY c.code, m1.code, m2.code, d.row_index) AS r
        , 'EXEC dbo27.usp_import_saved_reports '
        +        COALESCE('N''' + REPLACE(c.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(t.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(m1.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(m2.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE(CAST(d.row_index AS nvarchar), 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(d.id1, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE(CAST(d.id2 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(d.ref_number AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(d.report AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(d.row_level AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(d.row_format AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(d.hide AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(d.zero AS nvarchar), 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(d.code1, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(d.code2, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(d.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(d.description, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE(CAST(data00 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(data01 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(data02 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(data03 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(data04 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(data05 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(data06 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(data07 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(data08 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(data09 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(data10 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(data11 AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(data12 AS nvarchar), 'NULL')
        + ', ' + COALESCE('''' + CONVERT(nvarchar, [transaction_start_time], 120) + '''', 'NULL')
        + ';' AS command
    FROM
        dbo27.saved_reports d
        INNER JOIN dbo27.saved_report_types t ON t.id = d.type_id
        INNER JOIN dbo27.members m1 ON m1.id = d.category_id
        INNER JOIN dbo27.members m2 ON m2.id = d.time_id
        INNER JOIN dbo27.users u ON u.company_id = m1.company_id AND u.username = USER_NAME() AND u.is_active = 1 AND u.is_admin = 1
        INNER JOIN dbo27.companies c ON c.id = m1.company_id
    WHERE
        c.code = COALESCE(@company, c.code)
)
SELECT
    command
FROM
    cte
ORDER BY
    part
    , r

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Selects SQL commands to insert subsidiary_groups
-- =============================================

CREATE PROCEDURE [dbo27].[usp_export_subsidiary_groups]
    @company nvarchar(50) = NULL
AS
BEGIN

SET NOCOUNT ON;

WITH cte(part, r, command) AS (
    SELECT
        1 AS part
        , ROW_NUMBER() OVER (ORDER BY c.code, t.code) AS r
        , 'EXEC dbo27.usp_import_subsidiary_groups ' +
               + COALESCE('N''' + REPLACE(c.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(t.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(t.name, '''', '''''') + '''', 'NULL')
        + ';' AS command
    FROM
        dbo27.subsidiary_groups t
        INNER JOIN dbo27.users u ON u.company_id = t.company_id AND u.username = USER_NAME()
        INNER JOIN dbo27.companies c ON c.id = t.company_id
    WHERE
        c.code = COALESCE(@company, c.code)
)
SELECT
    command
FROM
    cte
ORDER BY
    part
    , r

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Selects SQL commands to insert translations
-- =============================================

CREATE PROCEDURE [dbo27].[usp_export_translations]
    @company nvarchar(50) = NULL
    , @language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

;WITH cte(part, r, command) AS (
    SELECT
        1 AS part
        , ROW_NUMBER() OVER(ORDER BY c.code, t.language, m.sort_order, m.code) AS r
        , 'EXEC dbo27.usp_import_translations '
        + 'N''' + REPLACE(c.code, '''', '''''') + ''''
        + ', N''' + REPLACE(tt.code, '''', '''''') + ''''
        + ', N''' + REPLACE(m.code, '''', '''''') + ''''
        + ', N''' + REPLACE(t.language, '''', '''''') + ''''
        + ', N''' + REPLACE(t.name, '''', '''''') + ''''
        + ';' AS command
    FROM
        (
            SELECT 2 AS sort_order, t.id AS company_id, 2 AS table_id, t.code, t.id AS member_id, t.name, 1 AS is_translatable FROM dbo27.companies t
            UNION ALL SELECT 3 AS sort_order, t.company_id, 3 AS table_id, t.code, t.id AS member_id, t.name, t.is_translatable FROM dbo27.units t
            UNION ALL SELECT 4 AS sort_order, t.company_id, 4 AS table_id, t.code, t.id AS member_id, t.name, t.is_translatable FROM dbo27.vat_rates t
            UNION ALL SELECT 7 AS sort_order, t.company_id, 10 AS table_id, t.code, t.id AS member_id, t.name, 1 AS is_translatable FROM dbo27.subsidiary_groups t
            UNION ALL SELECT 8 AS sort_order, t.company_id, 11 AS table_id, t.code, t.id AS member_id, t.name, 1 AS is_translatable FROM dbo27.ledger_accounts t
            UNION ALL SELECT 9 AS sort_order, t.company_id, 12 AS table_id, t.code, t.id AS member_id, t.name, 1 AS is_translatable FROM dbo27.saved_report_types t
            UNION ALL SELECT 10 AS sort_order, t.company_id, 1 AS table_id, t.code, t.id AS member_id, t.name, t.is_translatable FROM dbo27.members t
        ) m
        INNER JOIN dbo27.translations t ON t.company_id = m.company_id AND t.table_id = m.table_id AND t.member_id = m.member_id
        INNER JOIN dbo27.translated_tables tt ON tt.id = m.table_id
        INNER JOIN dbo27.users u ON u.company_id = t.company_id AND u.username = USER_NAME()
        INNER JOIN dbo27.companies c ON c.id = t.company_id
    WHERE
        c.code = COALESCE(@company, c.code)
        AND t.language = COALESCE(@language, t.language)
        AND t.name IS NOT NULL
)
SELECT
    command
FROM
    cte
ORDER BY
    part
    , r

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Selects SQL commands to insert units
-- =============================================

CREATE PROCEDURE [dbo27].[usp_export_units]
    @company nvarchar(50) = NULL
AS
BEGIN

SET NOCOUNT ON;

WITH cte(part, r, command) AS (
    SELECT
        1 AS part
        , ROW_NUMBER() OVER (ORDER BY c.code, t.code) AS r
        , 'EXEC dbo27.usp_import_units ' +
               + COALESCE('N''' + REPLACE(c.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(t.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(t.name, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE(CAST(t.sort_order AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(t.factor AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(CAST(t.is_currency AS tinyint) AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(CAST(t.is_functional_currency AS tinyint) AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(CAST(t.is_base_currency AS tinyint) AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(CAST(t.is_translatable AS tinyint) AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(CAST(t.is_active AS tinyint) AS nvarchar), 'NULL')
        + ';' AS command
    FROM
        dbo27.units t
        INNER JOIN dbo27.users u ON u.company_id = t.company_id AND u.username = USER_NAME()
        INNER JOIN dbo27.companies c ON c.id = t.company_id
    WHERE
        c.code = COALESCE(@company, c.code)
)
SELECT
    command
FROM
    cte
ORDER BY
    part
    , r

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Selects SQL commands to insert users
-- =============================================

CREATE PROCEDURE [dbo27].[usp_export_users]
    @company nvarchar(50) = NULL
AS
BEGIN

SET NOCOUNT ON;

WITH cte(part, r, command) AS (
    SELECT
        1 AS part
        , ROW_NUMBER() OVER (ORDER BY c.code, m.username) AS r
        , 'EXEC dbo27.usp_import_users ' +
               + COALESCE('N''' + REPLACE(c.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(m.username, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(m.name, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE(CAST(CAST(m.is_admin AS tinyint) AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(CAST(m.is_default AS tinyint) AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(CAST(m.is_active AS tinyint) AS nvarchar), 'NULL')
        + ';' AS command
    FROM
        dbo27.companies c
        INNER JOIN dbo27.users u ON u.company_id = c.id AND u.username = USER_NAME() AND u.is_active = 1 AND u.is_admin = 1
        INNER JOIN dbo27.users m ON m.company_id = c.id
    WHERE
        c.code = COALESCE(@company, c.code)
)
SELECT
    command
FROM
    cte
ORDER BY
    part
    , r

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Selects SQL commands to insert vat_rates
-- =============================================

CREATE PROCEDURE [dbo27].[usp_export_vat_rates]
    @company nvarchar(50) = NULL
AS
BEGIN

SET NOCOUNT ON;

WITH cte(part, r, command) AS (
    SELECT
        1 AS part
        , ROW_NUMBER() OVER (ORDER BY c.code, t.code) AS r
        , 'EXEC dbo27.usp_import_vat_rates ' +
               + COALESCE('N''' + REPLACE(c.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(t.code, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE('N''' + REPLACE(t.name, '''', '''''') + '''', 'NULL')
        + ', ' + COALESCE(CAST(t.sort_order AS nvarchar), 'NULL')
        + ', ' + COALESCE(CASE WHEN CAST(CAST(t.factor AS nvarchar) AS float) = t.factor THEN CAST(t.factor AS nvarchar) ELSE STR(t.factor, 15, 15) END, 'NULL')
        + ', ' + COALESCE(CAST(CAST(t.is_translatable AS tinyint) AS nvarchar), 'NULL')
        + ', ' + COALESCE(CAST(CAST(t.is_active AS tinyint) AS nvarchar), 'NULL')
        + ';' AS command
    FROM
        dbo27.vat_rates t
        INNER JOIN dbo27.users u ON u.company_id = t.company_id AND u.username = USER_NAME()
        INNER JOIN dbo27.companies c ON c.id = t.company_id
    WHERE
        c.code = COALESCE(@company, c.code)
)
SELECT
    command
FROM
    cte
ORDER BY
    part
    , r

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Executes all export procedures
-- =============================================

CREATE PROCEDURE [dbo27].[usp_export_all]
    @company nvarchar(50) = NULL
    , @print_go bit = 1
AS
BEGIN

SET NOCOUNT ON

DECLARE @company_id int

SELECT TOP 1 @company_id = c.id FROM dbo27.companies c INNER JOIN dbo27.users u ON u.company_id = c.id  WHERE c.code = @company AND u.username = USER_NAME() AND u.is_active = 1 AND u.is_admin = 1

IF @company_id IS NULL
    RETURN

DECLARE @goLine nvarchar(2) = CASE WHEN @print_go = 1 THEN 'GO' ELSE '' END

DECLARE @t TABLE (id int IDENTITY(1,1), command nvarchar(max))

INSERT INTO @t (command) VALUES ('-- Uncomment the line below to clear all data first'), ('-- EXEC dbo27.usp_import_clear_all_data ''' + REPLACE(@company, '''', '''''') + ''', ''yes'''), (@goLine), ('')

INSERT INTO @t (command) EXEC dbo27.usp_export_companies @company
INSERT INTO @t (command) VALUES (@goLine), ('')

INSERT INTO @t (command) EXEC dbo27.usp_export_users @company
INSERT INTO @t (command) VALUES (@goLine), ('')

INSERT INTO @t (command) EXEC dbo27.usp_export_vat_rates @company
INSERT INTO @t (command) VALUES (@goLine), ('')

INSERT INTO @t (command) EXEC dbo27.usp_export_units @company
INSERT INTO @t (command) VALUES (@goLine), ('')

INSERT INTO @t (command) EXEC dbo27.usp_export_subsidiary_groups @company
INSERT INTO @t (command) VALUES (@goLine), ('')

INSERT INTO @t (command) EXEC dbo27.usp_export_ledger_accounts @company
INSERT INTO @t (command) VALUES (@goLine), ('')

INSERT INTO @t (command) EXEC dbo27.usp_export_ledger_account_properties @company
INSERT INTO @t (command) VALUES (@goLine), ('')

INSERT INTO @t (command) EXEC dbo27.usp_export_members @company
INSERT INTO @t (command) VALUES (@goLine), ('')

INSERT INTO @t (command) EXEC dbo27.usp_export_member_properties @company
INSERT INTO @t (command) VALUES (@goLine), ('')

INSERT INTO @t (command) EXEC dbo27.usp_export_member_groups @company
INSERT INTO @t (command) VALUES (@goLine), ('')

INSERT INTO @t (command) EXEC dbo27.usp_export_member_relations @company
INSERT INTO @t (command) VALUES (@goLine), ('')

INSERT INTO @t (command) EXEC dbo27.usp_export_member_permissions @company
INSERT INTO @t (command) VALUES (@goLine), ('')

INSERT INTO @t (command) EXEC dbo27.usp_export_budget_currency_rates @company
INSERT INTO @t (command) VALUES (@goLine), ('')

INSERT INTO @t (command) EXEC dbo27.usp_export_budget_balances @company
INSERT INTO @t (command) VALUES (@goLine), ('')

INSERT INTO @t (command) EXEC dbo27.usp_export_budget_requests @company
INSERT INTO @t (command) VALUES (@goLine), ('')

INSERT INTO @t (command) EXEC dbo27.usp_export_actual_currency_rates @company
INSERT INTO @t (command) VALUES (@goLine), ('')

INSERT INTO @t (command) EXEC dbo27.usp_export_actual_balances @company
INSERT INTO @t (command) VALUES (@goLine), ('')

INSERT INTO @t (command) EXEC dbo27.usp_export_journals @company
INSERT INTO @t (command) VALUES (@goLine), ('')

INSERT INTO @t (command) EXEC dbo27.usp_export_actual_closed_periods @company
INSERT INTO @t (command) VALUES (@goLine), ('')

INSERT INTO @t (command) EXEC dbo27.usp_export_report_sections @company
INSERT INTO @t (command) VALUES (@goLine), ('')

INSERT INTO @t (command) EXEC dbo27.usp_export_report_section_properties @company
INSERT INTO @t (command) VALUES (@goLine), ('')

INSERT INTO @t (command) EXEC dbo27.usp_export_saved_report_types @company
INSERT INTO @t (command) VALUES (@goLine), ('')

INSERT INTO @t (command) EXEC dbo27.usp_export_saved_reports @company
INSERT INTO @t (command) VALUES (@goLine), ('')

INSERT INTO @t (command) EXEC dbo27.usp_export_translations @company
INSERT INTO @t (command) VALUES (@goLine), ('')

INSERT INTO @t (command) EXEC dbo27.usp_export_report_section_translations @company
INSERT INTO @t (command) VALUES (@goLine), ('')

SELECT command FROM @t ORDER BY id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Imports budget requests
-- =============================================

CREATE PROCEDURE [dbo27].[usp_import_actual_balances]
    @company nvarchar(50) = NULL
    , @account_code nvarchar(50) = NULL
    , @subsidiary_account_code nvarchar(50) = NULL
    , @balance float = NULL
    , @balance$ float = NULL
AS
BEGIN

SET NOCOUNT ON

DECLARE @company_id int

SELECT TOP 1 @company_id = c.id FROM dbo27.companies c INNER JOIN dbo27.users u ON u.company_id = c.id  WHERE c.code = @company AND u.username = USER_NAME() AND u.is_active = 1 AND u.is_admin = 1

IF @company_id IS NULL
    RETURN

DECLARE @account_id int = (SELECT id FROM dbo27.ledger_accounts WHERE company_id = @company_id AND code = @account_code)
DECLARE @subsidiary_account_id int = (SELECT id FROM dbo27.members WHERE company_id = @company_id AND code = @subsidiary_account_code)

UPDATE dbo27.actual_balances
SET
    balance = @balance
    , balance$ = @balance$
WHERE
    account_id = @account_id
    AND COALESCE(subsidiary_account_id, 0) = COALESCE(@subsidiary_account_id, 0)

IF @@ROWCOUNT = 0
INSERT INTO dbo27.actual_balances
    ( account_id
    , subsidiary_account_id
    , balance
    , balance$
    )
VALUES
    ( @account_id
    , @subsidiary_account_id
    , @balance
    , @balance$
    )

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Imports actual closed period
-- =============================================

CREATE PROCEDURE [dbo27].[usp_import_actual_closed_periods]
    @company nvarchar(50) = NULL
    , @date date = NULL
    , @is_closed bit = NULL
AS
BEGIN

SET NOCOUNT ON

DECLARE @company_id int

SELECT TOP 1 @company_id = c.id FROM dbo27.companies c INNER JOIN dbo27.users u ON u.company_id = c.id  WHERE c.code = @company AND u.username = USER_NAME() AND u.is_active = 1 AND u.is_admin = 1

IF @company_id IS NULL
    RETURN

IF @date IS NULL
    RETURN

UPDATE dbo27.actual_closed_periods
SET
    is_closed = COALESCE(@is_closed, 0)
WHERE
    company_id = @company_id
    AND date = @date

IF @@ROWCOUNT = 0
INSERT INTO dbo27.actual_closed_periods
    ( company_id
    , date
    , is_closed
    )
VALUES
    ( @company_id
    , @date
    , COALESCE(@is_closed, 0)
    )

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Imports actual currency rates
-- =============================================

CREATE PROCEDURE [dbo27].[usp_import_actual_currency_rates]
    @company nvarchar(50) = NULL
    , @currency_code nvarchar(50) = NULL
    , @date date = NULL
    , @rate smallmoney = NULL
    , @is_checked bit = NULL
AS
BEGIN

SET NOCOUNT ON

DECLARE @company_id int

SELECT TOP 1 @company_id = c.id FROM dbo27.companies c INNER JOIN dbo27.users u ON u.company_id = c.id  WHERE c.code = @company AND u.username = USER_NAME() AND u.is_active = 1 AND u.is_admin = 1

IF @company_id IS NULL
    RETURN

DECLARE @currency_id int = (SELECT id FROM dbo27.units WHERE company_id = @company_id AND code = @currency_code)

IF @currency_id IS NULL OR @date IS NULL OR @rate IS NULL
    RETURN

UPDATE dbo27.actual_currency_rates
SET
    rate = @rate
    , is_checked = COALESCE(@is_checked, 0)
WHERE
    currency_id = @currency_id
    AND date = @date

IF @@ROWCOUNT = 0
INSERT INTO dbo27.actual_currency_rates
    ( currency_id
    , date
    , rate
    , is_checked
    )
VALUES
    ( @currency_id
    , @date
    , @rate
    , COALESCE(@is_checked, 0)
    )

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Imports budget balances
-- =============================================

CREATE PROCEDURE [dbo27].[usp_import_budget_balances]
    @company nvarchar(50) = NULL
    , @category_code nvarchar(50) = NULL
    , @time_code nvarchar(50) = NULL
    , @account_code nvarchar(50) = NULL
    , @debit float = NULL
    , @credit float = NULL
AS
BEGIN

SET NOCOUNT ON

DECLARE @company_id int

SELECT TOP 1 @company_id = c.id FROM dbo27.companies c INNER JOIN dbo27.users u ON u.company_id = c.id  WHERE c.code = @company AND u.username = USER_NAME() AND u.is_active = 1 AND u.is_admin = 1

IF @company_id IS NULL
    RETURN

DECLARE @category_id int = (SELECT id FROM dbo27.members WHERE company_id = @company_id AND code = @category_code)
DECLARE @time_id int = (SELECT id FROM dbo27.members WHERE company_id = @company_id AND code = @time_code)
DECLARE @account_id int = (SELECT id FROM dbo27.ledger_accounts WHERE company_id = @company_id AND code = @account_code)

UPDATE dbo27.budget_balances
SET
    debit = @debit
    , credit = @credit
WHERE
    category_id = @category_id
    AND time_id = @time_id
    AND account_id = @account_id

IF @@ROWCOUNT = 0
INSERT INTO dbo27.budget_balances
    ( category_id
    , time_id
    , account_id
    , debit
    , credit
    )
VALUES
    ( @category_id
    , @time_id
    , @account_id
    , @debit
    , @credit
    )

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Imports budget currency rates
-- =============================================

CREATE PROCEDURE [dbo27].[usp_import_budget_currency_rates]
    @company nvarchar(50) = NULL
    , @category_code nvarchar(50) = NULL
    , @time_code nvarchar(50) = NULL
    , @unit_code nvarchar(50) = NULL
    , @balance00 float = NULL
    , @period01 float = NULL
    , @balance01 float = NULL
    , @period02 float = NULL
    , @balance02 float = NULL
    , @period03 float = NULL
    , @balance03 float = NULL
    , @period04 float = NULL
    , @balance04 float = NULL
    , @period05 float = NULL
    , @balance05 float = NULL
    , @period06 float = NULL
    , @balance06 float = NULL
    , @period07 float = NULL
    , @balance07 float = NULL
    , @period08 float = NULL
    , @balance08 float = NULL
    , @period09 float = NULL
    , @balance09 float = NULL
    , @period10 float = NULL
    , @balance10 float = NULL
    , @period11 float = NULL
    , @balance11 float = NULL
    , @period12 float = NULL
    , @balance12 float = NULL
    , @row_formulas nvarchar(max) = NULL
AS
BEGIN

SET NOCOUNT ON

DECLARE @company_id int

SELECT TOP 1 @company_id = c.id FROM dbo27.companies c INNER JOIN dbo27.users u ON u.company_id = c.id  WHERE c.code = @company AND u.username = USER_NAME() AND u.is_active = 1 AND u.is_admin = 1

IF @company_id IS NULL
    RETURN

DECLARE @category_id int = (SELECT id FROM dbo27.members WHERE company_id = @company_id AND code = @category_code)
DECLARE @time_id int = (SELECT id FROM dbo27.members WHERE company_id = @company_id AND code = @time_code)
DECLARE @unit_id int = (SELECT id FROM dbo27.units WHERE company_id = @company_id AND code = @unit_code)

IF @category_id IS NULL OR @time_id IS NULL OR @unit_id IS NULL
    RETURN

UPDATE dbo27.budget_currency_rates
SET
    balance00 = @balance00
    , period01 = @period01
    , balance01 = @balance01
    , period02 = @period02
    , balance02 = @balance02
    , period03 = @period03
    , balance03 = @balance03
    , period04 = @period04
    , balance04 = @balance04
    , period05 = @period05
    , balance05 = @balance05
    , period06 = @period06
    , balance06 = @balance06
    , period07 = @period07
    , balance07 = @balance07
    , period08 = @period08
    , balance08 = @balance08
    , period09 = @period09
    , balance09 = @balance09
    , period10 = @period10
    , balance10 = @balance10
    , period11 = @period11
    , balance11 = @balance11
    , period12 = @period12
    , balance12 = @balance12
    , row_formulas = @row_formulas
WHERE
    category_id = @category_id
    AND time_id = @time_id
    AND unit_id = @unit_id

IF @@ROWCOUNT = 0
INSERT INTO dbo27.budget_currency_rates
    ( category_id
    , time_id
    , unit_id
    , balance00
    , period01
    , balance01
    , period02
    , balance02
    , period03
    , balance03
    , period04
    , balance04
    , period05
    , balance05
    , period06
    , balance06
    , period07
    , balance07
    , period08
    , balance08
    , period09
    , balance09
    , period10
    , balance10
    , period11
    , balance11
    , period12
    , balance12
    , row_formulas
    )
VALUES
    ( @category_id
    , @time_id
    , @unit_id
    , @balance00
    , @period01
    , @balance01
    , @period02
    , @balance02
    , @period03
    , @balance03
    , @period04
    , @balance04
    , @period05
    , @balance05
    , @period06
    , @balance06
    , @period07
    , @balance07
    , @period08
    , @balance08
    , @period09
    , @balance09
    , @period10
    , @balance10
    , @period11
    , @balance11
    , @period12
    , @balance12
    , @row_formulas
    )

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Imports budget requests
-- =============================================

CREATE PROCEDURE [dbo27].[usp_import_budget_requests]
    @company nvarchar(50) = NULL
    , @entity_code nvarchar(50) = NULL
    , @category_code nvarchar(50) = NULL
    , @time_code nvarchar(50) = NULL
    , @row_index int = NULL
    , @row_format int = NULL
    , @description nvarchar(255) = NULL
    , @account_code nvarchar(50) = NULL
    , @subaccount_code nvarchar(50) = NULL
    , @region_code nvarchar(50) = NULL
    , @product_code nvarchar(50) = NULL
    , @vat_rate_code nvarchar(50) = NULL
    , @unit_code nvarchar(50) = NULL
    , @total_payments float = NULL, @total_charges float = NULL, @balance00 float = NULL
    , @payments01 float = NULL, @charges01 float = NULL, @balance01 float = NULL
    , @payments02 float = NULL, @charges02 float = NULL, @balance02 float = NULL
    , @payments03 float = NULL, @charges03 float = NULL, @balance03 float = NULL
    , @payments04 float = NULL, @charges04 float = NULL, @balance04 float = NULL
    , @payments05 float = NULL, @charges05 float = NULL, @balance05 float = NULL
    , @payments06 float = NULL, @charges06 float = NULL, @balance06 float = NULL
    , @payments07 float = NULL, @charges07 float = NULL, @balance07 float = NULL
    , @payments08 float = NULL, @charges08 float = NULL, @balance08 float = NULL
    , @payments09 float = NULL, @charges09 float = NULL, @balance09 float = NULL
    , @payments10 float = NULL, @charges10 float = NULL, @balance10 float = NULL
    , @payments11 float = NULL, @charges11 float = NULL, @balance11 float = NULL
    , @payments12 float = NULL, @charges12 float = NULL, @balance12 float = NULL
    , @row_formulas nvarchar(max) = NULL
    , @transaction_start_time datetime = NULL
AS
BEGIN

SET NOCOUNT ON

DECLARE @company_id int

SELECT TOP 1 @company_id = c.id FROM dbo27.companies c INNER JOIN dbo27.users u ON u.company_id = c.id  WHERE c.code = @company AND u.username = USER_NAME() AND u.is_active = 1 AND u.is_admin = 1

IF @company_id IS NULL
    RETURN

DECLARE @category_id int = (SELECT id FROM dbo27.members WHERE company_id = @company_id AND code = @category_code)
DECLARE @time_id int = (SELECT id FROM dbo27.members WHERE company_id = @company_id AND code = @time_code)
DECLARE @entity_id int = (SELECT id FROM dbo27.members WHERE company_id = @company_id AND code = @entity_code)

IF @category_id IS NULL OR @time_id IS NULL OR @entity_id IS NULL
    RETURN

DECLARE @account_id int = (SELECT id FROM dbo27.members WHERE company_id = @company_id AND code = @account_code)
DECLARE @subsidiary_account_id int = (SELECT id FROM dbo27.members WHERE company_id = @company_id AND code = @subaccount_code)
DECLARE @region_id int = (SELECT id FROM dbo27.members WHERE company_id = @company_id AND code = @region_code)
DECLARE @product_id int = (SELECT id FROM dbo27.members WHERE company_id = @company_id AND code = @product_code)
DECLARE @vat_rate_id tinyint = (SELECT id FROM dbo27.vat_rates WHERE company_id = @company_id AND code = @vat_rate_code)
DECLARE @unit_id int = (SELECT id FROM dbo27.units WHERE company_id = @company_id AND code = @unit_code)

UPDATE dbo27.budget_requests
SET
    row_format = @row_format
    , description = @description
    , account_id = @account_id
    , subsidiary_account_id = @subsidiary_account_id
    , region_id = @region_id
    , product_id = @product_id
    , vat_rate_id = @vat_rate_id
    , unit_id = @unit_id
    , total_payments = @total_payments, total_charges = @total_charges, balance00 = @balance00
    , payments01 = @payments01, charges01 = @charges01, balance01 = @balance01
    , payments02 = @payments02, charges02 = @charges02, balance02 = @balance02
    , payments03 = @payments03, charges03 = @charges03, balance03 = @balance03
    , payments04 = @payments04, charges04 = @charges04, balance04 = @balance04
    , payments05 = @payments05, charges05 = @charges05, balance05 = @balance05
    , payments06 = @payments06, charges06 = @charges06, balance06 = @balance06
    , payments07 = @payments07, charges07 = @charges07, balance07 = @balance07
    , payments08 = @payments08, charges08 = @charges08, balance08 = @balance08
    , payments09 = @payments09, charges09 = @charges09, balance09 = @balance09
    , payments10 = @payments10, charges10 = @charges10, balance10 = @balance10
    , payments11 = @payments11, charges11 = @charges11, balance11 = @balance11
    , payments12 = @payments12, charges12 = @charges12, balance12 = @balance12
    , row_formulas = @row_formulas
    , transaction_start_time = @transaction_start_time
WHERE
    [entity_id] = @entity_id
    AND category_id = @category_id
    AND time_id = @time_id
    AND row_index = @row_index

IF @@ROWCOUNT = 0
INSERT INTO dbo27.budget_requests
    ( [entity_id]
    , category_id
    , time_id
    , row_index
    , row_format
    , description
    , account_id
    , subsidiary_account_id
    , region_id
    , product_id
    , vat_rate_id
    , unit_id
    , total_payments, total_charges, balance00
    , payments01, charges01, balance01
    , payments02, charges02, balance02
    , payments03, charges03, balance03
    , payments04, charges04, balance04
    , payments05, charges05, balance05
    , payments06, charges06, balance06
    , payments07, charges07, balance07
    , payments08, charges08, balance08
    , payments09, charges09, balance09
    , payments10, charges10, balance10
    , payments11, charges11, balance11
    , payments12, charges12, balance12
    , row_formulas
    , transaction_start_time
    )
VALUES
    ( @entity_id
    , @category_id
    , @time_id
    , @row_index
    , @row_format
    , @description
    , @account_id
    , @subsidiary_account_id
    , @region_id
    , @product_id
    , @vat_rate_id
    , @unit_id
    , @total_payments, @total_charges, @balance00
    , @payments01, @charges01, @balance01
    , @payments02, @charges02, @balance02
    , @payments03, @charges03, @balance03
    , @payments04, @charges04, @balance04
    , @payments05, @charges05, @balance05
    , @payments06, @charges06, @balance06
    , @payments07, @charges07, @balance07
    , @payments08, @charges08, @balance08
    , @payments09, @charges09, @balance09
    , @payments10, @charges10, @balance10
    , @payments11, @charges11, @balance11
    , @payments12, @charges12, @balance12
    , @row_formulas
    , @transaction_start_time
    )

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Clears all user's data before importing
-- =============================================

CREATE PROCEDURE [dbo27].[usp_import_clear_all_data]
    @company nvarchar(50) = NULL
    , @confirm nvarchar(50)
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

DECLARE @message nvarchar(max)

DECLARE @company_id int

SELECT TOP 1 @company_id = c.id FROM dbo27.companies c INNER JOIN dbo27.users u ON u.company_id = c.id  WHERE c.code = @company AND u.username = USER_NAME() AND u.is_active = 1 AND u.is_admin = 1

IF @company_id IS NULL
    BEGIN
    SET @message = dbo27.get_translated_string('Incorrect company_id', @data_language)
    RAISERROR (@message, 11, 0)
    RETURN
    END

IF @confirm IS NULL OR NOT @confirm = 'yes'
    RETURN

BEGIN TRANSACTION

DELETE FROM dbo27.translations                WHERE company_id = @company_id

DELETE FROM dbo27.journals                    WHERE company_id = @company_id

DELETE FROM dbo27.actual_balances            WHERE account_id IN (SELECT id FROM dbo27.ledger_accounts WHERE company_id = @company_id)
DELETE FROM dbo27.actual_currency_rates        WHERE currency_id IN (SELECT id FROM dbo27.units WHERE company_id = @company_id)
DELETE FROM dbo27.actual_closed_periods        WHERE company_id = @company_id

DELETE FROM dbo27.budget_balances            WHERE category_id IN (SELECT id FROM dbo27.members WHERE company_id = @company_id)
DELETE FROM dbo27.saved_reports                WHERE category_id IN (SELECT id FROM dbo27.members WHERE company_id = @company_id)
DELETE FROM dbo27.budget_requests            WHERE category_id IN (SELECT id FROM dbo27.members WHERE company_id = @company_id)
DELETE FROM dbo27.budget_currency_rates        WHERE category_id IN (SELECT id FROM dbo27.members WHERE company_id = @company_id)

DELETE FROM dbo27.saved_report_types        WHERE company_id = @company_id

DELETE FROM dbo27.member_groups                WHERE group_id IN (SELECT id FROM dbo27.subsidiary_groups WHERE company_id = @company_id)
DELETE FROM dbo27.subsidiary_groups            WHERE company_id = @company_id

DELETE FROM dbo27.member_permissions        WHERE member_id IN (SELECT id FROM dbo27.members WHERE company_id = @company_id)
DELETE FROM dbo27.member_relations            WHERE member_id IN (SELECT id FROM dbo27.members WHERE company_id = @company_id)

DELETE FROM dbo27.members                    WHERE company_id = @company_id

DELETE FROM dbo27.ledger_accounts            WHERE company_id = @company_id

DELETE FROM dbo27.report_sections            WHERE company_id = @company_id

DELETE FROM dbo27.vat_rates                    WHERE company_id = @company_id
DELETE FROM dbo27.units                        WHERE company_id = @company_id
DELETE FROM dbo27.users                        WHERE company_id = @company_id

DELETE FROM dbo27.companies                    WHERE id = @company_id

DECLARE @id int

SET @id = COALESCE((SELECT MAX(id) FROM dbo27.actual_balances), 0);

DBCC CHECKIDENT ('dbo27.actual_balances'    , RESEED, @id) WITH NO_INFOMSGS;

SET @id = COALESCE((SELECT MAX(id) FROM dbo27.budget_balances), @id);

DBCC CHECKIDENT ('dbo27.budget_balances'    , RESEED, @id) WITH NO_INFOMSGS;

SET @id = COALESCE((SELECT MAX(id) FROM dbo27.budget_requests), @id);

DBCC CHECKIDENT ('dbo27.budget_requests'    , RESEED, @id) WITH NO_INFOMSGS;

SET @id = COALESCE((SELECT MAX(id) FROM dbo27.companies), @id);

DBCC CHECKIDENT ('dbo27.companies'            , RESEED, @id) WITH NO_INFOMSGS;

SET @id = COALESCE((SELECT MAX(id) FROM dbo27.journals), @id);

DBCC CHECKIDENT ('dbo27.journals'            , RESEED, @id) WITH NO_INFOMSGS;

SET @id = COALESCE((SELECT MAX(id) FROM dbo27.ledger_accounts), @id);

DBCC CHECKIDENT ('dbo27.ledger_accounts'    , RESEED, @id) WITH NO_INFOMSGS;

SET @id = COALESCE((SELECT MAX(id) FROM dbo27.members), @id);

DBCC CHECKIDENT ('dbo27.members'            , RESEED, @id) WITH NO_INFOMSGS;

SET @id = COALESCE((SELECT MAX(id) FROM dbo27.report_sections), @id);

DBCC CHECKIDENT ('dbo27.report_sections'    , RESEED, @id) WITH NO_INFOMSGS;

SET @id = COALESCE((SELECT MAX(id) FROM dbo27.subsidiary_groups), @id);

DBCC CHECKIDENT ('dbo27.subsidiary_groups'    , RESEED, @id) WITH NO_INFOMSGS;

SET @id = COALESCE((SELECT MAX(id) FROM dbo27.units), @id);

DBCC CHECKIDENT ('dbo27.units'                , RESEED, @id) WITH NO_INFOMSGS;

SET @id = COALESCE((SELECT MAX(id) FROM dbo27.users), @id);

DBCC CHECKIDENT ('dbo27.users'                , RESEED, @id) WITH NO_INFOMSGS;

SET @id = COALESCE((SELECT MAX(id) FROM dbo27.vat_rates), @id);

DBCC CHECKIDENT ('dbo27.vat_rates'            , RESEED, @id) WITH NO_INFOMSGS;

COMMIT TRANSACTION

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Imports companies
-- =============================================

CREATE PROCEDURE [dbo27].[usp_import_companies]
    @code nvarchar(50)
    , @name nvarchar(100)
    , @default_language varchar(10) = NULL
    , @sort_order int = NULL
AS
BEGIN

SET NOCOUNT ON

DECLARE @company_id int = (SELECT id FROM dbo27.companies WHERE code = @code)

IF @company_id IS NOT NULL
    BEGIN

    IF NOT EXISTS (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1 AND is_admin = 1)
        RETURN

    UPDATE dbo27.companies
    SET
        name = @name
        , default_language = COALESCE(@default_language, 'en')
        , sort_order = @sort_order
    WHERE
        code = @code

    END
ELSE
    BEGIN
    INSERT INTO dbo27.companies
        (code, name, default_language, sort_order)
    VALUES
        (@code, @name, @default_language, @sort_order)

    SET @company_id = SCOPE_IDENTITY()

    INSERT INTO dbo27.users (company_id, username, name, is_admin, is_active)
    VALUES (@company_id, USER_NAME(), USER_NAME(), 1, 1)

    END

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Imports journal records
-- =============================================

CREATE PROCEDURE [dbo27].[usp_import_journals]
    @company nvarchar(50) = NULL
    , @date date = NULL
    , @amount float = NULL
    , @amount$ float = NULL
    , @description nvarchar(255) = NULL
    , @debit_account_code nvarchar(50) = NULL
    , @credit_account_code nvarchar(50) = NULL
    , @debit_subsidiary_account_code nvarchar(50) = NULL
    , @credit_subsidiary_account_code nvarchar(50) = NULL
    , @entity_code nvarchar(50) = NULL
    , @account_code nvarchar(50) = NULL
    , @region_code nvarchar(50) = NULL
    , @product_code nvarchar(50) = NULL
    , @ref_record_id int = NULL
AS
BEGIN

SET NOCOUNT ON

DECLARE @company_id int

SELECT TOP 1 @company_id = c.id FROM dbo27.companies c INNER JOIN dbo27.users u ON u.company_id = c.id  WHERE c.code = @company AND u.username = USER_NAME() AND u.is_active = 1 AND u.is_admin = 1

IF @company_id IS NULL
    RETURN

DECLARE @debit_account_id int = (SELECT id FROM dbo27.ledger_accounts WHERE company_id = @company_id AND code = @debit_account_code)
DECLARE @credit_account_id int = (SELECT id FROM dbo27.ledger_accounts WHERE company_id = @company_id AND code = @credit_account_code)
DECLARE @debit_subsidiary_account_id int = (SELECT id FROM dbo27.members WHERE company_id = @company_id AND code = @debit_subsidiary_account_code)
DECLARE @credit_subsidiary_account_id int = (SELECT id FROM dbo27.members WHERE company_id = @company_id AND code = @credit_subsidiary_account_code)

DECLARE @entity_id int = (SELECT id FROM dbo27.members WHERE company_id = @company_id AND code = @entity_code)
DECLARE @account_id int = (SELECT id FROM dbo27.members WHERE company_id = @company_id AND code = @account_code)
DECLARE @region_id int = (SELECT id FROM dbo27.members WHERE company_id = @company_id AND code = @region_code)
DECLARE @product_id int = (SELECT id FROM dbo27.members WHERE company_id = @company_id AND code = @product_code)

INSERT INTO dbo27.journals
    (company_id, date, amount, amount$, description, debit_account_id, debit_subsidiary_account_id, credit_account_id, credit_subsidiary_account_id, entity_id, account_id, region_id, product_id, ref_record_id, modified_on, modified_by)
VALUES
    (@company_id, @date, @amount, @amount$, @description, @debit_account_id, @debit_subsidiary_account_id, @credit_account_id, @credit_subsidiary_account_id, @entity_id, @account_id, @region_id, @product_id, @ref_record_id, GETDATE(), USER_NAME())

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Imports account properties
-- =============================================

CREATE PROCEDURE [dbo27].[usp_import_ledger_account_properties]
    @company nvarchar(50) = NULL
    , @account_code nvarchar(50) = NULL
    , @parent_code nvarchar(50) = NULL
    , @account_type_code nvarchar(50) = NULL
    , @subsidiary_group_code nvarchar(50) = NULL
    , @closing_child_account_code nvarchar(50) = NULL
    , @closing_debit_account_code nvarchar(50) = NULL
    , @closing_credit_account_code nvarchar(50) = NULL
    , @ref_number int = NULL
AS
BEGIN

SET NOCOUNT ON

DECLARE @company_id int

SELECT TOP 1 @company_id = c.id FROM dbo27.companies c INNER JOIN dbo27.users u ON u.company_id = c.id  WHERE c.code = @company AND u.username = USER_NAME() AND u.is_active = 1 AND u.is_admin = 1

IF @company_id IS NULL
    RETURN

DECLARE @account_id int = (SELECT id FROM dbo27.ledger_accounts WHERE company_id = @company_id AND code = @account_code)

IF @account_id IS NULL
    RETURN

DECLARE @account_type_id int = (SELECT id FROM dbo27.ledger_account_types WHERE code = @account_type_code)
DECLARE @subsidiary_group_id int = (SELECT id FROM dbo27.subsidiary_groups WHERE company_id = @company_id AND code = @subsidiary_group_code)

DECLARE @parent_account_id int = (SELECT id FROM dbo27.ledger_accounts WHERE company_id = @company_id AND code = @parent_code)
DECLARE @closing_child_account_id int = (SELECT id FROM dbo27.ledger_accounts WHERE company_id = @company_id AND code = @closing_child_account_code)
DECLARE @closing_debit_account_id int = (SELECT id FROM dbo27.ledger_accounts WHERE company_id = @company_id AND code = @closing_debit_account_code)
DECLARE @closing_credit_account_id int = (SELECT id FROM dbo27.ledger_accounts WHERE company_id = @company_id AND code = @closing_credit_account_code)

UPDATE dbo27.ledger_accounts
SET
    parent_id = @parent_account_id
    , account_type_id = @account_type_id
    , subsidiary_group_id = @subsidiary_group_id
    , closing_child_account_id = @closing_child_account_id
    , closing_debit_account_id = @closing_debit_account_id
    , closing_credit_account_id = @closing_credit_account_id
    , ref_number = @ref_number
WHERE
    id = @account_id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Imports accounts
-- =============================================

CREATE PROCEDURE [dbo27].[usp_import_ledger_accounts]
    @company nvarchar(50) = NULL
    , @code nvarchar(50)
    , @name nvarchar(100)
    , @is_active bit = NULL
AS
BEGIN

SET NOCOUNT ON

DECLARE @company_id int

SELECT TOP 1 @company_id = c.id FROM dbo27.companies c INNER JOIN dbo27.users u ON u.company_id = c.id  WHERE c.code = @company AND u.username = USER_NAME() AND u.is_active = 1 AND u.is_admin = 1

IF @company_id IS NULL
    RETURN

IF @is_active IS NULL SET @is_active = 1

UPDATE dbo27.ledger_accounts
SET
    name = @name
    , is_active = @is_active
WHERE
    company_id = @company_id
    AND code = @code

IF @@ROWCOUNT = 0
    INSERT INTO dbo27.ledger_accounts
        (company_id, code, name, is_active)
    VALUES
        (@company_id, @code, @name, @is_active)

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Imports member groups
-- =============================================

CREATE PROCEDURE [dbo27].[usp_import_member_groups]
    @company nvarchar(50) = NULL
    , @member_code nvarchar(50) = NULL
    , @group_code nvarchar(50) = NULL
AS
BEGIN

SET NOCOUNT ON

DECLARE @company_id int

SELECT TOP 1 @company_id = c.id FROM dbo27.companies c INNER JOIN dbo27.users u ON u.company_id = c.id  WHERE c.code = @company AND u.username = USER_NAME() AND u.is_active = 1 AND u.is_admin = 1

IF @company_id IS NULL
    RETURN

DECLARE @member_id int = (SELECT id FROM dbo27.members WHERE company_id = @company_id AND code = @member_code)
DECLARE @group_id int = (SELECT id FROM dbo27.subsidiary_groups WHERE company_id = @company_id AND code = @group_code)

IF @member_id IS NULL OR @group_id IS NULL
    RETURN

IF NOT EXISTS (SELECT member_id FROM dbo27.member_groups WHERE member_id = @member_id AND group_id = @group_id)
    INSERT INTO dbo27.member_groups (member_id, group_id)
        VALUES (@member_id, @group_id)

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Imports member permissions
-- =============================================

CREATE PROCEDURE [dbo27].[usp_import_member_permissions]
    @company nvarchar(50) = NULL
    , @member_code nvarchar(50) = NULL
    , @username nvarchar(128) = NULL
    , @select_permission tinyint = NULL
    , @update_permission tinyint = NULL
AS
BEGIN

SET NOCOUNT ON

IF @username IS NULL
    RETURN

DECLARE @company_id int

SELECT TOP 1 @company_id = c.id FROM dbo27.companies c INNER JOIN dbo27.users u ON u.company_id = c.id  WHERE c.code = @company AND u.username = USER_NAME() AND u.is_active = 1 AND u.is_admin = 1

IF @company_id IS NULL
    RETURN

DECLARE @member_id int = (SELECT id FROM dbo27.members WHERE company_id = @company_id AND code = @member_code)

IF @member_id IS NULL
    RETURN

UPDATE dbo27.member_permissions
SET
    select_permission = @select_permission
    , update_permission = @update_permission
WHERE
    member_id = @member_id
    AND username = @username

IF @@ROWCOUNT = 0
    INSERT INTO dbo27.member_permissions (member_id, username, select_permission, update_permission, is_inherited)
        VALUES (@member_id, @username, @select_permission, @update_permission, 0)

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Imports member properties
-- =============================================

CREATE PROCEDURE [dbo27].[usp_import_member_properties]
    @company nvarchar(50) = NULL
    , @member_code nvarchar(50) = NULL
    , @parent_code nvarchar(50) = NULL
    , @unit_code nvarchar(50) = NULL
    , @vat_rate_code nvarchar(50) = NULL
    , @account_type_code nvarchar(50) = NULL
    , @payment_debit_code nvarchar(50) = NULL
    , @payment_credit_code nvarchar(50) = NULL
    , @charge_debit_code nvarchar(50) = NULL
    , @charge_credit_code nvarchar(50) = NULL
    , @vat_debit_code nvarchar(50) = NULL
    , @vat_credit_code nvarchar(50) = NULL
AS
BEGIN

SET NOCOUNT ON

DECLARE @company_id int

SELECT TOP 1 @company_id = c.id FROM dbo27.companies c INNER JOIN dbo27.users u ON u.company_id = c.id  WHERE c.code = @company AND u.username = USER_NAME() AND u.is_active = 1 AND u.is_admin = 1

IF @company_id IS NULL
    RETURN

DECLARE @member_id int = (SELECT id FROM dbo27.members WHERE company_id = @company_id AND code = @member_code)

IF @member_id IS NULL
    RETURN

DECLARE @account_type_id int = (SELECT id FROM dbo27.member_types WHERE code = @account_type_code)

DECLARE @parent_id int = (SELECT id FROM dbo27.members WHERE company_id = @company_id AND code = @parent_code)
DECLARE @vat_rate_id int = (SELECT id FROM dbo27.vat_rates WHERE company_id = @company_id AND code = @vat_rate_code)
DECLARE @unit_id int = (SELECT id FROM dbo27.units WHERE company_id = @company_id AND code = @unit_code)

DECLARE @payment_debit_id int = (SELECT id FROM dbo27.ledger_accounts WHERE company_id = @company_id AND code = @payment_debit_code)
DECLARE @payment_credit_id int = (SELECT id FROM dbo27.ledger_accounts WHERE company_id = @company_id AND code = @payment_credit_code)
DECLARE @charge_debit_id int = (SELECT id FROM dbo27.ledger_accounts WHERE company_id = @company_id AND code = @charge_debit_code)
DECLARE @charge_credit_id int = (SELECT id FROM dbo27.ledger_accounts WHERE company_id = @company_id AND code = @charge_credit_code)
DECLARE @vat_debit_id int = (SELECT id FROM dbo27.ledger_accounts WHERE company_id = @company_id AND code = @vat_debit_code)
DECLARE @vat_credit_id int = (SELECT id FROM dbo27.ledger_accounts WHERE company_id = @company_id AND code = @vat_credit_code)

UPDATE dbo27.members
SET
    parent_id = @parent_id
    , vat_rate_id = @vat_rate_id
    , unit_id = @unit_id
    , account_type_id = @account_type_id
    , payment_debit_id = @payment_debit_id
    , payment_credit_id = @payment_credit_id
    , charge_debit_id = @charge_debit_id
    , charge_credit_id = @charge_credit_id
    , vat_debit_id = @vat_debit_id
    , vat_credit_id = @vat_credit_id
WHERE
    id = @member_id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Imports member relations
-- =============================================

CREATE PROCEDURE [dbo27].[usp_import_member_relations]
    @company nvarchar(50) = NULL
    , @member_code nvarchar(50) = NULL
    , @partner_code nvarchar(50) = NULL
    , @select_permission tinyint = NULL
    , @update_permission tinyint = NULL
AS
BEGIN

SET NOCOUNT ON

DECLARE @company_id int

SELECT TOP 1 @company_id = c.id FROM dbo27.companies c INNER JOIN dbo27.users u ON u.company_id = c.id  WHERE c.code = @company AND u.username = USER_NAME() AND u.is_active = 1 AND u.is_admin = 1

IF @company_id IS NULL
    RETURN

DECLARE @member_id int = (SELECT id FROM dbo27.members WHERE company_id = @company_id AND code = @member_code)
DECLARE @partner_id int = (SELECT id FROM dbo27.members WHERE company_id = @company_id AND code = @partner_code)

IF @member_id IS NULL OR @partner_id IS NULL
    RETURN

UPDATE dbo27.member_relations
SET
    select_permission = @select_permission
    , update_permission = @update_permission
WHERE
    member_id = @member_id
    AND partner_id = @partner_id

IF @@ROWCOUNT = 0
    INSERT INTO dbo27.member_relations (member_id, partner_id, select_permission, update_permission)
        VALUES (@member_id, @partner_id, @select_permission, @update_permission)

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Imports members
-- =============================================

CREATE PROCEDURE [dbo27].[usp_import_members]
    @company nvarchar(50) = NULL
    , @dimension_id tinyint
    , @sort_order int
    , @code nvarchar(50)
    , @name nvarchar(100)
    , @is_translatable bit = NULL
    , @is_active bit = NULL
AS
BEGIN

SET NOCOUNT ON

DECLARE @company_id int

SELECT TOP 1 @company_id = c.id FROM dbo27.companies c INNER JOIN dbo27.users u ON u.company_id = c.id  WHERE c.code = @company AND u.username = USER_NAME() AND u.is_active = 1 AND u.is_admin = 1

IF @company_id IS NULL
    RETURN

IF @is_active IS NULL SET @is_active = 1

UPDATE dbo27.members
SET
    dimension_id = @dimension_id
    , sort_order = @sort_order
    , name = @name
    , is_translatable = COALESCE(@is_translatable, 1)
    , is_active = COALESCE(@is_active, 1)
WHERE
    company_id = @company_id
    AND code = @code

IF @@ROWCOUNT = 0
    INSERT INTO dbo27.members
        (company_id, dimension_id, sort_order, code, name, is_translatable, is_active)
    VALUES
        (@company_id, @dimension_id, @sort_order, @code, @name, COALESCE(@is_translatable, 1), COALESCE(@is_active, 1))

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Imports report_sections
-- =============================================

CREATE PROCEDURE [dbo27].[usp_import_report_section_properties]
    @company nvarchar(50) = NULL
    , @report_type_id tinyint = NULL
    , @section int = NULL
    , @parent_section int = NULL
    , @parent2_section int = NULL
AS
BEGIN

SET NOCOUNT ON

DECLARE @company_id int

SELECT TOP 1 @company_id = c.id FROM dbo27.companies c INNER JOIN dbo27.users u ON u.company_id = c.id  WHERE c.code = @company AND u.username = USER_NAME() AND u.is_active = 1 AND u.is_admin = 1

IF @company_id IS NULL
    RETURN

DECLARE @parent_id int = (SELECT TOP 1 id FROM dbo27.report_sections WHERE company_id = @company_id AND report_type_id = @report_type_id AND section = @parent_section)
DECLARE @parent2_id int = (SELECT TOP 1 id FROM dbo27.report_sections WHERE company_id = @company_id AND report_type_id = @report_type_id AND section = @parent2_section)

UPDATE dbo27.report_sections
SET
    parent_id = @parent_id
    , parent2_id = @parent2_id
WHERE
    company_id = @company_id
    AND report_type_id = @report_type_id
    AND section = @section

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Imports translations of report_sections
-- =============================================

CREATE PROCEDURE [dbo27].[usp_import_report_section_translations]
    @company nvarchar(50) = NULL
    , @report_type_id tinyint = NULL
    , @section int = NULL
    , @language varchar(10)
    , @name nvarchar(100) = NULL
AS
BEGIN

SET NOCOUNT ON

DECLARE @company_id int

SELECT TOP 1 @company_id = c.id FROM dbo27.companies c INNER JOIN dbo27.users u ON u.company_id = c.id  WHERE c.code = @company AND u.username = USER_NAME() AND u.is_active = 1 AND u.is_admin = 1

IF @company_id IS NULL
    RETURN

DECLARE @member_id int

SELECT TOP 1 @member_id = t.id FROM dbo27.report_sections t INNER JOIN dbo27.users u ON u.company_id = t.company_id  WHERE t.company_id = @company_id AND t.report_type_id = @report_type_id AND t.section = @section AND u.username = USER_NAME() AND u.is_active = 1

IF @member_id IS NULL
    RETURN

;MERGE dbo27.translations t
USING
    (
    SELECT company_id = @company_id, 9 AS table_id, @member_id AS member_id, @language AS language, @name AS name
    ) s ON s.company_id = t.company_id AND s.table_id = t.table_id AND s.member_id = t.member_id AND s.language = t.language
WHEN MATCHED AND NOT COALESCE(t.name, '') = COALESCE(s.name, '') THEN
    UPDATE SET name = s.name
WHEN NOT MATCHED THEN
    INSERT (company_id, table_id, member_id, language, name) VALUES (s.company_id, s.table_id, s.member_id, s.language, s.name);

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Imports report_sections
-- =============================================

CREATE PROCEDURE [dbo27].[usp_import_report_sections]
    @company nvarchar(50) = NULL
    , @report_type_id tinyint = NULL
    , @section int = NULL
    , @row_format int = NULL
    , @ref_number int = NULL
    , @code nvarchar(50)
    , @description nvarchar(255)
    , @section_type_id tinyint = NULL
    , @inverse_sign bit = NULL
    , @hide_items bit = NULL
    , @show_line bit = NULL
    , @show_line_before bit = NULL
    , @show_line_after bit = NULL
    , @page_break_before bit = NULL
AS
BEGIN

SET NOCOUNT ON

DECLARE @company_id int

SELECT TOP 1 @company_id = c.id FROM dbo27.companies c INNER JOIN dbo27.users u ON u.company_id = c.id  WHERE c.code = @company AND u.username = USER_NAME() AND u.is_active = 1 AND u.is_admin = 1

IF @company_id IS NULL
    RETURN

UPDATE dbo27.report_sections
SET
    row_format = @row_format
    , ref_number = @ref_number
    , code = @code
    , description = @description
    , section_type_id = @section_type_id
    , inverse_sign = COALESCE(@inverse_sign, 0)
    , hide_items = @hide_items
    , show_line = @show_line
    , show_line_before = @show_line_before
    , show_line_after = @show_line_after
    , page_break_before = @page_break_before
WHERE
    company_id = @company_id
    AND report_type_id = @report_type_id
    AND section = @section

IF @@ROWCOUNT = 0
INSERT INTO dbo27.report_sections
    ( company_id
    , report_type_id
    , row_format
    , section
    , ref_number
    , code
    , description
    , section_type_id
    , inverse_sign
    , hide_items
    , show_line
    , show_line_before
    , show_line_after
    , page_break_before
    )
VALUES
    ( @company_id
    , @report_type_id
    , @row_format
    , @section
    , @ref_number
    , @code
    , @description
    , @section_type_id
    , COALESCE(@inverse_sign, 0)
    , @hide_items
    , @show_line
    , @show_line_before
    , @show_line_after
    , @page_break_before
    )

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Imports saved_report_types
-- =============================================

CREATE PROCEDURE [dbo27].[usp_import_saved_report_types]
    @company nvarchar(50)
    , @code nvarchar(50)
    , @name nvarchar(100)
AS
BEGIN

SET NOCOUNT ON

DECLARE @company_id int

SELECT TOP 1 @company_id = c.id FROM dbo27.companies c INNER JOIN dbo27.users u ON u.company_id = c.id  WHERE c.code = @company AND u.username = USER_NAME() AND u.is_active = 1 AND u.is_admin = 1

IF @company_id IS NULL
    RETURN

UPDATE dbo27.saved_report_types
SET
    name = @name
WHERE
    company_id = @company_id
    AND code = @code

IF @@ROWCOUNT = 0
    INSERT INTO dbo27.saved_report_types
        ( company_id
        , code
        , name
        )
    VALUES
        ( @company_id
        , @code
        , @name
        )

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Imports budget reports
-- =============================================

CREATE PROCEDURE [dbo27].[usp_import_saved_reports]
    @company nvarchar(50) = NULL
    , @type_code nvarchar(50) = NULL
    , @category_code nvarchar(50) = NULL
    , @time_code nvarchar(50) = NULL
    , @row_index int = NULL
    , @id1 nvarchar(50) = NULL
    , @id2 int = NULL
    , @ref_number int = NULL
    , @report int = NULL
    , @row_level int = NULL
    , @row_format int = NULL
    , @hide int = NULL
    , @zero int = NULL
    , @code1 nvarchar(50) = NULL
    , @code2 nvarchar(50) = NULL
    , @code nvarchar(50) = NULL
    , @description nvarchar(255) = NULL
    , @data00 float = NULL
    , @data01 float = NULL
    , @data02 float = NULL
    , @data03 float = NULL
    , @data04 float = NULL
    , @data05 float = NULL
    , @data06 float = NULL
    , @data07 float = NULL
    , @data08 float = NULL
    , @data09 float = NULL
    , @data10 float = NULL
    , @data11 float = NULL
    , @data12 float = NULL
    , @transaction_start_time datetime = NULL
AS
BEGIN

SET NOCOUNT ON

DECLARE @company_id int

SELECT TOP 1 @company_id = c.id FROM dbo27.companies c INNER JOIN dbo27.users u ON u.company_id = c.id  WHERE c.code = @company AND u.username = USER_NAME() AND u.is_active = 1 AND u.is_admin = 1

IF @company_id IS NULL
    RETURN

DECLARE @type_id int = (SELECT id FROM dbo27.saved_report_types WHERE company_id = @company_id AND code = @type_code)
DECLARE @category_id int = (SELECT id FROM dbo27.members WHERE company_id = @company_id AND code = @category_code)
DECLARE @time_id int = (SELECT id FROM dbo27.members WHERE company_id = @company_id AND code = @time_code)

IF @type_id IS NULL OR @category_id IS NULL OR @time_id IS NULL
    RETURN

UPDATE dbo27.saved_reports
SET
    id1 = @id1
    , id2 = @id2
    , ref_number = @ref_number
    , report = @report
    , row_level = @row_level
    , row_format = @row_format
    , hide = @hide
    , zero = @zero
    , code1 = @code1
    , code2 = @code2
    , code = @code
    , description = @description
    , data00 = @data00
    , data01 = @data01
    , data02 = @data02
    , data03 = @data03
    , data04 = @data04
    , data05 = @data05
    , data06 = @data06
    , data07 = @data07
    , data08 = @data08
    , data09 = @data09
    , data10 = @data10
    , data11 = @data11
    , data12 = @data12
    , transaction_start_time = @transaction_start_time
WHERE
    type_id = @type_id
    AND category_id = @category_id
    AND time_id = @time_id
    AND row_index = @row_index

IF @@ROWCOUNT = 0
INSERT INTO dbo27.saved_reports
    ( type_id
    , category_id
    , time_id
    , row_index
    , id1
    , id2
    , ref_number
    , report
    , row_level
    , row_format
    , hide
    , zero
    , code1
    , code2
    , code
    , description
    , data00
    , data01
    , data02
    , data03
    , data04
    , data05
    , data06
    , data07
    , data08
    , data09
    , data10
    , data11
    , data12
    , transaction_start_time
    )
VALUES
    ( @type_id
    , @category_id
    , @time_id
    , @row_index
    , @id1
    , @id2
    , @ref_number
    , @report
    , @row_level
    , @row_format
    , @hide
    , @zero
    , @code1
    , @code2
    , @code
    , @description
    , @data00
    , @data01
    , @data02
    , @data03
    , @data04
    , @data05
    , @data06
    , @data07
    , @data08
    , @data09
    , @data10
    , @data11
    , @data12
    , @transaction_start_time
    )


END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Imports subsidiary_groups
-- =============================================

CREATE PROCEDURE [dbo27].[usp_import_subsidiary_groups]
    @company nvarchar(50)
    , @code nvarchar(50)
    , @name nvarchar(100)
AS
BEGIN

SET NOCOUNT ON

DECLARE @company_id int

SELECT TOP 1 @company_id = c.id FROM dbo27.companies c INNER JOIN dbo27.users u ON u.company_id = c.id  WHERE c.code = @company AND u.username = USER_NAME() AND u.is_active = 1 AND u.is_admin = 1

IF @company_id IS NULL
    RETURN

UPDATE dbo27.subsidiary_groups
SET
    name = @name
WHERE
    company_id = @company_id
    AND code = @code

IF @@ROWCOUNT = 0
    INSERT INTO dbo27.subsidiary_groups
        ( company_id
        , code
        , name
        )
    VALUES
        ( @company_id
        , @code
        , @name
        )

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Imports translations
-- =============================================

CREATE PROCEDURE [dbo27].[usp_import_translations]
    @company nvarchar(50)
    , @table nvarchar(50) = NULL
    , @member nvarchar(50) = NULL
    , @language varchar(10)
    , @name nvarchar(100) = NULL
AS
BEGIN

SET NOCOUNT ON

IF @language IS NULL
    RETURN

DECLARE @company_id int

SELECT TOP 1 @company_id = c.id FROM dbo27.companies c INNER JOIN dbo27.users u ON u.company_id = c.id  WHERE c.code = @company AND u.username = USER_NAME() AND u.is_active = 1 AND u.is_admin = 1

IF @company_id IS NULL
    RETURN

DECLARE @table_id tinyint = (SELECT TOP 1 t.id FROM dbo27.translated_tables t WHERE t.code = @table)

DECLARE @member_id int

IF @table_id = 1
    SELECT TOP 1 @member_id = t.id FROM dbo27.members t INNER JOIN dbo27.users u ON u.company_id = t.company_id  WHERE t.company_id = @company_id AND t.code = @member AND u.username = USER_NAME() AND u.is_active = 1
ELSE IF @table_id = 2
    SET @member_id = @company_id
ELSE IF @table_id = 3
    SELECT TOP 1 @member_id = t.id FROM dbo27.units t INNER JOIN dbo27.users u ON u.company_id = t.company_id  WHERE t.company_id = @company_id AND t.code = @member AND u.username = USER_NAME() AND u.is_active = 1
ELSE IF @table_id = 4
    SELECT TOP 1 @member_id = t.id FROM dbo27.vat_rates t INNER JOIN dbo27.users u ON u.company_id = t.company_id  WHERE t.company_id = @company_id AND t.code = @member AND u.username = USER_NAME() AND u.is_active = 1
ELSE IF @table_id = 10
    SELECT TOP 1 @member_id = t.id FROM dbo27.subsidiary_groups t INNER JOIN dbo27.users u ON u.company_id = t.company_id  WHERE t.company_id = @company_id AND t.code = @member AND u.username = USER_NAME() AND u.is_active = 1
ELSE IF @table_id = 11
    SELECT TOP 1 @member_id = t.id FROM dbo27.ledger_accounts t INNER JOIN dbo27.users u ON u.company_id = t.company_id  WHERE t.company_id = @company_id AND t.code = @member AND u.username = USER_NAME() AND u.is_active = 1
ELSE IF @table_id = 12
    SELECT TOP 1 @member_id = t.id FROM dbo27.saved_report_types t INNER JOIN dbo27.users u ON u.company_id = t.company_id  WHERE t.company_id = @company_id AND t.code = @member AND u.username = USER_NAME() AND u.is_active = 1
ELSE
    RETURN

IF @member_id IS NULL
    RETURN

;MERGE dbo27.translations t
USING
    (
    SELECT company_id = @company_id, @table_id AS table_id, @member_id AS member_id, @language AS language, @name AS name
    ) s ON s.company_id = t.company_id AND s.table_id = t.table_id AND s.member_id = t.member_id AND s.language = t.language
WHEN MATCHED AND NOT COALESCE(t.name, '') = COALESCE(s.name, '') THEN
    UPDATE SET name = s.name
WHEN NOT MATCHED THEN
    INSERT (company_id, table_id, member_id, language, name) VALUES (s.company_id, s.table_id, s.member_id, s.language, s.name);

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Imports units
-- =============================================

CREATE PROCEDURE [dbo27].[usp_import_units]
    @company nvarchar(50)
    , @code nvarchar(50)
    , @name nvarchar(100)
    , @sort_order int = NULL
    , @factor float = NULL
    , @is_currency bit = NULL
    , @is_functional_currency bit = NULL
    , @is_base_currency bit = NULL
    , @is_translatable bit = NULL
    , @is_active bit = NULL
AS
BEGIN

SET NOCOUNT ON

DECLARE @company_id int

SELECT TOP 1 @company_id = c.id FROM dbo27.companies c INNER JOIN dbo27.users u ON u.company_id = c.id  WHERE c.code = @company AND u.username = USER_NAME() AND u.is_active = 1 AND u.is_admin = 1

IF @company_id IS NULL
    RETURN

UPDATE dbo27.units
SET
    name = @name
    , sort_order = COALESCE(@sort_order, 0)
    , factor = COALESCE(@factor, 1)
    , is_currency = COALESCE(@is_currency, 1)
    , is_functional_currency = COALESCE(@is_functional_currency, 0)
    , is_base_currency = COALESCE(@is_base_currency, 0)
    , is_translatable = COALESCE(@is_translatable, 1)
    , is_active = COALESCE(@is_active, 1)
WHERE
    company_id = @company_id
    AND code = @code

IF @@ROWCOUNT = 0
    INSERT INTO dbo27.units
        ( company_id
        , code
        , name
        , sort_order
        , factor
        , is_currency
        , is_functional_currency
        , is_base_currency
        , is_translatable
        , is_active
        )
    VALUES
        ( @company_id
        , @code
        , @name
        , COALESCE(@sort_order, 0)
        , COALESCE(@factor, 1)
        , COALESCE(@is_currency, 1)
        , COALESCE(@is_functional_currency, 1)
        , COALESCE(@is_base_currency, 0)
        , COALESCE(@is_translatable, 1)
        , COALESCE(@is_active, 1)
        )

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Imports users
-- =============================================

CREATE PROCEDURE [dbo27].[usp_import_users]
    @company nvarchar(50) = NULL
    , @username nvarchar(128)
    , @name nvarchar(100)
    , @is_admin bit = NULL
    , @is_default bit = NULL
    , @is_active bit = NULL
AS
BEGIN

SET NOCOUNT ON

DECLARE @company_id int

SELECT TOP 1 @company_id = c.id FROM dbo27.companies c INNER JOIN dbo27.users u ON u.company_id = c.id  WHERE c.code = @company AND u.username = USER_NAME() AND u.is_active = 1 AND u.is_admin = 1

IF @company_id IS NULL
    RETURN

UPDATE dbo27.users
SET
    name = @name
    , is_admin = COALESCE(@is_admin, 0)
    , is_default = COALESCE(@is_default, 0)
    , is_active = COALESCE(@is_active, 1)
WHERE
    company_id = @company_id
    AND username = @username

IF @@ROWCOUNT = 0
    INSERT INTO dbo27.users
        (company_id, username, name, is_admin, is_default, is_active)
    VALUES
        (@company_id, @username, @name, COALESCE(@is_admin, 0), COALESCE(@is_default, 0), COALESCE(@is_active, 1))

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Imports tax rates
-- =============================================

CREATE PROCEDURE [dbo27].[usp_import_vat_rates]
    @company nvarchar(50) = NULL
    , @code nvarchar(50)
    , @name nvarchar(100)
    , @sort_order tinyint = NULL
    , @factor float = NULL
    , @is_translatable bit = NULL
    , @is_active bit = NULL
AS
BEGIN

SET NOCOUNT ON

DECLARE @company_id int

SELECT TOP 1 @company_id = c.id FROM dbo27.companies c INNER JOIN dbo27.users u ON u.company_id = c.id  WHERE c.code = @company AND u.username = USER_NAME() AND u.is_active = 1 AND u.is_admin = 1

IF @company_id IS NULL
    RETURN

UPDATE dbo27.vat_rates
SET
    name = @name
    , sort_order = @sort_order
    , factor = @factor
    , is_translatable = COALESCE(@is_translatable, 1)
    , is_active = COALESCE(@is_active, 1)
WHERE
    company_id = @company_id
    AND code = @code

IF @@ROWCOUNT = 0
    INSERT INTO dbo27.vat_rates (company_id, code, name, sort_order, factor, is_translatable, is_active)
        VALUES (@company_id, @code, @name, @sort_order, @factor, COALESCE(@is_translatable, 1), COALESCE(@is_active, 1))

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Sets permissions of Database Help Framework roles
-- =============================================

CREATE PROCEDURE [dbo27].[xl_actions_set_doc_role_permissions]
AS
BEGIN

SET NOCOUNT ON

DECLARE @sql nvarchar(max)

IF USER_ID('doc_readers') IS NOT NULL
    BEGIN
    EXEC sp_addrolemember 'doc_writers',    'budgeting_app_developers';

    SET @sql ='
GRANT VIEW DEFINITION ON ROLE::doc_readers TO budgeting_app_developers;
GRANT VIEW DEFINITION ON ROLE::doc_writers TO budgeting_app_developers;
'
    EXEC (@sql);
    END

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Sets permissions of  on Change Tracking Framework roles
-- =============================================

CREATE PROCEDURE [dbo27].[xl_actions_set_log_role_permissions]
AS
BEGIN

SET NOCOUNT ON

DECLARE @sql nvarchar(max)

IF USER_ID('log_users') IS NOT NULL
    BEGIN
    EXEC sp_addrolemember 'log_admins',     'budgeting_app_developers';
    EXEC sp_addrolemember 'log_users',      'budgeting_app_admins';
    EXEC sp_addrolemember 'log_users',      'budgeting_app_accountants';
    EXEC sp_addrolemember 'log_users',      'budgeting_app_analysts';

    SET @sql ='
GRANT VIEW DEFINITION ON ROLE::log_admins   TO budgeting_app_developers;
GRANT VIEW DEFINITION ON ROLE::log_users    TO budgeting_app_developers;
'
    EXEC (@sql);
    END


END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Sets permissions of the budgeting application roles
-- =============================================

CREATE PROCEDURE [dbo27].[xl_actions_set_role_permissions]
WITH EXECUTE AS OWNER
AS
BEGIN

SET NOCOUNT ON

DECLARE @sql nvarchar(max)

EXEC sp_addrolemember 'xls_developers',     'budgeting_app';

EXEC sp_addrolemember 'xls_users',          'budgeting_app_admins';
EXEC sp_addrolemember 'xls_formats',        'budgeting_app_admins';
EXEC sp_addrolemember 'xls_developers',     'budgeting_app_developers';
EXEC sp_addrolemember 'xls_users',          'budgeting_app_accountants';
EXEC sp_addrolemember 'xls_formats',        'budgeting_app_accountants';
EXEC sp_addrolemember 'xls_users',          'budgeting_app_analysts';
EXEC sp_addrolemember 'xls_formats',        'budgeting_app_analysts';
EXEC sp_addrolemember 'xls_users',          'budgeting_app_users';

IF USER_ID('xls_admins') IS NOT NULL
    BEGIN
    EXEC sp_addrolemember 'xls_admins', 'budgeting_app_admins';
    END

GRANT ALTER, VIEW DEFINITION ON ROLE::budgeting_app_admins      TO budgeting_app_developers;
GRANT ALTER, VIEW DEFINITION ON ROLE::budgeting_app_accountants TO budgeting_app_developers;
GRANT ALTER, VIEW DEFINITION ON ROLE::budgeting_app_analysts    TO budgeting_app_developers;
GRANT ALTER, VIEW DEFINITION ON ROLE::budgeting_app_developers  TO budgeting_app_developers;
GRANT ALTER, VIEW DEFINITION ON ROLE::budgeting_app_users       TO budgeting_app_developers;

GRANT VIEW DEFINITION ON ROLE::xls_users                        TO budgeting_app_developers;
GRANT VIEW DEFINITION ON ROLE::xls_developers                   TO budgeting_app_developers;
GRANT VIEW DEFINITION ON ROLE::xls_formats                      TO budgeting_app_developers;

GRANT VIEW DEFINITION ON ROLE::budgeting_app_users              TO budgeting_app_admins;
GRANT VIEW DEFINITION ON ROLE::budgeting_app_accountants        TO budgeting_app_admins;

GRANT EXECUTE ON SCHEMA::dbo27                                  TO budgeting_app_developers;
GRANT SELECT, EXECUTE ON SCHEMA::xls27                          TO budgeting_app_developers;

GRANT SELECT  ON xls27.xl_automatic_handlers                    TO budgeting_app_admins;
GRANT SELECT  ON xls27.xl_online_help_handlers                  TO budgeting_app_admins;

GRANT EXECUTE ON xls27.usp_companies                            TO budgeting_app_admins;
GRANT EXECUTE ON xls27.usp_companies_insert                     TO budgeting_app_admins;
GRANT EXECUTE ON xls27.usp_companies_update                     TO budgeting_app_admins;
GRANT EXECUTE ON xls27.usp_companies_delete                     TO budgeting_app_admins;

GRANT EXECUTE ON xls27.usp_users                                TO budgeting_app_admins;
GRANT EXECUTE ON xls27.usp_users_insert                         TO budgeting_app_admins;
GRANT EXECUTE ON xls27.usp_users_update                         TO budgeting_app_admins;
GRANT EXECUTE ON xls27.usp_users_delete                         TO budgeting_app_admins;

GRANT EXECUTE ON xls27.usp_member_permissions                   TO budgeting_app_admins;
GRANT EXECUTE ON xls27.usp_member_permissions_change            TO budgeting_app_admins;

GRANT EXECUTE ON xls27.usp_actual_closed_periods                TO budgeting_app_admins;
GRANT EXECUTE ON xls27.usp_actual_closed_periods_change         TO budgeting_app_admins;

GRANT EXECUTE ON xls27.usp_budget_closed_periods                TO budgeting_app_admins;
GRANT EXECUTE ON xls27.usp_budget_closed_periods_change         TO budgeting_app_admins;

GRANT EXECUTE ON xls27.usp_role_members                         TO budgeting_app_admins;
GRANT EXECUTE ON xls27.usp_role_members_change                  TO budgeting_app_admins;

GRANT EXECUTE ON xls27.xl_parameter_values_company_id           TO budgeting_app_admins;
GRANT EXECUTE ON xls27.xl_parameter_values_dimension_id         TO budgeting_app_admins;
GRANT EXECUTE ON xls27.xl_parameter_values_username             TO budgeting_app_admins;

GRANT SELECT  ON xls27.xl_automatic_handlers                            TO budgeting_app_users;
GRANT SELECT  ON xls27.xl_online_help_handlers                          TO budgeting_app_users;

GRANT EXECUTE ON xls27.usp_budget_request1                              TO budgeting_app_users;
GRANT EXECUTE ON xls27.usp_budget_request1_delete                       TO budgeting_app_users;
GRANT EXECUTE ON xls27.usp_budget_request1_insert                       TO budgeting_app_users;
GRANT EXECUTE ON xls27.usp_budget_request1_update                       TO budgeting_app_users;
GRANT EXECUTE ON xls27.usp_budget_request2                              TO budgeting_app_users;
GRANT EXECUTE ON xls27.usp_budget_request2_delete                       TO budgeting_app_users;
GRANT EXECUTE ON xls27.usp_budget_request2_insert                       TO budgeting_app_users;
GRANT EXECUTE ON xls27.usp_budget_request2_update                       TO budgeting_app_users;

GRANT EXECUTE ON xls27.xl_actions_select_members                        TO budgeting_app_users;

GRANT EXECUTE ON xls27.xl_parameter_values_category_id                  TO budgeting_app_users;
GRANT EXECUTE ON xls27.xl_parameter_values_category_id_not_null         TO budgeting_app_users;
GRANT EXECUTE ON xls27.xl_parameter_values_company_id                   TO budgeting_app_users;
GRANT EXECUTE ON xls27.xl_parameter_values_currency_id                  TO budgeting_app_users;
GRANT EXECUTE ON xls27.xl_parameter_values_day                          TO budgeting_app_users;
GRANT EXECUTE ON xls27.xl_parameter_values_entity_id                    TO budgeting_app_users;
GRANT EXECUTE ON xls27.xl_parameter_values_entity_id_not_null           TO budgeting_app_users;
GRANT EXECUTE ON xls27.xl_parameter_values_month                        TO budgeting_app_users;
GRANT EXECUTE ON xls27.xl_parameter_values_subsidiary_account_id        TO budgeting_app_users;
GRANT EXECUTE ON xls27.xl_parameter_values_subsidiary_group_id          TO budgeting_app_users;
GRANT EXECUTE ON xls27.xl_parameter_values_time_id                      TO budgeting_app_users;
GRANT EXECUTE ON xls27.xl_parameter_values_time_id_not_null             TO budgeting_app_users;
GRANT EXECUTE ON xls27.xl_parameter_values_year                         TO budgeting_app_users;

GRANT EXECUTE ON xls27.xl_validation_list_budgeting_account_id_code     TO budgeting_app_users;
GRANT EXECUTE ON xls27.xl_validation_list_currency_id                   TO budgeting_app_users;
GRANT EXECUTE ON xls27.xl_validation_list_currency_id_code              TO budgeting_app_users;
GRANT EXECUTE ON xls27.xl_validation_list_entity_id                     TO budgeting_app_users;
GRANT EXECUTE ON xls27.xl_validation_list_entity_id_code                TO budgeting_app_users;
GRANT EXECUTE ON xls27.xl_validation_list_product_id                    TO budgeting_app_users;
GRANT EXECUTE ON xls27.xl_validation_list_product_id_code               TO budgeting_app_users;
GRANT EXECUTE ON xls27.xl_validation_list_region_id                     TO budgeting_app_users;
GRANT EXECUTE ON xls27.xl_validation_list_region_id_code                TO budgeting_app_users;
GRANT EXECUTE ON xls27.xl_validation_list_subsidiary_account_id         TO budgeting_app_users;
GRANT EXECUTE ON xls27.xl_validation_list_subsidiary_account_id_code    TO budgeting_app_users;
GRANT EXECUTE ON xls27.xl_validation_list_unit_id                       TO budgeting_app_users;
GRANT EXECUTE ON xls27.xl_validation_list_unit_id_code                  TO budgeting_app_users;
GRANT EXECUTE ON xls27.xl_validation_list_vat_rate_id                   TO budgeting_app_users;

GRANT SELECT  ON xls27.xl_automatic_handlers                            TO budgeting_app_analysts;
GRANT SELECT  ON xls27.xl_online_help_handlers                          TO budgeting_app_analysts;

GRANT EXECUTE ON xls27.usp_actual_balances                              TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_actual_balances_delete                       TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_actual_balances_insert                       TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_actual_balances_update                       TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_actual_closed_periods                        TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_actual_currency_rates                        TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_actual_reports                               TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_balance_sheet_trial                          TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_budget_balances                              TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_budget_balances_delete                       TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_budget_balances_insert                       TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_budget_balances_update                       TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_budget_closed_periods                        TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_budget_closed_periods_change                 TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_budget_currency_rates                        TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_budget_currency_rates_delete                 TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_budget_currency_rates_insert                 TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_budget_currency_rates_update                 TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_budget_data                                  TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_budget_journal                               TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_budget_reports                               TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_budget_reports_raw                           TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_budget_request1                              TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_budget_request1_delete                       TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_budget_request1_insert                       TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_budget_request1_update                       TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_budget_request2                              TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_budget_request2_delete                       TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_budget_request2_insert                       TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_budget_request2_update                       TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_budget_requests                              TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_budget_requests_totals                       TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_budgeting_accounts                           TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_budgeting_accounts_delete                    TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_budgeting_accounts_insert                    TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_budgeting_accounts_update                    TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_journal                                      TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_journal_delete                               TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_journal_insert                               TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_journal_update                               TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_ledger_accounts                              TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_ledger_accounts_delete                       TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_ledger_accounts_insert                       TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_ledger_accounts_update                       TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_member_relations                             TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_member_relations_change                      TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_members                                      TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_members_delete                               TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_members_insert                               TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_members_update                               TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_report_sections                              TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_report_sections_delete                       TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_report_sections_insert                       TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_report_sections_update                       TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_saved_report_types                           TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_saved_report_types_delete                    TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_saved_report_types_insert                    TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_saved_report_types_update                    TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_saved_reports                                TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_saved_reports_delete                         TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_saved_reports_insert                         TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_saved_reports_update                         TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_subsidiary_accounts                          TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_subsidiary_accounts_delete                   TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_subsidiary_accounts_insert                   TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_subsidiary_accounts_update                   TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_subsidiary_groups                            TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_subsidiary_groups_delete                     TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_subsidiary_groups_insert                     TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_subsidiary_groups_update                     TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_translations                                 TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_translations_change                          TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_translations_common                          TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_translations_xls                             TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_translations_xls_change                      TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_units                                        TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_units_delete                                 TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_units_insert                                 TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_units_update                                 TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_users                                        TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_vat_rates                                    TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_vat_rates_delete                             TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_vat_rates_insert                             TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.usp_vat_rates_update                             TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.xl_actions_actual_report_cell_data               TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.xl_actions_budget_report_cell_data               TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.xl_actions_select_members                        TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.xl_parameter_values_category_id                  TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.xl_parameter_values_category_id_not_null         TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.xl_parameter_values_company_id                   TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.xl_parameter_values_currency_id                  TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.xl_parameter_values_day                          TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.xl_parameter_values_dimension_id                 TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.xl_parameter_values_dimension_id_not_null        TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.xl_parameter_values_entity_id                    TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.xl_parameter_values_entity_id_not_null           TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.xl_parameter_values_ledger_account_id_code       TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.xl_parameter_values_member_type_id               TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.xl_parameter_values_month                        TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.xl_parameter_values_report_type_id               TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.xl_parameter_values_report_type_id_code          TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.xl_parameter_values_saved_report_type_id         TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.xl_parameter_values_subsidiary_account_id        TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.xl_parameter_values_subsidiary_group_id          TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.xl_parameter_values_time_id                      TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.xl_parameter_values_time_id_not_null             TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.xl_parameter_values_username                     TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.xl_parameter_values_year                         TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.xl_validation_list_budgeting_account_id_code     TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.xl_validation_list_budgeting_account_type_id     TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.xl_validation_list_budgeting_parent_id_code      TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.xl_validation_list_credit_account_id_code        TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.xl_validation_list_credit_subsidiary_account_id  TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.xl_validation_list_currency_id                   TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.xl_validation_list_currency_id_code              TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.xl_validation_list_debit_account_id_code         TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.xl_validation_list_debit_subsidiary_account_id   TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.xl_validation_list_dimension_id                  TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.xl_validation_list_entity_id                     TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.xl_validation_list_entity_id_code                TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.xl_validation_list_ledger_account_id             TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.xl_validation_list_ledger_account_id_code        TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.xl_validation_list_ledger_account_type_id        TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.xl_validation_list_member_type_id                TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.xl_validation_list_product_id                    TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.xl_validation_list_product_id_code               TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.xl_validation_list_region_id                     TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.xl_validation_list_region_id_code                TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.xl_validation_list_report_section_id             TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.xl_validation_list_report_section_type_id        TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.xl_validation_list_report_type_id_code           TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.xl_validation_list_subsidiary_account_id         TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.xl_validation_list_subsidiary_account_id_code    TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.xl_validation_list_subsidiary_group_id           TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.xl_validation_list_unit_id                       TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.xl_validation_list_unit_id_code                  TO budgeting_app_analysts;
GRANT EXECUTE ON xls27.xl_validation_list_vat_rate_id                   TO budgeting_app_analysts;

GRANT SELECT  ON xls27.xl_automatic_handlers                            TO budgeting_app_accountants;
GRANT SELECT  ON xls27.xl_online_help_handlers                          TO budgeting_app_accountants;

GRANT EXECUTE ON xls27.usp_actual_balances                              TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.usp_actual_balances_delete                       TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.usp_actual_balances_insert                       TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.usp_actual_balances_update                       TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.usp_actual_closed_periods                        TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.usp_actual_closed_periods_change                 TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.usp_actual_currency_rates                        TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.usp_actual_currency_rates_delete                 TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.usp_actual_currency_rates_insert                 TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.usp_actual_currency_rates_update                 TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.usp_actual_reports                               TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.usp_balance_sheet_trial                          TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.usp_budget_journal                               TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.usp_budgeting_accounts                           TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.usp_journal                                      TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.usp_journal_delete                               TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.usp_journal_insert                               TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.usp_journal_update                               TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.usp_ledger_accounts                              TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.usp_ledger_accounts_delete                       TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.usp_ledger_accounts_insert                       TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.usp_ledger_accounts_update                       TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.usp_members                                      TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.usp_members_delete                               TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.usp_members_insert                               TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.usp_members_update                               TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.usp_subsidiary_accounts                          TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.usp_subsidiary_accounts_delete                   TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.usp_subsidiary_accounts_insert                   TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.usp_subsidiary_accounts_update                   TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.usp_subsidiary_groups                            TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.usp_subsidiary_groups_delete                     TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.usp_subsidiary_groups_insert                     TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.usp_subsidiary_groups_update                     TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.usp_units                                        TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.usp_vat_rates                                    TO budgeting_app_accountants;

GRANT EXECUTE ON xls27.xl_actions_auto_calc_all                         TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.xl_actions_select_members                        TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.xl_actions_actual_report_cell_data               TO budgeting_app_accountants;

GRANT EXECUTE ON xls27.xl_parameter_values_category_id                  TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.xl_parameter_values_category_id_not_null         TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.xl_parameter_values_company_id                   TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.xl_parameter_values_currency_id                  TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.xl_parameter_values_day                          TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.xl_parameter_values_dimension_id                 TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.xl_parameter_values_dimension_id_not_null        TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.xl_parameter_values_entity_id                    TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.xl_parameter_values_entity_id_not_null           TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.xl_parameter_values_ledger_account_id_code       TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.xl_parameter_values_month                        TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.xl_parameter_values_member_type_id               TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.xl_parameter_values_report_type_id               TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.xl_parameter_values_report_type_id_code          TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.xl_parameter_values_saved_report_type_id         TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.xl_parameter_values_subsidiary_account_id        TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.xl_parameter_values_subsidiary_group_id          TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.xl_parameter_values_time_id                      TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.xl_parameter_values_time_id_not_null             TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.xl_parameter_values_year                         TO budgeting_app_accountants;

GRANT EXECUTE ON xls27.xl_validation_list_budgeting_account_id_code     TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.xl_validation_list_budgeting_account_type_id     TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.xl_validation_list_budgeting_parent_id_code      TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.xl_validation_list_credit_account_id_code        TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.xl_validation_list_credit_subsidiary_account_id  TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.xl_validation_list_currency_id                   TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.xl_validation_list_currency_id_code              TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.xl_validation_list_debit_account_id_code         TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.xl_validation_list_debit_subsidiary_account_id   TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.xl_validation_list_dimension_id                  TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.xl_validation_list_entity_id                     TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.xl_validation_list_entity_id_code                TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.xl_validation_list_entry_side_id                 TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.xl_validation_list_ledger_account_id             TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.xl_validation_list_ledger_account_id_code        TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.xl_validation_list_ledger_account_type_id        TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.xl_validation_list_member_type_id                TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.xl_validation_list_product_id                    TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.xl_validation_list_product_id_code               TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.xl_validation_list_region_id                     TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.xl_validation_list_region_id_code                TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.xl_validation_list_report_section_id             TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.xl_validation_list_report_section_type_id        TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.xl_validation_list_report_type_id_code           TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.xl_validation_list_subsidiary_account_id         TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.xl_validation_list_subsidiary_account_id_code    TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.xl_validation_list_subsidiary_group_id           TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.xl_validation_list_unit_id                       TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.xl_validation_list_unit_id_code                  TO budgeting_app_accountants;
GRANT EXECUTE ON xls27.xl_validation_list_vat_rate_id                   TO budgeting_app_accountants;

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: The procedure selects actual_balances
-- =============================================

CREATE PROCEDURE [xls27].[usp_actual_balances]
    @company_id int = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

;WITH parents (id, parent_id) AS (
    SELECT
        a.id
        , a.id
    FROM
        dbo27.ledger_accounts a
        INNER JOIN dbo27.ledger_account_types t ON t.id = a.account_type_id
    WHERE
        a.company_id = @company_id
        AND COALESCE(t.is_pl, 0) = 0

    UNION ALL
    SELECT
        p.id
        , a.parent_id
    FROM
        parents p
        INNER JOIN dbo27.ledger_accounts a ON a.id = p.parent_id
    WHERE
        a.parent_id IS NOT NULL
        AND NOT p.id = a.parent_id
)

SELECT
    t.id
    , t.account_id
    , t.subsidiary_account_id
    , CASE WHEN lat.bs_sign = -1 THEN 0 WHEN s.id IS NOT NULL THEN 1 WHEN a.id IS NULL OR a.subsidiary_group_id IS NOT NULL OR p.parent_id IS NOT NULL THEN 0 ELSE 1 END AS is_debit_editable
    , CASE WHEN lat.bs_sign = 1  THEN 0 WHEN s.id IS NOT NULL THEN 1 WHEN a.id IS NULL OR a.subsidiary_group_id IS NOT NULL OR p.parent_id IS NOT NULL THEN 0 ELSE 1 END AS is_credit_editable
    , CASE WHEN p.parent_id IS NULL THEN 0 ELSE 1 END AS is_parent
    , a.code AS code
    , COALESCE(tr2.name, s.name) AS subsidiary_name
    , COALESCE('    ' + COALESCE(tr2.name, s.name), CASE WHEN a.parent_id IS NULL THEN '' ELSE '  ' END + COALESCE(tr1.name, a.name), 'Total') AS name
    , c.name AS currency
    , CASE WHEN s.id IS NOT NULL THEN t.debit WHEN a.id IS NULL OR a.subsidiary_group_id IS NOT NULL OR p.parent_id IS NOT NULL THEN NULL ELSE t.debit END AS debit
    , CASE WHEN s.id IS NOT NULL THEN t.credit WHEN a.id IS NULL OR a.subsidiary_group_id IS NOT NULL OR p.parent_id IS NOT NULL THEN NULL ELSE t.credit END AS credit
    , t.debit$
    , t.credit$
FROM
    (
        -- Accounts * subsidiary_accounts

        SELECT
            b.id
            , a.id AS account_id
            , s.id AS subsidiary_account_id
            , b.debit
            , b.credit
            , b.debit$
            , b.credit$
        FROM
            dbo27.ledger_accounts a
            INNER JOIN dbo27.member_groups g ON g.group_id = a.subsidiary_group_id
            INNER JOIN dbo27.members s ON s.id = g.member_id
            INNER JOIN dbo27.ledger_account_types t ON t.id = a.account_type_id
            LEFT OUTER JOIN dbo27.actual_balances b ON b.account_id = a.id AND b.subsidiary_account_id = s.id
        WHERE
            a.company_id = @company_id
            AND t.is_pl = 0

        -- Parent actual_balances

        UNION ALL
        SELECT
            NULL AS id
            , p.parent_id AS account_id
            , NULL AS subsidiary_account_id
            , SUM(b.debit) AS debit
            , SUM(b.credit) AS credit
            , SUM(b.debit$) AS debit$
            , SUM(b.credit$) AS credit$
        FROM
            parents p
            LEFT OUTER JOIN dbo27.actual_balances b ON b.account_id = p.id
        GROUP BY
            p.parent_id

        -- Totals

        UNION ALL
        SELECT
            NULL AS id
            , NULL AS account_id
            , NULL AS subsidiary_account_id
            , NULL AS debit
            , NULL AS credit
            , SUM(b.debit$) AS debit$
            , SUM(b.credit$) AS credit$
        FROM
            dbo27.actual_balances b
            INNER JOIN dbo27.ledger_accounts a ON a.id = b.account_id
        WHERE
            a.company_id = @company_id
    ) t
    LEFT OUTER JOIN dbo27.ledger_accounts a ON a.id = t.account_id
    LEFT JOIN dbo27.ledger_account_types lat ON lat.id = a.account_type_id
    LEFT OUTER JOIN dbo27.members s ON s.id = t.subsidiary_account_id
    LEFT OUTER JOIN dbo27.units c ON c.id = s.unit_id
    LEFT OUTER JOIN (
        SELECT DISTINCT a.parent_id FROM dbo27.ledger_accounts a WHERE a.company_id = @company_id
    ) p ON p.parent_id = a.id
    LEFT OUTER JOIN dbo27.translations tr1 ON tr1.company_id = a.company_id AND tr1.table_id = 11 AND tr1.member_id = a.id AND tr1.language = @data_language
    LEFT OUTER JOIN dbo27.translations tr2 ON tr2.company_id = s.company_id AND tr2.table_id = 1 AND tr2.member_id = s.id AND tr2.language = @data_language
ORDER BY
    a.code
    , s.name

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: The procedure deleted data from dbo27.actual_balances
-- =============================================

CREATE PROCEDURE [xls27].[usp_actual_balances_delete]
    @account_id int
    , @subsidiary_account_id int = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

DECLARE @company_id int = NULL

SET @company_id = (SELECT TOP 1 a.company_id FROM dbo27.ledger_accounts a INNER JOIN dbo27.users u ON u.company_id = a.company_id WHERE a.id = @account_id AND u.username = USER_NAME() AND u.is_active = 1)

IF @company_id IS NULL
    RETURN

DECLARE @message nvarchar(max)

IF EXISTS(SELECT TOP 1 p.is_closed FROM dbo27.actual_closed_periods p WHERE p.is_closed = 1 AND p.date < (SELECT MIN(date) FROM dbo27.journals WHERE company_id = @company_id))
    BEGIN
    SET @message = dbo27.get_translated_string('The period is closed for changes', @data_language)
    RAISERROR (@message, 11, 0)
    RETURN
    END

SET NOCOUNT OFF

DELETE FROM dbo27.actual_balances
WHERE
    account_id = @account_id
    AND COALESCE(subsidiary_account_id, -1) = COALESCE(@subsidiary_account_id, -1)

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: The procedure updates data of dbo27.actual_balances
-- =============================================

CREATE PROCEDURE [xls27].[usp_actual_balances_update]
    @account_id int
    , @subsidiary_account_id int = NULL
    , @debit float = NULL
    , @credit float = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

IF @account_id IS NULL
    RETURN

DECLARE @company_id int = NULL

SET @company_id = (SELECT TOP 1 a.company_id FROM dbo27.ledger_accounts a INNER JOIN dbo27.users u ON u.company_id = a.company_id WHERE a.id = @account_id AND u.username = USER_NAME() AND u.is_active = 1)

IF @subsidiary_account_id IS NOT NULL AND
    NOT EXISTS (SELECT id FROM dbo27.members WHERE id = @subsidiary_account_id AND company_id = @company_id)
    RETURN

DECLARE @message nvarchar(max)

IF EXISTS(SELECT TOP 1 p.is_closed FROM dbo27.actual_closed_periods p WHERE p.is_closed = 1 AND p.date < (SELECT MIN(date) FROM dbo27.journals WHERE company_id = @company_id))
    BEGIN
    SET @message = dbo27.get_translated_string('The period is closed for changes', @data_language)
    RAISERROR (@message, 11, 0)
    RETURN
    END

DECLARE @currency_id int = (SELECT m.unit_id FROM dbo27.members m INNER JOIN dbo27.units u ON u.id = m.unit_id WHERE m.id = @subsidiary_account_id AND u.is_functional_currency = 0)

DECLARE @balance money = COALESCE(@debit, 0) - COALESCE(@credit, 0)

IF @balance = 0
    BEGIN
    DELETE dbo27.actual_balances
    WHERE
        account_id = @account_id
        AND COALESCE(subsidiary_account_id, -1) = COALESCE(@subsidiary_account_id, -1)
    RETURN
    END

DECLARE @balance$ money = @balance

DECLARE @rate float

IF @currency_id IS NOT NULL
    BEGIN

    SELECT @rate = rate FROM dbo27.actual_currency_rates WHERE currency_id = @currency_id
        AND date = (SELECT MIN(date) FROM dbo27.actual_currency_rates WHERE currency_id = @currency_id)

    SELECT
        @balance$ = ROUND(@balance * CASE WHEN is_base_currency = 0 OR @rate = 0 THEN COALESCE(@rate, 1.0) ELSE 1.0 / COALESCE(@rate, 1.0) END, 2)
    FROM
        dbo27.units
    WHERE
        id = @currency_id

    END

SET NOCOUNT OFF

UPDATE dbo27.actual_balances
SET
    account_id = @account_id
    , subsidiary_account_id = @subsidiary_account_id
    , balance = @balance
    , balance$ = COALESCE(@balance$, @balance)
WHERE
    account_id = @account_id
    AND COALESCE(subsidiary_account_id, -1) = COALESCE(@subsidiary_account_id, -1)

IF @@ROWCOUNT = 0
INSERT INTO dbo27.actual_balances
    ( account_id
    , subsidiary_account_id
    , balance
    , balance$
    )
VALUES
    ( @account_id
    , @subsidiary_account_id
    , @balance
    , COALESCE(@balance$, @balance)
    )

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: The procedure inserts data into dbo27.actual_balances
-- =============================================

CREATE PROCEDURE [xls27].[usp_actual_balances_insert]
    @account_id int
    , @subsidiary_account_id int = NULL
    , @debit float = NULL
    , @credit float = NULL
AS
BEGIN

SET NOCOUNT ON

EXEC xls27.usp_actual_balances_update @account_id, @subsidiary_account_id, @debit, @credit

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Selects rows to set closed periods
-- =============================================

CREATE PROCEDURE [xls27].[usp_actual_closed_periods]
    @company_id int = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

;WITH e1(n) AS
(
    SELECT 0 UNION ALL SELECT 1 UNION ALL SELECT 2 UNION ALL SELECT 3 UNION ALL SELECT 4 UNION ALL
    SELECT 5 UNION ALL SELECT 6 UNION ALL SELECT 7 UNION ALL SELECT 8 UNION ALL SELECT 9
),
e2(n) AS (SELECT d.n * 10 + e1.n FROM e1 d CROSS JOIN e1),
e3(n) AS (SELECT c.n * 100 + e2.n FROM e1 c CROSS JOIN e2)

SELECT
    DATEADD(MONTH, e3.n, '2019-01-01') AS date
    , CAST(COALESCE(is_closed, 0) AS bit) AS is_closed
FROM
    e3
    LEFT OUTER JOIN dbo27.actual_closed_periods p ON p.date = DATEADD(MONTH, e3.n, '2019-01-01') AND p.company_id = @company_id
WHERE
    e3.n < 132
    AND DATEADD(MONTH, e3.n, '2019-01-01') BETWEEN
        (SELECT DATEADD(MONTH, DATEDIFF(MONTH, 0, MIN(date)), 0) FROM dbo27.journals WHERE company_id = @company_id) AND GETDATE()
ORDER BY
    e3.n

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Cell change event handler for usp_closed_periods
-- =============================================

CREATE PROCEDURE [xls27].[usp_actual_closed_periods_change]
    @column_name nvarchar(128) = NULL
    , @cell_number_value int = NULL
    , @company_id int = NULL
    , @date date = NULL
AS
BEGIN

SET NOCOUNT ON

DECLARE @message nvarchar(max)

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

IF @date IS NULL OR @company_id IS NULL OR NOT @column_name = 'is_closed'
    RETURN

DECLARE @value bit = CASE WHEN COALESCE(@cell_number_value, 0) > 0 THEN 1 ELSE 0 END

SET @date = DATEADD(D, 1 - DATEPART(D, @date), @date)

SET NOCOUNT OFF

UPDATE dbo27.actual_closed_periods SET is_closed = @value WHERE date = @date AND company_id = @company_id

IF @@ROWCOUNT = 0
    INSERT dbo27.actual_closed_periods (date, company_id, is_closed) VALUES (@date, @company_id, @value)


END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: The procedure selects data from dbo27.actual_currency_rates
-- =============================================

CREATE PROCEDURE [xls27].[usp_actual_currency_rates]
    @company_id int = NULL
    , @currency_id int = NULL
AS
BEGIN

SET NOCOUNT ON

SELECT
    t.date
    , t.rate
    , t.is_checked
FROM
    dbo27.actual_currency_rates t
    INNER JOIN dbo27.units c ON c.id = t.currency_id
    INNER JOIN dbo27.users u ON u.company_id = c.company_id AND u.username = USER_NAME() AND u.is_active = 1
WHERE
    t.currency_id = @currency_id
ORDER BY
    t.date DESC

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: The procedure deletes data from dbo27.actual_currency_rates
-- =============================================

CREATE PROCEDURE [xls27].[usp_actual_currency_rates_delete]
    @currency_id tinyint = NULL
    , @date date = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

DECLARE @company_id int

SELECT TOP 1 @company_id = t.company_id FROM dbo27.units t INNER JOIN dbo27.users u ON u.company_id = t.company_id  WHERE t.id = @currency_id AND u.username = USER_NAME() AND u.is_active = 1

IF @company_id IS NULL
    RETURN

DECLARE @message nvarchar(max)

IF (SELECT p.is_closed FROM dbo27.actual_closed_periods p WHERE p.date = DATEADD(D, 1 - DATEPART(d, @date), @date) AND p.company_id = @company_id) = 1
    BEGIN
    SET @message = dbo27.get_translated_string('The period is closed for changes', @data_language)
    RAISERROR (@message, 11, 0)
    RETURN
    END

IF EXISTS(
    SELECT
        TOP 1 j.id
    FROM
        dbo27.journals j
        LEFT OUTER JOIN dbo27.members ds ON ds.id = j.debit_subsidiary_account_id AND ds.unit_id = @currency_id
        LEFT OUTER JOIN dbo27.members cs ON cs.id = j.credit_subsidiary_account_id AND ds.unit_id = @currency_id
    WHERE
        j.date = @date
    )
    BEGIN
    DECLARE @date_string nvarchar(20) = CAST(@date AS nvarchar)
    SET @message = dbo27.get_translated_string('The journal has operations on %s', @data_language)
    RAISERROR (@message, 11, 0, @date_string)
    RETURN
    END

SET NOCOUNT OFF

DELETE FROM dbo27.actual_currency_rates WHERE currency_id = @currency_id AND date = @date

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: The procedure updates data of dbo27.actual_currency_rates
-- =============================================

CREATE PROCEDURE [xls27].[usp_actual_currency_rates_update]
    @currency_id int = NULL
    , @date date = NULL
    , @rate smallmoney = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

DECLARE @company_id int

SELECT TOP 1 @company_id = t.company_id FROM dbo27.units t INNER JOIN dbo27.users u ON u.company_id = t.company_id  WHERE t.id = @currency_id AND u.username = USER_NAME() AND u.is_active = 1

IF @company_id IS NULL
    RETURN

DECLARE @message nvarchar(max)

IF @date IS NULL OR @rate IS NULL
    RETURN

IF NOT EXISTS (SELECT id FROM dbo27.units WHERE id = @currency_id AND is_currency = 1 AND is_functional_currency = 0)
    RETURN

IF (SELECT p.is_closed FROM dbo27.actual_closed_periods p WHERE p.date = DATEADD(D, 1 - DATEPART(d, @date), @date) AND p.company_id = @company_id) = 1
    BEGIN
    SET @message = dbo27.get_translated_string('The period is closed for changes', @data_language)
    RAISERROR (@message, 11, 0)
    RETURN
    END

DECLARE @current_rate smallmoney
DECLARE @is_checked bit

SELECT @current_rate = rate, @is_checked = is_checked FROM dbo27.actual_currency_rates WHERE currency_id = @currency_id AND date = @date

IF @current_rate IS NULL
    BEGIN
    INSERT INTO dbo27.actual_currency_rates (currency_id, date, rate, is_checked)
    VALUES (@currency_id, @date, @rate, 1)
    RETURN
    END
ELSE IF @current_rate = @rate AND @is_checked = 1
    RETURN
ELSE IF @current_rate = @rate
    BEGIN
    UPDATE dbo27.actual_currency_rates
    SET
        is_checked = 1
    WHERE
        currency_id = @currency_id
        AND date = @date
        AND NOT (
            COALESCE(is_checked, 0) = 1
            )
    RETURN
    END

UPDATE dbo27.actual_currency_rates
SET
      rate = @rate
    , is_checked = 1
WHERE
    currency_id = @currency_id
    AND date = @date
    AND NOT (
        COALESCE(rate, -1) = COALESCE(@rate, -2)
        AND COALESCE(is_checked, -1) = 1
        )

DECLARE @is_base_currency bit = (SELECT is_base_currency FROM dbo27.units WHERE id = @currency_id)

DECLARE @rate_factor float = CASE WHEN @is_base_currency = 0 OR @rate = 0 THEN COALESCE(@rate, 1.0) ELSE 1.0 / COALESCE(@rate, 1.0) END

UPDATE dbo27.journals
SET
    amount$ = ROUND(amount * @rate_factor, 2)
FROM
    dbo27.journals j
    LEFT OUTER JOIN dbo27.members ds ON ds.id = j.debit_subsidiary_account_id
    LEFT OUTER JOIN dbo27.members cs ON cs.id = j.credit_subsidiary_account_id
WHERE
    j.date = @date
    AND (ds.unit_id = @currency_id OR cs.unit_id = @currency_id)
    AND j.auto_type_id = 0
    AND NOT (
        COALESCE(amount$, -1) = COALESCE(ROUND(amount * @rate_factor, 2), -2)
        )

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: The procedure inserts data into dbo27.actual_currency_rates
-- =============================================

CREATE PROCEDURE [xls27].[usp_actual_currency_rates_insert]
    @currency_id int = NULL
    , @date date = NULL
    , @rate smallmoney = NULL
AS
BEGIN

SET NOCOUNT ON

EXEC xls27.usp_actual_currency_rates_update @currency_id, @date, @rate

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: The procedure selects actual financial reports
-- =============================================

CREATE PROCEDURE [xls27].[usp_actual_reports]
    @company_id int = NULL
    , @year int = NULL
    , @entity_id int = NULL
    , @report_id int = NULL
    , @unit int = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

DECLARE @start_date date
DECLARE @end_date date

SET @start_date = DATEFROMPARTS(COALESCE(@year, YEAR(GETDATE())), 1, 1)
SET @end_date = DATEFROMPARTS(COALESCE(@year, YEAR(GETDATE())), 12, 31)

-- Factor like 1, 0.001, or 0.000001

DECLARE @factor float = 1.0 / COALESCE(@unit, 1)

;WITH b1 AS (

    -- This section converts raw records to entry sides and data by month

    SELECT
        CASE WHEN s.id = 1 THEN j.debit_account_id ELSE j.credit_account_id END AS ledger_account_id
        , CASE WHEN s.id = 1 THEN j.debit_subsidiary_account_id ELSE j.credit_subsidiary_account_id END AS subsidiary_account_id
        , CASE WHEN s.id = 1 THEN j.credit_account_id ELSE j.debit_account_id END AS pair_account_id
        , s.id AS entry_side_id
        , NULL AS data00
        , CASE WHEN DATEPART(M, j.date) = 01 THEN j.amount$ ELSE NULL END AS data01
        , CASE WHEN DATEPART(M, j.date) = 02 THEN j.amount$ ELSE NULL END AS data02
        , CASE WHEN DATEPART(M, j.date) = 03 THEN j.amount$ ELSE NULL END AS data03
        , CASE WHEN DATEPART(M, j.date) = 04 THEN j.amount$ ELSE NULL END AS data04
        , CASE WHEN DATEPART(M, j.date) = 05 THEN j.amount$ ELSE NULL END AS data05
        , CASE WHEN DATEPART(M, j.date) = 06 THEN j.amount$ ELSE NULL END AS data06
        , CASE WHEN DATEPART(M, j.date) = 07 THEN j.amount$ ELSE NULL END AS data07
        , CASE WHEN DATEPART(M, j.date) = 08 THEN j.amount$ ELSE NULL END AS data08
        , CASE WHEN DATEPART(M, j.date) = 09 THEN j.amount$ ELSE NULL END AS data09
        , CASE WHEN DATEPART(M, j.date) = 10 THEN j.amount$ ELSE NULL END AS data10
        , CASE WHEN DATEPART(M, j.date) = 11 THEN j.amount$ ELSE NULL END AS data11
        , CASE WHEN DATEPART(M, j.date) = 12 THEN j.amount$ ELSE NULL END AS data12
    FROM
        dbo27.journals j
        CROSS JOIN dbo27.entry_sides s
    WHERE
        j.company_id = @company_id
        AND j.date BETWEEN @start_date AND @end_date
        AND COALESCE(j.entity_id, -1) = COALESCE(@entity_id, j.entity_id, -1)

    -- This section converts raw records to entries and selects balance00, dr, cr on ledger and subsidiary accounts

    UNION ALL
    SELECT
        b.account_id AS ledger_account_id
        , b.subsidiary_account_id
        , NULL AS pair_account_id
        , s.id AS entry_side_id
        , CASE WHEN s.id = 1 AND b.balance$ > 0 THEN b.balance$ WHEN s.id = 2 AND b.balance$ < 0 THEN b.balance$ ELSE NULL END AS data00
        , NULL AS data01, NULL AS data02, NULL AS data03, NULL AS data04, NULL AS data05, NULL AS data06, NULL AS data07, NULL AS data08, NULL AS data09, NULL AS data10, NULL AS data11, NULL AS data12
    FROM
        dbo27.actual_balances b
        INNER JOIN dbo27.ledger_accounts a ON a.id = b.account_id
        CROSS JOIN dbo27.entry_sides s
    WHERE
        a.company_id = @company_id
        AND (s.id = 1 AND balance$ > 0 OR s.id = 2 AND balance$ < 0)
        AND @entity_id IS NULL
)

, c1 AS (

    -- This section aggregates data by a report section, account, subsidiary account, and a value type

    SELECT
        rsa.section_type_id
        , CASE WHEN rst.hide_accounts = 1 THEN NULL ELSE b1.ledger_account_id END ledger_account_id
        , CASE WHEN rsa.value_type_id IN (3, 4) THEN b1.subsidiary_account_id ELSE NULL END AS subsidiary_account_id
        , rsa.value_type_id
        , SUM(rsa.value_sign * data00) AS data00
        , SUM(rsa.value_sign * data01) AS data01
        , SUM(rsa.value_sign * data02) AS data02
        , SUM(rsa.value_sign * data03) AS data03
        , SUM(rsa.value_sign * data04) AS data04
        , SUM(rsa.value_sign * data05) AS data05
        , SUM(rsa.value_sign * data06) AS data06
        , SUM(rsa.value_sign * data07) AS data07
        , SUM(rsa.value_sign * data08) AS data08
        , SUM(rsa.value_sign * data09) AS data09
        , SUM(rsa.value_sign * data10) AS data10
        , SUM(rsa.value_sign * data11) AS data11
        , SUM(rsa.value_sign * data12) AS data12
    FROM
        b1
        INNER JOIN dbo27.ledger_accounts a ON a.id = b1.ledger_account_id
        LEFT OUTER JOIN dbo27.ledger_accounts p ON p.id = b1.pair_account_id
        INNER JOIN dbo27.report_section_accounts rsa ON rsa.account_type_id = a.account_type_id AND rsa.entry_side_id = b1.entry_side_id
        INNER JOIN dbo27.report_section_types rst ON rst.id = rsa.section_type_id
        LEFT OUTER JOIN dbo27.ledger_accounts c ON c.id = b1.pair_account_id
    WHERE
        rst.report_type_id = COALESCE(@report_id, rst.report_type_id)
        AND (rsa.pair_account_type_id IS NULL OR rsa.pair_account_type_id = c.account_type_id)
        AND (p.id IS NULL OR NOT p.account_type_id = 150)
    GROUP BY
        rsa.section_type_id
        , CASE WHEN rst.hide_accounts = 1 THEN NULL ELSE b1.ledger_account_id END
        , CASE WHEN rsa.value_type_id IN (3, 4) THEN b1.subsidiary_account_id END
        , rsa.value_type_id
)

, c2 AS (

    -- This section calculates flow and balance values

    SELECT
        section_type_id
        , ledger_account_id
        , subsidiary_account_id
        , value_type_id
        , CASE WHEN value_type_id = 1 THEN NULL ELSE data00 END AS data00
        , CASE WHEN value_type_id = 1 THEN data01 ELSE COALESCE(data00, 0) + COALESCE(data01, 0) END AS data01
        , CASE WHEN value_type_id = 1 THEN data02 ELSE COALESCE(data00, 0) + COALESCE(data01, 0) + COALESCE(data02, 0) END AS data02
        , CASE WHEN value_type_id = 1 THEN data03 ELSE COALESCE(data00, 0) + COALESCE(data01, 0) + COALESCE(data02, 0) + COALESCE(data03, 0) END AS data03
        , CASE WHEN value_type_id = 1 THEN data04 ELSE COALESCE(data00, 0) + COALESCE(data01, 0) + COALESCE(data02, 0) + COALESCE(data03, 0) + COALESCE(data04, 0) END AS data04
        , CASE WHEN value_type_id = 1 THEN data05 ELSE COALESCE(data00, 0) + COALESCE(data01, 0) + COALESCE(data02, 0) + COALESCE(data03, 0) + COALESCE(data04, 0) + COALESCE(data05, 0) END AS data05
        , CASE WHEN value_type_id = 1 THEN data06 ELSE COALESCE(data00, 0) + COALESCE(data01, 0) + COALESCE(data02, 0) + COALESCE(data03, 0) + COALESCE(data04, 0) + COALESCE(data05, 0) + COALESCE(data06, 0) END AS data06
        , CASE WHEN value_type_id = 1 THEN data07 ELSE COALESCE(data00, 0) + COALESCE(data01, 0) + COALESCE(data02, 0) + COALESCE(data03, 0) + COALESCE(data04, 0) + COALESCE(data05, 0) + COALESCE(data06, 0) + COALESCE(data07, 0) END AS data07
        , CASE WHEN value_type_id = 1 THEN data08 ELSE COALESCE(data00, 0) + COALESCE(data01, 0) + COALESCE(data02, 0) + COALESCE(data03, 0) + COALESCE(data04, 0) + COALESCE(data05, 0) + COALESCE(data06, 0) + COALESCE(data07, 0) + COALESCE(data08, 0) END AS data08
        , CASE WHEN value_type_id = 1 THEN data09 ELSE COALESCE(data00, 0) + COALESCE(data01, 0) + COALESCE(data02, 0) + COALESCE(data03, 0) + COALESCE(data04, 0) + COALESCE(data05, 0) + COALESCE(data06, 0) + COALESCE(data07, 0) + COALESCE(data08, 0) + COALESCE(data09, 0) END AS data09
        , CASE WHEN value_type_id = 1 THEN data10 ELSE COALESCE(data00, 0) + COALESCE(data01, 0) + COALESCE(data02, 0) + COALESCE(data03, 0) + COALESCE(data04, 0) + COALESCE(data05, 0) + COALESCE(data06, 0) + COALESCE(data07, 0) + COALESCE(data08, 0) + COALESCE(data09, 0) + COALESCE(data10, 0) END AS data10
        , CASE WHEN value_type_id = 1 THEN data11 ELSE COALESCE(data00, 0) + COALESCE(data01, 0) + COALESCE(data02, 0) + COALESCE(data03, 0) + COALESCE(data04, 0) + COALESCE(data05, 0) + COALESCE(data06, 0) + COALESCE(data07, 0) + COALESCE(data08, 0) + COALESCE(data09, 0) + COALESCE(data10, 0) + COALESCE(data11, 0) END AS data11
        , CASE WHEN value_type_id = 1 THEN data12 ELSE COALESCE(data00, 0) + COALESCE(data01, 0) + COALESCE(data02, 0) + COALESCE(data03, 0) + COALESCE(data04, 0) + COALESCE(data05, 0) + COALESCE(data06, 0) + COALESCE(data07, 0) + COALESCE(data08, 0) + COALESCE(data09, 0) + COALESCE(data10, 0) + COALESCE(data11, 0) + COALESCE(data12, 0) END AS data12
    FROM
        c1
)

, c3 AS (

    -- This section calculates debit and credit balances. It removes value_type_id

    SELECT
        section_type_id
        , ledger_account_id
        , subsidiary_account_id
        , CASE WHEN value_type_id = 3 AND data00 < 0 THEN NULL WHEN value_type_id = 4 AND data00 > 0 THEN NULL ELSE data00 END AS data00
        , CASE WHEN value_type_id = 3 AND data01 < 0 THEN NULL WHEN value_type_id = 4 AND data01 > 0 THEN NULL ELSE data01 END AS data01
        , CASE WHEN value_type_id = 3 AND data02 < 0 THEN NULL WHEN value_type_id = 4 AND data02 > 0 THEN NULL ELSE data02 END AS data02
        , CASE WHEN value_type_id = 3 AND data03 < 0 THEN NULL WHEN value_type_id = 4 AND data03 > 0 THEN NULL ELSE data03 END AS data03
        , CASE WHEN value_type_id = 3 AND data04 < 0 THEN NULL WHEN value_type_id = 4 AND data04 > 0 THEN NULL ELSE data04 END AS data04
        , CASE WHEN value_type_id = 3 AND data05 < 0 THEN NULL WHEN value_type_id = 4 AND data05 > 0 THEN NULL ELSE data05 END AS data05
        , CASE WHEN value_type_id = 3 AND data06 < 0 THEN NULL WHEN value_type_id = 4 AND data06 > 0 THEN NULL ELSE data06 END AS data06
        , CASE WHEN value_type_id = 3 AND data07 < 0 THEN NULL WHEN value_type_id = 4 AND data07 > 0 THEN NULL ELSE data07 END AS data07
        , CASE WHEN value_type_id = 3 AND data08 < 0 THEN NULL WHEN value_type_id = 4 AND data08 > 0 THEN NULL ELSE data08 END AS data08
        , CASE WHEN value_type_id = 3 AND data09 < 0 THEN NULL WHEN value_type_id = 4 AND data09 > 0 THEN NULL ELSE data09 END AS data09
        , CASE WHEN value_type_id = 3 AND data10 < 0 THEN NULL WHEN value_type_id = 4 AND data10 > 0 THEN NULL ELSE data10 END AS data10
        , CASE WHEN value_type_id = 3 AND data11 < 0 THEN NULL WHEN value_type_id = 4 AND data11 > 0 THEN NULL ELSE data11 END AS data11
        , CASE WHEN value_type_id = 3 AND data12 < 0 THEN NULL WHEN value_type_id = 4 AND data12 > 0 THEN NULL ELSE data12 END AS data12
    FROM
        c2
)

, c4 AS (

    -- This section aggregates data by a report section and accounts
    -- The data contains the correct values for flows, balances, debit balances and credit balances
    -- It removes the subsidiary account

    SELECT
        section_type_id
        , ledger_account_id
        , SUM(data00) AS data00
        , SUM(data01) AS data01
        , SUM(data02) AS data02
        , SUM(data03) AS data03
        , SUM(data04) AS data04
        , SUM(data05) AS data05
        , SUM(data06) AS data06
        , SUM(data07) AS data07
        , SUM(data08) AS data08
        , SUM(data09) AS data09
        , SUM(data10) AS data10
        , SUM(data11) AS data11
        , SUM(data12) AS data12
    FROM
        c3
    GROUP BY
        section_type_id
        , ledger_account_id
)

, factors (id, parent_id, is_parent) AS (

    -- This section selects child-parent factors for report sections

    SELECT
        rs.id
        , rs.id AS parent_id
        , COALESCE(rs.hide_items, 0) AS is_parent
    FROM
        dbo27.report_sections rs
    WHERE
        rs.company_id = @company_id
        AND rs.report_type_id = COALESCE(@report_id, rs.report_type_id)

    UNION ALL
    SELECT
        rs.id
        , rs.parent2_id
        , 1 AS is_parent
    FROM
        dbo27.report_sections rs
    WHERE
        rs.company_id = @company_id
        AND rs.report_type_id = COALESCE(@report_id, rs.report_type_id)
        AND rs.parent2_id IS NOT NULL

    UNION ALL
    SELECT
        f.id
        , rs.parent_id
        , 1 AS is_parent
    FROM
        factors f
        INNER JOIN dbo27.report_sections rs ON rs.id = f.parent_id
    WHERE
        rs.parent_id IS NOT NULL
        AND NOT f.id = rs.parent_id
)

, report_rows AS (

    -- This section multiplies section rows by factors and calculates totals by section and ledger account
    -- It also adds empty sections to show report headers
    -- Also it selects the total_type_id of the report sections

    SELECT
        section_id
        , ledger_account_id
        , MAX(total_type_id) AS total_type_id
        , SUM(data00) AS data00, SUM(data01) AS data01, SUM(data02) AS data02, SUM(data03) AS data03, SUM(data04) AS data04, SUM(data05) AS data05, SUM(data06) AS data06, SUM(data07) AS data07, SUM(data08) AS data08, SUM(data09) AS data09, SUM(data10) AS data10, SUM(data11) AS data11, SUM(data12) AS data12
        , SUM(data_rows) AS data_rows
    FROM
        (
        SELECT
            f.parent_id AS section_id
            , CASE WHEN f.is_parent = 1 THEN NULL ELSE r.ledger_account_id END AS ledger_account_id
            , rst.total_type_id
            , data00, data01, data02, data03, data04, data05, data06, data07, data08, data09, data10, data11, data12
            , 1 AS data_rows
        FROM
            c4 r
            INNER JOIN dbo27.report_sections rs ON rs.section_type_id = r.section_type_id
            INNER JOIN dbo27.report_section_types rst ON rst.id = rs.section_type_id
            INNER JOIN factors f ON f.id = rs.id
        WHERE
            rs.company_id = @company_id

        -- Adding report rows to show even without values

        UNION ALL
        SELECT
            rs.id AS section_id
            , NULL AS ledger_account_id
            , NULL AS total_type_id
            , NULL AS data00, NULL AS data01, NULL AS data02, NULL AS data03, NULL AS data04, NULL AS data05, NULL AS data06, NULL AS data07, NULL AS data08, NULL AS data09, NULL AS data10, NULL AS data11, NULL AS data12
            , NULL AS data_rows
        FROM
            dbo27.report_sections rs
        WHERE
            rs.company_id = @company_id
            AND rs.report_type_id = COALESCE(@report_id, rs.report_type_id)
            AND COALESCE(rs.show_line, 1) = 1
            AND rs.section_type_id IS NULL
        ) r
    GROUP BY
        section_id
        , ledger_account_id
)

, result AS (

    -- Main report output

    SELECT
        row_index
        , ref_number
        , code AS account
        , report
        , page_break
        , CAST(NULL AS int) AS row_level
        , row_format
        , 1 AS hide
        , CASE WHEN data00 <> 0 OR  data01 <> 0 OR  data02 <> 0 OR  data03 <> 0 OR  data04 <> 0 OR  data05 <> 0 OR  data06 <> 0 OR  data07 <> 0 OR  data08 <> 0 OR  data09 <> 0 OR  data10 <> 0 OR  data11 <> 0 OR  data12 <> 0 THEN 1 ELSE 0 END AS zero
        , CAST(NULL AS nvarchar(50)) AS code1
        , CAST(NULL AS nvarchar(50)) AS code2
        , code
        , name
        , CASE total_type_id
            WHEN 2 THEN data00
            WHEN 3 THEN data12
            WHEN 0 THEN NULL
            ELSE COALESCE(data01, 0) + COALESCE(data02, 0) + COALESCE(data03, 0) + COALESCE(data04, 0) + COALESCE(data05, 0) + COALESCE(data06, 0) + COALESCE(data07, 0) + COALESCE(data08, 0) + COALESCE(data09, 0) + COALESCE(data10, 0) + COALESCE(data11, 0) + COALESCE(data12, 0) END AS data00
        , data01, data02, data03, data04, data05, data06, data07, data08, data09, data10, data11, data12
    FROM
        (
            SELECT
                ROW_NUMBER() OVER (ORDER BY rs.report_type_id, rs.section, v.r, la.code, la.name) AS row_index
                , CASE WHEN v.r = 0 THEN rs.ref_number + COALESCE(la.ref_number, 0) ELSE NULL END AS ref_number
                , rs.report_type_id AS report
                , CASE WHEN rs.page_break_before IS NULL THEN NULL
                    WHEN rs.show_line_before = 1 AND v.r = -1 THEN 1
                    WHEN COALESCE(rs.show_line_before, 0) = 0 AND v.r = 0 THEN 1
                    ELSE NULL END AS page_break
                , CASE WHEN rs.row_format = 9 AND v.r = -1 THEN 8 WHEN v.r = -1 THEN NULL WHEN v.r = 1 THEN NULL
                    WHEN r.ledger_account_id IS NULL THEN rs.row_format ELSE NULL END row_format
                , CASE WHEN v.r = 0 THEN la.code ELSE NULL END AS code
                , CASE WHEN v.r = 0 THEN COALESCE(tr2.name, la.name, tr1.name, rs.description) ELSE NULL END AS name
                , CASE WHEN v.r = 0 AND data_rows > 0 THEN r.total_type_id ELSE 0 END AS total_type_id
                , data00 * @factor * f * rs.line_factor AS data00
                , data01 * @factor * f * rs.line_factor AS data01
                , data02 * @factor * f * rs.line_factor AS data02
                , data03 * @factor * f * rs.line_factor AS data03
                , data04 * @factor * f * rs.line_factor AS data04
                , data05 * @factor * f * rs.line_factor AS data05
                , data06 * @factor * f * rs.line_factor AS data06
                , data07 * @factor * f * rs.line_factor AS data07
                , data08 * @factor * f * rs.line_factor AS data08
                , data09 * @factor * f * rs.line_factor AS data09
                , data10 * @factor * f * rs.line_factor AS data10
                , data11 * @factor * f * rs.line_factor AS data11
                , data12 * @factor * f * rs.line_factor AS data12
            FROM
                report_rows r
                INNER JOIN dbo27.report_sections rs ON rs.id = r.section_id
                LEFT OUTER JOIN dbo27.ledger_accounts la ON la.id = r.ledger_account_id
                LEFT OUTER JOIN dbo27.translations tr1 ON tr1.company_id = rs.company_id AND tr1.table_id = 9 AND tr1.member_id = rs.id AND tr1.language = @data_language
                LEFT OUTER JOIN dbo27.translations tr2 ON tr2.company_id = rs.company_id AND tr2.table_id = 11 AND tr2.member_id = la.id AND tr2.language = @data_language
                CROSS JOIN (VALUES (-1, NULL), (0, 1), (1, NULL)) v(r, f)
            WHERE
                (rs.show_line = 1
                    OR (data00 <> 0 OR  data01 <> 0 OR  data02 <> 0 OR  data03 <> 0 OR  data04 <> 0 OR  data05 <> 0 OR  data06 <> 0 OR  data07 <> 0 OR  data08 <> 0 OR  data09 <> 0 OR  data10 <> 0 OR  data11 <> 0 OR  data12 <> 0)
                )
                AND (COALESCE(rs.show_line, 1) = 1 OR r.ledger_account_id IS NOT NULL)
                AND (r.ledger_account_id IS NULL OR COALESCE(rs.hide_items, 0) = 0)
                AND (v.f = 1
                    OR rs.show_line_before = 1 AND v.r = -1
                    OR rs.show_line_after = 1 AND v.r = 1
                )

        ) t
)

SELECT * FROM result ORDER BY row_index

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Turnover balance sheet
-- =============================================

CREATE PROCEDURE [xls27].[usp_balance_sheet_trial]
    @start_year int = NULL
    , @start_month int = NULL
    , @start_day int = NULL
    , @end_year int = NULL
    , @end_month int = NULL
    , @end_day int = NULL
    , @company_id int = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

DECLARE @start_date date
DECLARE @end_date date

SET @start_date = DATEFROMPARTS(COALESCE(@start_year, YEAR(GETDATE())), COALESCE(@start_month, 1), 1)
SET @end_date = DATEFROMPARTS(COALESCE(@end_year, YEAR(GETDATE())), COALESCE(@end_month, 12), 1)

IF @start_day > 1
    IF DATEADD(DAY, @start_day - 1, @start_date) < DATEADD(MONTH, 1, @start_date)
        SET @start_date = DATEADD(DAY, @start_day - 1, @start_date)
    ELSE
        SET @start_date = DATEADD(DAY, -1, DATEADD(MONTH, 1, @start_date))

IF @end_day > 1 AND DATEADD(DAY, @end_day - 1, @end_date) < DATEADD(MONTH, 1, @end_date)
    SET @end_date = DATEADD(DAY, @end_day - 1, @end_date)
ELSE
    SET @end_date = DATEADD(DAY, -1, DATEADD(MONTH, 1, @end_date))

DECLARE @system_currency nvarchar(50) = (SELECT name FROM dbo27.units WHERE company_id = @company_id AND is_functional_currency = 1)

;WITH data AS (

-- Opening actual_balances

SELECT
    NULL AS id
    , b.account_id
    , b.subsidiary_account_id
    , b.balance AS balance
    , b.balance$ AS balance$
    , NULL AS debit
    , NULL AS debit$
    , NULL AS credit
    , NULL AS credit$
FROM
    dbo27.actual_balances b
    INNER JOIN dbo27.ledger_accounts a ON a.id = b.account_id
WHERE
    a.company_id = @company_id

-- debit opening balance

UNION ALL
SELECT
    j.id
    , j.debit_account_id AS account_id
    , j.debit_subsidiary_account_id AS subsidiary_account_id
    , j.amount AS balance
    , j.amount$ AS balance$
    , NULL AS debit
    , NULL AS debit$
    , NULL AS credit
    , NULL AS credit$
FROM
    dbo27.journals j
WHERE
    j.company_id = @company_id
    AND j.[date] < @start_date

-- credit opening balance

UNION ALL
SELECT
    j.id
    , j.credit_account_id AS account_id
    , j.credit_subsidiary_account_id AS subsidiary_account_id
    , -j.amount AS balance
    , -j.amount$ AS balance$
    , NULL AS debit
    , NULL AS debit$
    , NULL AS credit
    , NULL AS credit$
FROM
    dbo27.journals j
WHERE
    j.company_id = @company_id
    AND j.[date] < @start_date

-- debit turnover

UNION ALL
SELECT
    j.id
    , j.debit_account_id AS account_id
    , j.debit_subsidiary_account_id AS subsidiary_account_id
    , NULL AS balance
    , NULL AS balance$
    , j.amount AS debit
    , j.amount$ AS debit$
    , NULL AS credit
    , NULL AS credit$
FROM
    dbo27.journals j
WHERE
    j.company_id = @company_id
    AND j.[date] BETWEEN @start_date AND @end_date

-- credit turnover

UNION ALL
SELECT
    j.id
    , j.credit_account_id AS account_id
    , j.credit_subsidiary_account_id AS subsidiary_account_id
    , NULL AS balance
    , NULL AS balance$
    , NULL AS debit
    , NULL AS debit$
    , j.amount AS credit
    , j.amount$ AS credit$
FROM
    dbo27.journals j
WHERE
    j.company_id = @company_id
    AND j.[date] BETWEEN @start_date AND @end_date
)

, subamounts AS (

SELECT
    j.account_id
    , j.subsidiary_account_id
    , SUM(j.balance) AS balance
    , SUM(j.balance$) AS balance$
    , SUM(j.debit) AS debit
    , SUM(j.debit$) AS debit$
    , SUM(j.credit) AS credit
    , SUM(j.credit$) AS credit$
FROM
    data j
GROUP BY
    j.account_id
    , j.subsidiary_account_id
)

, amounts AS (

SELECT
    j.account_id
    , j.subsidiary_account_id
    , CASE WHEN j.balance < 0 THEN NULL ELSE j.balance END AS opening_debit
    , CASE WHEN j.balance < 0 THEN -j.balance ELSE NULL END opening_credit
    , CASE WHEN j.balance$ < 0 THEN NULL ELSE j.balance$ END AS opening_debit$
    , CASE WHEN j.balance$ < 0 THEN -j.balance$ ELSE NULL END opening_credit$
    , j.debit
    , j.debit$
    , j.credit
    , j.credit$
    , CASE WHEN (COALESCE(j.balance, 0) + COALESCE(j.debit, 0) - COALESCE(j.credit, 0)) > 0 THEN COALESCE(j.balance, 0) + COALESCE(j.debit, 0) - COALESCE(j.credit, 0) ELSE NULL END AS closing_debit
    , CASE WHEN (COALESCE(j.balance, 0) + COALESCE(j.debit, 0) - COALESCE(j.credit, 0)) < 0 THEN -(COALESCE(j.balance, 0) + COALESCE(j.debit, 0) - COALESCE(j.credit, 0)) ELSE NULL END AS closing_credit
    , CASE WHEN (COALESCE(j.balance$, 0) + COALESCE(j.debit$, 0) - COALESCE(j.credit$, 0)) > 0 THEN (COALESCE(j.balance$, 0) + COALESCE(j.debit$, 0) - COALESCE(j.credit$, 0)) ELSE NULL END AS closing_debit$
    , CASE WHEN (COALESCE(j.balance$, 0) + COALESCE(j.debit$, 0) - COALESCE(j.credit$, 0)) < 0 THEN -(COALESCE(j.balance$, 0) + COALESCE(j.debit$, 0) - COALESCE(j.credit$, 0)) ELSE NULL END AS closing_credit$
FROM
    subamounts j

)

, parents (id, parent_id) AS (
    SELECT
        s.id
        , s.id
    FROM
        dbo27.ledger_accounts s
    WHERE
        s.company_id = @company_id

    UNION ALL
    SELECT
        parents.id
        , s.parent_id
    FROM
        parents
        INNER JOIN dbo27.ledger_accounts s ON s.id = parents.parent_id
    WHERE
        s.parent_id IS NOT NULL
        AND NOT parents.id = s.parent_id
)

SELECT
    j.account_id
    , j.subsidiary_account_id
    , CASE WHEN j.subsidiary_account_id IS NOT NULL THEN NULL WHEN a.parent_id IS NULL THEN 1 ELSE 2 END AS row_format
    , CASE WHEN j.subsidiary_account_id IS NOT NULL THEN 2 WHEN a.parent_id IS NULL THEN 0 ELSE 1 END AS level
    , line.n AS line
    , a.code AS code
    , COALESCE(tr2.name, s.name) AS subsidiary_name
    , COALESCE('    ' + s.name, CASE WHEN a.parent_id IS NULL THEN '' ELSE '  ' END + COALESCE(tr1.name, a.name))
        + CASE WHEN line.n = 1 THEN ' (' + COALESCE(c.name,  NULL) + ')' ELSE '' END AS name
    , CASE WHEN line.n = 1 THEN COALESCE(c.name, NULL) WHEN c.is_functional_currency = 1 THEN @system_currency ELSE NULL END AS currency
    , CASE WHEN line.n = 0 AND j.opening_debit$ IS NULL AND j.opening_credit$ IS NULL THEN NULL
           WHEN line.n = 0 THEN COALESCE(j.opening_debit$, 0) - COALESCE(j.opening_credit$, 0)
           WHEN j.opening_debit IS NULL AND j.opening_credit IS NULL THEN NULL
           ELSE COALESCE(j.opening_debit, 0) - COALESCE(j.opening_credit, 0)
           END AS opening_balance
    , CASE WHEN line.n = 0 THEN j.opening_debit$ ELSE j.opening_debit END AS opening_debit
    , CASE WHEN line.n = 0 THEN j.opening_credit$ ELSE j.opening_credit END AS opening_credit
    , CASE WHEN line.n = 0 THEN j.debit$ ELSE j.debit END AS debit_turnover
    , CASE WHEN line.n = 0 THEN j.credit$ ELSE j.credit END AS credit_turnover
    , CASE WHEN line.n = 0 AND j.closing_debit$ IS NULL AND j.closing_credit$ IS NULL THEN NULL
           WHEN line.n = 0 THEN ROUND(COALESCE(j.closing_debit$, 0) - COALESCE(j.closing_credit$, 0), 2)
           WHEN j.closing_debit IS NULL AND j.closing_credit IS NULL THEN NULL
           ELSE ROUND(COALESCE(j.closing_debit, 0) - COALESCE(j.closing_credit, 0), 2)
           END AS closing_balance
    , CASE WHEN line.n = 0 THEN ROUND(j.closing_debit$, 2) ELSE ROUND(j.closing_debit, 2) END AS closing_debit
    , CASE WHEN line.n = 0 THEN ROUND(j.closing_credit$, 2) ELSE ROUND(j.closing_credit, 2) END AS closing_credit
FROM
    (

        SELECT
            j.account_id
            , j.subsidiary_account_id
            , j.opening_debit
            , j.opening_credit
            , j.opening_debit$
            , j.opening_credit$
            , j.debit
            , j.debit$
            , j.credit
            , j.credit$
            , j.closing_debit
            , j.closing_credit
            , j.closing_debit$
            , j.closing_credit$
        FROM
            amounts j
        WHERE
            j.subsidiary_account_id IS NOT NULL

        UNION ALL

        SELECT
            p.parent_id AS account_id
            , NULL AS subsidiary_account_id
            , SUM(j.opening_debit) AS opening_debit
            , SUM(j.opening_credit) AS opening_credit
            , SUM(j.opening_debit$) AS opening_debit$
            , SUM(j.opening_credit$) AS opening_credit$
            , SUM(j.debit) AS debit
            , SUM(j.debit$) AS debit$
            , SUM(j.credit) AS credit
            , SUM(j.credit$) AS credit$
            , SUM(j.closing_debit) AS closing_debit
            , SUM(j.closing_credit) AS closing_credit
            , SUM(j.closing_debit$) AS closing_debit$
            , SUM(j.closing_credit$) AS closing_credit$
        FROM
            amounts j
            INNER JOIN parents p ON p.id = j.account_id
        GROUP BY
            p.parent_id
    ) j
    INNER JOIN dbo27.ledger_accounts a ON a.id = j.account_id
    LEFT OUTER JOIN dbo27.members s ON s.id = j.subsidiary_account_id
    LEFT OUTER JOIN dbo27.units c ON c.id = s.unit_id
    LEFT OUTER JOIN dbo27.translations tr1 ON tr1.company_id = a.company_id AND tr1.table_id = 11 AND tr1.member_id = a.id AND tr1.language = @data_language
    LEFT OUTER JOIN dbo27.translations tr2 ON tr2.company_id = s.company_id AND tr2.table_id = 1 AND tr2.member_id = s.id AND tr2.language = @data_language
    CROSS JOIN (VALUES (0), (1)) line(n)
WHERE
    (line.n = 0 OR c.is_functional_currency <> 1)
    AND (
        COALESCE(j.opening_debit, 0) <> 0
        OR COALESCE(j.opening_credit, 0) <> 0
        OR COALESCE(j.debit, 0) <> 0
        OR COALESCE(j.credit, 0) <> 0
        OR COALESCE(j.closing_debit, 0) <> 0
        OR COALESCE(j.closing_credit, 0) <> 0
        OR COALESCE(j.opening_debit$, 0) <> 0
        OR COALESCE(j.opening_credit$, 0) <> 0
        OR COALESCE(j.debit$, 0) <> 0
        OR COALESCE(j.credit$, 0) <> 0
        OR COALESCE(j.closing_debit$, 0) <> 0
        OR COALESCE(j.closing_credit$, 0) <> 0
    )
ORDER BY
    a.code
    , s.name
    , line.n


END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: The procedure selects balances
-- =============================================

CREATE PROCEDURE [xls27].[usp_budget_balances]
    @company_id int = NULL
    , @category_id int = NULL
    , @time_id int = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SELECT TOP 1 @company_id = company_id FROM dbo27.members WHERE id IN (@category_id, @time_id)

SELECT
    t.id
    , t.account_id
    , CASE WHEN lat.bs_sign = -1 THEN 0 WHEN a.id IS NULL OR p.parent_id IS NOT NULL THEN 0 ELSE 1 END AS is_debit_editable
    , CASE WHEN lat.bs_sign = 1  THEN 0 WHEN a.id IS NULL OR p.parent_id IS NOT NULL THEN 0 ELSE 1 END AS is_credit_editable
    , CASE WHEN p.parent_id IS NULL THEN 0 ELSE 1 END AS is_parent
    , t.code
    , COALESCE(tr.name, a.name, t.name) AS name
    , t.debit
    , t.credit
FROM
    (
        SELECT
            t.id
            , a.id AS account_id
            , a.code
            , a.name
            , t.debit
            , t.credit
        FROM
            dbo27.ledger_accounts a
            INNER JOIN dbo27.users u ON u.company_id = a.company_id AND u.username = USER_NAME() AND u.is_active = 1
            LEFT OUTER JOIN dbo27.budget_balances t ON t.account_id = a.id AND t.category_id = @category_id AND t.time_id = @time_id
            LEFT JOIN dbo27.ledger_account_types lat ON lat.id = a.account_type_id
        WHERE
            a.company_id = @company_id
            AND COALESCE(lat.is_pl, 0) = 0

        UNION ALL
        SELECT
            NULL
            , NULL AS account_id
            , NULL AS code
            , 'Total' AS name
            , SUM(t.debit) AS debit
            , SUM(t.credit) AS credit
        FROM
            dbo27.budget_balances t
            INNER JOIN dbo27.members m1 ON m1.id = t.category_id
            INNER JOIN dbo27.users u ON u.company_id = m1.company_id AND u.username = USER_NAME() AND u.is_active = 1
        WHERE
            t.category_id = @category_id AND t.time_id = @time_id
            AND m1.company_id = @company_id
    ) t
    LEFT OUTER JOIN dbo27.ledger_accounts a ON a.id = t.account_id
    LEFT JOIN dbo27.ledger_account_types lat ON lat.id = a.account_type_id
    LEFT OUTER JOIN (
        SELECT DISTINCT a.parent_id FROM dbo27.ledger_accounts a WHERE a.company_id = @company_id
    ) p ON p.parent_id = t.account_id
    LEFT OUTER JOIN dbo27.translations tr ON tr.company_id = @company_id AND tr.table_id = 11 AND tr.member_id = a.id AND tr.language = @data_language

ORDER BY
    code

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: The procedure deleted data from dbo27.budget_balances
-- =============================================

CREATE PROCEDURE [xls27].[usp_budget_balances_delete]
    @category_id int
    , @time_id int
    , @account_id int
AS
BEGIN

SET NOCOUNT ON

DECLARE @company_id int

SELECT TOP 1 @company_id = t.company_id FROM dbo27.members t INNER JOIN dbo27.users u ON u.company_id = t.company_id  WHERE t.id = @category_id AND u.username = USER_NAME() AND u.is_active = 1

IF @company_id IS NULL
    RETURN

SET NOCOUNT OFF

DELETE FROM dbo27.budget_balances
WHERE
    category_id = @category_id
    AND time_id = @time_id
    AND account_id = @account_id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: The procedure updates data of dbo27.budget_balances
-- =============================================

CREATE PROCEDURE [xls27].[usp_budget_balances_update]
    @category_id int
    , @time_id int
    , @account_id int
    , @debit money = NULL
    , @credit money = NULL
AS
BEGIN

SET NOCOUNT ON

IF @debit IS NULL AND @credit IS NULL
    BEGIN
    EXEC xls27.usp_budget_balances_delete @category_id, @time_id, @account_id
    RETURN
    END

DECLARE @company_id int

SELECT TOP 1 @company_id = t.company_id FROM dbo27.members t INNER JOIN dbo27.users u ON u.company_id = t.company_id  WHERE t.id = @category_id AND u.username = USER_NAME() AND u.is_active = 1

IF @company_id IS NULL
    RETURN

IF NOT EXISTS (SELECT TOP 1 id FROM dbo27.members WHERE id = @time_id AND company_id = @company_id)
    RETURN

IF NOT EXISTS (SELECT TOP 1 id FROM dbo27.ledger_accounts WHERE id = @account_id AND company_id = @company_id)
    RETURN

SET NOCOUNT OFF

UPDATE dbo27.budget_balances
SET
    category_id = @category_id
    , time_id = @time_id
    , account_id = @account_id
    , debit = @debit
    , credit = @credit
WHERE
    category_id = @category_id
    AND time_id = @time_id
    AND account_id = @account_id

IF @@ROWCOUNT = 0
INSERT INTO dbo27.budget_balances
    ( category_id
    , time_id
    , account_id
    , debit
    , credit
    )
VALUES
    ( @category_id
    , @time_id
    , @account_id
    , @debit
    , @credit
    )

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: The procedure inserts data into dbo27.budget_balances
-- =============================================

CREATE PROCEDURE [xls27].[usp_budget_balances_insert]
    @category_id int
    , @time_id int
    , @account_id int
    , @debit money = NULL
    , @credit money = NULL
AS
BEGIN

SET NOCOUNT ON

EXEC xls27.usp_budget_balances_update @category_id, @time_id, @account_id, @debit, @credit

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Selects rows to set closed periods
-- =============================================

CREATE PROCEDURE [xls27].[usp_budget_closed_periods]
    @company_id int = NULL
WITH EXECUTE AS OWNER
AS
BEGIN

SET NOCOUNT ON

EXECUTE AS CALLER

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

REVERT

DECLARE @columns nvarchar(max) = NULL

IF @company_id IS NOT NULL
    SELECT @columns = STUFF((
        SELECT
            ', [' + CAST(m.code AS nvarchar) + ']'
        FROM
            dbo27.members m
        WHERE
            m.dimension_id = 3
            AND m.is_active = 1
            AND m.company_id = @company_id
        ORDER BY
            m.sort_order
            , m.code
        FOR XML PATH(''), TYPE
    ).value('.', 'nvarchar(MAX)'), 1, 2, '')

IF @columns IS NULL
    BEGIN
    SELECT
        m.id
        , m.sort_order
        , m.code
        , m.name
        , NULL AS data_format
    FROM
        dbo27.members m
    WHERE
        m.id IS NULL
    RETURN
    END

-- PRINT @columns

DECLARE @sql nvarchar(max)

SET @sql = 'SELECT
    m.id
    , m.sort_order
    , m.code
    , m.name
    , NULL AS data_format
    , ' + @columns + '
FROM
    dbo27.members m
    LEFT OUTER JOIN (
        SELECT
            m.id
            , c.code
            , CAST(mp.update_permission AS tinyint) AS value
        FROM
            dbo27.member_relations mp
            INNER JOIN dbo27.members m ON m.id = mp.member_id
            INNER JOIN dbo27.members c ON c.id = mp.partner_id
        WHERE
            m.dimension_id = 2
            AND c.dimension_id = 3
            AND m.company_id = ' + CAST(@company_id AS nvarchar) + '
    ) s PIVOT (
        MAX(value) FOR code IN (' + @columns + ')
    ) p ON p.id = m.id
WHERE
    m.dimension_id = 2
    AND m.company_id = ' + CAST(@company_id AS nvarchar) + '
ORDER BY
    m.sort_order
    , m.code
'

-- PRINT @sql

EXEC (@sql)

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Cell change event handler for usp_closed_periods
-- =============================================

CREATE PROCEDURE [xls27].[usp_budget_closed_periods_change]
    @column_name nvarchar(128) = NULL
    , @cell_number_value int = NULL
    , @id int = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

DECLARE @message nvarchar(max)

-- Protecting non-data columns

IF @column_name IN ('id', 'sort_order', 'data_format')
    BEGIN
    SET @message = dbo27.get_translated_string('The column ''%s'' is not updatable', @data_language)
    RAISERROR (@message, 11, 0, @column_name)
    RETURN
    END

DECLARE @company_id int

SELECT TOP 1 @company_id = t.company_id FROM dbo27.members t INNER JOIN dbo27.users u ON u.company_id = t.company_id  WHERE t.id = @id AND u.username = USER_NAME() AND u.is_active = 1

IF @company_id IS NULL
    BEGIN
    SET @message = dbo27.get_translated_string('Cannot find member_id %i', @data_language)
    RAISERROR (@message, 11, 0, @id)
    RETURN
    END

DECLARE @category_code nvarchar(128) = @column_name
DECLARE @category_id int

SELECT @category_id = id FROM dbo27.members WHERE code = @category_code AND company_id = @company_id

IF @category_id IS NULL
    BEGIN
    SET @message = dbo27.get_translated_string('Cannot find member_id %s', @data_language)
    RAISERROR (@message, 11, 0, @category_code)
    RETURN
    END

DECLARE @update_permission bit = NULL

IF @cell_number_value IS NULL
    BEGIN
    DELETE FROM dbo27.member_relations WHERE member_id = @id AND partner_id = @category_id
    RETURN
    END
ELSE IF @cell_number_value = 0
    BEGIN
    SET @update_permission = 0
    END
ELSE IF @cell_number_value = 1
    BEGIN
    SET @update_permission = 1
    END
ELSE
    BEGIN
    SET @message = dbo27.get_translated_string('Unknown option: %i (Use 0 or 1)', @data_language)
    RAISERROR (@message, 11, 0, @cell_number_value)
    END

UPDATE dbo27.member_relations
SET
    update_permission = @update_permission
WHERE
    member_id = @id
    AND partner_id = @category_id

IF @@ROWCOUNT = 0
    INSERT INTO dbo27.member_relations (member_id, partner_id, update_permission)
    VALUES (@id, @category_id, @update_permission)

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: The procedure selects data from dbo27.budget_currency_rates
-- =============================================

CREATE PROCEDURE [xls27].[usp_budget_currency_rates]
    @company_id int = NULL
    , @category_id int = NULL
    , @time_id int = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

DECLARE @system_currency_code nvarchar(50) = (SELECT code FROM dbo27.units WHERE company_id = @company_id AND is_functional_currency = 1)

SELECT
    c.id AS category_id
    , p.id AS time_id
    , u.id AS unit_id
    , COALESCE(t1.name, c.name) AS category_name
    , COALESCE(t2.name, p.name) AS period_name
    , CASE WHEN u.is_base_currency = 0 THEN @system_currency_code + '/' + u.code ELSE u.code + '/' + @system_currency_code END AS pair
    , CAST(CASE WHEN u.is_base_currency = 0 OR t.balance00 = 0 THEN t.balance00 ELSE 1 / t.balance00 END AS smallmoney) AS balance00
    , CAST(CASE WHEN u.is_base_currency = 0 OR t.period01  = 0 THEN t.period01  ELSE 1 / t.period01  END AS smallmoney) AS period01
    , CAST(CASE WHEN u.is_base_currency = 0 OR t.balance01 = 0 THEN t.balance01 ELSE 1 / t.balance01 END AS smallmoney) AS balance01
    , CAST(CASE WHEN u.is_base_currency = 0 OR t.period02  = 0 THEN t.period02  ELSE 1 / t.period02  END AS smallmoney) AS period02
    , CAST(CASE WHEN u.is_base_currency = 0 OR t.balance02 = 0 THEN t.balance02 ELSE 1 / t.balance02 END AS smallmoney) AS balance02
    , CAST(CASE WHEN u.is_base_currency = 0 OR t.period03  = 0 THEN t.period03  ELSE 1 / t.period03  END AS smallmoney) AS period03
    , CAST(CASE WHEN u.is_base_currency = 0 OR t.balance03 = 0 THEN t.balance03 ELSE 1 / t.balance03 END AS smallmoney) AS balance03
    , CAST(CASE WHEN u.is_base_currency = 0 OR t.period04  = 0 THEN t.period04  ELSE 1 / t.period04  END AS smallmoney) AS period04
    , CAST(CASE WHEN u.is_base_currency = 0 OR t.balance04 = 0 THEN t.balance04 ELSE 1 / t.balance04 END AS smallmoney) AS balance04
    , CAST(CASE WHEN u.is_base_currency = 0 OR t.period05  = 0 THEN t.period05  ELSE 1 / t.period05  END AS smallmoney) AS period05
    , CAST(CASE WHEN u.is_base_currency = 0 OR t.balance05 = 0 THEN t.balance05 ELSE 1 / t.balance05 END AS smallmoney) AS balance05
    , CAST(CASE WHEN u.is_base_currency = 0 OR t.period06  = 0 THEN t.period06  ELSE 1 / t.period06  END AS smallmoney) AS period06
    , CAST(CASE WHEN u.is_base_currency = 0 OR t.balance06 = 0 THEN t.balance06 ELSE 1 / t.balance06 END AS smallmoney) AS balance06
    , CAST(CASE WHEN u.is_base_currency = 0 OR t.period07  = 0 THEN t.period07  ELSE 1 / t.period07  END AS smallmoney) AS period07
    , CAST(CASE WHEN u.is_base_currency = 0 OR t.balance07 = 0 THEN t.balance07 ELSE 1 / t.balance07 END AS smallmoney) AS balance07
    , CAST(CASE WHEN u.is_base_currency = 0 OR t.period08  = 0 THEN t.period08  ELSE 1 / t.period08  END AS smallmoney) AS period08
    , CAST(CASE WHEN u.is_base_currency = 0 OR t.balance08 = 0 THEN t.balance08 ELSE 1 / t.balance08 END AS smallmoney) AS balance08
    , CAST(CASE WHEN u.is_base_currency = 0 OR t.period09  = 0 THEN t.period09  ELSE 1 / t.period09  END AS smallmoney) AS period09
    , CAST(CASE WHEN u.is_base_currency = 0 OR t.balance09 = 0 THEN t.balance09 ELSE 1 / t.balance09 END AS smallmoney) AS balance09
    , CAST(CASE WHEN u.is_base_currency = 0 OR t.period10  = 0 THEN t.period10  ELSE 1 / t.period10  END AS smallmoney) AS period10
    , CAST(CASE WHEN u.is_base_currency = 0 OR t.balance10 = 0 THEN t.balance10 ELSE 1 / t.balance10 END AS smallmoney) AS balance10
    , CAST(CASE WHEN u.is_base_currency = 0 OR t.period11  = 0 THEN t.period11  ELSE 1 / t.period11  END AS smallmoney) AS period11
    , CAST(CASE WHEN u.is_base_currency = 0 OR t.balance11 = 0 THEN t.balance11 ELSE 1 / t.balance11 END AS smallmoney) AS balance11
    , CAST(CASE WHEN u.is_base_currency = 0 OR t.period12  = 0 THEN t.period12  ELSE 1 / t.period12  END AS smallmoney) AS period12
    , CAST(CASE WHEN u.is_base_currency = 0 OR t.balance12 = 0 THEN t.balance12 ELSE 1 / t.balance12 END AS smallmoney) AS balance12
    , t.row_formulas
FROM
    dbo27.units u
    CROSS JOIN dbo27.members c
    CROSS JOIN dbo27.members p
    LEFT OUTER JOIN dbo27.budget_currency_rates t ON t.unit_id = u.id AND t.category_id = c.id AND t.time_id = p.id
    LEFT OUTER JOIN dbo27.translations t1 ON t1.company_id = c.company_id AND t1.table_id = 1 AND t1.member_id = c.id AND t1.language = @data_language
    LEFT OUTER JOIN dbo27.translations t2 ON t2.company_id = p.company_id AND t2.table_id = 1 AND t2.member_id = p.id AND t2.language = @data_language
WHERE
    u.is_currency = 1
    AND u.is_functional_currency = 0
    AND u.company_id = @company_id
    AND c.dimension_id = 3 AND c.id = COALESCE(@category_id, c.id) AND c.company_id = @company_id
    AND p.dimension_id = 2 AND p.id = COALESCE(@time_id, p.id) AND p.company_id = @company_id
ORDER BY
    u.sort_order
    , u.id
    , c.sort_order
    , c.code
    , p.sort_order
    , p.code

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: The procedure deletes data from dbo27.budget_currency_rates
-- =============================================

CREATE PROCEDURE [xls27].[usp_budget_currency_rates_delete]
    @category_id int = NULL
    , @time_id int = NULL
    , @unit_id int = NULL
AS
BEGIN

SET NOCOUNT ON

IF NOT EXISTS (SELECT TOP 1 u.company_id FROM dbo27.members t INNER JOIN dbo27.users u ON u.company_id = t.company_id  WHERE t.id = @category_id AND u.username = USER_NAME() AND u.is_active = 1)
    RETURN

SET NOCOUNT OFF

DELETE FROM dbo27.budget_currency_rates
WHERE
    category_id = @category_id
    AND time_id = @time_id
    AND unit_id = @unit_id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: The procedure updates data of dbo27.budget_currency_rates
-- =============================================

CREATE PROCEDURE [xls27].[usp_budget_currency_rates_update]
    @category_id int = NULL
    , @time_id int = NULL
    , @unit_id int = NULL
    , @balance00 smallmoney = NULL
    , @period01 smallmoney = NULL, @balance01 smallmoney = NULL
    , @period02 smallmoney = NULL, @balance02 smallmoney = NULL
    , @period03 smallmoney = NULL, @balance03 smallmoney = NULL
    , @period04 smallmoney = NULL, @balance04 smallmoney = NULL
    , @period05 smallmoney = NULL, @balance05 smallmoney = NULL
    , @period06 smallmoney = NULL, @balance06 smallmoney = NULL
    , @period07 smallmoney = NULL, @balance07 smallmoney = NULL
    , @period08 smallmoney = NULL, @balance08 smallmoney = NULL
    , @period09 smallmoney = NULL, @balance09 smallmoney = NULL
    , @period10 smallmoney = NULL, @balance10 smallmoney = NULL
    , @period11 smallmoney = NULL, @balance11 smallmoney = NULL
    , @period12 smallmoney = NULL, @balance12 smallmoney = NULL
    , @row_formulas nvarchar(max) = NULL
AS
BEGIN

SET NOCOUNT ON

DECLARE @company_id int = NULL

SELECT TOP 1 @company_id = u.company_id FROM dbo27.members t INNER JOIN dbo27.users u ON u.company_id = t.company_id  WHERE t.id = @category_id AND u.username = USER_NAME() AND u.is_active = 1

IF @company_id IS NULL OR @category_id IS NULL OR @time_id IS NULL OR @unit_id IS NULL
    RETURN

IF NOT EXISTS (SELECT TOP 1 id FROM dbo27.members WHERE id = @time_id AND company_id = @company_id)
    RETURN

DECLARE @is_base_currency bit = (SELECT is_base_currency FROM dbo27.units WHERE id = @unit_id AND company_id = @company_id)

IF @is_base_currency IS NULL
    RETURN

SET NOCOUNT OFF

UPDATE dbo27.budget_currency_rates
SET
        balance00 = CASE WHEN @is_base_currency = 0 OR @balance00 = 0 THEN @balance00 ELSE 1 / CAST(@balance00 AS float) END
    , period01  = CASE WHEN @is_base_currency = 0 OR @period01  = 0 THEN @period01  ELSE 1 / CAST(@period01  AS float) END
    , balance01 = CASE WHEN @is_base_currency = 0 OR @balance01 = 0 THEN @balance01 ELSE 1 / CAST(@balance01 AS float) END
    , period02  = CASE WHEN @is_base_currency = 0 OR @period02  = 0 THEN @period02  ELSE 1 / CAST(@period02  AS float) END
    , balance02 = CASE WHEN @is_base_currency = 0 OR @balance02 = 0 THEN @balance02 ELSE 1 / CAST(@balance02 AS float) END
    , period03  = CASE WHEN @is_base_currency = 0 OR @period03  = 0 THEN @period03  ELSE 1 / CAST(@period03  AS float) END
    , balance03 = CASE WHEN @is_base_currency = 0 OR @balance03 = 0 THEN @balance03 ELSE 1 / CAST(@balance03 AS float) END
    , period04  = CASE WHEN @is_base_currency = 0 OR @period04  = 0 THEN @period04  ELSE 1 / CAST(@period04  AS float) END
    , balance04 = CASE WHEN @is_base_currency = 0 OR @balance04 = 0 THEN @balance04 ELSE 1 / CAST(@balance04 AS float) END
    , period05  = CASE WHEN @is_base_currency = 0 OR @period05  = 0 THEN @period05  ELSE 1 / CAST(@period05  AS float) END
    , balance05 = CASE WHEN @is_base_currency = 0 OR @balance05 = 0 THEN @balance05 ELSE 1 / CAST(@balance05 AS float) END
    , period06  = CASE WHEN @is_base_currency = 0 OR @period06  = 0 THEN @period06  ELSE 1 / CAST(@period06  AS float) END
    , balance06 = CASE WHEN @is_base_currency = 0 OR @balance06 = 0 THEN @balance06 ELSE 1 / CAST(@balance06 AS float) END
    , period07  = CASE WHEN @is_base_currency = 0 OR @period07  = 0 THEN @period07  ELSE 1 / CAST(@period07  AS float) END
    , balance07 = CASE WHEN @is_base_currency = 0 OR @balance07 = 0 THEN @balance07 ELSE 1 / CAST(@balance07 AS float) END
    , period08  = CASE WHEN @is_base_currency = 0 OR @period08  = 0 THEN @period08  ELSE 1 / CAST(@period08  AS float) END
    , balance08 = CASE WHEN @is_base_currency = 0 OR @balance08 = 0 THEN @balance08 ELSE 1 / CAST(@balance08 AS float) END
    , period09  = CASE WHEN @is_base_currency = 0 OR @period09  = 0 THEN @period09  ELSE 1 / CAST(@period09  AS float) END
    , balance09 = CASE WHEN @is_base_currency = 0 OR @balance09 = 0 THEN @balance09 ELSE 1 / CAST(@balance09 AS float) END
    , period10  = CASE WHEN @is_base_currency = 0 OR @period10  = 0 THEN @period10  ELSE 1 / CAST(@period10  AS float) END
    , balance10 = CASE WHEN @is_base_currency = 0 OR @balance10 = 0 THEN @balance10 ELSE 1 / CAST(@balance10 AS float) END
    , period11  = CASE WHEN @is_base_currency = 0 OR @period11  = 0 THEN @period11  ELSE 1 / CAST(@period11  AS float) END
    , balance11 = CASE WHEN @is_base_currency = 0 OR @balance11 = 0 THEN @balance11 ELSE 1 / CAST(@balance11 AS float) END
    , period12  = CASE WHEN @is_base_currency = 0 OR @period12  = 0 THEN @period12  ELSE 1 / CAST(@period12  AS float) END
    , balance12 = CASE WHEN @is_base_currency = 0 OR @balance12 = 0 THEN @balance12 ELSE 1 / CAST(@balance12 AS float) END
    , row_formulas = @row_formulas
WHERE
    category_id = @category_id
    AND time_id = @time_id
    AND unit_id = @unit_id

IF @@ROWCOUNT = 0
INSERT INTO dbo27.budget_currency_rates
    ( category_id
    , time_id
    , unit_id
    , balance00
    , period01, balance01, period02, balance02, period03, balance03, period04, balance04, period05, balance05, period06, balance06
    , period07, balance07, period08, balance08, period09, balance09, period10, balance10, period11, balance11, period12, balance12
    , row_formulas
    )
VALUES
    ( @category_id
    , @time_id
    , @unit_id
    , CASE WHEN @is_base_currency = 0 OR @balance00 = 0 THEN @balance00 ELSE 1 / @balance00 END
    , CASE WHEN @is_base_currency = 0 OR @period01  = 0 THEN @period01  ELSE 1 / @period01  END
    , CASE WHEN @is_base_currency = 0 OR @balance01 = 0 THEN @balance01 ELSE 1 / @balance01 END
    , CASE WHEN @is_base_currency = 0 OR @period02  = 0 THEN @period02  ELSE 1 / @period02  END
    , CASE WHEN @is_base_currency = 0 OR @balance02 = 0 THEN @balance02 ELSE 1 / @balance02 END
    , CASE WHEN @is_base_currency = 0 OR @period03  = 0 THEN @period03  ELSE 1 / @period03  END
    , CASE WHEN @is_base_currency = 0 OR @balance03 = 0 THEN @balance03 ELSE 1 / @balance03 END
    , CASE WHEN @is_base_currency = 0 OR @period04  = 0 THEN @period04  ELSE 1 / @period04  END
    , CASE WHEN @is_base_currency = 0 OR @balance04 = 0 THEN @balance04 ELSE 1 / @balance04 END
    , CASE WHEN @is_base_currency = 0 OR @period05  = 0 THEN @period05  ELSE 1 / @period05  END
    , CASE WHEN @is_base_currency = 0 OR @balance05 = 0 THEN @balance05 ELSE 1 / @balance05 END
    , CASE WHEN @is_base_currency = 0 OR @period06  = 0 THEN @period06  ELSE 1 / @period06  END
    , CASE WHEN @is_base_currency = 0 OR @balance06 = 0 THEN @balance06 ELSE 1 / @balance06 END
    , CASE WHEN @is_base_currency = 0 OR @period07  = 0 THEN @period07  ELSE 1 / @period07  END
    , CASE WHEN @is_base_currency = 0 OR @balance07 = 0 THEN @balance07 ELSE 1 / @balance07 END
    , CASE WHEN @is_base_currency = 0 OR @period08  = 0 THEN @period08  ELSE 1 / @period08  END
    , CASE WHEN @is_base_currency = 0 OR @balance08 = 0 THEN @balance08 ELSE 1 / @balance08 END
    , CASE WHEN @is_base_currency = 0 OR @period09  = 0 THEN @period09  ELSE 1 / @period09  END
    , CASE WHEN @is_base_currency = 0 OR @balance09 = 0 THEN @balance09 ELSE 1 / @balance09 END
    , CASE WHEN @is_base_currency = 0 OR @period10  = 0 THEN @period10  ELSE 1 / @period10  END
    , CASE WHEN @is_base_currency = 0 OR @balance10 = 0 THEN @balance10 ELSE 1 / @balance10 END
    , CASE WHEN @is_base_currency = 0 OR @period11  = 0 THEN @period11  ELSE 1 / @period11  END
    , CASE WHEN @is_base_currency = 0 OR @balance11 = 0 THEN @balance11 ELSE 1 / @balance11 END
    , CASE WHEN @is_base_currency = 0 OR @period12  = 0 THEN @period12  ELSE 1 / @period12  END
    , CASE WHEN @is_base_currency = 0 OR @balance12 = 0 THEN @balance12 ELSE 1 / @balance12 END
    , @row_formulas
    )

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: The procedure inserts data into dbo27.budget_currency_rates
-- =============================================

CREATE PROCEDURE [xls27].[usp_budget_currency_rates_insert]
    @category_id int = NULL
    , @time_id int = NULL
    , @unit_id int = NULL
    , @balance00 smallmoney = NULL
    , @period01 smallmoney = NULL, @balance01 smallmoney = NULL
    , @period02 smallmoney = NULL, @balance02 smallmoney = NULL
    , @period03 smallmoney = NULL, @balance03 smallmoney = NULL
    , @period04 smallmoney = NULL, @balance04 smallmoney = NULL
    , @period05 smallmoney = NULL, @balance05 smallmoney = NULL
    , @period06 smallmoney = NULL, @balance06 smallmoney = NULL
    , @period07 smallmoney = NULL, @balance07 smallmoney = NULL
    , @period08 smallmoney = NULL, @balance08 smallmoney = NULL
    , @period09 smallmoney = NULL, @balance09 smallmoney = NULL
    , @period10 smallmoney = NULL, @balance10 smallmoney = NULL
    , @period11 smallmoney = NULL, @balance11 smallmoney = NULL
    , @period12 smallmoney = NULL, @balance12 smallmoney = NULL
    , @row_formulas nvarchar(max) = NULL
AS
BEGIN

SET NOCOUNT ON

EXEC xls27.usp_budget_currency_rates_update
    @category_id
    , @time_id
    , @unit_id
    , @balance00
    , @period01, @balance01, @period02, @balance02, @period03, @balance03, @period04, @balance04, @period05, @balance05, @period06, @balance06
    , @period07, @balance07, @period08, @balance08, @period09, @balance09, @period10, @balance10, @period11, @balance11, @period12, @balance12
    , @row_formulas

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: The procedure selects data from dbo27.budget_requests
-- =============================================

CREATE PROCEDURE [xls27].[usp_budget_data]
    @company_id int = NULL
    , @category_id int = NULL
    , @time_id int = NULL
    , @entity_id int = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

;WITH a1 AS (

    -- raw budget request payments, charges, vat, balance00 on account level

    SELECT
        r.id, r.account_id, r.[entity_id], r.product_id, r.region_id, r.subsidiary_account_id

        , cf_sign, pl_sign, vat_sign, is_charge_net

        , payment_debit_id, payment_credit_id, charge_debit_id, charge_credit_id, vat_debit_id, vat_credit_id

        , COALESCE(CAST(r.payments01 * COALESCE(cr.period01, 1) AS numeric(15,2)), 0) AS payments01
        , COALESCE(CAST(r.payments02 * COALESCE(cr.period02, 1) AS numeric(15,2)), 0) AS payments02
        , COALESCE(CAST(r.payments03 * COALESCE(cr.period03, 1) AS numeric(15,2)), 0) AS payments03
        , COALESCE(CAST(r.payments04 * COALESCE(cr.period04, 1) AS numeric(15,2)), 0) AS payments04
        , COALESCE(CAST(r.payments05 * COALESCE(cr.period05, 1) AS numeric(15,2)), 0) AS payments05
        , COALESCE(CAST(r.payments06 * COALESCE(cr.period06, 1) AS numeric(15,2)), 0) AS payments06
        , COALESCE(CAST(r.payments07 * COALESCE(cr.period07, 1) AS numeric(15,2)), 0) AS payments07
        , COALESCE(CAST(r.payments08 * COALESCE(cr.period08, 1) AS numeric(15,2)), 0) AS payments08
        , COALESCE(CAST(r.payments09 * COALESCE(cr.period09, 1) AS numeric(15,2)), 0) AS payments09
        , COALESCE(CAST(r.payments10 * COALESCE(cr.period10, 1) AS numeric(15,2)), 0) AS payments10
        , COALESCE(CAST(r.payments11 * COALESCE(cr.period11, 1) AS numeric(15,2)), 0) AS payments11
        , COALESCE(CAST(r.payments12 * COALESCE(cr.period12, 1) AS numeric(15,2)), 0) AS payments12

        , COALESCE(CAST(r.charges01 * COALESCE(cr.period01, 1) AS numeric(15,2)), 0) AS charges01
        , COALESCE(CAST(r.charges02 * COALESCE(cr.period02, 1) AS numeric(15,2)), 0) AS charges02
        , COALESCE(CAST(r.charges03 * COALESCE(cr.period03, 1) AS numeric(15,2)), 0) AS charges03
        , COALESCE(CAST(r.charges04 * COALESCE(cr.period04, 1) AS numeric(15,2)), 0) AS charges04
        , COALESCE(CAST(r.charges05 * COALESCE(cr.period05, 1) AS numeric(15,2)), 0) AS charges05
        , COALESCE(CAST(r.charges06 * COALESCE(cr.period06, 1) AS numeric(15,2)), 0) AS charges06
        , COALESCE(CAST(r.charges07 * COALESCE(cr.period07, 1) AS numeric(15,2)), 0) AS charges07
        , COALESCE(CAST(r.charges08 * COALESCE(cr.period08, 1) AS numeric(15,2)), 0) AS charges08
        , COALESCE(CAST(r.charges09 * COALESCE(cr.period09, 1) AS numeric(15,2)), 0) AS charges09
        , COALESCE(CAST(r.charges10 * COALESCE(cr.period10, 1) AS numeric(15,2)), 0) AS charges10
        , COALESCE(CAST(r.charges11 * COALESCE(cr.period11, 1) AS numeric(15,2)), 0) AS charges11
        , COALESCE(CAST(r.charges12 * COALESCE(cr.period12, 1) AS numeric(15,2)), 0) AS charges12

        , COALESCE(CAST(r.charges01 * COALESCE(cr.period01, 1) * COALESCE(vr.factor, 0) AS numeric(15,2)), 0) AS vat01
        , COALESCE(CAST(r.charges02 * COALESCE(cr.period02, 1) * COALESCE(vr.factor, 0) AS numeric(15,2)), 0) AS vat02
        , COALESCE(CAST(r.charges03 * COALESCE(cr.period03, 1) * COALESCE(vr.factor, 0) AS numeric(15,2)), 0) AS vat03
        , COALESCE(CAST(r.charges04 * COALESCE(cr.period04, 1) * COALESCE(vr.factor, 0) AS numeric(15,2)), 0) AS vat04
        , COALESCE(CAST(r.charges05 * COALESCE(cr.period05, 1) * COALESCE(vr.factor, 0) AS numeric(15,2)), 0) AS vat05
        , COALESCE(CAST(r.charges06 * COALESCE(cr.period06, 1) * COALESCE(vr.factor, 0) AS numeric(15,2)), 0) AS vat06
        , COALESCE(CAST(r.charges07 * COALESCE(cr.period07, 1) * COALESCE(vr.factor, 0) AS numeric(15,2)), 0) AS vat07
        , COALESCE(CAST(r.charges08 * COALESCE(cr.period08, 1) * COALESCE(vr.factor, 0) AS numeric(15,2)), 0) AS vat08
        , COALESCE(CAST(r.charges09 * COALESCE(cr.period09, 1) * COALESCE(vr.factor, 0) AS numeric(15,2)), 0) AS vat09
        , COALESCE(CAST(r.charges10 * COALESCE(cr.period10, 1) * COALESCE(vr.factor, 0) AS numeric(15,2)), 0) AS vat10
        , COALESCE(CAST(r.charges11 * COALESCE(cr.period11, 1) * COALESCE(vr.factor, 0) AS numeric(15,2)), 0) AS vat11
        , COALESCE(CAST(r.charges12 * COALESCE(cr.period12, 1) * COALESCE(vr.factor, 0) AS numeric(15,2)), 0) AS vat12

        , COALESCE(CAST(r.balance00 * COALESCE(cr.balance00, 1) AS numeric(15,2)), 0) AS balance00
    FROM
        dbo27.budget_requests r
        INNER JOIN dbo27.members m1 ON m1.id = r.account_id
        INNER JOIN dbo27.member_types t ON t.id = m1.account_type_id
        LEFT OUTER JOIN dbo27.vat_rates vr ON vr.id = r.vat_rate_id
        LEFT OUTER JOIN dbo27.budget_currency_rates cr ON cr.category_id = r.category_id AND cr.time_id = r.time_id AND cr.unit_id = r.unit_id
    WHERE
        r.category_id = @category_id
        AND r.time_id = @time_id
        AND m1.company_id = @company_id
        AND r.[entity_id] = COALESCE(@entity_id, r.[entity_id])
)

, a2 AS (

    -- final raw payments, charges + cf, pl, signed vat on account level with analytic members

    SELECT
        id, account_id, [entity_id], product_id, region_id, subsidiary_account_id

        , cf_sign, pl_sign, vat_sign, is_charge_net

         , payments01, payments02, payments03, payments04, payments05, payments06, payments07, payments08, payments09, payments10, payments11, payments12
         , charges01, charges02, charges03, charges04, charges05, charges06, charges07, charges08, charges09, charges10, charges11, charges12

        , cf_sign * payments01 AS cf01
        , cf_sign * payments02 AS cf02
        , cf_sign * payments03 AS cf03
        , cf_sign * payments04 AS cf04
        , cf_sign * payments05 AS cf05
        , cf_sign * payments06 AS cf06
        , cf_sign * payments07 AS cf07
        , cf_sign * payments08 AS cf08
        , cf_sign * payments09 AS cf09
        , cf_sign * payments10 AS cf10
        , cf_sign * payments11 AS cf11
        , cf_sign * payments12 AS cf12

        , vat_sign * vat01 AS vat01
        , vat_sign * vat02 AS vat02
        , vat_sign * vat03 AS vat03
        , vat_sign * vat04 AS vat04
        , vat_sign * vat05 AS vat05
        , vat_sign * vat06 AS vat06
        , vat_sign * vat07 AS vat07
        , vat_sign * vat08 AS vat08
        , vat_sign * vat09 AS vat09
        , vat_sign * vat10 AS vat10
        , vat_sign * vat11 AS vat11
        , vat_sign * vat12 AS vat12

        , pl_sign * (charges01 - COALESCE(vat01, 0)) AS pl01
        , pl_sign * (charges02 - COALESCE(vat02, 0)) AS pl02
        , pl_sign * (charges03 - COALESCE(vat03, 0)) AS pl03
        , pl_sign * (charges04 - COALESCE(vat04, 0)) AS pl04
        , pl_sign * (charges05 - COALESCE(vat05, 0)) AS pl05
        , pl_sign * (charges06 - COALESCE(vat06, 0)) AS pl06
        , pl_sign * (charges07 - COALESCE(vat07, 0)) AS pl07
        , pl_sign * (charges08 - COALESCE(vat08, 0)) AS pl08
        , pl_sign * (charges09 - COALESCE(vat09, 0)) AS pl09
        , pl_sign * (charges10 - COALESCE(vat10, 0)) AS pl10
        , pl_sign * (charges11 - COALESCE(vat11, 0)) AS pl11
        , pl_sign * (charges12 - COALESCE(vat12, 0)) AS pl12

    FROM
        a1
)

, b1 AS (

    -- raw dr, cr, balance00 on ledger and subsidiary accounts based on raw data and configured accounts

    SELECT
        payment_debit_id AS ledger_account_id
        , CASE WHEN cf_sign = 1 THEN -1 ELSE COALESCE(subsidiary_account_id, -1) END AS subsidiary_account_id
        , NULL AS balance00
        , payments01 AS dr01, payments02 AS dr02, payments03 AS dr03, payments04 AS dr04, payments05 AS dr05, payments06 AS dr06, payments07 AS dr07, payments08 AS dr08, payments09 AS dr09, payments10 AS dr10, payments11 AS dr11, payments12 AS dr12
        , NULL AS cr01, NULL AS cr02, NULL AS cr03, NULL AS cr04, NULL AS cr05, NULL AS cr06, NULL AS cr07, NULL AS cr08, NULL AS cr09, NULL AS cr10, NULL AS cr11, NULL AS cr12
    FROM
        a1
    WHERE
        payment_debit_id IS NOT NULL AND payment_credit_id IS NOT NULL

    UNION ALL
    SELECT
        payment_credit_id AS ledger_account_id
        , CASE WHEN cf_sign = -1 THEN -1 ELSE COALESCE(subsidiary_account_id, -1) END AS subsidiary_account_id
        , NULL AS balance00
        , NULL AS dr01, NULL AS dr02, NULL AS dr03, NULL AS dr04, NULL AS dr05, NULL AS dr06, NULL AS dr07, NULL AS dr08, NULL AS dr09, NULL AS dr10, NULL AS dr11, NULL AS dr12
        , payments01 AS cr01, payments02 AS cr02, payments03 AS cr03, payments04 AS cr04, payments05 AS cr05, payments06 AS cr06, payments07 AS cr07, payments08 AS cr08, payments09 AS cr09, payments10 AS cr10, payments11 AS cr11, payments12 AS cr12
    FROM
        a1
    WHERE
        payment_debit_id IS NOT NULL AND payment_credit_id IS NOT NULL

    UNION ALL
    SELECT
        charge_debit_id AS ledger_account_id
        , CASE WHEN pl_sign = -1 THEN -1 ELSE COALESCE(subsidiary_account_id, -1) END AS subsidiary_account_id
        , NULL AS balance00
        , charges01 - is_charge_net * vat01 AS dr01
        , charges02 - is_charge_net * vat02 AS dr02
        , charges03 - is_charge_net * vat03 AS dr03
        , charges04 - is_charge_net * vat04 AS dr04
        , charges05 - is_charge_net * vat05 AS dr05
        , charges06 - is_charge_net * vat06 AS dr06
        , charges07 - is_charge_net * vat07 AS dr07
        , charges08 - is_charge_net * vat08 AS dr08
        , charges09 - is_charge_net * vat09 AS dr09
        , charges10 - is_charge_net * vat10 AS dr10
        , charges11 - is_charge_net * vat11 AS dr11
        , charges12 - is_charge_net * vat12 AS dr12
        , NULL AS cr01, NULL AS cr02, NULL AS cr03, NULL AS cr04, NULL AS cr05, NULL AS cr06, NULL AS cr07, NULL AS cr08, NULL AS cr09, NULL AS cr10, NULL AS cr11, NULL AS cr12
    FROM
        a1
    WHERE
        charge_debit_id IS NOT NULL AND charge_credit_id IS NOT NULL


    UNION ALL
    SELECT
        charge_credit_id AS ledger_account_id
        , CASE WHEN pl_sign = 1 THEN -1 ELSE COALESCE(subsidiary_account_id, -1) END AS subsidiary_account_id
        , NULL AS balance00
        , NULL AS dr01, NULL AS dr02, NULL AS dr03, NULL AS dr04, NULL AS dr05, NULL AS dr06, NULL AS dr07, NULL AS dr08, NULL AS dr09, NULL AS dr10, NULL AS dr11, NULL AS dr12
        , charges01 - is_charge_net * vat01 AS cr01
        , charges02 - is_charge_net * vat02 AS cr02
        , charges03 - is_charge_net * vat03 AS cr03
        , charges04 - is_charge_net * vat04 AS cr04
        , charges05 - is_charge_net * vat05 AS cr05
        , charges06 - is_charge_net * vat06 AS cr06
        , charges07 - is_charge_net * vat07 AS cr07
        , charges08 - is_charge_net * vat08 AS cr08
        , charges09 - is_charge_net * vat09 AS cr09
        , charges10 - is_charge_net * vat10 AS cr10
        , charges11 - is_charge_net * vat11 AS cr11
        , charges12 - is_charge_net * vat12 AS cr12
    FROM
        a1
    WHERE
        charge_debit_id IS NOT NULL AND charge_credit_id IS NOT NULL

    UNION ALL
    SELECT
        vat_debit_id AS ledger_account_id
        , CASE WHEN vat_debit_id = charge_debit_id THEN COALESCE(subsidiary_account_id, -1) ELSE -1 END AS subsidiary_account_id
        , NULL AS balance00
        , vat01 AS dr01, vat02 AS dr02, vat03 AS dr03, vat04 AS dr04, vat05 AS dr05, vat06 AS dr06, vat07 AS dr07, vat08 AS dr08, vat09 AS dr09, vat10 AS dr10, vat11 AS dr11, vat12 AS dr12
        , NULL AS cr01, NULL AS cr02, NULL AS cr03, NULL AS cr04, NULL AS cr05, NULL AS cr06, NULL AS cr07, NULL AS cr08, NULL AS cr09, NULL AS cr10, NULL AS cr11, NULL AS cr12
    FROM
        a1
    WHERE
        vat_debit_id IS NOT NULL AND vat_credit_id IS NOT NULL

    UNION ALL
    SELECT
        vat_credit_id AS ledger_account_id
        , CASE WHEN vat_credit_id = charge_credit_id THEN COALESCE(subsidiary_account_id, -1) ELSE -1 END AS subsidiary_account_id
        , NULL AS balance00
        , NULL AS dr01, NULL AS dr02, NULL AS dr03, NULL AS dr04, NULL AS dr05, NULL AS dr06, NULL AS dr07, NULL AS dr08, NULL AS dr09, NULL AS dr10, NULL AS dr11, NULL AS dr12
        , vat01 AS cr01, vat02 AS cr02, vat03 AS cr03, vat04 AS cr04, vat05 AS cr05, vat06 AS cr06, vat07 AS cr07, vat08 AS cr08, vat09 AS cr09, vat10 AS cr10, vat11 AS cr11, vat12 AS cr12
    FROM
        a1
    WHERE
        vat_debit_id IS NOT NULL AND vat_credit_id IS NOT NULL

    UNION ALL
    SELECT
        CASE WHEN cf_sign = 1 THEN payment_credit_id ELSE payment_debit_id END AS ledger_account_id
        , COALESCE(subsidiary_account_id, -1) AS subsidiary_account_id
        , CASE WHEN cf_sign = 1 THEN balance00 ELSE -balance00 END AS balance00
        , NULL AS dr01, NULL AS dr02, NULL AS dr03, NULL AS dr04, NULL AS dr05, NULL AS dr06, NULL AS dr07, NULL AS dr08, NULL AS dr09, NULL AS dr10, NULL AS dr11, NULL AS dr12
        , NULL AS cr01, NULL AS cr02, NULL AS cr03, NULL AS cr04, NULL AS cr05, NULL AS cr06, NULL AS cr07, NULL AS cr08, NULL AS cr09, NULL AS cr10, NULL AS cr11, NULL AS cr12
    FROM
        a1
    WHERE
        payment_debit_id IS NOT NULL AND payment_credit_id IS NOT NULL
)

, b2 AS (

    -- total dr, cr, balance00 on ledger and subsidiary accounts based on b1

    SELECT
        ledger_account_id
        , subsidiary_account_id
        , COALESCE(SUM(balance00), 0) AS balance00
        , COALESCE(SUM(dr01), 0) AS dr01, COALESCE(SUM(dr02), 0) AS dr02, COALESCE(SUM(dr03), 0) AS dr03, COALESCE(SUM(dr04), 0) AS dr04, COALESCE(SUM(dr05), 0) AS dr05, COALESCE(SUM(dr06), 0) AS dr06, COALESCE(SUM(dr07), 0) AS dr07, COALESCE(SUM(dr08), 0) AS dr08, COALESCE(SUM(dr09), 0) AS dr09, COALESCE(SUM(dr10), 0) AS dr10, COALESCE(SUM(dr11), 0) AS dr11, COALESCE(SUM(dr12), 0) AS dr12
        , COALESCE(SUM(cr01), 0) AS cr01, COALESCE(SUM(cr02), 0) AS cr02, COALESCE(SUM(cr03), 0) AS cr03, COALESCE(SUM(cr04), 0) AS cr04, COALESCE(SUM(cr05), 0) AS cr05, COALESCE(SUM(cr06), 0) AS cr06, COALESCE(SUM(cr07), 0) AS cr07, COALESCE(SUM(cr08), 0) AS cr08, COALESCE(SUM(cr09), 0) AS cr09, COALESCE(SUM(cr10), 0) AS cr10, COALESCE(SUM(cr11), 0) AS cr11, COALESCE(SUM(cr12), 0) AS cr12
    FROM
        b1
    GROUP BY
        ledger_account_id
        , subsidiary_account_id
)

, b3 AS (

    -- total dr, cr, balance00 + balances + bs_sign on ledger and subsidiary accounts

    SELECT
        ledger_account_id
        , subsidiary_account_id
        , dr01, dr02, dr03, dr04, dr05, dr06, dr07, dr08, dr09, dr10, dr11, dr12
        , cr01, cr02, cr03, cr04, cr05, cr06, cr07, cr08, cr09, cr10, cr11, cr12
        , balance00 AS balance00
        , balance00 + dr01 - cr01 AS balance01
        , balance00 + dr01 - cr01 + dr02 - cr02 AS balance02
        , balance00 + dr01 - cr01 + dr02 - cr02 + dr03 - cr03 AS balance03
        , balance00 + dr01 - cr01 + dr02 - cr02 + dr03 - cr03 + dr04 - cr04 AS balance04
        , balance00 + dr01 - cr01 + dr02 - cr02 + dr03 - cr03 + dr04 - cr04 + dr05 - cr05 AS balance05
        , balance00 + dr01 - cr01 + dr02 - cr02 + dr03 - cr03 + dr04 - cr04 + dr05 - cr05 + dr06 - cr06 AS balance06
        , balance00 + dr01 - cr01 + dr02 - cr02 + dr03 - cr03 + dr04 - cr04 + dr05 - cr05 + dr06 - cr06 + dr07 - cr07 AS balance07
        , balance00 + dr01 - cr01 + dr02 - cr02 + dr03 - cr03 + dr04 - cr04 + dr05 - cr05 + dr06 - cr06 + dr07 - cr07 + dr08 - cr08 AS balance08
        , balance00 + dr01 - cr01 + dr02 - cr02 + dr03 - cr03 + dr04 - cr04 + dr05 - cr05 + dr06 - cr06 + dr07 - cr07 + dr08 - cr08 + dr09 - cr09 AS balance09
        , balance00 + dr01 - cr01 + dr02 - cr02 + dr03 - cr03 + dr04 - cr04 + dr05 - cr05 + dr06 - cr06 + dr07 - cr07 + dr08 - cr08 + dr09 - cr09 + dr10 - cr10 AS balance10
        , balance00 + dr01 - cr01 + dr02 - cr02 + dr03 - cr03 + dr04 - cr04 + dr05 - cr05 + dr06 - cr06 + dr07 - cr07 + dr08 - cr08 + dr09 - cr09 + dr10 - cr10 + dr11 - cr11 AS balance11
        , balance00 + dr01 - cr01 + dr02 - cr02 + dr03 - cr03 + dr04 - cr04 + dr05 - cr05 + dr06 - cr06 + dr07 - cr07 + dr08 - cr08 + dr09 - cr09 + dr10 - cr10 + dr11 - cr11 + dr12 - cr12 AS balance12
        , bs_sign
    FROM
        b2
        INNER JOIN dbo27.ledger_accounts a ON a.id = ledger_account_id
        LEFT OUTER JOIN dbo27.ledger_account_types t ON t.id = a.account_type_id
)

, b4 AS (

    -- total dr, cr, balances + debit and credit balances on ledger and subsidiary accounts

    SELECT
        ledger_account_id
        , subsidiary_account_id
        , dr01, dr02, dr03, dr04, dr05, dr06, dr07, dr08, dr09, dr10, dr11, dr12
        , cr01, cr02, cr03, cr04, cr05, cr06, cr07, cr08, cr09, cr10, cr11, cr12
        , balance00, balance01, balance02, balance03, balance04, balance05, balance06, balance07, balance08, balance09, balance10, balance11, balance12
        , bs_sign
        , CASE WHEN bs_sign = 1 OR bs_sign = 0 AND balance00 > 0 THEN balance00 ELSE NULL END AS bd00
        , CASE WHEN bs_sign = 1 OR bs_sign = 0 AND balance01 > 0 THEN balance01 ELSE NULL END AS bd01
        , CASE WHEN bs_sign = 1 OR bs_sign = 0 AND balance02 > 0 THEN balance02 ELSE NULL END AS bd02
        , CASE WHEN bs_sign = 1 OR bs_sign = 0 AND balance03 > 0 THEN balance03 ELSE NULL END AS bd03
        , CASE WHEN bs_sign = 1 OR bs_sign = 0 AND balance04 > 0 THEN balance04 ELSE NULL END AS bd04
        , CASE WHEN bs_sign = 1 OR bs_sign = 0 AND balance05 > 0 THEN balance05 ELSE NULL END AS bd05
        , CASE WHEN bs_sign = 1 OR bs_sign = 0 AND balance06 > 0 THEN balance06 ELSE NULL END AS bd06
        , CASE WHEN bs_sign = 1 OR bs_sign = 0 AND balance07 > 0 THEN balance07 ELSE NULL END AS bd07
        , CASE WHEN bs_sign = 1 OR bs_sign = 0 AND balance08 > 0 THEN balance08 ELSE NULL END AS bd08
        , CASE WHEN bs_sign = 1 OR bs_sign = 0 AND balance09 > 0 THEN balance09 ELSE NULL END AS bd09
        , CASE WHEN bs_sign = 1 OR bs_sign = 0 AND balance10 > 0 THEN balance10 ELSE NULL END AS bd10
        , CASE WHEN bs_sign = 1 OR bs_sign = 0 AND balance11 > 0 THEN balance11 ELSE NULL END AS bd11
        , CASE WHEN bs_sign = 1 OR bs_sign = 0 AND balance12 > 0 THEN balance12 ELSE NULL END AS bd12
        , CASE WHEN bs_sign = -1 OR bs_sign = 0 AND balance00 < 0 THEN -balance00 ELSE NULL END AS bc00
        , CASE WHEN bs_sign = -1 OR bs_sign = 0 AND balance01 < 0 THEN -balance01 ELSE NULL END AS bc01
        , CASE WHEN bs_sign = -1 OR bs_sign = 0 AND balance02 < 0 THEN -balance02 ELSE NULL END AS bc02
        , CASE WHEN bs_sign = -1 OR bs_sign = 0 AND balance03 < 0 THEN -balance03 ELSE NULL END AS bc03
        , CASE WHEN bs_sign = -1 OR bs_sign = 0 AND balance04 < 0 THEN -balance04 ELSE NULL END AS bc04
        , CASE WHEN bs_sign = -1 OR bs_sign = 0 AND balance05 < 0 THEN -balance05 ELSE NULL END AS bc05
        , CASE WHEN bs_sign = -1 OR bs_sign = 0 AND balance06 < 0 THEN -balance06 ELSE NULL END AS bc06
        , CASE WHEN bs_sign = -1 OR bs_sign = 0 AND balance07 < 0 THEN -balance07 ELSE NULL END AS bc07
        , CASE WHEN bs_sign = -1 OR bs_sign = 0 AND balance08 < 0 THEN -balance08 ELSE NULL END AS bc08
        , CASE WHEN bs_sign = -1 OR bs_sign = 0 AND balance09 < 0 THEN -balance09 ELSE NULL END AS bc09
        , CASE WHEN bs_sign = -1 OR bs_sign = 0 AND balance10 < 0 THEN -balance10 ELSE NULL END AS bc10
        , CASE WHEN bs_sign = -1 OR bs_sign = 0 AND balance11 < 0 THEN -balance11 ELSE NULL END AS bc11
        , CASE WHEN bs_sign = -1 OR bs_sign = 0 AND balance12 < 0 THEN -balance12 ELSE NULL END AS bc12
        , 0 AS debit, 0 AS credit
    FROM
        b3

    UNION ALL
    SELECT
        r.account_id AS ledger_account_id
        , NULL AS subsidiary_account_id

        , 0 AS dr01, 0 AS dr02, 0 AS dr03, 0 AS dr04, 0 AS dr05, 0 AS dr06, 0 AS dr07, 0 AS dr08, 0 AS dr09, 0 AS dr10, 0 AS dr11, 0 AS dr12
        , 0 AS cr01, 0 AS cr02, 0 AS cr03, 0 AS cr04, 0 AS cr05, 0 AS cr06, 0 AS cr07, 0 AS cr08, 0 AS cr09, 0 AS cr10, 0 AS cr11, 0 AS cr12
        , 0 AS balance00, 0 AS balance01, 0 AS balance02, 0 AS balance03, 0 AS balance04, 0 AS balance05, 0 AS balance06, 0 AS balance07, 0 AS balance08, 0 AS balance09, 0 AS balance10, 0 AS balance11, 0 AS balance12
        , bs_sign
        , 0 AS bd00, 0 AS bd01, 0 AS bd02, 0 AS bd03, 0 AS bd04, 0 AS bd05, 0 AS bd06, 0 AS bd07, 0 AS bd08, 0 AS bd09, 0 AS bd10, 0 AS bd11, 0 AS bd12
        , 0 AS bc00, 0 AS bc01, 0 AS bc02, 0 AS bc03, 0 AS bc04, 0 AS bc05, 0 AS bc06, 0 AS bc07, 0 AS bc08, 0 AS bc09, 0 AS bc10, 0 AS bc11, 0 AS bc12
        , COALESCE(debit, 0) AS debit, COALESCE(credit, 0) AS credit
    FROM
        dbo27.budget_balances r
        INNER JOIN dbo27.ledger_accounts a ON a.id = r.account_id
        LEFT OUTER JOIN dbo27.ledger_account_types t ON t.id = a.account_type_id
    WHERE
        r.category_id = @category_id
        AND r.time_id = @time_id
        AND (r.debit IS NOT NULL OR r.credit IS NOT NULL)
        --AND @entity_id IS NULL
)

, c1 AS (

    -- total dr, cr, balances + debit and credit balances on ledger and subsidiary accounts

    SELECT
        ledger_account_id
        , COALESCE(SUM(dr01), 0) AS dr01, COALESCE(SUM(dr02), 0) AS dr02, COALESCE(SUM(dr03), 0) AS dr03, COALESCE(SUM(dr04), 0) AS dr04, COALESCE(SUM(dr05), 0) AS dr05, COALESCE(SUM(dr06), 0) AS dr06, COALESCE(SUM(dr07), 0) AS dr07, COALESCE(SUM(dr08), 0) AS dr08, COALESCE(SUM(dr09), 0) AS dr09, COALESCE(SUM(dr10), 0) AS dr10, COALESCE(SUM(dr11), 0) AS dr11, COALESCE(SUM(dr12), 0) AS dr12
        , COALESCE(SUM(cr01), 0) AS cr01, COALESCE(SUM(cr02), 0) AS cr02, COALESCE(SUM(cr03), 0) AS cr03, COALESCE(SUM(cr04), 0) AS cr04, COALESCE(SUM(cr05), 0) AS cr05, COALESCE(SUM(cr06), 0) AS cr06, COALESCE(SUM(cr07), 0) AS cr07, COALESCE(SUM(cr08), 0) AS cr08, COALESCE(SUM(cr09), 0) AS cr09, COALESCE(SUM(cr10), 0) AS cr10, COALESCE(SUM(cr11), 0) AS cr11, COALESCE(SUM(cr12), 0) AS cr12
        , SUM(debit) AS debit
        , SUM(credit) AS credit
        , SUM(debit - credit) AS balance00
        , SUM(debit - credit + dr01 - cr01) AS balance01
        , SUM(debit - credit + dr01 - cr01 + dr02 - cr02) AS balance02
        , SUM(debit - credit + dr01 - cr01 + dr02 - cr02 + dr03 - cr03) AS balance03
        , SUM(debit - credit + dr01 - cr01 + dr02 - cr02 + dr03 - cr03 + dr04 - cr04) AS balance04
        , SUM(debit - credit + dr01 - cr01 + dr02 - cr02 + dr03 - cr03 + dr04 - cr04 + dr05 - cr05) AS balance05
        , SUM(debit - credit + dr01 - cr01 + dr02 - cr02 + dr03 - cr03 + dr04 - cr04 + dr05 - cr05 + dr06 - cr06) AS balance06
        , SUM(debit - credit + dr01 - cr01 + dr02 - cr02 + dr03 - cr03 + dr04 - cr04 + dr05 - cr05 + dr06 - cr06 + dr07 - cr07) AS balance07
        , SUM(debit - credit + dr01 - cr01 + dr02 - cr02 + dr03 - cr03 + dr04 - cr04 + dr05 - cr05 + dr06 - cr06 + dr07 - cr07 + dr08 - cr08) AS balance08
        , SUM(debit - credit + dr01 - cr01 + dr02 - cr02 + dr03 - cr03 + dr04 - cr04 + dr05 - cr05 + dr06 - cr06 + dr07 - cr07 + dr08 - cr08 + dr09 - cr09) AS balance09
        , SUM(debit - credit + dr01 - cr01 + dr02 - cr02 + dr03 - cr03 + dr04 - cr04 + dr05 - cr05 + dr06 - cr06 + dr07 - cr07 + dr08 - cr08 + dr09 - cr09 + dr10 - cr10) AS balance10
        , SUM(debit - credit + dr01 - cr01 + dr02 - cr02 + dr03 - cr03 + dr04 - cr04 + dr05 - cr05 + dr06 - cr06 + dr07 - cr07 + dr08 - cr08 + dr09 - cr09 + dr10 - cr10 + dr11 - cr11) AS balance11
        , SUM(debit - credit + dr01 - cr01 + dr02 - cr02 + dr03 - cr03 + dr04 - cr04 + dr05 - cr05 + dr06 - cr06 + dr07 - cr07 + dr08 - cr08 + dr09 - cr09 + dr10 - cr10 + dr11 - cr11 + dr12 - cr12) AS balance12
        , COALESCE(SUM(bd00), 0) AS bd00, COALESCE(SUM(bd01), 0) AS bd01, COALESCE(SUM(bd02), 0) AS bd02, COALESCE(SUM(bd03), 0) AS bd03, COALESCE(SUM(bd04), 0) AS bd04, COALESCE(SUM(bd05), 0) AS bd05, COALESCE(SUM(bd06), 0) AS bd06, COALESCE(SUM(bd07), 0) AS bd07, COALESCE(SUM(bd08), 0) AS bd08, COALESCE(SUM(bd09), 0) AS bd09, COALESCE(SUM(bd10), 0) AS bd10, COALESCE(SUM(bd11), 0) AS bd11, COALESCE(SUM(bd12), 0) AS bd12
        , COALESCE(SUM(bc00), 0) AS bc00, COALESCE(SUM(bc01), 0) AS bc01, COALESCE(SUM(bc02), 0) AS bc02, COALESCE(SUM(bc03), 0) AS bc03, COALESCE(SUM(bc04), 0) AS bc04, COALESCE(SUM(bc05), 0) AS bc05, COALESCE(SUM(bc06), 0) AS bc06, COALESCE(SUM(bc07), 0) AS bc07, COALESCE(SUM(bc08), 0) AS bc08, COALESCE(SUM(bc09), 0) AS bc09, COALESCE(SUM(bc10), 0) AS bc10, COALESCE(SUM(bc11), 0) AS bc11, COALESCE(SUM(bc12), 0) AS bc12
        , MAX(bs_sign) AS bs_sign
    FROM
        b4
    GROUP BY
        ledger_account_id
)

, c2 AS (

    -- final data on ledger accounts

    SELECT
        ledger_account_id
        , dr01, dr02, dr03, dr04, dr05, dr06, dr07, dr08, dr09, dr10, dr11, dr12
        , cr01, cr02, cr03, cr04, cr05, cr06, cr07, cr08, cr09, cr10, cr11, cr12
        , debit - credit AS balance00, balance01, balance02, balance03, balance04, balance05, balance06, balance07, balance08, balance09, balance10, balance11, balance12
        , debit AS bd00
        , CASE WHEN bs_sign = 1 THEN balance01 WHEN bs_sign = -1 THEN NULL WHEN bd01 > 0 THEN bd01 ELSE NULL END AS bd01
        , CASE WHEN bs_sign = 1 THEN balance02 WHEN bs_sign = -1 THEN NULL WHEN bd02 > 0 THEN bd02 ELSE NULL END AS bd02
        , CASE WHEN bs_sign = 1 THEN balance03 WHEN bs_sign = -1 THEN NULL WHEN bd03 > 0 THEN bd03 ELSE NULL END AS bd03
        , CASE WHEN bs_sign = 1 THEN balance04 WHEN bs_sign = -1 THEN NULL WHEN bd04 > 0 THEN bd04 ELSE NULL END AS bd04
        , CASE WHEN bs_sign = 1 THEN balance05 WHEN bs_sign = -1 THEN NULL WHEN bd05 > 0 THEN bd05 ELSE NULL END AS bd05
        , CASE WHEN bs_sign = 1 THEN balance06 WHEN bs_sign = -1 THEN NULL WHEN bd06 > 0 THEN bd06 ELSE NULL END AS bd06
        , CASE WHEN bs_sign = 1 THEN balance07 WHEN bs_sign = -1 THEN NULL WHEN bd07 > 0 THEN bd07 ELSE NULL END AS bd07
        , CASE WHEN bs_sign = 1 THEN balance08 WHEN bs_sign = -1 THEN NULL WHEN bd08 > 0 THEN bd08 ELSE NULL END AS bd08
        , CASE WHEN bs_sign = 1 THEN balance09 WHEN bs_sign = -1 THEN NULL WHEN bd09 > 0 THEN bd09 ELSE NULL END AS bd09
        , CASE WHEN bs_sign = 1 THEN balance10 WHEN bs_sign = -1 THEN NULL WHEN bd10 > 0 THEN bd10 ELSE NULL END AS bd10
        , CASE WHEN bs_sign = 1 THEN balance11 WHEN bs_sign = -1 THEN NULL WHEN bd11 > 0 THEN bd11 ELSE NULL END AS bd11
        , CASE WHEN bs_sign = 1 THEN balance12 WHEN bs_sign = -1 THEN NULL WHEN bd12 > 0 THEN bd12 ELSE NULL END AS bd12

        , credit AS bc00
        , CASE WHEN bs_sign = -1 THEN -balance01 WHEN bs_sign = 1 THEN NULL WHEN bd01 > 0 THEN -balance01 + bd01 ELSE NULL END AS bc01
        , CASE WHEN bs_sign = -1 THEN -balance02 WHEN bs_sign = 1 THEN NULL WHEN bd02 > 0 THEN -balance02 + bd02 ELSE NULL END AS bc02
        , CASE WHEN bs_sign = -1 THEN -balance03 WHEN bs_sign = 1 THEN NULL WHEN bd03 > 0 THEN -balance03 + bd03 ELSE NULL END AS bc03
        , CASE WHEN bs_sign = -1 THEN -balance04 WHEN bs_sign = 1 THEN NULL WHEN bd04 > 0 THEN -balance04 + bd04 ELSE NULL END AS bc04
        , CASE WHEN bs_sign = -1 THEN -balance05 WHEN bs_sign = 1 THEN NULL WHEN bd05 > 0 THEN -balance05 + bd05 ELSE NULL END AS bc05
        , CASE WHEN bs_sign = -1 THEN -balance06 WHEN bs_sign = 1 THEN NULL WHEN bd06 > 0 THEN -balance06 + bd06 ELSE NULL END AS bc06
        , CASE WHEN bs_sign = -1 THEN -balance07 WHEN bs_sign = 1 THEN NULL WHEN bd07 > 0 THEN -balance07 + bd07 ELSE NULL END AS bc07
        , CASE WHEN bs_sign = -1 THEN -balance08 WHEN bs_sign = 1 THEN NULL WHEN bd08 > 0 THEN -balance08 + bd08 ELSE NULL END AS bc08
        , CASE WHEN bs_sign = -1 THEN -balance09 WHEN bs_sign = 1 THEN NULL WHEN bd09 > 0 THEN -balance09 + bd09 ELSE NULL END AS bc09
        , CASE WHEN bs_sign = -1 THEN -balance10 WHEN bs_sign = 1 THEN NULL WHEN bd10 > 0 THEN -balance10 + bd10 ELSE NULL END AS bc10
        , CASE WHEN bs_sign = -1 THEN -balance11 WHEN bs_sign = 1 THEN NULL WHEN bd11 > 0 THEN -balance11 + bd11 ELSE NULL END AS bc11
        , CASE WHEN bs_sign = -1 THEN -balance12 WHEN bs_sign = 1 THEN NULL WHEN bd12 > 0 THEN -balance12 + bd12 ELSE NULL END AS bc12
    FROM
        c1
)

-- SELECT * FROM c1

SELECT
    *
FROM
    (

SELECT
    'A-' + m1.code AS [key]
    , 'accounts' AS section
    , m1.code
    , m1.name

    , payments01, payments02, payments03, payments04, payments05, payments06, payments07, payments08, payments09, payments10, payments11, payments12
    , charges01, charges02, charges03, charges04, charges05, charges06, charges07, charges08, charges09, charges10, charges11, charges12
    , cf01, cf02, cf03, cf04, cf05, cf06, cf07, cf08, cf09, cf10, cf11, cf12
    , vat01, vat02, vat03, vat04, vat05, vat06, vat07, vat08, vat09, vat10, vat11, vat12
    , pl01, pl02, pl03, pl04, pl05, pl06, pl07, pl08, pl09, pl10, pl11, pl12

    , NULL AS dr01, NULL AS dr02, NULL AS dr03, NULL AS dr04, NULL AS dr05, NULL AS dr06, NULL AS dr07, NULL AS dr08, NULL AS dr09, NULL AS dr10, NULL AS dr11, NULL AS dr12
    , NULL AS cr01, NULL AS cr02, NULL AS cr03, NULL AS cr04, NULL AS cr05, NULL AS cr06, NULL AS cr07, NULL AS cr08, NULL AS cr09, NULL AS cr10, NULL AS cr11, NULL AS cr12
    , NULL AS balance00, NULL AS balance01, NULL AS balance02, NULL AS balance03, NULL AS balance04, NULL AS balance05, NULL AS balance06, NULL AS balance07, NULL AS balance08, NULL AS balance09, NULL AS balance10, NULL AS balance11, NULL AS balance12
    , NULL AS bd00, NULL AS bd01, NULL AS bd02, NULL AS bd03, NULL AS bd04, NULL AS bd05, NULL AS bd06, NULL AS bd07, NULL AS bd08, NULL AS bd09, NULL AS bd10, NULL AS bd11, NULL AS bd12
    , NULL AS bc00, NULL AS bc01, NULL AS bc02, NULL AS bc03, NULL AS bc04, NULL AS bc05, NULL AS bc06, NULL AS bc07, NULL AS bc08, NULL AS bc09, NULL AS bc10, NULL AS bc11, NULL AS bc12
FROM
    (
    SELECT
        account_id
        , COALESCE(SUM(payments01), 0) AS payments01, COALESCE(SUM(payments02), 0) AS payments02, COALESCE(SUM(payments03), 0) AS payments03, COALESCE(SUM(payments04), 0) AS payments04, COALESCE(SUM(payments05), 0) AS payments05, COALESCE(SUM(payments06), 0) AS payments06, COALESCE(SUM(payments07), 0) AS payments07, COALESCE(SUM(payments08), 0) AS payments08, COALESCE(SUM(payments09), 0) AS payments09, COALESCE(SUM(payments10), 0) AS payments10, COALESCE(SUM(payments11), 0) AS payments11, COALESCE(SUM(payments12), 0) AS payments12
        , COALESCE(SUM(charges01), 0) AS charges01, COALESCE(SUM(charges02), 0) AS charges02, COALESCE(SUM(charges03), 0) AS charges03, COALESCE(SUM(charges04), 0) AS charges04, COALESCE(SUM(charges05), 0) AS charges05, COALESCE(SUM(charges06), 0) AS charges06, COALESCE(SUM(charges07), 0) AS charges07, COALESCE(SUM(charges08), 0) AS charges08, COALESCE(SUM(charges09), 0) AS charges09, COALESCE(SUM(charges10), 0) AS charges10, COALESCE(SUM(charges11), 0) AS charges11, COALESCE(SUM(charges12), 0) AS charges12
        , COALESCE(SUM(cf01), 0) AS cf01, COALESCE(SUM(cf02), 0) AS cf02, COALESCE(SUM(cf03), 0) AS cf03, COALESCE(SUM(cf04), 0) AS cf04, COALESCE(SUM(cf05), 0) AS cf05, COALESCE(SUM(cf06), 0) AS cf06, COALESCE(SUM(cf07), 0) AS cf07, COALESCE(SUM(cf08), 0) AS cf08, COALESCE(SUM(cf09), 0) AS cf09, COALESCE(SUM(cf10), 0) AS cf10, COALESCE(SUM(cf11), 0) AS cf11, COALESCE(SUM(cf12), 0) AS cf12
        , COALESCE(SUM(vat01), 0) AS vat01, COALESCE(SUM(vat02), 0) AS vat02, COALESCE(SUM(vat03), 0) AS vat03, COALESCE(SUM(vat04), 0) AS vat04, COALESCE(SUM(vat05), 0) AS vat05, COALESCE(SUM(vat06), 0) AS vat06, COALESCE(SUM(vat07), 0) AS vat07, COALESCE(SUM(vat08), 0) AS vat08, COALESCE(SUM(vat09), 0) AS vat09, COALESCE(SUM(vat10), 0) AS vat10, COALESCE(SUM(vat11), 0) AS vat11, COALESCE(SUM(vat12), 0) AS vat12
        , COALESCE(SUM(pl01), 0) AS pl01, COALESCE(SUM(pl02), 0) AS pl02, COALESCE(SUM(pl03), 0) AS pl03, COALESCE(SUM(pl04), 0) AS pl04, COALESCE(SUM(pl05), 0) AS pl05, COALESCE(SUM(pl06), 0) AS pl06, COALESCE(SUM(pl07), 0) AS pl07, COALESCE(SUM(pl08), 0) AS pl08, COALESCE(SUM(pl09), 0) AS pl09, COALESCE(SUM(pl10), 0) AS pl10, COALESCE(SUM(pl11), 0) AS pl11, COALESCE(SUM(pl12), 0) AS pl12
    FROM
        a2
    GROUP BY
        account_id
    ) t
    INNER JOIN dbo27.members m1 ON m1.id = t.account_id

UNION ALL
SELECT
    'E-' + m1.code AS [key]
    , 'entities' AS section
    , m1.code
    , m1.name

    , NULL AS payments01, NULL AS payments02, NULL AS payments03, NULL AS payments04, NULL AS payments05, NULL AS payments06, NULL AS payments07, NULL AS payments08, NULL AS payments09, NULL AS payments10, NULL AS payments11, NULL AS payments12
    , NULL AS charges01, NULL AS charges02, NULL AS charges03, NULL AS charges04, NULL AS charges05, NULL AS charges06, NULL AS charges07, NULL AS charges08, NULL AS charges09, NULL AS charges10, NULL AS charges11, NULL AS charges12
    , cf01, cf02, cf03, cf04, cf05, cf06, cf07, cf08, cf09, cf10, cf11, cf12
    , vat01, vat02, vat03, vat04, vat05, vat06, vat07, vat08, vat09, vat10, vat11, vat12
    , pl01, pl02, pl03, pl04, pl05, pl06, pl07, pl08, pl09, pl10, pl11, pl12

    , NULL AS dr01, NULL AS dr02, NULL AS dr03, NULL AS dr04, NULL AS dr05, NULL AS dr06, NULL AS dr07, NULL AS dr08, NULL AS dr09, NULL AS dr10, NULL AS dr11, NULL AS dr12
    , NULL AS cr01, NULL AS cr02, NULL AS cr03, NULL AS cr04, NULL AS cr05, NULL AS cr06, NULL AS cr07, NULL AS cr08, NULL AS cr09, NULL AS cr10, NULL AS cr11, NULL AS cr12
    , NULL AS balance00, NULL AS balance01, NULL AS balance02, NULL AS balance03, NULL AS balance04, NULL AS balance05, NULL AS balance06, NULL AS balance07, NULL AS balance08, NULL AS balance09, NULL AS balance10, NULL AS balance11, NULL AS balance12
    , NULL AS bd00, NULL AS bd01, NULL AS bd02, NULL AS bd03, NULL AS bd04, NULL AS bd05, NULL AS bd06, NULL AS bd07, NULL AS bd08, NULL AS bd09, NULL AS bd10, NULL AS bd11, NULL AS bd12
    , NULL AS bc00, NULL AS bc01, NULL AS bc02, NULL AS bc03, NULL AS bc04, NULL AS bc05, NULL AS bc06, NULL AS bc07, NULL AS bc08, NULL AS bc09, NULL AS bc10, NULL AS bc11, NULL AS bc12
FROM
    (
    SELECT
        entity_id
        , COALESCE(SUM(payments01), 0) AS payments01, COALESCE(SUM(payments02), 0) AS payments02, COALESCE(SUM(payments03), 0) AS payments03, COALESCE(SUM(payments04), 0) AS payments04, COALESCE(SUM(payments05), 0) AS payments05, COALESCE(SUM(payments06), 0) AS payments06, COALESCE(SUM(payments07), 0) AS payments07, COALESCE(SUM(payments08), 0) AS payments08, COALESCE(SUM(payments09), 0) AS payments09, COALESCE(SUM(payments10), 0) AS payments10, COALESCE(SUM(payments11), 0) AS payments11, COALESCE(SUM(payments12), 0) AS payments12
        , COALESCE(SUM(charges01), 0) AS charges01, COALESCE(SUM(charges02), 0) AS charges02, COALESCE(SUM(charges03), 0) AS charges03, COALESCE(SUM(charges04), 0) AS charges04, COALESCE(SUM(charges05), 0) AS charges05, COALESCE(SUM(charges06), 0) AS charges06, COALESCE(SUM(charges07), 0) AS charges07, COALESCE(SUM(charges08), 0) AS charges08, COALESCE(SUM(charges09), 0) AS charges09, COALESCE(SUM(charges10), 0) AS charges10, COALESCE(SUM(charges11), 0) AS charges11, COALESCE(SUM(charges12), 0) AS charges12
        , COALESCE(SUM(cf01), 0) AS cf01, COALESCE(SUM(cf02), 0) AS cf02, COALESCE(SUM(cf03), 0) AS cf03, COALESCE(SUM(cf04), 0) AS cf04, COALESCE(SUM(cf05), 0) AS cf05, COALESCE(SUM(cf06), 0) AS cf06, COALESCE(SUM(cf07), 0) AS cf07, COALESCE(SUM(cf08), 0) AS cf08, COALESCE(SUM(cf09), 0) AS cf09, COALESCE(SUM(cf10), 0) AS cf10, COALESCE(SUM(cf11), 0) AS cf11, COALESCE(SUM(cf12), 0) AS cf12
        , COALESCE(SUM(vat01), 0) AS vat01, COALESCE(SUM(vat02), 0) AS vat02, COALESCE(SUM(vat03), 0) AS vat03, COALESCE(SUM(vat04), 0) AS vat04, COALESCE(SUM(vat05), 0) AS vat05, COALESCE(SUM(vat06), 0) AS vat06, COALESCE(SUM(vat07), 0) AS vat07, COALESCE(SUM(vat08), 0) AS vat08, COALESCE(SUM(vat09), 0) AS vat09, COALESCE(SUM(vat10), 0) AS vat10, COALESCE(SUM(vat11), 0) AS vat11, COALESCE(SUM(vat12), 0) AS vat12
        , COALESCE(SUM(pl01), 0) AS pl01, COALESCE(SUM(pl02), 0) AS pl02, COALESCE(SUM(pl03), 0) AS pl03, COALESCE(SUM(pl04), 0) AS pl04, COALESCE(SUM(pl05), 0) AS pl05, COALESCE(SUM(pl06), 0) AS pl06, COALESCE(SUM(pl07), 0) AS pl07, COALESCE(SUM(pl08), 0) AS pl08, COALESCE(SUM(pl09), 0) AS pl09, COALESCE(SUM(pl10), 0) AS pl10, COALESCE(SUM(pl11), 0) AS pl11, COALESCE(SUM(pl12), 0) AS pl12
    FROM
        a2
    GROUP BY
        entity_id
    ) t
    INNER JOIN dbo27.members m1 ON m1.id = t.entity_id

UNION ALL
SELECT
    'A-' + m1.code + '-' + COALESCE(m2.code, 'xx') AS [key]
    , 'accounts+products' AS section
    , m1.code + '-' + COALESCE(m2.code, 'xx') AS code
    , m1.name + ' - ' + COALESCE(m2.name, 'xx') AS name

    , payments01, payments02, payments03, payments04, payments05, payments06, payments07, payments08, payments09, payments10, payments11, payments12
    , charges01, charges02, charges03, charges04, charges05, charges06, charges07, charges08, charges09, charges10, charges11, charges12
    , cf01, cf02, cf03, cf04, cf05, cf06, cf07, cf08, cf09, cf10, cf11, cf12
    , vat01, vat02, vat03, vat04, vat05, vat06, vat07, vat08, vat09, vat10, vat11, vat12
    , pl01, pl02, pl03, pl04, pl05, pl06, pl07, pl08, pl09, pl10, pl11, pl12

    , NULL AS dr01, NULL AS dr02, NULL AS dr03, NULL AS dr04, NULL AS dr05, NULL AS dr06, NULL AS dr07, NULL AS dr08, NULL AS dr09, NULL AS dr10, NULL AS dr11, NULL AS dr12
    , NULL AS cr01, NULL AS cr02, NULL AS cr03, NULL AS cr04, NULL AS cr05, NULL AS cr06, NULL AS cr07, NULL AS cr08, NULL AS cr09, NULL AS cr10, NULL AS cr11, NULL AS cr12
    , NULL AS balance00, NULL AS balance01, NULL AS balance02, NULL AS balance03, NULL AS balance04, NULL AS balance05, NULL AS balance06, NULL AS balance07, NULL AS balance08, NULL AS balance09, NULL AS balance10, NULL AS balance11, NULL AS balance12
    , NULL AS bd00, NULL AS bd01, NULL AS bd02, NULL AS bd03, NULL AS bd04, NULL AS bd05, NULL AS bd06, NULL AS bd07, NULL AS bd08, NULL AS bd09, NULL AS bd10, NULL AS bd11, NULL AS bd12
    , NULL AS bc00, NULL AS bc01, NULL AS bc02, NULL AS bc03, NULL AS bc04, NULL AS bc05, NULL AS bc06, NULL AS bc07, NULL AS bc08, NULL AS bc09, NULL AS bc10, NULL AS bc11, NULL AS bc12
FROM
    (
    SELECT
        account_id
        , product_id
        , COALESCE(SUM(payments01), 0) AS payments01, COALESCE(SUM(payments02), 0) AS payments02, COALESCE(SUM(payments03), 0) AS payments03, COALESCE(SUM(payments04), 0) AS payments04, COALESCE(SUM(payments05), 0) AS payments05, COALESCE(SUM(payments06), 0) AS payments06, COALESCE(SUM(payments07), 0) AS payments07, COALESCE(SUM(payments08), 0) AS payments08, COALESCE(SUM(payments09), 0) AS payments09, COALESCE(SUM(payments10), 0) AS payments10, COALESCE(SUM(payments11), 0) AS payments11, COALESCE(SUM(payments12), 0) AS payments12
        , COALESCE(SUM(charges01), 0) AS charges01, COALESCE(SUM(charges02), 0) AS charges02, COALESCE(SUM(charges03), 0) AS charges03, COALESCE(SUM(charges04), 0) AS charges04, COALESCE(SUM(charges05), 0) AS charges05, COALESCE(SUM(charges06), 0) AS charges06, COALESCE(SUM(charges07), 0) AS charges07, COALESCE(SUM(charges08), 0) AS charges08, COALESCE(SUM(charges09), 0) AS charges09, COALESCE(SUM(charges10), 0) AS charges10, COALESCE(SUM(charges11), 0) AS charges11, COALESCE(SUM(charges12), 0) AS charges12
        , COALESCE(SUM(cf01), 0) AS cf01, COALESCE(SUM(cf02), 0) AS cf02, COALESCE(SUM(cf03), 0) AS cf03, COALESCE(SUM(cf04), 0) AS cf04, COALESCE(SUM(cf05), 0) AS cf05, COALESCE(SUM(cf06), 0) AS cf06, COALESCE(SUM(cf07), 0) AS cf07, COALESCE(SUM(cf08), 0) AS cf08, COALESCE(SUM(cf09), 0) AS cf09, COALESCE(SUM(cf10), 0) AS cf10, COALESCE(SUM(cf11), 0) AS cf11, COALESCE(SUM(cf12), 0) AS cf12
        , COALESCE(SUM(vat01), 0) AS vat01, COALESCE(SUM(vat02), 0) AS vat02, COALESCE(SUM(vat03), 0) AS vat03, COALESCE(SUM(vat04), 0) AS vat04, COALESCE(SUM(vat05), 0) AS vat05, COALESCE(SUM(vat06), 0) AS vat06, COALESCE(SUM(vat07), 0) AS vat07, COALESCE(SUM(vat08), 0) AS vat08, COALESCE(SUM(vat09), 0) AS vat09, COALESCE(SUM(vat10), 0) AS vat10, COALESCE(SUM(vat11), 0) AS vat11, COALESCE(SUM(vat12), 0) AS vat12
        , COALESCE(SUM(pl01), 0) AS pl01, COALESCE(SUM(pl02), 0) AS pl02, COALESCE(SUM(pl03), 0) AS pl03, COALESCE(SUM(pl04), 0) AS pl04, COALESCE(SUM(pl05), 0) AS pl05, COALESCE(SUM(pl06), 0) AS pl06, COALESCE(SUM(pl07), 0) AS pl07, COALESCE(SUM(pl08), 0) AS pl08, COALESCE(SUM(pl09), 0) AS pl09, COALESCE(SUM(pl10), 0) AS pl10, COALESCE(SUM(pl11), 0) AS pl11, COALESCE(SUM(pl12), 0) AS pl12
    FROM
        a2
    GROUP BY
        account_id
        , product_id
    ) t
    INNER JOIN dbo27.members m1 ON m1.id = t.account_id
    LEFT OUTER JOIN dbo27.members m2 ON m2.id = t.product_id

UNION ALL
SELECT
    'R-' + m1.code + '-' + COALESCE(m2.code, 'x') AS [key]
    , 'accounts+regions' AS section
    , m1.code + '-' + COALESCE(m2.code, 'x') AS code
    , m1.name + ' - ' + COALESCE(m2.name, 'x') AS name

    , payments01, payments02, payments03, payments04, payments05, payments06, payments07, payments08, payments09, payments10, payments11, payments12
    , charges01, charges02, charges03, charges04, charges05, charges06, charges07, charges08, charges09, charges10, charges11, charges12
    , cf01, cf02, cf03, cf04, cf05, cf06, cf07, cf08, cf09, cf10, cf11, cf12
    , vat01, vat02, vat03, vat04, vat05, vat06, vat07, vat08, vat09, vat10, vat11, vat12
    , pl01, pl02, pl03, pl04, pl05, pl06, pl07, pl08, pl09, pl10, pl11, pl12

    , NULL AS dr01, NULL AS dr02, NULL AS dr03, NULL AS dr04, NULL AS dr05, NULL AS dr06, NULL AS dr07, NULL AS dr08, NULL AS dr09, NULL AS dr10, NULL AS dr11, NULL AS dr12
    , NULL AS cr01, NULL AS cr02, NULL AS cr03, NULL AS cr04, NULL AS cr05, NULL AS cr06, NULL AS cr07, NULL AS cr08, NULL AS cr09, NULL AS cr10, NULL AS cr11, NULL AS cr12
    , NULL AS balance00, NULL AS balance01, NULL AS balance02, NULL AS balance03, NULL AS balance04, NULL AS balance05, NULL AS balance06, NULL AS balance07, NULL AS balance08, NULL AS balance09, NULL AS balance10, NULL AS balance11, NULL AS balance12
    , NULL AS bd00, NULL AS bd01, NULL AS bd02, NULL AS bd03, NULL AS bd04, NULL AS bd05, NULL AS bd06, NULL AS bd07, NULL AS bd08, NULL AS bd09, NULL AS bd10, NULL AS bd11, NULL AS bd12
    , NULL AS bc00, NULL AS bc01, NULL AS bc02, NULL AS bc03, NULL AS bc04, NULL AS bc05, NULL AS bc06, NULL AS bc07, NULL AS bc08, NULL AS bc09, NULL AS bc10, NULL AS bc11, NULL AS bc12
FROM
    (
    SELECT
        account_id
        , region_id
        , COALESCE(SUM(payments01), 0) AS payments01, COALESCE(SUM(payments02), 0) AS payments02, COALESCE(SUM(payments03), 0) AS payments03, COALESCE(SUM(payments04), 0) AS payments04, COALESCE(SUM(payments05), 0) AS payments05, COALESCE(SUM(payments06), 0) AS payments06, COALESCE(SUM(payments07), 0) AS payments07, COALESCE(SUM(payments08), 0) AS payments08, COALESCE(SUM(payments09), 0) AS payments09, COALESCE(SUM(payments10), 0) AS payments10, COALESCE(SUM(payments11), 0) AS payments11, COALESCE(SUM(payments12), 0) AS payments12
        , COALESCE(SUM(charges01), 0) AS charges01, COALESCE(SUM(charges02), 0) AS charges02, COALESCE(SUM(charges03), 0) AS charges03, COALESCE(SUM(charges04), 0) AS charges04, COALESCE(SUM(charges05), 0) AS charges05, COALESCE(SUM(charges06), 0) AS charges06, COALESCE(SUM(charges07), 0) AS charges07, COALESCE(SUM(charges08), 0) AS charges08, COALESCE(SUM(charges09), 0) AS charges09, COALESCE(SUM(charges10), 0) AS charges10, COALESCE(SUM(charges11), 0) AS charges11, COALESCE(SUM(charges12), 0) AS charges12
        , COALESCE(SUM(cf01), 0) AS cf01, COALESCE(SUM(cf02), 0) AS cf02, COALESCE(SUM(cf03), 0) AS cf03, COALESCE(SUM(cf04), 0) AS cf04, COALESCE(SUM(cf05), 0) AS cf05, COALESCE(SUM(cf06), 0) AS cf06, COALESCE(SUM(cf07), 0) AS cf07, COALESCE(SUM(cf08), 0) AS cf08, COALESCE(SUM(cf09), 0) AS cf09, COALESCE(SUM(cf10), 0) AS cf10, COALESCE(SUM(cf11), 0) AS cf11, COALESCE(SUM(cf12), 0) AS cf12
        , COALESCE(SUM(vat01), 0) AS vat01, COALESCE(SUM(vat02), 0) AS vat02, COALESCE(SUM(vat03), 0) AS vat03, COALESCE(SUM(vat04), 0) AS vat04, COALESCE(SUM(vat05), 0) AS vat05, COALESCE(SUM(vat06), 0) AS vat06, COALESCE(SUM(vat07), 0) AS vat07, COALESCE(SUM(vat08), 0) AS vat08, COALESCE(SUM(vat09), 0) AS vat09, COALESCE(SUM(vat10), 0) AS vat10, COALESCE(SUM(vat11), 0) AS vat11, COALESCE(SUM(vat12), 0) AS vat12
        , COALESCE(SUM(pl01), 0) AS pl01, COALESCE(SUM(pl02), 0) AS pl02, COALESCE(SUM(pl03), 0) AS pl03, COALESCE(SUM(pl04), 0) AS pl04, COALESCE(SUM(pl05), 0) AS pl05, COALESCE(SUM(pl06), 0) AS pl06, COALESCE(SUM(pl07), 0) AS pl07, COALESCE(SUM(pl08), 0) AS pl08, COALESCE(SUM(pl09), 0) AS pl09, COALESCE(SUM(pl10), 0) AS pl10, COALESCE(SUM(pl11), 0) AS pl11, COALESCE(SUM(pl12), 0) AS pl12
    FROM
        a2
    GROUP BY
        account_id
        , region_id
    ) t
    INNER JOIN dbo27.members m1 ON m1.id = t.account_id
    LEFT OUTER JOIN dbo27.members m2 ON m2.id = t.region_id

UNION ALL
SELECT
    'A-' + m1.code + '-' + COALESCE(m2.code, 'xxx') AS [key]
    , 'accounts+companies' AS section
    , m1.code + '-' + COALESCE(m2.code, 'xxx') AS code
    , m1.name + ' - ' + m2.name AS name

    , payments01, payments02, payments03, payments04, payments05, payments06, payments07, payments08, payments09, payments10, payments11, payments12
    , charges01, charges02, charges03, charges04, charges05, charges06, charges07, charges08, charges09, charges10, charges11, charges12
    , cf01, cf02, cf03, cf04, cf05, cf06, cf07, cf08, cf09, cf10, cf11, cf12
    , vat01, vat02, vat03, vat04, vat05, vat06, vat07, vat08, vat09, vat10, vat11, vat12
    , pl01, pl02, pl03, pl04, pl05, pl06, pl07, pl08, pl09, pl10, pl11, pl12

    , NULL AS dr01, NULL AS dr02, NULL AS dr03, NULL AS dr04, NULL AS dr05, NULL AS dr06, NULL AS dr07, NULL AS dr08, NULL AS dr09, NULL AS dr10, NULL AS dr11, NULL AS dr12
    , NULL AS cr01, NULL AS cr02, NULL AS cr03, NULL AS cr04, NULL AS cr05, NULL AS cr06, NULL AS cr07, NULL AS cr08, NULL AS cr09, NULL AS cr10, NULL AS cr11, NULL AS cr12
    , NULL AS balance00, NULL AS balance01, NULL AS balance02, NULL AS balance03, NULL AS balance04, NULL AS balance05, NULL AS balance06, NULL AS balance07, NULL AS balance08, NULL AS balance09, NULL AS balance10, NULL AS balance11, NULL AS balance12
    , NULL AS bd00, NULL AS bd01, NULL AS bd02, NULL AS bd03, NULL AS bd04, NULL AS bd05, NULL AS bd06, NULL AS bd07, NULL AS bd08, NULL AS bd09, NULL AS bd10, NULL AS bd11, NULL AS bd12
    , NULL AS bc00, NULL AS bc01, NULL AS bc02, NULL AS bc03, NULL AS bc04, NULL AS bc05, NULL AS bc06, NULL AS bc07, NULL AS bc08, NULL AS bc09, NULL AS bc10, NULL AS bc11, NULL AS bc12
FROM
    (
    SELECT
        account_id
        , subsidiary_account_id
        , COALESCE(SUM(payments01), 0) AS payments01, COALESCE(SUM(payments02), 0) AS payments02, COALESCE(SUM(payments03), 0) AS payments03, COALESCE(SUM(payments04), 0) AS payments04, COALESCE(SUM(payments05), 0) AS payments05, COALESCE(SUM(payments06), 0) AS payments06, COALESCE(SUM(payments07), 0) AS payments07, COALESCE(SUM(payments08), 0) AS payments08, COALESCE(SUM(payments09), 0) AS payments09, COALESCE(SUM(payments10), 0) AS payments10, COALESCE(SUM(payments11), 0) AS payments11, COALESCE(SUM(payments12), 0) AS payments12
        , COALESCE(SUM(charges01), 0) AS charges01, COALESCE(SUM(charges02), 0) AS charges02, COALESCE(SUM(charges03), 0) AS charges03, COALESCE(SUM(charges04), 0) AS charges04, COALESCE(SUM(charges05), 0) AS charges05, COALESCE(SUM(charges06), 0) AS charges06, COALESCE(SUM(charges07), 0) AS charges07, COALESCE(SUM(charges08), 0) AS charges08, COALESCE(SUM(charges09), 0) AS charges09, COALESCE(SUM(charges10), 0) AS charges10, COALESCE(SUM(charges11), 0) AS charges11, COALESCE(SUM(charges12), 0) AS charges12
        , COALESCE(SUM(cf01), 0) AS cf01, COALESCE(SUM(cf02), 0) AS cf02, COALESCE(SUM(cf03), 0) AS cf03, COALESCE(SUM(cf04), 0) AS cf04, COALESCE(SUM(cf05), 0) AS cf05, COALESCE(SUM(cf06), 0) AS cf06, COALESCE(SUM(cf07), 0) AS cf07, COALESCE(SUM(cf08), 0) AS cf08, COALESCE(SUM(cf09), 0) AS cf09, COALESCE(SUM(cf10), 0) AS cf10, COALESCE(SUM(cf11), 0) AS cf11, COALESCE(SUM(cf12), 0) AS cf12
        , COALESCE(SUM(vat01), 0) AS vat01, COALESCE(SUM(vat02), 0) AS vat02, COALESCE(SUM(vat03), 0) AS vat03, COALESCE(SUM(vat04), 0) AS vat04, COALESCE(SUM(vat05), 0) AS vat05, COALESCE(SUM(vat06), 0) AS vat06, COALESCE(SUM(vat07), 0) AS vat07, COALESCE(SUM(vat08), 0) AS vat08, COALESCE(SUM(vat09), 0) AS vat09, COALESCE(SUM(vat10), 0) AS vat10, COALESCE(SUM(vat11), 0) AS vat11, COALESCE(SUM(vat12), 0) AS vat12
        , COALESCE(SUM(pl01), 0) AS pl01, COALESCE(SUM(pl02), 0) AS pl02, COALESCE(SUM(pl03), 0) AS pl03, COALESCE(SUM(pl04), 0) AS pl04, COALESCE(SUM(pl05), 0) AS pl05, COALESCE(SUM(pl06), 0) AS pl06, COALESCE(SUM(pl07), 0) AS pl07, COALESCE(SUM(pl08), 0) AS pl08, COALESCE(SUM(pl09), 0) AS pl09, COALESCE(SUM(pl10), 0) AS pl10, COALESCE(SUM(pl11), 0) AS pl11, COALESCE(SUM(pl12), 0) AS pl12
    FROM
        a2
    GROUP BY
        account_id
        , subsidiary_account_id
    ) t
    INNER JOIN dbo27.members m1 ON m1.id = t.account_id
    INNER JOIN dbo27.members m2 ON m2.id = t.subsidiary_account_id

UNION ALL
SELECT
    'C-' + CASE cf_sign WHEN -1 THEN 'CF-' WHEN 0 THEN 'CF0' WHEN 1 THEN 'CF+' ELSE 'CF?' END AS [key]
    , 'totals_cf' AS section
    , CASE cf_sign WHEN -1 THEN 'CF-' WHEN 0 THEN 'CF0' WHEN 1 THEN 'CF+' ELSE 'CF?' END AS code
    , NULL AS name

    , NULL AS payments01, NULL AS payments02, NULL AS payments03, NULL AS payments04, NULL AS payments05, NULL AS payments06, NULL AS payments07, NULL AS payments08, NULL AS payments09, NULL AS payments10, NULL AS payments11, NULL AS payments12
    , NULL AS charges01, NULL AS charges02, NULL AS charges03, NULL AS charges04, NULL AS charges05, NULL AS charges06, NULL AS charges07, NULL AS charges08, NULL AS charges09, NULL AS charges10, NULL AS charges11, NULL AS charges12
    , cf01, cf02, cf03, cf04, cf05, cf06, cf07, cf08, cf09, cf10, cf11, cf12
    , NULL AS vat01, NULL AS vat02, NULL AS vat03, NULL AS vat04, NULL AS vat05, NULL AS vat06, NULL AS vat07, NULL AS vat08, NULL AS vat09, NULL AS vat10, NULL AS vat11, NULL AS vat12
    , NULL AS pl01, NULL AS pl02, NULL AS pl03, NULL AS pl04, NULL AS pl05, NULL AS pl06, NULL AS pl07, NULL AS pl08, NULL AS pl09, NULL AS pl10, NULL AS pl11, NULL AS pl12

    , NULL AS dr01, NULL AS dr02, NULL AS dr03, NULL AS dr04, NULL AS dr05, NULL AS dr06, NULL AS dr07, NULL AS dr08, NULL AS dr09, NULL AS dr10, NULL AS dr11, NULL AS dr12
    , NULL AS cr01, NULL AS cr02, NULL AS cr03, NULL AS cr04, NULL AS cr05, NULL AS cr06, NULL AS cr07, NULL AS cr08, NULL AS cr09, NULL AS cr10, NULL AS cr11, NULL AS cr12
    , NULL AS balance00, NULL AS balance01, NULL AS balance02, NULL AS balance03, NULL AS balance04, NULL AS balance05, NULL AS balance06, NULL AS balance07, NULL AS balance08, NULL AS balance09, NULL AS balance10, NULL AS balance11, NULL AS balance12
    , NULL AS bd00, NULL AS bd01, NULL AS bd02, NULL AS bd03, NULL AS bd04, NULL AS bd05, NULL AS bd06, NULL AS bd07, NULL AS bd08, NULL AS bd09, NULL AS bd10, NULL AS bd11, NULL AS bd12
    , NULL AS bc00, NULL AS bc01, NULL AS bc02, NULL AS bc03, NULL AS bc04, NULL AS bc05, NULL AS bc06, NULL AS bc07, NULL AS bc08, NULL AS bc09, NULL AS bc10, NULL AS bc11, NULL AS bc12
FROM
    (
    SELECT
        cf_sign
        , COALESCE(SUM(payments01), 0) AS payments01, COALESCE(SUM(payments02), 0) AS payments02, COALESCE(SUM(payments03), 0) AS payments03, COALESCE(SUM(payments04), 0) AS payments04, COALESCE(SUM(payments05), 0) AS payments05, COALESCE(SUM(payments06), 0) AS payments06, COALESCE(SUM(payments07), 0) AS payments07, COALESCE(SUM(payments08), 0) AS payments08, COALESCE(SUM(payments09), 0) AS payments09, COALESCE(SUM(payments10), 0) AS payments10, COALESCE(SUM(payments11), 0) AS payments11, COALESCE(SUM(payments12), 0) AS payments12
        , COALESCE(SUM(charges01), 0) AS charges01, COALESCE(SUM(charges02), 0) AS charges02, COALESCE(SUM(charges03), 0) AS charges03, COALESCE(SUM(charges04), 0) AS charges04, COALESCE(SUM(charges05), 0) AS charges05, COALESCE(SUM(charges06), 0) AS charges06, COALESCE(SUM(charges07), 0) AS charges07, COALESCE(SUM(charges08), 0) AS charges08, COALESCE(SUM(charges09), 0) AS charges09, COALESCE(SUM(charges10), 0) AS charges10, COALESCE(SUM(charges11), 0) AS charges11, COALESCE(SUM(charges12), 0) AS charges12
        , COALESCE(SUM(cf01), 0) AS cf01, COALESCE(SUM(cf02), 0) AS cf02, COALESCE(SUM(cf03), 0) AS cf03, COALESCE(SUM(cf04), 0) AS cf04, COALESCE(SUM(cf05), 0) AS cf05, COALESCE(SUM(cf06), 0) AS cf06, COALESCE(SUM(cf07), 0) AS cf07, COALESCE(SUM(cf08), 0) AS cf08, COALESCE(SUM(cf09), 0) AS cf09, COALESCE(SUM(cf10), 0) AS cf10, COALESCE(SUM(cf11), 0) AS cf11, COALESCE(SUM(cf12), 0) AS cf12
        , COALESCE(SUM(vat01), 0) AS vat01, COALESCE(SUM(vat02), 0) AS vat02, COALESCE(SUM(vat03), 0) AS vat03, COALESCE(SUM(vat04), 0) AS vat04, COALESCE(SUM(vat05), 0) AS vat05, COALESCE(SUM(vat06), 0) AS vat06, COALESCE(SUM(vat07), 0) AS vat07, COALESCE(SUM(vat08), 0) AS vat08, COALESCE(SUM(vat09), 0) AS vat09, COALESCE(SUM(vat10), 0) AS vat10, COALESCE(SUM(vat11), 0) AS vat11, COALESCE(SUM(vat12), 0) AS vat12
        , COALESCE(SUM(pl01), 0) AS pl01, COALESCE(SUM(pl02), 0) AS pl02, COALESCE(SUM(pl03), 0) AS pl03, COALESCE(SUM(pl04), 0) AS pl04, COALESCE(SUM(pl05), 0) AS pl05, COALESCE(SUM(pl06), 0) AS pl06, COALESCE(SUM(pl07), 0) AS pl07, COALESCE(SUM(pl08), 0) AS pl08, COALESCE(SUM(pl09), 0) AS pl09, COALESCE(SUM(pl10), 0) AS pl10, COALESCE(SUM(pl11), 0) AS pl11, COALESCE(SUM(pl12), 0) AS pl12
    FROM
        a2
    GROUP BY
        cf_sign
    ) t


UNION ALL
SELECT
    'C-' + CASE pl_sign WHEN 1 THEN 'PL+' WHEN 0 THEN 'PL0' WHEN -1 THEN 'PL-' ELSE 'PL?' END AS [key]
    , 'totals_pl' AS section
    , CASE pl_sign WHEN 1 THEN 'PL+' WHEN 0 THEN 'PL0' WHEN -1 THEN 'PL-' ELSE 'PL?' END AS code
    , NULL AS name

    , NULL AS payments01, NULL AS payments02, NULL AS payments03, NULL AS payments04, NULL AS payments05, NULL AS payments06, NULL AS payments07, NULL AS payments08, NULL AS payments09, NULL AS payments10, NULL AS payments11, NULL AS payments12
    , NULL AS charges01, NULL AS charges02, NULL AS charges03, NULL AS charges04, NULL AS charges05, NULL AS charges06, NULL AS charges07, NULL AS charges08, NULL AS charges09, NULL AS charges10, NULL AS charges11, NULL AS charges12
    , NULL AS cf01, NULL AS cf02, NULL AS cf03, NULL AS cf04, NULL AS cf05, NULL AS cf06, NULL AS cf07, NULL AS cf08, NULL AS cf09, NULL AS cf10, NULL AS cf11, NULL AS cf12
    , vat01, vat02, vat03, vat04, vat05, vat06, vat07, vat08, vat09, vat10, vat11, vat12
    , pl01, pl02, pl03, pl04, pl05, pl06, pl07, pl08, pl09, pl10, pl11, pl12

    , NULL AS dr01, NULL AS dr02, NULL AS dr03, NULL AS dr04, NULL AS dr05, NULL AS dr06, NULL AS dr07, NULL AS dr08, NULL AS dr09, NULL AS dr10, NULL AS dr11, NULL AS dr12
    , NULL AS cr01, NULL AS cr02, NULL AS cr03, NULL AS cr04, NULL AS cr05, NULL AS cr06, NULL AS cr07, NULL AS cr08, NULL AS cr09, NULL AS cr10, NULL AS cr11, NULL AS cr12
    , NULL AS balance00, NULL AS balance01, NULL AS balance02, NULL AS balance03, NULL AS balance04, NULL AS balance05, NULL AS balance06, NULL AS balance07, NULL AS balance08, NULL AS balance09, NULL AS balance10, NULL AS balance11, NULL AS balance12
    , NULL AS bd00, NULL AS bd01, NULL AS bd02, NULL AS bd03, NULL AS bd04, NULL AS bd05, NULL AS bd06, NULL AS bd07, NULL AS bd08, NULL AS bd09, NULL AS bd10, NULL AS bd11, NULL AS bd12
    , NULL AS bc00, NULL AS bc01, NULL AS bc02, NULL AS bc03, NULL AS bc04, NULL AS bc05, NULL AS bc06, NULL AS bc07, NULL AS bc08, NULL AS bc09, NULL AS bc10, NULL AS bc11, NULL AS bc12
FROM
    (
    SELECT
        pl_sign
        , COALESCE(SUM(payments01), 0) AS payments01, COALESCE(SUM(payments02), 0) AS payments02, COALESCE(SUM(payments03), 0) AS payments03, COALESCE(SUM(payments04), 0) AS payments04, COALESCE(SUM(payments05), 0) AS payments05, COALESCE(SUM(payments06), 0) AS payments06, COALESCE(SUM(payments07), 0) AS payments07, COALESCE(SUM(payments08), 0) AS payments08, COALESCE(SUM(payments09), 0) AS payments09, COALESCE(SUM(payments10), 0) AS payments10, COALESCE(SUM(payments11), 0) AS payments11, COALESCE(SUM(payments12), 0) AS payments12
        , COALESCE(SUM(charges01), 0) AS charges01, COALESCE(SUM(charges02), 0) AS charges02, COALESCE(SUM(charges03), 0) AS charges03, COALESCE(SUM(charges04), 0) AS charges04, COALESCE(SUM(charges05), 0) AS charges05, COALESCE(SUM(charges06), 0) AS charges06, COALESCE(SUM(charges07), 0) AS charges07, COALESCE(SUM(charges08), 0) AS charges08, COALESCE(SUM(charges09), 0) AS charges09, COALESCE(SUM(charges10), 0) AS charges10, COALESCE(SUM(charges11), 0) AS charges11, COALESCE(SUM(charges12), 0) AS charges12
        , COALESCE(SUM(cf01), 0) AS cf01, COALESCE(SUM(cf02), 0) AS cf02, COALESCE(SUM(cf03), 0) AS cf03, COALESCE(SUM(cf04), 0) AS cf04, COALESCE(SUM(cf05), 0) AS cf05, COALESCE(SUM(cf06), 0) AS cf06, COALESCE(SUM(cf07), 0) AS cf07, COALESCE(SUM(cf08), 0) AS cf08, COALESCE(SUM(cf09), 0) AS cf09, COALESCE(SUM(cf10), 0) AS cf10, COALESCE(SUM(cf11), 0) AS cf11, COALESCE(SUM(cf12), 0) AS cf12
        , COALESCE(SUM(vat01), 0) AS vat01, COALESCE(SUM(vat02), 0) AS vat02, COALESCE(SUM(vat03), 0) AS vat03, COALESCE(SUM(vat04), 0) AS vat04, COALESCE(SUM(vat05), 0) AS vat05, COALESCE(SUM(vat06), 0) AS vat06, COALESCE(SUM(vat07), 0) AS vat07, COALESCE(SUM(vat08), 0) AS vat08, COALESCE(SUM(vat09), 0) AS vat09, COALESCE(SUM(vat10), 0) AS vat10, COALESCE(SUM(vat11), 0) AS vat11, COALESCE(SUM(vat12), 0) AS vat12
        , COALESCE(SUM(pl01), 0) AS pl01, COALESCE(SUM(pl02), 0) AS pl02, COALESCE(SUM(pl03), 0) AS pl03, COALESCE(SUM(pl04), 0) AS pl04, COALESCE(SUM(pl05), 0) AS pl05, COALESCE(SUM(pl06), 0) AS pl06, COALESCE(SUM(pl07), 0) AS pl07, COALESCE(SUM(pl08), 0) AS pl08, COALESCE(SUM(pl09), 0) AS pl09, COALESCE(SUM(pl10), 0) AS pl10, COALESCE(SUM(pl11), 0) AS pl11, COALESCE(SUM(pl12), 0) AS pl12
    FROM
        a2
    GROUP BY
        pl_sign
    ) t

UNION ALL
SELECT
    'B-' + m1.code AS [key]
    , 'ledger_accounts' AS section
    , m1.code
    , m1.name

    , NULL AS payments01, NULL AS payments02, NULL AS payments03, NULL AS payments04, NULL AS payments05, NULL AS payments06, NULL AS payments07, NULL AS payments08, NULL AS payments09, NULL AS payments10, NULL AS payments11, NULL AS payments12
    , NULL AS charges01, NULL AS charges02, NULL AS charges03, NULL AS charges04, NULL AS charges05, NULL AS charges06, NULL AS charges07, NULL AS charges08, NULL AS charges09, NULL AS charges10, NULL AS charges11, NULL AS charges12
    , NULL AS cf01, NULL AS cf02, NULL AS cf03, NULL AS cf04, NULL AS cf05, NULL AS cf06, NULL AS cf07, NULL AS cf08, NULL AS cf09, NULL AS cf10, NULL AS cf11, NULL AS cf12
    , NULL AS vat01, NULL AS vat02, NULL AS vat03, NULL AS vat04, NULL AS vat05, NULL AS vat06, NULL AS vat07, NULL AS vat08, NULL AS vat09, NULL AS vat10, NULL AS vat11, NULL AS vat12
    , NULL AS pl01, NULL AS pl02, NULL AS pl03, NULL AS pl04, NULL AS pl05, NULL AS pl06, NULL AS pl07, NULL AS pl08, NULL AS pl09, NULL AS pl10, NULL AS pl11, NULL AS pl12

    , dr01, dr02, dr03, dr04, dr05, dr06, dr07, dr08, dr09, dr10, dr11, dr12
    , cr01, cr02, cr03, cr04, cr05, cr06, cr07, cr08, cr09, cr10, cr11, cr12
    , balance00, balance01, balance02, balance03, balance04, balance05, balance06, balance07, balance08, balance09, balance10, balance11, balance12
    , bd00, bd01, bd02, bd03, bd04, bd05, bd06, bd07, bd08, bd09, bd10, bd11, bd12
    , bc00, bc01, bc02, bc03, bc04, bc05, bc06, bc07, bc08, bc09, bc10, bc11, bc12
FROM
    c2
    INNER JOIN dbo27.ledger_accounts m1 ON m1.id = ledger_account_id

UNION ALL
SELECT
    'B-' + m1.code + '-' + m2.code AS [key]
    , 'ledger+subsidiary_accounts' AS section
    , m1.code + '-' + m2.code AS code
    , m2.name

    , NULL AS payments01, NULL AS payments02, NULL AS payments03, NULL AS payments04, NULL AS payments05, NULL AS payments06, NULL AS payments07, NULL AS payments08, NULL AS payments09, NULL AS payments10, NULL AS payments11, NULL AS payments12
    , NULL AS charges01, NULL AS charges02, NULL AS charges03, NULL AS charges04, NULL AS charges05, NULL AS charges06, NULL AS charges07, NULL AS charges08, NULL AS charges09, NULL AS charges10, NULL AS charges11, NULL AS charges12
    , NULL AS cf01, NULL AS cf02, NULL AS cf03, NULL AS cf04, NULL AS cf05, NULL AS cf06, NULL AS cf07, NULL AS cf08, NULL AS cf09, NULL AS cf10, NULL AS cf11, NULL AS cf12
    , NULL AS vat01, NULL AS vat02, NULL AS vat03, NULL AS vat04, NULL AS vat05, NULL AS vat06, NULL AS vat07, NULL AS vat08, NULL AS vat09, NULL AS vat10, NULL AS vat11, NULL AS vat12
    , NULL AS pl01, NULL AS pl02, NULL AS pl03, NULL AS pl04, NULL AS pl05, NULL AS pl06, NULL AS pl07, NULL AS pl08, NULL AS pl09, NULL AS pl10, NULL AS pl11, NULL AS pl12

    , dr01, dr02, dr03, dr04, dr05, dr06, dr07, dr08, dr09, dr10, dr11, dr12
    , cr01, cr02, cr03, cr04, cr05, cr06, cr07, cr08, cr09, cr10, cr11, cr12
    , balance00, balance01, balance02, balance03, balance04, balance05, balance06, balance07, balance08, balance09, balance10, balance11, balance12
    , bd00, bd01, bd02, bd03, bd04, bd05, bd06, bd07, bd08, bd09, bd10, bd11, bd12
    , bc00, bc01, bc02, bc03, bc04, bc05, bc06, bc07, bc08, bc09, bc10, bc11, bc12
FROM
    b4
    INNER JOIN dbo27.ledger_accounts m1 ON m1.id = ledger_account_id
    INNER JOIN dbo27.members m2 ON m2.id = subsidiary_account_id

    ) t
ORDER BY
    section
    , [key]

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: The procedure selects budget requests as a journal
-- =============================================

CREATE PROCEDURE [xls27].[usp_budget_journal]
    @company_id int = NULL
    , @category_id int = NULL
    , @time_id int = NULL
    , @entity_id int = NULL
    , @subsidiary_account_id int = NULL
    , @region_id int = NULL
    , @product_id int = NULL
    , @first_month int = 1
    , @last_month int = 12
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

IF @first_month IS NULL SET @first_month = 1
IF @last_month IS NULL SET @last_month = 12

;WITH entries AS (
    SELECT
        r.id
        , en.n AS entry_id
        , DATEADD(MONTH, dt.n - 1, p.start_date) AS date
        , CASE en.n WHEN 1 THEN a.payment_debit_id WHEN 2 THEN a.charge_debit_id WHEN 3 THEN a.vat_debit_id ELSE NULL END AS debit_account_id
        , CASE en.n WHEN 1 THEN a.payment_credit_id WHEN 2 THEN a.charge_credit_id WHEN 3 THEN a.vat_credit_id ELSE NULL END AS credit_account_id
        , v.factor
        , CASE en.n
            WHEN 1 THEN CASE dt.n
                WHEN 1 THEN payments01
                WHEN 2 THEN payments02
                WHEN 3 THEN payments03
                WHEN 4 THEN payments04
                WHEN 5 THEN payments05
                WHEN 6 THEN payments06
                WHEN 7 THEN payments07
                WHEN 8 THEN payments08
                WHEN 9 THEN payments09
                WHEN 10 THEN payments10
                WHEN 11 THEN payments11
                WHEN 12 THEN payments12
                END
            WHEN 2 THEN case dt.n
                WHEN 1  THEN CASE WHEN a.is_charge_net = 1 THEN charges01 - COALESCE(ROUND(charges01 * v.factor, 2), 0) ELSE charges01 END
                WHEN 2  THEN CASE WHEN a.is_charge_net = 1 THEN charges02 - COALESCE(ROUND(charges02 * v.factor, 2), 0) ELSE charges02 END
                WHEN 3  THEN CASE WHEN a.is_charge_net = 1 THEN charges03 - COALESCE(ROUND(charges03 * v.factor, 2), 0) ELSE charges03 END
                WHEN 4  THEN CASE WHEN a.is_charge_net = 1 THEN charges04 - COALESCE(ROUND(charges04 * v.factor, 2), 0) ELSE charges04 END
                WHEN 5  THEN CASE WHEN a.is_charge_net = 1 THEN charges05 - COALESCE(ROUND(charges05 * v.factor, 2), 0) ELSE charges05 END
                WHEN 6  THEN CASE WHEN a.is_charge_net = 1 THEN charges06 - COALESCE(ROUND(charges06 * v.factor, 2), 0) ELSE charges06 END
                WHEN 7  THEN CASE WHEN a.is_charge_net = 1 THEN charges07 - COALESCE(ROUND(charges07 * v.factor, 2), 0) ELSE charges07 END
                WHEN 8  THEN CASE WHEN a.is_charge_net = 1 THEN charges08 - COALESCE(ROUND(charges08 * v.factor, 2), 0) ELSE charges08 END
                WHEN 9  THEN CASE WHEN a.is_charge_net = 1 THEN charges09 - COALESCE(ROUND(charges09 * v.factor, 2), 0) ELSE charges09 END
                WHEN 10 THEN CASE WHEN a.is_charge_net = 1 THEN charges10 - COALESCE(ROUND(charges10 * v.factor, 2), 0) ELSE charges10 END
                WHEN 11 THEN CASE WHEN a.is_charge_net = 1 THEN charges11 - COALESCE(ROUND(charges11 * v.factor, 2), 0) ELSE charges11 END
                WHEN 12 THEN CASE WHEN a.is_charge_net = 1 THEN charges12 - COALESCE(ROUND(charges12 * v.factor, 2), 0) ELSE charges12 END
                END
            WHEN 3 THEN case dt.n
                WHEN 1  THEN ROUND(charges01 * v.factor, 2)
                WHEN 2  THEN ROUND(charges02 * v.factor, 2)
                WHEN 3  THEN ROUND(charges03 * v.factor, 2)
                WHEN 4  THEN ROUND(charges04 * v.factor, 2)
                WHEN 5  THEN ROUND(charges05 * v.factor, 2)
                WHEN 6  THEN ROUND(charges06 * v.factor, 2)
                WHEN 7  THEN ROUND(charges07 * v.factor, 2)
                WHEN 8  THEN ROUND(charges08 * v.factor, 2)
                WHEN 9  THEN ROUND(charges09 * v.factor, 2)
                WHEN 10 THEN ROUND(charges10 * v.factor, 2)
                WHEN 11 THEN ROUND(charges11 * v.factor, 2)
                WHEN 12 THEN ROUND(charges12 * v.factor, 2)
                END
            ELSE NULL END AS amount
        , CASE en.n
            WHEN 1 THEN CASE dt.n
                WHEN 1  THEN payments01 * COALESCE(cr.period01, 1)
                WHEN 2  THEN payments02 * COALESCE(cr.period02, 1)
                WHEN 3  THEN payments03 * COALESCE(cr.period03, 1)
                WHEN 4  THEN payments04 * COALESCE(cr.period04, 1)
                WHEN 5  THEN payments05 * COALESCE(cr.period05, 1)
                WHEN 6  THEN payments06 * COALESCE(cr.period06, 1)
                WHEN 7  THEN payments07 * COALESCE(cr.period07, 1)
                WHEN 8  THEN payments08 * COALESCE(cr.period08, 1)
                WHEN 9  THEN payments09 * COALESCE(cr.period09, 1)
                WHEN 10 THEN payments10 * COALESCE(cr.period10, 1)
                WHEN 11 THEN payments11 * COALESCE(cr.period11, 1)
                WHEN 12 THEN payments12 * COALESCE(cr.period12, 1)
                END
            WHEN 2 THEN case dt.n
                WHEN 1  THEN ROUND(CASE WHEN a.is_charge_net = 1 THEN charges01 - COALESCE(ROUND(charges01 * v.factor, 2), 0) ELSE charges01 END * COALESCE(cr.period01, 1), 2)
                WHEN 2  THEN ROUND(CASE WHEN a.is_charge_net = 1 THEN charges02 - COALESCE(ROUND(charges02 * v.factor, 2), 0) ELSE charges02 END * COALESCE(cr.period02, 1), 2)
                WHEN 3  THEN ROUND(CASE WHEN a.is_charge_net = 1 THEN charges03 - COALESCE(ROUND(charges03 * v.factor, 2), 0) ELSE charges03 END * COALESCE(cr.period03, 1), 2)
                WHEN 4  THEN ROUND(CASE WHEN a.is_charge_net = 1 THEN charges04 - COALESCE(ROUND(charges04 * v.factor, 2), 0) ELSE charges04 END * COALESCE(cr.period04, 1), 2)
                WHEN 5  THEN ROUND(CASE WHEN a.is_charge_net = 1 THEN charges05 - COALESCE(ROUND(charges05 * v.factor, 2), 0) ELSE charges05 END * COALESCE(cr.period05, 1), 2)
                WHEN 6  THEN ROUND(CASE WHEN a.is_charge_net = 1 THEN charges06 - COALESCE(ROUND(charges06 * v.factor, 2), 0) ELSE charges06 END * COALESCE(cr.period06, 1), 2)
                WHEN 7  THEN ROUND(CASE WHEN a.is_charge_net = 1 THEN charges07 - COALESCE(ROUND(charges07 * v.factor, 2), 0) ELSE charges07 END * COALESCE(cr.period07, 1), 2)
                WHEN 8  THEN ROUND(CASE WHEN a.is_charge_net = 1 THEN charges08 - COALESCE(ROUND(charges08 * v.factor, 2), 0) ELSE charges08 END * COALESCE(cr.period08, 1), 2)
                WHEN 9  THEN ROUND(CASE WHEN a.is_charge_net = 1 THEN charges09 - COALESCE(ROUND(charges09 * v.factor, 2), 0) ELSE charges09 END * COALESCE(cr.period09, 1), 2)
                WHEN 10 THEN ROUND(CASE WHEN a.is_charge_net = 1 THEN charges10 - COALESCE(ROUND(charges10 * v.factor, 2), 0) ELSE charges10 END * COALESCE(cr.period10, 1), 2)
                WHEN 11 THEN ROUND(CASE WHEN a.is_charge_net = 1 THEN charges11 - COALESCE(ROUND(charges11 * v.factor, 2), 0) ELSE charges11 END * COALESCE(cr.period11, 1), 2)
                WHEN 12 THEN ROUND(CASE WHEN a.is_charge_net = 1 THEN charges12 - COALESCE(ROUND(charges12 * v.factor, 2), 0) ELSE charges12 END * COALESCE(cr.period12, 1), 2)
                END
            WHEN 3 THEN case dt.n
                WHEN 1  THEN ROUND(charges01 * v.factor * COALESCE(cr.period01, 1), 2)
                WHEN 2  THEN ROUND(charges02 * v.factor * COALESCE(cr.period02, 1), 2)
                WHEN 3  THEN ROUND(charges03 * v.factor * COALESCE(cr.period03, 1), 2)
                WHEN 4  THEN ROUND(charges04 * v.factor * COALESCE(cr.period04, 1), 2)
                WHEN 5  THEN ROUND(charges05 * v.factor * COALESCE(cr.period05, 1), 2)
                WHEN 6  THEN ROUND(charges06 * v.factor * COALESCE(cr.period06, 1), 2)
                WHEN 7  THEN ROUND(charges07 * v.factor * COALESCE(cr.period07, 1), 2)
                WHEN 8  THEN ROUND(charges08 * v.factor * COALESCE(cr.period08, 1), 2)
                WHEN 9  THEN ROUND(charges09 * v.factor * COALESCE(cr.period09, 1), 2)
                WHEN 10 THEN ROUND(charges10 * v.factor * COALESCE(cr.period10, 1), 2)
                WHEN 11 THEN ROUND(charges11 * v.factor * COALESCE(cr.period11, 1), 2)
                WHEN 12 THEN ROUND(charges12 * v.factor * COALESCE(cr.period12, 1), 2)
                END
            ELSE NULL END AS amount$
        , CASE dt.n
                WHEN 1 THEN cr.period01
                WHEN 2 THEN cr.period02
                WHEN 3 THEN cr.period03
                WHEN 4 THEN cr.period04
                WHEN 5 THEN cr.period05
                WHEN 6 THEN cr.period06
                WHEN 7 THEN cr.period07
                WHEN 8 THEN cr.period08
                WHEN 9 THEN cr.period09
                WHEN 10 THEN cr.period10
                WHEN 11 THEN cr.period11
                WHEN 12 THEN cr.period12
                END AS rate
    FROM
        dbo27.budget_requests r
        INNER JOIN dbo27.members a ON a.id = r.account_id
        INNER JOIN dbo27.member_types t ON t.id = a.account_type_id
        INNER JOIN dbo27.members p ON p.id = r.time_id
        LEFT OUTER JOIN dbo27.budget_currency_rates cr ON cr.unit_id = r.unit_id AND cr.time_id = r.time_id AND cr.category_id = r.category_id
        LEFT OUTER JOIN dbo27.vat_rates v ON v.id = r.vat_rate_id
        CROSS JOIN (VALUES (1), (2), (3)) en(n)
        CROSS JOIN (VALUES (1), (2), (3), (4), (5), (6), (7), (8), (9), (10), (11), (12)) dt(n)
    WHERE
        r.category_id = @category_id
        AND r.time_id = @time_id
        AND a.company_id = @company_id
        AND COALESCE(r.entity_id, 0) = COALESCE(@entity_id, r.entity_id, 0)
        AND COALESCE(r.subsidiary_account_id, 0) = COALESCE(@subsidiary_account_id, r.subsidiary_account_id, 0)
        AND COALESCE(r.region_id, 0) = COALESCE(@region_id, r.region_id, 0)
        AND COALESCE(r.product_id, 0) = COALESCE(@product_id, r.product_id, 0)
        AND dt.n BETWEEN @first_month AND @last_month
)

SELECT
    r.date
    , r.debit_account_id
    , r.credit_account_id
    , r.amount
    , r.debit_subsidiary_account_id
    , r.credit_subsidiary_account_id
    , r.description
    , r.currency
    , r.rate
    , r.amount$
    , r.entity_id
    , r.account_id
    , r.region_id
    , r.product_id
FROM
    (
        SELECT
            r.id
            , r.row_index
            , e.entry_id
            , CAST(e.date AS datetime) AS date
            , e.debit_account_id
            , e.credit_account_id
            , amount
            , dg.member_id AS debit_subsidiary_account_id
            , cg.member_id AS credit_subsidiary_account_id
            , r.description
            , COALESCE(du.name, cu.name) AS currency
            , rate
            , amount$
            , r.entity_id
            , r.account_id
            , r.region_id
            , r.product_id
            , COALESCE(u.name, r.modified_by) AS modified_by
            , r.modified_on
            , m4.code AS entity_code
        FROM
            entries e
            INNER JOIN dbo27.budget_requests r ON r.id = e.id
            INNER JOIN dbo27.members a ON a.id = r.account_id
            INNER JOIN dbo27.ledger_accounts d ON d.id = e.debit_account_id
            INNER JOIN dbo27.ledger_accounts c ON c.id = e.credit_account_id
            LEFT OUTER JOIN dbo27.users u ON u.company_id = a.company_id AND u.username = r.modified_by
            LEFT OUTER JOIN dbo27.member_groups dg ON dg.member_id = r.subsidiary_account_id AND dg.group_id = d.subsidiary_group_id
            LEFT OUTER JOIN dbo27.member_groups cg ON cg.member_id = r.subsidiary_account_id AND cg.group_id = c.subsidiary_group_id
            LEFT OUTER JOIN dbo27.members dm ON dm.id = dg.member_id
            LEFT OUTER JOIN dbo27.members cm ON cm.id = cg.member_id
            LEFT OUTER JOIN dbo27.units du ON du.id = dm.unit_id
            LEFT OUTER JOIN dbo27.units cu ON cu.id = cm.unit_id
            LEFT OUTER JOIN dbo27.members m4 ON m4.id = r.entity_id

    ) r
WHERE
    NOT r.amount = 0
ORDER BY
    r.entity_code
    , r.row_index
    , r.entry_id
    , r.date

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: The procedure selects budget financial reports
-- =============================================

CREATE PROCEDURE [xls27].[usp_budget_reports]
    @company_id int = NULL
    , @category_id int = NULL
    , @time_id int = NULL
    , @entity_id int = NULL
    , @report_id int = NULL
    , @unit int = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

-- Factor like 1, 0.001, or 0.000001

DECLARE @factor float = 1.0 / COALESCE(@unit, 1)

;WITH a1 AS (

    -- This section filters records and calculates values
    -- payments = payments * rate
    -- charges = charges * rate
    -- vat = charges * rate * factor

    SELECT
        r.account_id
        , r.subsidiary_account_id
        , is_charge_net

        , payment_debit_id, payment_credit_id, charge_debit_id, charge_credit_id, vat_debit_id, vat_credit_id

        , COALESCE(CAST(r.balance00 * COALESCE(cr.balance00, 1) AS numeric(15,2)), 0) AS balance00

        , COALESCE(CAST(r.payments01 * COALESCE(cr.period01, 1) AS numeric(15,2)), 0) AS payments01
        , COALESCE(CAST(r.payments02 * COALESCE(cr.period02, 1) AS numeric(15,2)), 0) AS payments02
        , COALESCE(CAST(r.payments03 * COALESCE(cr.period03, 1) AS numeric(15,2)), 0) AS payments03
        , COALESCE(CAST(r.payments04 * COALESCE(cr.period04, 1) AS numeric(15,2)), 0) AS payments04
        , COALESCE(CAST(r.payments05 * COALESCE(cr.period05, 1) AS numeric(15,2)), 0) AS payments05
        , COALESCE(CAST(r.payments06 * COALESCE(cr.period06, 1) AS numeric(15,2)), 0) AS payments06
        , COALESCE(CAST(r.payments07 * COALESCE(cr.period07, 1) AS numeric(15,2)), 0) AS payments07
        , COALESCE(CAST(r.payments08 * COALESCE(cr.period08, 1) AS numeric(15,2)), 0) AS payments08
        , COALESCE(CAST(r.payments09 * COALESCE(cr.period09, 1) AS numeric(15,2)), 0) AS payments09
        , COALESCE(CAST(r.payments10 * COALESCE(cr.period10, 1) AS numeric(15,2)), 0) AS payments10
        , COALESCE(CAST(r.payments11 * COALESCE(cr.period11, 1) AS numeric(15,2)), 0) AS payments11
        , COALESCE(CAST(r.payments12 * COALESCE(cr.period12, 1) AS numeric(15,2)), 0) AS payments12

        , COALESCE(CAST(r.charges01 * COALESCE(cr.period01, 1) AS numeric(15,2)), 0) AS charges01
        , COALESCE(CAST(r.charges02 * COALESCE(cr.period02, 1) AS numeric(15,2)), 0) AS charges02
        , COALESCE(CAST(r.charges03 * COALESCE(cr.period03, 1) AS numeric(15,2)), 0) AS charges03
        , COALESCE(CAST(r.charges04 * COALESCE(cr.period04, 1) AS numeric(15,2)), 0) AS charges04
        , COALESCE(CAST(r.charges05 * COALESCE(cr.period05, 1) AS numeric(15,2)), 0) AS charges05
        , COALESCE(CAST(r.charges06 * COALESCE(cr.period06, 1) AS numeric(15,2)), 0) AS charges06
        , COALESCE(CAST(r.charges07 * COALESCE(cr.period07, 1) AS numeric(15,2)), 0) AS charges07
        , COALESCE(CAST(r.charges08 * COALESCE(cr.period08, 1) AS numeric(15,2)), 0) AS charges08
        , COALESCE(CAST(r.charges09 * COALESCE(cr.period09, 1) AS numeric(15,2)), 0) AS charges09
        , COALESCE(CAST(r.charges10 * COALESCE(cr.period10, 1) AS numeric(15,2)), 0) AS charges10
        , COALESCE(CAST(r.charges11 * COALESCE(cr.period11, 1) AS numeric(15,2)), 0) AS charges11
        , COALESCE(CAST(r.charges12 * COALESCE(cr.period12, 1) AS numeric(15,2)), 0) AS charges12

        , COALESCE(CAST(r.charges01 * COALESCE(cr.period01, 1) * COALESCE(vr.factor, 0) AS numeric(15,2)), 0) AS vat01
        , COALESCE(CAST(r.charges02 * COALESCE(cr.period02, 1) * COALESCE(vr.factor, 0) AS numeric(15,2)), 0) AS vat02
        , COALESCE(CAST(r.charges03 * COALESCE(cr.period03, 1) * COALESCE(vr.factor, 0) AS numeric(15,2)), 0) AS vat03
        , COALESCE(CAST(r.charges04 * COALESCE(cr.period04, 1) * COALESCE(vr.factor, 0) AS numeric(15,2)), 0) AS vat04
        , COALESCE(CAST(r.charges05 * COALESCE(cr.period05, 1) * COALESCE(vr.factor, 0) AS numeric(15,2)), 0) AS vat05
        , COALESCE(CAST(r.charges06 * COALESCE(cr.period06, 1) * COALESCE(vr.factor, 0) AS numeric(15,2)), 0) AS vat06
        , COALESCE(CAST(r.charges07 * COALESCE(cr.period07, 1) * COALESCE(vr.factor, 0) AS numeric(15,2)), 0) AS vat07
        , COALESCE(CAST(r.charges08 * COALESCE(cr.period08, 1) * COALESCE(vr.factor, 0) AS numeric(15,2)), 0) AS vat08
        , COALESCE(CAST(r.charges09 * COALESCE(cr.period09, 1) * COALESCE(vr.factor, 0) AS numeric(15,2)), 0) AS vat09
        , COALESCE(CAST(r.charges10 * COALESCE(cr.period10, 1) * COALESCE(vr.factor, 0) AS numeric(15,2)), 0) AS vat10
        , COALESCE(CAST(r.charges11 * COALESCE(cr.period11, 1) * COALESCE(vr.factor, 0) AS numeric(15,2)), 0) AS vat11
        , COALESCE(CAST(r.charges12 * COALESCE(cr.period12, 1) * COALESCE(vr.factor, 0) AS numeric(15,2)), 0) AS vat12
    FROM
        dbo27.budget_requests r
        INNER JOIN dbo27.members m1 ON m1.id = r.account_id
        INNER JOIN dbo27.member_types t ON t.id = m1.account_type_id
        LEFT OUTER JOIN dbo27.vat_rates vr ON vr.id = r.vat_rate_id
        LEFT OUTER JOIN dbo27.budget_currency_rates cr ON cr.category_id = r.category_id AND cr.time_id = r.time_id AND cr.unit_id = r.unit_id
    WHERE
        r.category_id = @category_id
        AND r.time_id = @time_id
        AND m1.company_id = @company_id
        AND r.[entity_id] = COALESCE(@entity_id, r.[entity_id])
)

, b1 AS (

    -- This section converts raw records to entry sides and adds opening balances

    SELECT
        payment_debit_id AS ledger_account_id
        , subsidiary_account_id
        , payment_credit_id AS pair_account_id
        , 1 AS entry_side_id
        , NULL AS data00
        , payments01 AS data01, payments02 AS data02, payments03 AS data03, payments04 AS data04, payments05 AS data05, payments06 AS data06, payments07 AS data07, payments08 AS data08, payments09 AS data09, payments10 AS data10, payments11 AS data11, payments12 AS data12
    FROM
        a1
    WHERE
        payment_debit_id IS NOT NULL AND payment_credit_id IS NOT NULL

    UNION ALL
    SELECT
        payment_credit_id AS ledger_account_id
        , subsidiary_account_id
        , payment_debit_id AS pair_account_id
        , 2 AS entry_side_id
        , NULL AS data00
        , payments01 AS data, payments02 AS cr02, payments03 AS cr03, payments04 AS cr04, payments05 AS cr05, payments06 AS cr06, payments07 AS cr07, payments08 AS cr08, payments09 AS cr09, payments10 AS cr10, payments11 AS cr11, payments12 AS cr12
    FROM
        a1
    WHERE
        payment_debit_id IS NOT NULL AND payment_credit_id IS NOT NULL

    UNION ALL
    SELECT
        charge_debit_id AS ledger_account_id
        , subsidiary_account_id
        , charge_credit_id AS pair_account_id
        , 1 AS entry_side_id
        , NULL AS data00
        , charges01 - is_charge_net * vat01 AS data01
        , charges02 - is_charge_net * vat02 AS data02
        , charges03 - is_charge_net * vat03 AS data03
        , charges04 - is_charge_net * vat04 AS data04
        , charges05 - is_charge_net * vat05 AS data05
        , charges06 - is_charge_net * vat06 AS data06
        , charges07 - is_charge_net * vat07 AS data07
        , charges08 - is_charge_net * vat08 AS data08
        , charges09 - is_charge_net * vat09 AS data09
        , charges10 - is_charge_net * vat10 AS data10
        , charges11 - is_charge_net * vat11 AS data11
        , charges12 - is_charge_net * vat12 AS data12
    FROM
        a1
    WHERE
        charge_debit_id IS NOT NULL AND charge_credit_id IS NOT NULL

    UNION ALL
    SELECT
        charge_credit_id AS ledger_account_id
        , subsidiary_account_id
        , charge_debit_id AS pair_account_id
        , 2 AS entry_side_id
        , NULL AS data00
        , charges01 - is_charge_net * vat01 AS data01
        , charges02 - is_charge_net * vat02 AS data02
        , charges03 - is_charge_net * vat03 AS data03
        , charges04 - is_charge_net * vat04 AS data04
        , charges05 - is_charge_net * vat05 AS data05
        , charges06 - is_charge_net * vat06 AS data06
        , charges07 - is_charge_net * vat07 AS data07
        , charges08 - is_charge_net * vat08 AS data08
        , charges09 - is_charge_net * vat09 AS data09
        , charges10 - is_charge_net * vat10 AS data10
        , charges11 - is_charge_net * vat11 AS data11
        , charges12 - is_charge_net * vat12 AS data12
    FROM
        a1
    WHERE
        charge_debit_id IS NOT NULL AND charge_credit_id IS NOT NULL

    UNION ALL
    SELECT
        vat_debit_id AS ledger_account_id
        , subsidiary_account_id
        , vat_credit_id AS pair_account_id
        , 1 AS entry_side_id
        , NULL AS data00
        , vat01 AS data01, vat02 AS data02, vat03 AS data03, vat04 AS data04, vat05 AS data05, vat06 AS data06, vat07 AS data07, vat08 AS data08, vat09 AS data09, vat10 AS data10, vat11 AS data11, vat12 AS data12
    FROM
        a1
    WHERE
        vat_debit_id IS NOT NULL AND vat_credit_id IS NOT NULL

    UNION ALL
    SELECT
        vat_credit_id AS ledger_account_id
        , subsidiary_account_id
        , vat_credit_id AS pair_account_id
        , 2 AS entry_side_id
        , NULL AS data00
        , vat01 AS data01, vat02 AS data02, vat03 AS data03, vat04 AS data04, vat05 AS data05, vat06 AS data06, vat07 AS data07, vat08 AS data08, vat09 AS data09, vat10 AS data10, vat11 AS data11, vat12 AS data12
    FROM
        a1
    WHERE
        vat_debit_id IS NOT NULL AND vat_credit_id IS NOT NULL

    -- Opening balances from the request for entity

    UNION ALL
    SELECT
        CASE WHEN s.id = 1 THEN payment_debit_id ELSE payment_credit_id END AS ledger_account_id
        , COALESCE(subsidiary_account_id, -1) AS subsidiary_account_id
        , NULL AS pair_account_id
        , s.id AS entry_side_id
        , CASE WHEN dt.specific_type_id = 1 AND s.id = 1 THEN balance00 ELSE -balance00 END AS data00
        , NULL AS data01, NULL AS data02, NULL AS data03, NULL AS data04, NULL AS data05, NULL AS data06, NULL AS data07, NULL AS data08, NULL AS data09, NULL AS data10, NULL AS data11, NULL AS data12
    FROM
        a1
        INNER JOIN dbo27.ledger_accounts d ON d.id = a1.payment_debit_id
        INNER JOIN dbo27.ledger_accounts c ON c.id = a1.payment_credit_id
        INNER JOIN dbo27.ledger_account_types dt ON dt.id = d.account_type_id
        INNER JOIN dbo27.ledger_account_types ct ON ct.id = c.account_type_id
        CROSS JOIN dbo27.entry_sides s
    WHERE
        @entity_id IS NOT NULL

    -- Opening balances for the entire company

    UNION ALL
    SELECT
        r.account_id AS ledger_account_id
        , NULL AS subsidiary_account_id
        , NULL AS pair_account_id
        , s.id AS entry_side_id
        , CASE WHEN s.id = 1 THEN r.debit ELSE r.credit END AS data00
        , NULL AS data01, NULL AS data02, NULL AS data03, NULL AS data04, NULL AS data05, NULL AS data06, NULL AS data07, NULL AS data08, NULL AS data09, NULL AS data10, NULL AS data11, NULL AS data12
    FROM
        dbo27.budget_balances r
        INNER JOIN dbo27.ledger_accounts a ON a.id = r.account_id
        CROSS JOIN dbo27.entry_sides s
    WHERE
        r.category_id = @category_id
        AND r.time_id = @time_id
        AND (r.debit IS NOT NULL OR r.credit IS NOT NULL)
        AND @entity_id IS NULL
)

, c1 AS (

    -- This section aggregates data by a report section, account, subsidiary account, and a value type

    SELECT
        rsa.section_type_id
        , CASE WHEN rst.hide_accounts = 1 THEN NULL ELSE b1.ledger_account_id END ledger_account_id
        , CASE WHEN rsa.value_type_id IN (3, 4) THEN b1.subsidiary_account_id ELSE NULL END AS subsidiary_account_id
        , rsa.value_type_id
        , SUM(rsa.value_sign * data00) AS data00
        , SUM(rsa.value_sign * data01) AS data01
        , SUM(rsa.value_sign * data02) AS data02
        , SUM(rsa.value_sign * data03) AS data03
        , SUM(rsa.value_sign * data04) AS data04
        , SUM(rsa.value_sign * data05) AS data05
        , SUM(rsa.value_sign * data06) AS data06
        , SUM(rsa.value_sign * data07) AS data07
        , SUM(rsa.value_sign * data08) AS data08
        , SUM(rsa.value_sign * data09) AS data09
        , SUM(rsa.value_sign * data10) AS data10
        , SUM(rsa.value_sign * data11) AS data11
        , SUM(rsa.value_sign * data12) AS data12
    FROM
        b1
        INNER JOIN dbo27.ledger_accounts a ON a.id = b1.ledger_account_id
        INNER JOIN dbo27.report_section_accounts rsa ON rsa.account_type_id = a.account_type_id AND rsa.entry_side_id = b1.entry_side_id
        INNER JOIN dbo27.report_section_types rst ON rst.id = rsa.section_type_id
        LEFT OUTER JOIN dbo27.ledger_accounts c ON c.id = b1.pair_account_id
    WHERE
        rst.report_type_id = COALESCE(@report_id, rst.report_type_id)
        AND (rsa.pair_account_type_id IS NULL OR rsa.pair_account_type_id = c.account_type_id)
    GROUP BY
        rsa.section_type_id
        , CASE WHEN rst.hide_accounts = 1 THEN NULL ELSE b1.ledger_account_id END
        , CASE WHEN rsa.value_type_id IN (3, 4) THEN b1.subsidiary_account_id END
        , rsa.value_type_id
)

, c2 AS (

    -- This section calculates flow and balance values

    SELECT
        section_type_id
        , ledger_account_id
        , subsidiary_account_id
        , value_type_id
        , CASE WHEN value_type_id = 1 THEN NULL ELSE data00 END AS data00
        , CASE WHEN value_type_id = 1 THEN data01 ELSE COALESCE(data00, 0) + COALESCE(data01, 0) END AS data01
        , CASE WHEN value_type_id = 1 THEN data02 ELSE COALESCE(data00, 0) + COALESCE(data01, 0) + COALESCE(data02, 0) END AS data02
        , CASE WHEN value_type_id = 1 THEN data03 ELSE COALESCE(data00, 0) + COALESCE(data01, 0) + COALESCE(data02, 0) + COALESCE(data03, 0) END AS data03
        , CASE WHEN value_type_id = 1 THEN data04 ELSE COALESCE(data00, 0) + COALESCE(data01, 0) + COALESCE(data02, 0) + COALESCE(data03, 0) + COALESCE(data04, 0) END AS data04
        , CASE WHEN value_type_id = 1 THEN data05 ELSE COALESCE(data00, 0) + COALESCE(data01, 0) + COALESCE(data02, 0) + COALESCE(data03, 0) + COALESCE(data04, 0) + COALESCE(data05, 0) END AS data05
        , CASE WHEN value_type_id = 1 THEN data06 ELSE COALESCE(data00, 0) + COALESCE(data01, 0) + COALESCE(data02, 0) + COALESCE(data03, 0) + COALESCE(data04, 0) + COALESCE(data05, 0) + COALESCE(data06, 0) END AS data06
        , CASE WHEN value_type_id = 1 THEN data07 ELSE COALESCE(data00, 0) + COALESCE(data01, 0) + COALESCE(data02, 0) + COALESCE(data03, 0) + COALESCE(data04, 0) + COALESCE(data05, 0) + COALESCE(data06, 0) + COALESCE(data07, 0) END AS data07
        , CASE WHEN value_type_id = 1 THEN data08 ELSE COALESCE(data00, 0) + COALESCE(data01, 0) + COALESCE(data02, 0) + COALESCE(data03, 0) + COALESCE(data04, 0) + COALESCE(data05, 0) + COALESCE(data06, 0) + COALESCE(data07, 0) + COALESCE(data08, 0) END AS data08
        , CASE WHEN value_type_id = 1 THEN data09 ELSE COALESCE(data00, 0) + COALESCE(data01, 0) + COALESCE(data02, 0) + COALESCE(data03, 0) + COALESCE(data04, 0) + COALESCE(data05, 0) + COALESCE(data06, 0) + COALESCE(data07, 0) + COALESCE(data08, 0) + COALESCE(data09, 0) END AS data09
        , CASE WHEN value_type_id = 1 THEN data10 ELSE COALESCE(data00, 0) + COALESCE(data01, 0) + COALESCE(data02, 0) + COALESCE(data03, 0) + COALESCE(data04, 0) + COALESCE(data05, 0) + COALESCE(data06, 0) + COALESCE(data07, 0) + COALESCE(data08, 0) + COALESCE(data09, 0) + COALESCE(data10, 0) END AS data10
        , CASE WHEN value_type_id = 1 THEN data11 ELSE COALESCE(data00, 0) + COALESCE(data01, 0) + COALESCE(data02, 0) + COALESCE(data03, 0) + COALESCE(data04, 0) + COALESCE(data05, 0) + COALESCE(data06, 0) + COALESCE(data07, 0) + COALESCE(data08, 0) + COALESCE(data09, 0) + COALESCE(data10, 0) + COALESCE(data11, 0) END AS data11
        , CASE WHEN value_type_id = 1 THEN data12 ELSE COALESCE(data00, 0) + COALESCE(data01, 0) + COALESCE(data02, 0) + COALESCE(data03, 0) + COALESCE(data04, 0) + COALESCE(data05, 0) + COALESCE(data06, 0) + COALESCE(data07, 0) + COALESCE(data08, 0) + COALESCE(data09, 0) + COALESCE(data10, 0) + COALESCE(data11, 0) + COALESCE(data12, 0) END AS data12
    FROM
        c1
)

, c3 AS (

    -- This section calculates debit and credit balances. It removes value_type_id

    SELECT
        section_type_id
        , ledger_account_id
        , subsidiary_account_id
        , CASE WHEN value_type_id = 3 AND data00 < 0 THEN NULL WHEN value_type_id = 4 AND data00 > 0 THEN NULL ELSE data00 END AS data00
        , CASE WHEN value_type_id = 3 AND data01 < 0 THEN NULL WHEN value_type_id = 4 AND data01 > 0 THEN NULL ELSE data01 END AS data01
        , CASE WHEN value_type_id = 3 AND data02 < 0 THEN NULL WHEN value_type_id = 4 AND data02 > 0 THEN NULL ELSE data02 END AS data02
        , CASE WHEN value_type_id = 3 AND data03 < 0 THEN NULL WHEN value_type_id = 4 AND data03 > 0 THEN NULL ELSE data03 END AS data03
        , CASE WHEN value_type_id = 3 AND data04 < 0 THEN NULL WHEN value_type_id = 4 AND data04 > 0 THEN NULL ELSE data04 END AS data04
        , CASE WHEN value_type_id = 3 AND data05 < 0 THEN NULL WHEN value_type_id = 4 AND data05 > 0 THEN NULL ELSE data05 END AS data05
        , CASE WHEN value_type_id = 3 AND data06 < 0 THEN NULL WHEN value_type_id = 4 AND data06 > 0 THEN NULL ELSE data06 END AS data06
        , CASE WHEN value_type_id = 3 AND data07 < 0 THEN NULL WHEN value_type_id = 4 AND data07 > 0 THEN NULL ELSE data07 END AS data07
        , CASE WHEN value_type_id = 3 AND data08 < 0 THEN NULL WHEN value_type_id = 4 AND data08 > 0 THEN NULL ELSE data08 END AS data08
        , CASE WHEN value_type_id = 3 AND data09 < 0 THEN NULL WHEN value_type_id = 4 AND data09 > 0 THEN NULL ELSE data09 END AS data09
        , CASE WHEN value_type_id = 3 AND data10 < 0 THEN NULL WHEN value_type_id = 4 AND data10 > 0 THEN NULL ELSE data10 END AS data10
        , CASE WHEN value_type_id = 3 AND data11 < 0 THEN NULL WHEN value_type_id = 4 AND data11 > 0 THEN NULL ELSE data11 END AS data11
        , CASE WHEN value_type_id = 3 AND data12 < 0 THEN NULL WHEN value_type_id = 4 AND data12 > 0 THEN NULL ELSE data12 END AS data12
    FROM
        c2
)

, c4 AS (

    -- This section aggregates data by a report section and accounts
    -- The data contains the correct values for flows, balances, debit balances and credit balances
    -- It removes the subsidiary account

    SELECT
        section_type_id
        , ledger_account_id
        , SUM(data00) AS data00
        , SUM(data01) AS data01
        , SUM(data02) AS data02
        , SUM(data03) AS data03
        , SUM(data04) AS data04
        , SUM(data05) AS data05
        , SUM(data06) AS data06
        , SUM(data07) AS data07
        , SUM(data08) AS data08
        , SUM(data09) AS data09
        , SUM(data10) AS data10
        , SUM(data11) AS data11
        , SUM(data12) AS data12
    FROM
        c3
    GROUP BY
        section_type_id
        , ledger_account_id
)

, factors (id, parent_id, is_parent) AS (

    -- This section selects child-parent factors for report sections

    SELECT
        rs.id
        , rs.id AS parent_id
        , COALESCE(rs.hide_items, 0) AS is_parent
    FROM
        dbo27.report_sections rs
    WHERE
        rs.company_id = @company_id
        AND rs.report_type_id = COALESCE(@report_id, rs.report_type_id)

    UNION ALL
    SELECT
        rs.id
        , rs.parent2_id
        , 1 AS is_parent
    FROM
        dbo27.report_sections rs
    WHERE
        rs.company_id = @company_id
        AND rs.report_type_id = COALESCE(@report_id, rs.report_type_id)
        AND rs.parent2_id IS NOT NULL

    UNION ALL
    SELECT
        f.id
        , rs.parent_id
        , 1 AS is_parent
    FROM
        factors f
        INNER JOIN dbo27.report_sections rs ON rs.id = f.parent_id
    WHERE
        rs.parent_id IS NOT NULL
        AND NOT f.id = rs.parent_id
)

, report_rows AS (

    -- This section multiplies section rows by factors and calculates totals by section and ledger account
    -- It also adds empty sections to show report headers
    -- Also it selects the total_type_id of the report sections

    SELECT
        section_id
        , ledger_account_id
        , MAX(total_type_id) AS total_type_id
        , SUM(data00) AS data00, SUM(data01) AS data01, SUM(data02) AS data02, SUM(data03) AS data03, SUM(data04) AS data04, SUM(data05) AS data05, SUM(data06) AS data06, SUM(data07) AS data07, SUM(data08) AS data08, SUM(data09) AS data09, SUM(data10) AS data10, SUM(data11) AS data11, SUM(data12) AS data12
        , SUM(data_rows) AS data_rows
    FROM
        (
        SELECT
            f.parent_id AS section_id
            , CASE WHEN f.is_parent = 1 THEN NULL ELSE r.ledger_account_id END AS ledger_account_id
            , rst.total_type_id
            , data00, data01, data02, data03, data04, data05, data06, data07, data08, data09, data10, data11, data12
            , 1 AS data_rows
        FROM
            c4 r
            INNER JOIN dbo27.report_sections rs ON rs.section_type_id = r.section_type_id
            INNER JOIN dbo27.report_section_types rst ON rst.id = rs.section_type_id
            INNER JOIN factors f ON f.id = rs.id
        WHERE
            rs.company_id = @company_id

        -- Adding report rows to show even without values

        UNION ALL
        SELECT
            rs.id AS section_id
            , NULL AS ledger_account_id
            , NULL AS total_type_id
            , NULL AS data00, NULL AS data01, NULL AS data02, NULL AS data03, NULL AS data04, NULL AS data05, NULL AS data06, NULL AS data07, NULL AS data08, NULL AS data09, NULL AS data10, NULL AS data11, NULL AS data12
            , NULL AS data_rows
        FROM
            dbo27.report_sections rs
        WHERE
            rs.company_id = @company_id
            AND rs.report_type_id = COALESCE(@report_id, rs.report_type_id)
            AND COALESCE(rs.show_line, 1) = 1
            AND rs.section_type_id IS NULL
        ) r
    GROUP BY
        section_id
        , ledger_account_id
)

, result AS (

    -- Main report output

    SELECT
        row_index
        , ref_number
        , code AS account
        , report
        , page_break
        , CAST(NULL AS int) AS row_level
        , row_format
        , 1 AS hide
        , CASE WHEN data00 <> 0 OR  data01 <> 0 OR  data02 <> 0 OR  data03 <> 0 OR  data04 <> 0 OR  data05 <> 0 OR  data06 <> 0 OR  data07 <> 0 OR  data08 <> 0 OR  data09 <> 0 OR  data10 <> 0 OR  data11 <> 0 OR  data12 <> 0 THEN 1 ELSE 0 END AS zero
        , CAST(NULL AS nvarchar(50)) AS code1
        , CAST(NULL AS nvarchar(50)) AS code2
        , code
        , name
        , CASE total_type_id
            WHEN 2 THEN data00
            WHEN 3 THEN data12
            WHEN 0 THEN NULL
            ELSE COALESCE(data01, 0) + COALESCE(data02, 0) + COALESCE(data03, 0) + COALESCE(data04, 0) + COALESCE(data05, 0) + COALESCE(data06, 0) + COALESCE(data07, 0) + COALESCE(data08, 0) + COALESCE(data09, 0) + COALESCE(data10, 0) + COALESCE(data11, 0) + COALESCE(data12, 0) END AS data00
        , data01, data02, data03, data04, data05, data06, data07, data08, data09, data10, data11, data12
    FROM
        (
            SELECT
                ROW_NUMBER() OVER (ORDER BY rs.report_type_id, rs.section, v.r, la.code, la.name) AS row_index
                , CASE WHEN v.r = 0 THEN rs.ref_number + COALESCE(la.ref_number, 0) ELSE NULL END AS ref_number
                , rs.report_type_id AS report
                , CASE WHEN rs.page_break_before IS NULL THEN NULL
                    WHEN rs.show_line_before = 1 AND v.r = -1 THEN 1
                    WHEN COALESCE(rs.show_line_before, 0) = 0 AND v.r = 0 THEN 1
                    ELSE NULL END AS page_break
                , CASE WHEN rs.row_format = 9 AND v.r = -1 THEN 8 WHEN v.r = -1 THEN NULL WHEN v.r = 1 THEN NULL
                    WHEN r.ledger_account_id IS NULL THEN rs.row_format ELSE NULL END row_format
                , CASE WHEN v.r = 0 THEN la.code ELSE NULL END AS code
                , CASE WHEN v.r = 0 THEN COALESCE(tr2.name, la.name, tr1.name, rs.description) ELSE NULL END AS name
                , CASE WHEN v.r = 0 AND data_rows > 0 THEN r.total_type_id ELSE 0 END AS total_type_id
                , data00 * @factor * f * rs.line_factor AS data00
                , data01 * @factor * f * rs.line_factor AS data01
                , data02 * @factor * f * rs.line_factor AS data02
                , data03 * @factor * f * rs.line_factor AS data03
                , data04 * @factor * f * rs.line_factor AS data04
                , data05 * @factor * f * rs.line_factor AS data05
                , data06 * @factor * f * rs.line_factor AS data06
                , data07 * @factor * f * rs.line_factor AS data07
                , data08 * @factor * f * rs.line_factor AS data08
                , data09 * @factor * f * rs.line_factor AS data09
                , data10 * @factor * f * rs.line_factor AS data10
                , data11 * @factor * f * rs.line_factor AS data11
                , data12 * @factor * f * rs.line_factor AS data12
            FROM
                report_rows r
                INNER JOIN dbo27.report_sections rs ON rs.id = r.section_id
                LEFT OUTER JOIN dbo27.ledger_accounts la ON la.id = r.ledger_account_id
                LEFT OUTER JOIN dbo27.translations tr1 ON tr1.company_id = rs.company_id AND tr1.table_id = 9 AND tr1.member_id = rs.id AND tr1.language = @data_language
                LEFT OUTER JOIN dbo27.translations tr2 ON tr2.company_id = rs.company_id AND tr2.table_id = 11 AND tr2.member_id = la.id AND tr2.language = @data_language
                CROSS JOIN (VALUES (-1, NULL), (0, 1), (1, NULL)) v(r, f)
            WHERE
                (rs.show_line = 1
                    OR (data00 <> 0 OR  data01 <> 0 OR  data02 <> 0 OR  data03 <> 0 OR  data04 <> 0 OR  data05 <> 0 OR  data06 <> 0 OR  data07 <> 0 OR  data08 <> 0 OR  data09 <> 0 OR  data10 <> 0 OR  data11 <> 0 OR  data12 <> 0)
                )
                AND (COALESCE(rs.show_line, 1) = 1 OR r.ledger_account_id IS NOT NULL)
                AND (r.ledger_account_id IS NULL OR COALESCE(rs.hide_items, 0) = 0)
                AND (v.f = 1
                    OR rs.show_line_before = 1 AND v.r = -1
                    OR rs.show_line_after = 1 AND v.r = 1
                )

        ) t
)

SELECT * FROM result ORDER BY row_index

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: The procedure selects reports
-- =============================================

CREATE PROCEDURE [xls27].[usp_budget_reports_raw]
    @company_id int = NULL
    , @category_id int = NULL
    , @time_id int = NULL
    , @entity_id int = NULL
    , @subsidiary_account_id int = NULL
    , @region_id int = NULL
    , @product_id int = NULL
    , @report_id int = NULL
    , @level tinyint = NULL
    , @unit int = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

-- Factor like 1, 0.001, or 0.000001

DECLARE @factor float = 1.0 / COALESCE(@unit, 1)

;WITH cf AS (
    SELECT
        r.account_id
        , COALESCE(ROUND(r.payments01 * COALESCE(cr.period01, 1), 2), 0) AS data01
        , COALESCE(ROUND(r.payments02 * COALESCE(cr.period02, 1), 2), 0) AS data02
        , COALESCE(ROUND(r.payments03 * COALESCE(cr.period03, 1), 2), 0) AS data03
        , COALESCE(ROUND(r.payments04 * COALESCE(cr.period04, 1), 2), 0) AS data04
        , COALESCE(ROUND(r.payments05 * COALESCE(cr.period05, 1), 2), 0) AS data05
        , COALESCE(ROUND(r.payments06 * COALESCE(cr.period06, 1), 2), 0) AS data06
        , COALESCE(ROUND(r.payments07 * COALESCE(cr.period07, 1), 2), 0) AS data07
        , COALESCE(ROUND(r.payments08 * COALESCE(cr.period08, 1), 2), 0) AS data08
        , COALESCE(ROUND(r.payments09 * COALESCE(cr.period09, 1), 2), 0) AS data09
        , COALESCE(ROUND(r.payments10 * COALESCE(cr.period10, 1), 2), 0) AS data10
        , COALESCE(ROUND(r.payments11 * COALESCE(cr.period11, 1), 2), 0) AS data11
        , COALESCE(ROUND(r.payments12 * COALESCE(cr.period12, 1), 2), 0) AS data12
    FROM
        dbo27.budget_requests r
        INNER JOIN dbo27.members a ON a.id = r.account_id
        LEFT OUTER JOIN dbo27.budget_currency_rates cr ON cr.unit_id = r.unit_id AND cr.time_id = r.time_id AND cr.category_id = r.category_id
    WHERE
        r.category_id = @category_id
        AND r.time_id = @time_id
        AND a.company_id = @company_id
        AND COALESCE(r.entity_id, 0) = COALESCE(@entity_id, r.entity_id, 0)
        AND COALESCE(r.subsidiary_account_id, 0) = COALESCE(@subsidiary_account_id, r.subsidiary_account_id, 0)
        AND COALESCE(r.region_id, 0) = COALESCE(@region_id, r.region_id, 0)
        AND COALESCE(r.product_id, 0) = COALESCE(@product_id, r.product_id, 0)
)
, cfs AS (
    SELECT
        account_id
        , SUM(data01) AS data01
        , SUM(data02) AS data02
        , SUM(data03) AS data03
        , SUM(data04) AS data04
        , SUM(data05) AS data05
        , SUM(data06) AS data06
        , SUM(data07) AS data07
        , SUM(data08) AS data08
        , SUM(data09) AS data09
        , SUM(data10) AS data10
        , SUM(data11) AS data11
        , SUM(data12) AS data12
    FROM
        cf
    GROUP BY
        account_id
)
, pl AS (
    SELECT
        r.account_id
        , COALESCE(ROUND(r.charges01 * COALESCE(cr.period01, 1), 2), 0) - CASE WHEN a.vat_debit_id IS NOT NULL AND a.vat_credit_id IS NOT NULL THEN COALESCE(ROUND(r.charges01 * COALESCE(cr.period01, 1) * v.factor, 2), 0) ELSE 0 END AS data01
        , COALESCE(ROUND(r.charges02 * COALESCE(cr.period02, 1), 2), 0) - CASE WHEN a.vat_debit_id IS NOT NULL AND a.vat_credit_id IS NOT NULL THEN COALESCE(ROUND(r.charges02 * COALESCE(cr.period02, 1) * v.factor, 2), 0) ELSE 0 END AS data02
        , COALESCE(ROUND(r.charges03 * COALESCE(cr.period03, 1), 2), 0) - CASE WHEN a.vat_debit_id IS NOT NULL AND a.vat_credit_id IS NOT NULL THEN COALESCE(ROUND(r.charges03 * COALESCE(cr.period03, 1) * v.factor, 2), 0) ELSE 0 END AS data03
        , COALESCE(ROUND(r.charges04 * COALESCE(cr.period04, 1), 2), 0) - CASE WHEN a.vat_debit_id IS NOT NULL AND a.vat_credit_id IS NOT NULL THEN COALESCE(ROUND(r.charges04 * COALESCE(cr.period04, 1) * v.factor, 2), 0) ELSE 0 END AS data04
        , COALESCE(ROUND(r.charges05 * COALESCE(cr.period05, 1), 2), 0) - CASE WHEN a.vat_debit_id IS NOT NULL AND a.vat_credit_id IS NOT NULL THEN COALESCE(ROUND(r.charges05 * COALESCE(cr.period05, 1) * v.factor, 2), 0) ELSE 0 END AS data05
        , COALESCE(ROUND(r.charges06 * COALESCE(cr.period06, 1), 2), 0) - CASE WHEN a.vat_debit_id IS NOT NULL AND a.vat_credit_id IS NOT NULL THEN COALESCE(ROUND(r.charges06 * COALESCE(cr.period06, 1) * v.factor, 2), 0) ELSE 0 END AS data06
        , COALESCE(ROUND(r.charges07 * COALESCE(cr.period07, 1), 2), 0) - CASE WHEN a.vat_debit_id IS NOT NULL AND a.vat_credit_id IS NOT NULL THEN COALESCE(ROUND(r.charges07 * COALESCE(cr.period07, 1) * v.factor, 2), 0) ELSE 0 END AS data07
        , COALESCE(ROUND(r.charges08 * COALESCE(cr.period08, 1), 2), 0) - CASE WHEN a.vat_debit_id IS NOT NULL AND a.vat_credit_id IS NOT NULL THEN COALESCE(ROUND(r.charges08 * COALESCE(cr.period08, 1) * v.factor, 2), 0) ELSE 0 END AS data08
        , COALESCE(ROUND(r.charges09 * COALESCE(cr.period09, 1), 2), 0) - CASE WHEN a.vat_debit_id IS NOT NULL AND a.vat_credit_id IS NOT NULL THEN COALESCE(ROUND(r.charges09 * COALESCE(cr.period09, 1) * v.factor, 2), 0) ELSE 0 END AS data09
        , COALESCE(ROUND(r.charges10 * COALESCE(cr.period10, 1), 2), 0) - CASE WHEN a.vat_debit_id IS NOT NULL AND a.vat_credit_id IS NOT NULL THEN COALESCE(ROUND(r.charges10 * COALESCE(cr.period10, 1) * v.factor, 2), 0) ELSE 0 END AS data10
        , COALESCE(ROUND(r.charges11 * COALESCE(cr.period11, 1), 2), 0) - CASE WHEN a.vat_debit_id IS NOT NULL AND a.vat_credit_id IS NOT NULL THEN COALESCE(ROUND(r.charges11 * COALESCE(cr.period11, 1) * v.factor, 2), 0) ELSE 0 END AS data11
        , COALESCE(ROUND(r.charges12 * COALESCE(cr.period12, 1), 2), 0) - CASE WHEN a.vat_debit_id IS NOT NULL AND a.vat_credit_id IS NOT NULL THEN COALESCE(ROUND(r.charges12 * COALESCE(cr.period12, 1) * v.factor, 2), 0) ELSE 0 END AS data12
    FROM
        dbo27.budget_requests r
        INNER JOIN dbo27.members a ON a.id = r.account_id
        LEFT OUTER JOIN dbo27.budget_currency_rates cr ON cr.unit_id = r.unit_id AND cr.time_id = r.time_id AND cr.category_id = r.category_id
        LEFT OUTER JOIN dbo27.vat_rates v ON v.id = r.vat_rate_id
    WHERE
        r.category_id = @category_id
        AND r.time_id = @time_id
        AND a.company_id = @company_id
        AND COALESCE(r.entity_id, 0) = COALESCE(@entity_id, r.entity_id, 0)
        AND COALESCE(r.subsidiary_account_id, 0) = COALESCE(@subsidiary_account_id, r.subsidiary_account_id, 0)
        AND COALESCE(r.region_id, 0) = COALESCE(@region_id, r.region_id, 0)
        AND COALESCE(r.product_id, 0) = COALESCE(@product_id, r.product_id, 0)
)
, pls AS (
    SELECT
        account_id
        , SUM(data01) AS data01
        , SUM(data02) AS data02
        , SUM(data03) AS data03
        , SUM(data04) AS data04
        , SUM(data05) AS data05
        , SUM(data06) AS data06
        , SUM(data07) AS data07
        , SUM(data08) AS data08
        , SUM(data09) AS data09
        , SUM(data10) AS data10
        , SUM(data11) AS data11
        , SUM(data12) AS data12
    FROM
        pl
    GROUP BY
        account_id
)
, factors (id, parent_id) AS (
    SELECT
        id
        , parent_id
    FROM
        dbo27.members
    WHERE
        parent_id IS NOT NULL

    UNION ALL
    SELECT
        p.id
        , m.parent_id
    FROM
        factors p
        INNER JOIN dbo27.members m ON m.id = p.parent_id
    WHERE
        m.parent_id IS NOT NULL
        AND NOT p.id = m.parent_id
)

SELECT
    report
    , level
    , code
    , name
    , data01
    , data02
    , data03
    , data04
    , data05
    , data06
    , data07
    , data08
    , data09
    , data10
    , data11
    , data12
FROM
    (
        SELECT
            account_id
            , 1 AS report
            , CASE WHEN a.parent_id IS NULL THEN 0 ELSE 1 END AS level
            , a.code
            , a.name
            , data01 * pl_sign AS data01
            , data02 * pl_sign AS data02
            , data03 * pl_sign AS data03
            , data04 * pl_sign AS data04
            , data05 * pl_sign AS data05
            , data06 * pl_sign AS data06
            , data07 * pl_sign AS data07
            , data08 * pl_sign AS data08
            , data09 * pl_sign AS data09
            , data10 * pl_sign AS data10
            , data11 * pl_sign AS data11
            , data12 * pl_sign AS data12
        FROM
            pls
            INNER JOIN dbo27.members a ON a.id = pls.account_id
            INNER JOIN dbo27.member_types t ON t.id = a.account_type_id

        UNION ALL
        SELECT
            p.id AS account_id
            , 1 AS report
            , CASE WHEN MAX(p.parent_id) IS NULL THEN 0 ELSE 1 END AS level
            , MAX(p.code) AS code
            , MAX(p.name) AS name
            , SUM(data01 * pl_sign) AS data01
            , SUM(data02 * pl_sign) AS data02
            , SUM(data03 * pl_sign) AS data03
            , SUM(data04 * pl_sign) AS data04
            , SUM(data05 * pl_sign) AS data05
            , SUM(data06 * pl_sign) AS data06
            , SUM(data07 * pl_sign) AS data07
            , SUM(data08 * pl_sign) AS data08
            , SUM(data09 * pl_sign) AS data09
            , SUM(data10 * pl_sign) AS data10
            , SUM(data11 * pl_sign) AS data11
            , SUM(data12 * pl_sign) AS data12
        FROM
            pls
            INNER JOIN dbo27.members a ON a.id = pls.account_id
            INNER JOIN dbo27.member_types t ON t.id = a.account_type_id
            INNER JOIN factors f ON f.id = pls.account_id
            INNER JOIN dbo27.members p ON p.id = f.parent_id
        GROUP BY
            p.id

        UNION ALL
        SELECT
            NULL AS account_id
            , 4 AS report
            , 0 level
            , NULL AS code
            , NULL AS name
            , NULL AS data01
            , NULL AS data02
            , NULL AS data03
            , NULL AS data04
            , NULL AS data05
            , NULL AS data06
            , NULL AS data07
            , NULL AS data08
            , NULL AS data09
            , NULL AS data10
            , NULL AS data11
            , NULL AS data12

        UNION ALL
        SELECT
            account_id
            , 4 AS report
            , CASE WHEN a.parent_id IS NULL THEN 0 ELSE 1 END AS level
            , a.code
            , a.name
            , data01 * cf_sign AS data01
            , data02 * cf_sign AS data02
            , data03 * cf_sign AS data03
            , data04 * cf_sign AS data04
            , data05 * cf_sign AS data05
            , data06 * cf_sign AS data06
            , data07 * cf_sign AS data07
            , data08 * cf_sign AS data08
            , data09 * cf_sign AS data09
            , data10 * cf_sign AS data10
            , data11 * cf_sign AS data11
            , data12 * cf_sign AS data12
        FROM
            cfs
            INNER JOIN dbo27.members a ON a.id = cfs.account_id
            INNER JOIN dbo27.member_types t ON t.id = a.account_type_id

        UNION ALL
        SELECT
            p.id AS account_id
            , 4 AS report
            , CASE WHEN MAX(p.parent_id) IS NULL THEN 0 ELSE 1 END AS level
            , MAX(p.code) AS code
            , MAX(p.name) AS name
            , SUM(data01 * cf_sign) AS data01
            , SUM(data02 * cf_sign) AS data02
            , SUM(data03 * cf_sign) AS data03
            , SUM(data04 * cf_sign) AS data04
            , SUM(data05 * cf_sign) AS data05
            , SUM(data06 * cf_sign) AS data06
            , SUM(data07 * cf_sign) AS data07
            , SUM(data08 * cf_sign) AS data08
            , SUM(data09 * cf_sign) AS data09
            , SUM(data10 * cf_sign) AS data10
            , SUM(data11 * cf_sign) AS data11
            , SUM(data12 * cf_sign) AS data12
        FROM
            cfs
            INNER JOIN dbo27.members a ON a.id = cfs.account_id
            INNER JOIN dbo27.member_types t ON t.id = a.account_type_id
            INNER JOIN factors f ON f.id = cfs.account_id
            INNER JOIN dbo27.members p ON p.id = f.parent_id
        GROUP BY
            p.id
    ) d
WHERE
    (code IS NULL OR data01 <> 0 OR  data02 <> 0 OR  data03 <> 0 OR  data04 <> 0 OR  data05 <> 0 OR  data06 <> 0 OR  data07 <> 0 OR  data08 <> 0 OR  data09 <> 0 OR  data10 <> 0 OR  data11 <> 0 OR  data12 <> 0)
    AND level <= COALESCE(@level, 10)
ORDER BY
    report
    , code

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: The procedure selects data from dbo27.budget_requests
-- =============================================

CREATE PROCEDURE [xls27].[usp_budget_request1]
    @company_id int = NULL
    , @category_id int = NULL
    , @time_id int = NULL
    , @entity_id int = NULL
    , @rows int = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

DECLARE @message nvarchar(max)

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.members WHERE id IN (@category_id, @time_id))

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

SET @category_id = (SELECT id FROM dbo27.members WHERE id = @category_id AND company_id = @company_id)

IF @category_id IS NOT NULL AND @time_id IS NOT NULL AND @entity_id IS NOT NULL
    AND EXISTS (
        SELECT
            p.name
        FROM
            sys.database_principals p
            INNER JOIN sys.database_role_members rm ON rm.member_principal_id = p.principal_id
        WHERE
            p.name = USER_NAME()
            AND rm.role_principal_id = USER_ID('budgeting_app_users')
    ) AND 0 < (
        SELECT
            COUNT(*) - SUM(COALESCE(mp.select_permission, 0))
        FROM
            dbo27.members m
            LEFT OUTER JOIN dbo27.member_permissions mp ON mp.member_id = m.id AND mp.username = USER_NAME()
        WHERE
            m.id IN (@category_id, @time_id, @entity_id)
    )
    BEGIN
    SET @category_id = NULL
    SET @time_id = NULL
    SET @entity_id = NULL
    END

IF @rows IS NULL SET @rows = 5

DECLARE @row_count int = COALESCE((
    SELECT
        MAX(t.row_index) AS row
    FROM
        dbo27.budget_requests t
    WHERE
        t.[entity_id] = @entity_id
        AND t.category_id = @category_id
        AND t.[time_id] = @time_id
        AND t.is_empty = 0
    ), 0)

IF @row_count < @rows SET @row_count = @rows

;WITH e1(n) AS
(
    SELECT 1 UNION ALL SELECT 1 UNION ALL SELECT 1 UNION ALL SELECT 1 UNION ALL SELECT 1 UNION ALL
    SELECT 1 UNION ALL SELECT 1 UNION ALL SELECT 1 UNION ALL SELECT 1 UNION ALL SELECT 1
),                                              -- 10
e2(n) AS (SELECT 1 FROM e1 CROSS JOIN e1 AS b), -- 10*10
e3(n) AS (SELECT 1 FROM e1 CROSS JOIN e2)       -- 10*100

SELECT
    n.row_index
    , t.row_format
    , t.description
    , t.account_id
    , COALESCE(tr1.name, m1.name) AS account_name
    , t.subsidiary_account_id
    , t.region_id
    , t.product_id
    , t.vat_rate_id
    , t.unit_id
    , '=[@payments01]+[@payments02]+[@payments03]+[@payments04]+[@payments05]+[@payments06]+[@payments07]+[@payments08]+[@payments09]+[@payments10]+[@payments11]+[@payments12]' AS total_payments
    , '=[@charges01]+[@charges02]+[@charges03]+[@charges04]+[@charges05]+[@charges06]+[@charges07]+[@charges08]+[@charges09]+[@charges10]+[@charges11]+[@charges12]' AS total_charges
    , t.balance00
    , t.payments01
    , t.charges01
    , '=[@balance00]-[@payments01]+[@charges01]' balance01
    , t.payments02
    , t.charges02
    , '=[@balance01]-[@payments02]+[@charges02]' balance02
    , t.payments03
    , t.charges03
    , '=[@balance02]-[@payments03]+[@charges03]' balance03
    , t.payments04
    , t.charges04
    , '=[@balance03]-[@payments04]+[@charges04]' balance04
    , t.payments05
    , t.charges05
    , '=[@balance04]-[@payments05]+[@charges05]' balance05
    , t.payments06
    , t.charges06
    , '=[@balance05]-[@payments06]+[@charges06]' balance06
    , t.payments07
    , t.charges07
    , '=[@balance06]-[@payments07]+[@charges07]' balance07
    , t.payments08
    , t.charges08
    , '=[@balance07]-[@payments08]+[@charges08]' balance08
    , t.payments09
    , t.charges09
    , '=[@balance08]-[@payments09]+[@charges09]' balance09
    , t.payments10
    , t.charges10
    , '=[@balance09]-[@payments10]+[@charges10]' balance10
    , t.payments11
    , t.charges11
    , '=[@balance10]-[@payments11]+[@charges11]' balance11
    , t.payments12
    , t.charges12
    , '=[@balance11]-[@payments12]+[@charges12]' balance12
    , t.row_formulas
    , t.row_comments
    , COALESCE(u.name, t.modified_by) AS modified_by
    , t.modified_on
FROM
    (SELECT row_index = ROW_NUMBER() OVER (ORDER BY n) FROM e3) n
    LEFT OUTER JOIN dbo27.budget_requests t ON
        t.row_index = n.row_index
        AND t.category_id = @category_id
        AND t.[time_id] = @time_id
        AND t.[entity_id] = @entity_id
    LEFT OUTER JOIN dbo27.members m1 ON m1.id = t.account_id
    LEFT OUTER JOIN dbo27.users u ON u.company_id = @company_id AND u.username = t.modified_by
    LEFT OUTER JOIN dbo27.translations tr1 ON tr1.company_id = @company_id AND tr1.table_id = 1 AND tr1.member_id = m1.id AND tr1.language = @data_language
WHERE
    n.row_index BETWEEN 1 AND @row_count
ORDER BY
    n.row_index

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: The procedure deleted data from dbo27.budget_requests
-- =============================================

CREATE PROCEDURE [xls27].[usp_budget_request1_delete]
    @category_id int = NULL
    , @time_id int = NULL
    , @entity_id int = NULL
    , @rownum int = NULL
    , @row_index int = NULL
    , @transaction_start_time datetime = NULL
AS
BEGIN

SET NOCOUNT ON

IF NOT EXISTS (SELECT TOP 1 u.company_id FROM dbo27.members t INNER JOIN dbo27.users u ON u.company_id = t.company_id  WHERE t.id = @category_id AND u.username = USER_NAME() AND u.is_active = 1)
    RETURN

SET NOCOUNT OFF

DELETE FROM dbo27.budget_requests
WHERE
    category_id = @category_id
    AND time_id = @time_id
    AND [entity_id] = @entity_id
    AND row_index = @rownum
    AND transaction_start_time < @transaction_start_time

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: The procedure updates data of dbo27.budget_requests
-- =============================================

CREATE PROCEDURE [xls27].[usp_budget_request1_update]
    @category_id int = NULL
    , @time_id int = NULL
    , @entity_id int = NULL
    , @rownum int = NULL
    , @row_index int = NULL
    , @row_format int = NULL
    , @description nvarchar(255) = NULL
    , @account_id int = NULL
    , @subsidiary_account_id int = NULL
    , @region_id int = NULL
    , @product_id int = NULL
    , @vat_rate_id tinyint = NULL
    , @unit_id int = NULL
    , @total_payments float = NULL, @total_charges float = NULL, @balance00 float = NULL
    , @payments01 float = NULL, @charges01 float = NULL, @balance01 float = NULL
    , @payments02 float = NULL, @charges02 float = NULL, @balance02 float = NULL
    , @payments03 float = NULL, @charges03 float = NULL, @balance03 float = NULL
    , @payments04 float = NULL, @charges04 float = NULL, @balance04 float = NULL
    , @payments05 float = NULL, @charges05 float = NULL, @balance05 float = NULL
    , @payments06 float = NULL, @charges06 float = NULL, @balance06 float = NULL
    , @payments07 float = NULL, @charges07 float = NULL, @balance07 float = NULL
    , @payments08 float = NULL, @charges08 float = NULL, @balance08 float = NULL
    , @payments09 float = NULL, @charges09 float = NULL, @balance09 float = NULL
    , @payments10 float = NULL, @charges10 float = NULL, @balance10 float = NULL
    , @payments11 float = NULL, @charges11 float = NULL, @balance11 float = NULL
    , @payments12 float = NULL, @charges12 float = NULL, @balance12 float = NULL
    , @row_formulas nvarchar(max) = NULL
    , @row_comments nvarchar(max) = NULL
    , @transaction_start_time datetime = NULL
    , @is_insert bit = NULL
AS
BEGIN

SET NOCOUNT ON

DECLARE @company_id int = NULL

SELECT TOP 1 @company_id = u.company_id FROM dbo27.members t INNER JOIN dbo27.users u ON u.company_id = t.company_id  WHERE t.id = @category_id AND u.username = USER_NAME() AND u.is_active = 1

IF @company_id IS NULL OR @category_id IS NULL OR @time_id IS NULL
    RETURN

IF NOT EXISTS (SELECT TOP 1 id FROM dbo27.members WHERE id = @time_id AND company_id = @company_id)
    RETURN

SET NOCOUNT OFF

UPDATE dbo27.budget_requests
SET
    row_index = @rownum
    , row_format = @row_format
    , description = @description
    , account_id = @account_id
    , subsidiary_account_id = @subsidiary_account_id
    , region_id = @region_id
    , product_id = @product_id
    , vat_rate_id = @vat_rate_id
    , unit_id = @unit_id
    , total_payments = @total_payments, total_charges = @total_charges, balance00 = @balance00
    , payments01 = @payments01, charges01 = @charges01, balance01 = @balance01
    , payments02 = @payments02, charges02 = @charges02, balance02 = @balance02
    , payments03 = @payments03, charges03 = @charges03, balance03 = @balance03
    , payments04 = @payments04, charges04 = @charges04, balance04 = @balance04
    , payments05 = @payments05, charges05 = @charges05, balance05 = @balance05
    , payments06 = @payments06, charges06 = @charges06, balance06 = @balance06
    , payments07 = @payments07, charges07 = @charges07, balance07 = @balance07
    , payments08 = @payments08, charges08 = @charges08, balance08 = @balance08
    , payments09 = @payments09, charges09 = @charges09, balance09 = @balance09
    , payments10 = @payments10, charges10 = @charges10, balance10 = @balance10
    , payments11 = @payments11, charges11 = @charges11, balance11 = @balance11
    , payments12 = @payments12, charges12 = @charges12, balance12 = @balance12
    , row_formulas = @row_formulas
    , row_comments = @row_comments
    , transaction_start_time = @transaction_start_time
WHERE
    category_id = @category_id
    AND time_id = @time_id
    AND [entity_id] = @entity_id
    AND row_index = @rownum

IF @@ROWCOUNT = 0
    IF COALESCE(@is_insert, 0) = 1 OR dbo27.is_request_row_empty(
        @category_id
        , @time_id
        , @entity_id
        , @row_format
        , @description
        , @account_id
        , @subsidiary_account_id
        , @region_id
        , @product_id
        , @vat_rate_id
        , @unit_id
        , @total_payments, @total_charges, @balance00
        , @payments01, @charges01, @balance01
        , @payments02, @charges02, @balance02
        , @payments03, @charges03, @balance03
        , @payments04, @charges04, @balance04
        , @payments05, @charges05, @balance05
        , @payments06, @charges06, @balance06
        , @payments07, @charges07, @balance07
        , @payments08, @charges08, @balance08
        , @payments09, @charges09, @balance09
        , @payments10, @charges10, @balance10
        , @payments11, @charges11, @balance11
        , @payments12, @charges12, @balance12
        ) = 0
INSERT INTO dbo27.budget_requests
    ( category_id
    , time_id
    , [entity_id]
    , row_index
    , row_format
    , description
    , account_id
    , subsidiary_account_id
    , product_id
    , vat_rate_id
    , unit_id
    , total_payments, total_charges, balance00
    , payments01, charges01, balance01
    , payments02, charges02, balance02
    , payments03, charges03, balance03
    , payments04, charges04, balance04
    , payments05, charges05, balance05
    , payments06, charges06, balance06
    , payments07, charges07, balance07
    , payments08, charges08, balance08
    , payments09, charges09, balance09
    , payments10, charges10, balance10
    , payments11, charges11, balance11
    , payments12, charges12, balance12
    , row_formulas
    , row_comments
    , transaction_start_time
    )
VALUES
    ( @category_id
    , @time_id
    , @entity_id
    , @rownum
    , @row_format
    , @description
    , @account_id
    , @subsidiary_account_id
    , @product_id
    , @vat_rate_id
    , @unit_id
    , @total_payments, @total_charges, @balance00
    , @payments01, @charges01, @balance01
    , @payments02, @charges02, @balance02
    , @payments03, @charges03, @balance03
    , @payments04, @charges04, @balance04
    , @payments05, @charges05, @balance05
    , @payments06, @charges06, @balance06
    , @payments07, @charges07, @balance07
    , @payments08, @charges08, @balance08
    , @payments09, @charges09, @balance09
    , @payments10, @charges10, @balance10
    , @payments11, @charges11, @balance11
    , @payments12, @charges12, @balance12
    , @row_formulas
    , @row_comments
    , @transaction_start_time
    )

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: The procedure inserts data into dbo27.budget_requests
-- =============================================

CREATE PROCEDURE [xls27].[usp_budget_request1_insert]
    @category_id int = NULL
    , @time_id int = NULL
    , @entity_id int = NULL
    , @rownum int = NULL
    , @row_index int = NULL
    , @row_format int = NULL
    , @description nvarchar(255) = NULL
    , @account_id int = NULL
    , @subsidiary_account_id int = NULL
    , @region_id int = NULL
    , @product_id int = NULL
    , @vat_rate_id int = NULL
    , @unit_id int = NULL
    , @total_payments money = NULL, @total_charges money = NULL, @balance00 money = NULL
    , @payments01 money = NULL, @charges01 money = NULL, @balance01 money = NULL
    , @payments02 money = NULL, @charges02 money = NULL, @balance02 money = NULL
    , @payments03 money = NULL, @charges03 money = NULL, @balance03 money = NULL
    , @payments04 money = NULL, @charges04 money = NULL, @balance04 money = NULL
    , @payments05 money = NULL, @charges05 money = NULL, @balance05 money = NULL
    , @payments06 money = NULL, @charges06 money = NULL, @balance06 money = NULL
    , @payments07 money = NULL, @charges07 money = NULL, @balance07 money = NULL
    , @payments08 money = NULL, @charges08 money = NULL, @balance08 money = NULL
    , @payments09 money = NULL, @charges09 money = NULL, @balance09 money = NULL
    , @payments10 money = NULL, @charges10 money = NULL, @balance10 money = NULL
    , @payments11 money = NULL, @charges11 money = NULL, @balance11 money = NULL
    , @payments12 money = NULL, @charges12 money = NULL, @balance12 money = NULL
    , @row_formulas nvarchar(max) = NULL
    , @row_comments nvarchar(max) = NULL
    , @transaction_start_time datetime = NULL
AS
BEGIN

SET NOCOUNT ON

EXEC xls27.usp_budget_request1_update
    @category_id
    , @time_id
    , @entity_id
    , @rownum
    , @row_index
    , @row_format
    , @description
    , @account_id
    , @subsidiary_account_id
    , @region_id
    , @product_id
    , @vat_rate_id
    , @unit_id
    , @total_payments, @total_charges, @balance00
    , @payments01, @charges01, @balance01
    , @payments02, @charges02, @balance02
    , @payments03, @charges03, @balance03
    , @payments04, @charges04, @balance04
    , @payments05, @charges05, @balance05
    , @payments06, @charges06, @balance06
    , @payments07, @charges07, @balance07
    , @payments08, @charges08, @balance08
    , @payments09, @charges09, @balance09
    , @payments10, @charges10, @balance10
    , @payments11, @charges11, @balance11
    , @payments12, @charges12, @balance12
    , @row_formulas
    , @row_comments
    , @transaction_start_time
    , 1

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: The procedure selects data from dbo27.budget_requests
-- =============================================

CREATE PROCEDURE [xls27].[usp_budget_request2]
    @company_id int = NULL
    , @category_id int = NULL
    , @time_id int = NULL
    , @entity_id int = NULL
    , @rows int = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

DECLARE @message nvarchar(max)

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.members WHERE id IN (@category_id, @time_id))

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

SET @category_id = (SELECT id FROM dbo27.members WHERE id = @category_id AND company_id = @company_id)

IF @category_id IS NOT NULL AND @time_id IS NOT NULL AND @entity_id IS NOT NULL
    AND EXISTS (
        SELECT
            p.name
        FROM
            sys.database_principals p
            INNER JOIN sys.database_role_members rm ON rm.member_principal_id = p.principal_id
        WHERE
            p.name = USER_NAME()
            AND rm.role_principal_id = USER_ID('budgeting_app_users')
    ) AND 0 < (
        SELECT
            COUNT(*) - SUM(COALESCE(mp.select_permission, 0))
        FROM
            dbo27.members m
            LEFT OUTER JOIN dbo27.member_permissions mp ON mp.member_id = m.id AND mp.username = USER_NAME()
        WHERE
            m.id IN (@category_id, @time_id, @entity_id)
    )
    BEGIN
    SET @category_id = NULL
    SET @time_id = NULL
    SET @entity_id = NULL
    END

IF @rows IS NULL SET @rows = 5

DECLARE @row_count int = COALESCE((
    SELECT
        MAX(t.row_index) AS row
    FROM
        dbo27.budget_requests t
    WHERE
        t.[entity_id] = @entity_id
        AND t.category_id = @category_id
        AND t.[time_id] = @time_id
        AND t.is_empty = 0
    ), 0)

IF @row_count < @rows SET @row_count = @rows

;WITH e1(n) AS
(
    SELECT 1 UNION ALL SELECT 1 UNION ALL SELECT 1 UNION ALL SELECT 1 UNION ALL SELECT 1 UNION ALL
    SELECT 1 UNION ALL SELECT 1 UNION ALL SELECT 1 UNION ALL SELECT 1 UNION ALL SELECT 1
),                                              -- 10
e2(n) AS (SELECT 1 FROM e1 CROSS JOIN e1 AS b), -- 10*10
e3(n) AS (SELECT 1 FROM e1 CROSS JOIN e2)       -- 10*100

SELECT
    n.row_index
    , t.row_format
    , t.description
    , t.account_id
    , COALESCE(tr1.name, m1.name) AS account_name
    , t.subsidiary_account_id
    , t.region_id
    , t.product_id
    , t.vat_rate_id
    , t.unit_id
    , '=[@payments01]+[@payments02]+[@payments03]+[@payments04]+[@payments05]+[@payments06]+[@payments07]+[@payments08]+[@payments09]+[@payments10]+[@payments11]+[@payments12]' AS total_payments
    , '=[@charges01]+[@charges02]+[@charges03]+[@charges04]+[@charges05]+[@charges06]+[@charges07]+[@charges08]+[@charges09]+[@charges10]+[@charges11]+[@charges12]' AS total_charges
    , t.balance00
    , t.charges01
    , t.charges02
    , t.charges03
    , t.charges04
    , t.charges05
    , t.charges06
    , t.charges07
    , t.charges08
    , t.charges09
    , t.charges10
    , t.charges11
    , t.charges12
    , t.payments01
    , t.payments02
    , t.payments03
    , t.payments04
    , t.payments05
    , t.payments06
    , t.payments07
    , t.payments08
    , t.payments09
    , t.payments10
    , t.payments11
    , t.payments12
    , '=[@balance00]-[@payments01]+[@charges01]' balance01
    , '=[@balance01]-[@payments02]+[@charges02]' balance02
    , '=[@balance02]-[@payments03]+[@charges03]' balance03
    , '=[@balance03]-[@payments04]+[@charges04]' balance04
    , '=[@balance04]-[@payments05]+[@charges05]' balance05
    , '=[@balance05]-[@payments06]+[@charges06]' balance06
    , '=[@balance06]-[@payments07]+[@charges07]' balance07
    , '=[@balance07]-[@payments08]+[@charges08]' balance08
    , '=[@balance08]-[@payments09]+[@charges09]' balance09
    , '=[@balance09]-[@payments10]+[@charges10]' balance10
    , '=[@balance10]-[@payments11]+[@charges11]' balance11
    , '=[@balance11]-[@payments12]+[@charges12]' balance12
    , t.row_formulas
    , t.row_comments
    , COALESCE(u.name, t.modified_by) AS modified_by
    , t.modified_on
FROM
    (SELECT row_index = ROW_NUMBER() OVER (ORDER BY n) FROM e3) n
    LEFT OUTER JOIN dbo27.budget_requests t ON
        t.row_index = n.row_index
        AND t.category_id = @category_id
        AND t.[time_id] = @time_id
        AND t.[entity_id] = @entity_id
    LEFT OUTER JOIN dbo27.members m1 ON m1.id = t.account_id
    LEFT OUTER JOIN dbo27.users u ON u.company_id = @company_id AND u.username = t.modified_by
    LEFT OUTER JOIN dbo27.translations tr1 ON tr1.company_id = @company_id AND tr1.table_id = 1 AND tr1.member_id = m1.id AND tr1.language = @data_language
WHERE
    n.row_index BETWEEN 1 AND @row_count
ORDER BY
    n.row_index

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: The procedure deleted data from dbo27.budget_requests
-- =============================================

CREATE PROCEDURE [xls27].[usp_budget_request2_delete]
    @category_id int = NULL
    , @time_id int = NULL
    , @entity_id int = NULL
    , @rownum int = NULL
    , @row_index int = NULL
    , @transaction_start_time datetime = NULL
AS
BEGIN

SET NOCOUNT ON

EXEC xls27.usp_budget_request1_delete @category_id, @time_id, @entity_id, @rownum, @row_index, @transaction_start_time

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: The procedure inserts data into dbo27.budget_requests
-- =============================================

CREATE PROCEDURE [xls27].[usp_budget_request2_insert]
    @category_id int = NULL
    , @time_id int = NULL
    , @entity_id int = NULL
    , @rownum int = NULL
    , @row_index int = NULL
    , @row_format int = NULL
    , @description nvarchar(255) = NULL
    , @account_id int = NULL
    , @subsidiary_account_id int = NULL
    , @region_id int = NULL
    , @product_id int = NULL
    , @vat_rate_id int = NULL
    , @unit_id int = NULL
    , @total_payments money = NULL, @total_charges money = NULL, @balance00 money = NULL
    , @payments01 money = NULL, @charges01 money = NULL, @balance01 money = NULL
    , @payments02 money = NULL, @charges02 money = NULL, @balance02 money = NULL
    , @payments03 money = NULL, @charges03 money = NULL, @balance03 money = NULL
    , @payments04 money = NULL, @charges04 money = NULL, @balance04 money = NULL
    , @payments05 money = NULL, @charges05 money = NULL, @balance05 money = NULL
    , @payments06 money = NULL, @charges06 money = NULL, @balance06 money = NULL
    , @payments07 money = NULL, @charges07 money = NULL, @balance07 money = NULL
    , @payments08 money = NULL, @charges08 money = NULL, @balance08 money = NULL
    , @payments09 money = NULL, @charges09 money = NULL, @balance09 money = NULL
    , @payments10 money = NULL, @charges10 money = NULL, @balance10 money = NULL
    , @payments11 money = NULL, @charges11 money = NULL, @balance11 money = NULL
    , @payments12 money = NULL, @charges12 money = NULL, @balance12 money = NULL
    , @row_formulas nvarchar(max) = NULL
    , @row_comments nvarchar(max) = NULL
    , @transaction_start_time datetime = NULL
AS
BEGIN

SET NOCOUNT ON

EXEC xls27.usp_budget_request1_update
    @category_id
    , @time_id
    , @entity_id
    , @rownum
    , @row_index
    , @row_format
    , @description
    , @account_id
    , @subsidiary_account_id
    , @region_id
    , @product_id
    , @vat_rate_id
    , @unit_id
    , @total_payments, @total_charges, @balance00
    , @payments01, @charges01, @balance01
    , @payments02, @charges02, @balance02
    , @payments03, @charges03, @balance03
    , @payments04, @charges04, @balance04
    , @payments05, @charges05, @balance05
    , @payments06, @charges06, @balance06
    , @payments07, @charges07, @balance07
    , @payments08, @charges08, @balance08
    , @payments09, @charges09, @balance09
    , @payments10, @charges10, @balance10
    , @payments11, @charges11, @balance11
    , @payments12, @charges12, @balance12
    , @row_formulas
    , @row_comments
    , @transaction_start_time
    , 1

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: The procedure updates data of dbo27.budget_requests
-- =============================================

CREATE PROCEDURE [xls27].[usp_budget_request2_update]
    @category_id int = NULL
    , @time_id int = NULL
    , @entity_id int = NULL
    , @rownum int = NULL
    , @row_index int = NULL
    , @row_format int = NULL
    , @description nvarchar(255) = NULL
    , @account_id int = NULL
    , @subsidiary_account_id int = NULL
    , @region_id int = NULL
    , @product_id int = NULL
    , @vat_rate_id tinyint = NULL
    , @unit_id int = NULL
    , @total_payments money = NULL, @total_charges money = NULL, @balance00 money = NULL
    , @payments01 money = NULL, @charges01 money = NULL, @balance01 money = NULL
    , @payments02 money = NULL, @charges02 money = NULL, @balance02 money = NULL
    , @payments03 money = NULL, @charges03 money = NULL, @balance03 money = NULL
    , @payments04 money = NULL, @charges04 money = NULL, @balance04 money = NULL
    , @payments05 money = NULL, @charges05 money = NULL, @balance05 money = NULL
    , @payments06 money = NULL, @charges06 money = NULL, @balance06 money = NULL
    , @payments07 money = NULL, @charges07 money = NULL, @balance07 money = NULL
    , @payments08 money = NULL, @charges08 money = NULL, @balance08 money = NULL
    , @payments09 money = NULL, @charges09 money = NULL, @balance09 money = NULL
    , @payments10 money = NULL, @charges10 money = NULL, @balance10 money = NULL
    , @payments11 money = NULL, @charges11 money = NULL, @balance11 money = NULL
    , @payments12 money = NULL, @charges12 money = NULL, @balance12 money = NULL
    , @row_formulas nvarchar(max) = NULL
    , @row_comments nvarchar(max) = NULL
    , @transaction_start_time datetime = NULL
    , @is_insert bit = NULL
AS
BEGIN

SET NOCOUNT ON

EXEC xls27.usp_budget_request1_update
    @category_id
    , @time_id
    , @entity_id
    , @rownum
    , @row_index
    , @row_format
    , @description
    , @account_id
    , @subsidiary_account_id
    , @region_id
    , @product_id
    , @vat_rate_id
    , @unit_id
    , @total_payments, @total_charges, @balance00
    , @payments01, @charges01, @balance01
    , @payments02, @charges02, @balance02
    , @payments03, @charges03, @balance03
    , @payments04, @charges04, @balance04
    , @payments05, @charges05, @balance05
    , @payments06, @charges06, @balance06
    , @payments07, @charges07, @balance07
    , @payments08, @charges08, @balance08
    , @payments09, @charges09, @balance09
    , @payments10, @charges10, @balance10
    , @payments11, @charges11, @balance11
    , @payments12, @charges12, @balance12
    , @row_formulas
    , @row_comments
    , @transaction_start_time
    , @is_insert

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: The procedure selects budget requests
-- =============================================

CREATE PROCEDURE [xls27].[usp_budget_requests]
    @company_id int = NULL
    , @category_id int = NULL
    , @time_id int = NULL
    , @entity_id int = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.members WHERE id IN (@category_id, @time_id, @entity_id))

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

SELECT
    r.category_id
    , r.time_id
    , r.entity_id
    , COALESCE(tr1.name, m1.name) AS category_name
    , COALESCE(tr2.name, m2.name) AS period_name
    , COALESCE(tr3.name, m3.name) AS entity_name
    , r.rows
    , r.modified_on
FROM
    (
        SELECT
            r.category_id
            , r.time_id
            , r.entity_id
            , MAX(r.modified_on) AS modified_on
            , COUNT(*) - SUM(CAST(r.is_empty AS tinyint)) AS rows
        FROM
            dbo27.budget_requests r
            INNER JOIN dbo27.members m1 ON m1.id = r.category_id
        WHERE
            m1.company_id = @company_id
            AND r.category_id = COALESCE(@category_id, r.category_id)
            AND r.time_id = COALESCE(@time_id, r.time_id)
            AND r.entity_id = COALESCE(@entity_id, r.entity_id)
        GROUP BY
            r.category_id
            , r.time_id
            , r.entity_id
    ) r
    INNER JOIN dbo27.members m1 ON m1.id = r.category_id
    INNER JOIN dbo27.members m2 ON m2.id = r.time_id
    INNER JOIN dbo27.members m3 ON m3.id = r.entity_id
    LEFT OUTER JOIN dbo27.translations tr1 ON tr1.company_id = @company_id AND tr1.table_id = 1 AND tr1.member_id = m1.id AND tr1.language = @data_language
    LEFT OUTER JOIN dbo27.translations tr2 ON tr2.company_id = @company_id AND tr2.table_id = 1 AND tr2.member_id = m2.id AND tr2.language = @data_language
    LEFT OUTER JOIN dbo27.translations tr3 ON tr3.company_id = @company_id AND tr3.table_id = 1 AND tr3.member_id = m3.id AND tr3.language = @data_language
ORDER BY
    r.category_id
    , r.time_id
    , r.entity_id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: The procedure selects account totals
-- =============================================

CREATE PROCEDURE [xls27].[usp_budget_requests_totals]
    @company_id int = NULL
    , @category_id int = NULL
    , @time_id int = NULL
    , @entity_id int = NULL
    , @subsidiary_account_id int = NULL
    , @region_id int = NULL
    , @product_id int = NULL
    , @first_month int = 1
    , @last_month int = 12
    , @unit int = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

IF @first_month IS NULL SET @first_month = 1
IF @last_month IS NULL SET @last_month = 12

DECLARE @factor float = 1.0 / COALESCE(@unit, 1)

SET NOCOUNT ON

;WITH raw_data AS (
    SELECT
        r.id
        , r.account_id
        , r.subsidiary_account_id

        , COALESCE(ROUND(r.payments01 * COALESCE(cr.period01, 1), 2), 0) AS payments01
        , COALESCE(ROUND(r.payments02 * COALESCE(cr.period02, 1), 2), 0) AS payments02
        , COALESCE(ROUND(r.payments03 * COALESCE(cr.period03, 1), 2), 0) AS payments03
        , COALESCE(ROUND(r.payments04 * COALESCE(cr.period04, 1), 2), 0) AS payments04
        , COALESCE(ROUND(r.payments05 * COALESCE(cr.period05, 1), 2), 0) AS payments05
        , COALESCE(ROUND(r.payments06 * COALESCE(cr.period06, 1), 2), 0) AS payments06
        , COALESCE(ROUND(r.payments07 * COALESCE(cr.period07, 1), 2), 0) AS payments07
        , COALESCE(ROUND(r.payments08 * COALESCE(cr.period08, 1), 2), 0) AS payments08
        , COALESCE(ROUND(r.payments09 * COALESCE(cr.period09, 1), 2), 0) AS payments09
        , COALESCE(ROUND(r.payments10 * COALESCE(cr.period10, 1), 2), 0) AS payments10
        , COALESCE(ROUND(r.payments11 * COALESCE(cr.period11, 1), 2), 0) AS payments11
        , COALESCE(ROUND(r.payments12 * COALESCE(cr.period12, 1), 2), 0) AS payments12

        , COALESCE(ROUND(r.charges01 * COALESCE(cr.period01, 1), 2), 0) AS charges01
        , COALESCE(ROUND(r.charges02 * COALESCE(cr.period02, 1), 2), 0) AS charges02
        , COALESCE(ROUND(r.charges03 * COALESCE(cr.period03, 1), 2), 0) AS charges03
        , COALESCE(ROUND(r.charges04 * COALESCE(cr.period04, 1), 2), 0) AS charges04
        , COALESCE(ROUND(r.charges05 * COALESCE(cr.period05, 1), 2), 0) AS charges05
        , COALESCE(ROUND(r.charges06 * COALESCE(cr.period06, 1), 2), 0) AS charges06
        , COALESCE(ROUND(r.charges07 * COALESCE(cr.period07, 1), 2), 0) AS charges07
        , COALESCE(ROUND(r.charges08 * COALESCE(cr.period08, 1), 2), 0) AS charges08
        , COALESCE(ROUND(r.charges09 * COALESCE(cr.period09, 1), 2), 0) AS charges09
        , COALESCE(ROUND(r.charges10 * COALESCE(cr.period10, 1), 2), 0) AS charges10
        , COALESCE(ROUND(r.charges11 * COALESCE(cr.period11, 1), 2), 0) AS charges11
        , COALESCE(ROUND(r.charges12 * COALESCE(cr.period12, 1), 2), 0) AS charges12

        , COALESCE(ROUND(r.payments01 * COALESCE(cr.period01, 1) * t.cf_sign, 2), 0) AS cf01
        , COALESCE(ROUND(r.payments02 * COALESCE(cr.period02, 1) * t.cf_sign, 2), 0) AS cf02
        , COALESCE(ROUND(r.payments03 * COALESCE(cr.period03, 1) * t.cf_sign, 2), 0) AS cf03
        , COALESCE(ROUND(r.payments04 * COALESCE(cr.period04, 1) * t.cf_sign, 2), 0) AS cf04
        , COALESCE(ROUND(r.payments05 * COALESCE(cr.period05, 1) * t.cf_sign, 2), 0) AS cf05
        , COALESCE(ROUND(r.payments06 * COALESCE(cr.period06, 1) * t.cf_sign, 2), 0) AS cf06
        , COALESCE(ROUND(r.payments07 * COALESCE(cr.period07, 1) * t.cf_sign, 2), 0) AS cf07
        , COALESCE(ROUND(r.payments08 * COALESCE(cr.period08, 1) * t.cf_sign, 2), 0) AS cf08
        , COALESCE(ROUND(r.payments09 * COALESCE(cr.period09, 1) * t.cf_sign, 2), 0) AS cf09
        , COALESCE(ROUND(r.payments10 * COALESCE(cr.period10, 1) * t.cf_sign, 2), 0) AS cf10
        , COALESCE(ROUND(r.payments11 * COALESCE(cr.period11, 1) * t.cf_sign, 2), 0) AS cf11
        , COALESCE(ROUND(r.payments12 * COALESCE(cr.period12, 1) * t.cf_sign, 2), 0) AS cf12

        , COALESCE(ROUND(r.charges01 * COALESCE(cr.period01, 1) * t.cf_sign * v.factor, 2), 0) AS vat01
        , COALESCE(ROUND(r.charges02 * COALESCE(cr.period02, 1) * t.cf_sign * v.factor, 2), 0) AS vat02
        , COALESCE(ROUND(r.charges03 * COALESCE(cr.period03, 1) * t.cf_sign * v.factor, 2), 0) AS vat03
        , COALESCE(ROUND(r.charges04 * COALESCE(cr.period04, 1) * t.cf_sign * v.factor, 2), 0) AS vat04
        , COALESCE(ROUND(r.charges05 * COALESCE(cr.period05, 1) * t.cf_sign * v.factor, 2), 0) AS vat05
        , COALESCE(ROUND(r.charges06 * COALESCE(cr.period06, 1) * t.cf_sign * v.factor, 2), 0) AS vat06
        , COALESCE(ROUND(r.charges07 * COALESCE(cr.period07, 1) * t.cf_sign * v.factor, 2), 0) AS vat07
        , COALESCE(ROUND(r.charges08 * COALESCE(cr.period08, 1) * t.cf_sign * v.factor, 2), 0) AS vat08
        , COALESCE(ROUND(r.charges09 * COALESCE(cr.period09, 1) * t.cf_sign * v.factor, 2), 0) AS vat09
        , COALESCE(ROUND(r.charges10 * COALESCE(cr.period10, 1) * t.cf_sign * v.factor, 2), 0) AS vat10
        , COALESCE(ROUND(r.charges11 * COALESCE(cr.period11, 1) * t.cf_sign * v.factor, 2), 0) AS vat11
        , COALESCE(ROUND(r.charges12 * COALESCE(cr.period12, 1) * t.cf_sign * v.factor, 2), 0) AS vat12

        , COALESCE((ROUND(r.charges01 * COALESCE(cr.period01, 1), 2) - COALESCE(ROUND(r.charges01 * COALESCE(cr.period01, 1) * v.factor, 2), 0)) * t.pl_sign, 0) AS pl01
        , COALESCE((ROUND(r.charges02 * COALESCE(cr.period02, 1), 2) - COALESCE(ROUND(r.charges02 * COALESCE(cr.period02, 1) * v.factor, 2), 0)) * t.pl_sign, 0) AS pl02
        , COALESCE((ROUND(r.charges03 * COALESCE(cr.period03, 1), 2) - COALESCE(ROUND(r.charges03 * COALESCE(cr.period03, 1) * v.factor, 2), 0)) * t.pl_sign, 0) AS pl03
        , COALESCE((ROUND(r.charges04 * COALESCE(cr.period04, 1), 2) - COALESCE(ROUND(r.charges04 * COALESCE(cr.period04, 1) * v.factor, 2), 0)) * t.pl_sign, 0) AS pl04
        , COALESCE((ROUND(r.charges05 * COALESCE(cr.period05, 1), 2) - COALESCE(ROUND(r.charges05 * COALESCE(cr.period05, 1) * v.factor, 2), 0)) * t.pl_sign, 0) AS pl05
        , COALESCE((ROUND(r.charges06 * COALESCE(cr.period06, 1), 2) - COALESCE(ROUND(r.charges06 * COALESCE(cr.period06, 1) * v.factor, 2), 0)) * t.pl_sign, 0) AS pl06
        , COALESCE((ROUND(r.charges07 * COALESCE(cr.period07, 1), 2) - COALESCE(ROUND(r.charges07 * COALESCE(cr.period07, 1) * v.factor, 2), 0)) * t.pl_sign, 0) AS pl07
        , COALESCE((ROUND(r.charges08 * COALESCE(cr.period08, 1), 2) - COALESCE(ROUND(r.charges08 * COALESCE(cr.period08, 1) * v.factor, 2), 0)) * t.pl_sign, 0) AS pl08
        , COALESCE((ROUND(r.charges09 * COALESCE(cr.period09, 1), 2) - COALESCE(ROUND(r.charges09 * COALESCE(cr.period09, 1) * v.factor, 2), 0)) * t.pl_sign, 0) AS pl09
        , COALESCE((ROUND(r.charges10 * COALESCE(cr.period10, 1), 2) - COALESCE(ROUND(r.charges10 * COALESCE(cr.period10, 1) * v.factor, 2), 0)) * t.pl_sign, 0) AS pl10
        , COALESCE((ROUND(r.charges11 * COALESCE(cr.period11, 1), 2) - COALESCE(ROUND(r.charges11 * COALESCE(cr.period11, 1) * v.factor, 2), 0)) * t.pl_sign, 0) AS pl11
        , COALESCE((ROUND(r.charges12 * COALESCE(cr.period12, 1), 2) - COALESCE(ROUND(r.charges12 * COALESCE(cr.period12, 1) * v.factor, 2), 0)) * t.pl_sign, 0) AS pl12

        , CASE WHEN t.cf_sign = -1 AND t.pl_sign = 0 THEN COALESCE((ROUND(r.charges01 * COALESCE(cr.period01, 1), 2) - COALESCE(ROUND(r.charges01 * COALESCE(cr.period01, 1) * v.factor, 2), 0)), 0) WHEN t.cf_sign = 0 AND t.pl_sign = -1 THEN COALESCE(-r.charges01, 0) ELSE 0 END AS assets01
        , CASE WHEN t.cf_sign = -1 AND t.pl_sign = 0 THEN COALESCE((ROUND(r.charges02 * COALESCE(cr.period02, 1), 2) - COALESCE(ROUND(r.charges02 * COALESCE(cr.period02, 1) * v.factor, 2), 0)), 0) WHEN t.cf_sign = 0 AND t.pl_sign = -1 THEN COALESCE(-r.charges02, 0) ELSE 0 END AS assets02
        , CASE WHEN t.cf_sign = -1 AND t.pl_sign = 0 THEN COALESCE((ROUND(r.charges03 * COALESCE(cr.period03, 1), 2) - COALESCE(ROUND(r.charges03 * COALESCE(cr.period03, 1) * v.factor, 2), 0)), 0) WHEN t.cf_sign = 0 AND t.pl_sign = -1 THEN COALESCE(-r.charges03, 0) ELSE 0 END AS assets03
        , CASE WHEN t.cf_sign = -1 AND t.pl_sign = 0 THEN COALESCE((ROUND(r.charges04 * COALESCE(cr.period04, 1), 2) - COALESCE(ROUND(r.charges04 * COALESCE(cr.period04, 1) * v.factor, 2), 0)), 0) WHEN t.cf_sign = 0 AND t.pl_sign = -1 THEN COALESCE(-r.charges04, 0) ELSE 0 END AS assets04
        , CASE WHEN t.cf_sign = -1 AND t.pl_sign = 0 THEN COALESCE((ROUND(r.charges05 * COALESCE(cr.period05, 1), 2) - COALESCE(ROUND(r.charges05 * COALESCE(cr.period05, 1) * v.factor, 2), 0)), 0) WHEN t.cf_sign = 0 AND t.pl_sign = -1 THEN COALESCE(-r.charges05, 0) ELSE 0 END AS assets05
        , CASE WHEN t.cf_sign = -1 AND t.pl_sign = 0 THEN COALESCE((ROUND(r.charges06 * COALESCE(cr.period06, 1), 2) - COALESCE(ROUND(r.charges06 * COALESCE(cr.period06, 1) * v.factor, 2), 0)), 0) WHEN t.cf_sign = 0 AND t.pl_sign = -1 THEN COALESCE(-r.charges06, 0) ELSE 0 END AS assets06
        , CASE WHEN t.cf_sign = -1 AND t.pl_sign = 0 THEN COALESCE((ROUND(r.charges07 * COALESCE(cr.period07, 1), 2) - COALESCE(ROUND(r.charges07 * COALESCE(cr.period07, 1) * v.factor, 2), 0)), 0) WHEN t.cf_sign = 0 AND t.pl_sign = -1 THEN COALESCE(-r.charges07, 0) ELSE 0 END AS assets07
        , CASE WHEN t.cf_sign = -1 AND t.pl_sign = 0 THEN COALESCE((ROUND(r.charges08 * COALESCE(cr.period08, 1), 2) - COALESCE(ROUND(r.charges08 * COALESCE(cr.period08, 1) * v.factor, 2), 0)), 0) WHEN t.cf_sign = 0 AND t.pl_sign = -1 THEN COALESCE(-r.charges08, 0) ELSE 0 END AS assets08
        , CASE WHEN t.cf_sign = -1 AND t.pl_sign = 0 THEN COALESCE((ROUND(r.charges09 * COALESCE(cr.period09, 1), 2) - COALESCE(ROUND(r.charges09 * COALESCE(cr.period09, 1) * v.factor, 2), 0)), 0) WHEN t.cf_sign = 0 AND t.pl_sign = -1 THEN COALESCE(-r.charges09, 0) ELSE 0 END AS assets09
        , CASE WHEN t.cf_sign = -1 AND t.pl_sign = 0 THEN COALESCE((ROUND(r.charges10 * COALESCE(cr.period10, 1), 2) - COALESCE(ROUND(r.charges10 * COALESCE(cr.period10, 1) * v.factor, 2), 0)), 0) WHEN t.cf_sign = 0 AND t.pl_sign = -1 THEN COALESCE(-r.charges10, 0) ELSE 0 END AS assets10
        , CASE WHEN t.cf_sign = -1 AND t.pl_sign = 0 THEN COALESCE((ROUND(r.charges11 * COALESCE(cr.period11, 1), 2) - COALESCE(ROUND(r.charges11 * COALESCE(cr.period11, 1) * v.factor, 2), 0)), 0) WHEN t.cf_sign = 0 AND t.pl_sign = -1 THEN COALESCE(-r.charges11, 0) ELSE 0 END AS assets11
        , CASE WHEN t.cf_sign = -1 AND t.pl_sign = 0 THEN COALESCE((ROUND(r.charges12 * COALESCE(cr.period12, 1), 2) - COALESCE(ROUND(r.charges12 * COALESCE(cr.period12, 1) * v.factor, 2), 0)), 0) WHEN t.cf_sign = 0 AND t.pl_sign = -1 THEN COALESCE(-r.charges12, 0) ELSE 0 END AS assets12

        ,  COALESCE(ROUND(r.balance00 * COALESCE(cr.balance00 * t.cf_sign, 1), 2), 0) AS bs00
        , (COALESCE(ROUND(r.charges01 * COALESCE(cr.period01, 1), 2), 0) - COALESCE(ROUND(r.payments01 * COALESCE(cr.period01, 1), 2), 0)) * t.cf_sign AS bs01
        , (COALESCE(ROUND(r.charges02 * COALESCE(cr.period02, 1), 2), 0) - COALESCE(ROUND(r.payments02 * COALESCE(cr.period02, 1), 2), 0)) * t.cf_sign AS bs02
        , (COALESCE(ROUND(r.charges03 * COALESCE(cr.period03, 1), 2), 0) - COALESCE(ROUND(r.payments03 * COALESCE(cr.period03, 1), 2), 0)) * t.cf_sign AS bs03
        , (COALESCE(ROUND(r.charges04 * COALESCE(cr.period04, 1), 2), 0) - COALESCE(ROUND(r.payments04 * COALESCE(cr.period04, 1), 2), 0)) * t.cf_sign AS bs04
        , (COALESCE(ROUND(r.charges05 * COALESCE(cr.period05, 1), 2), 0) - COALESCE(ROUND(r.payments05 * COALESCE(cr.period05, 1), 2), 0)) * t.cf_sign AS bs05
        , (COALESCE(ROUND(r.charges06 * COALESCE(cr.period06, 1), 2), 0) - COALESCE(ROUND(r.payments06 * COALESCE(cr.period06, 1), 2), 0)) * t.cf_sign AS bs06
        , (COALESCE(ROUND(r.charges07 * COALESCE(cr.period07, 1), 2), 0) - COALESCE(ROUND(r.payments07 * COALESCE(cr.period07, 1), 2), 0)) * t.cf_sign AS bs07
        , (COALESCE(ROUND(r.charges08 * COALESCE(cr.period08, 1), 2), 0) - COALESCE(ROUND(r.payments08 * COALESCE(cr.period08, 1), 2), 0)) * t.cf_sign AS bs08
        , (COALESCE(ROUND(r.charges09 * COALESCE(cr.period09, 1), 2), 0) - COALESCE(ROUND(r.payments09 * COALESCE(cr.period09, 1), 2), 0)) * t.cf_sign AS bs09
        , (COALESCE(ROUND(r.charges10 * COALESCE(cr.period10, 1), 2), 0) - COALESCE(ROUND(r.payments10 * COALESCE(cr.period10, 1), 2), 0)) * t.cf_sign AS bs10
        , (COALESCE(ROUND(r.charges11 * COALESCE(cr.period11, 1), 2), 0) - COALESCE(ROUND(r.payments11 * COALESCE(cr.period11, 1), 2), 0)) * t.cf_sign AS bs11
        , (COALESCE(ROUND(r.charges12 * COALESCE(cr.period12, 1), 2), 0) - COALESCE(ROUND(r.payments12 * COALESCE(cr.period12, 1), 2), 0)) * t.cf_sign AS bs12

        , COALESCE(r.balance00 * t.cf_sign, 0) AS cs00
        , (COALESCE(r.charges01, 0) - COALESCE(r.payments01, 0)) * t.cf_sign AS cs01
        , (COALESCE(r.charges02, 0) - COALESCE(r.payments02, 0)) * t.cf_sign AS cs02
        , (COALESCE(r.charges03, 0) - COALESCE(r.payments03, 0)) * t.cf_sign AS cs03
        , (COALESCE(r.charges04, 0) - COALESCE(r.payments04, 0)) * t.cf_sign AS cs04
        , (COALESCE(r.charges05, 0) - COALESCE(r.payments05, 0)) * t.cf_sign AS cs05
        , (COALESCE(r.charges06, 0) - COALESCE(r.payments06, 0)) * t.cf_sign AS cs06
        , (COALESCE(r.charges07, 0) - COALESCE(r.payments07, 0)) * t.cf_sign AS cs07
        , (COALESCE(r.charges08, 0) - COALESCE(r.payments08, 0)) * t.cf_sign AS cs08
        , (COALESCE(r.charges09, 0) - COALESCE(r.payments09, 0)) * t.cf_sign AS cs09
        , (COALESCE(r.charges10, 0) - COALESCE(r.payments10, 0)) * t.cf_sign AS cs10
        , (COALESCE(r.charges11, 0) - COALESCE(r.payments11, 0)) * t.cf_sign AS cs11
        , (COALESCE(r.charges12, 0) - COALESCE(r.payments12, 0)) * t.cf_sign AS cs12
    FROM
        dbo27.budget_requests r
        LEFT OUTER JOIN dbo27.vat_rates v ON v.id = r.vat_rate_id
        INNER JOIN dbo27.members a ON a.id = r.account_id
        LEFT OUTER JOIN dbo27.member_types t ON t.id = a.account_type_id
        LEFT OUTER JOIN dbo27.budget_currency_rates cr ON cr.unit_id = r.unit_id AND cr.time_id = r.time_id AND cr.category_id = r.category_id
    WHERE
        r.category_id = @category_id
        AND r.time_id = @time_id
        AND a.company_id = @company_id
        AND COALESCE(r.entity_id, 0) = COALESCE(@entity_id, r.entity_id, 0)
        AND COALESCE(r.subsidiary_account_id, 0) = COALESCE(@subsidiary_account_id, r.subsidiary_account_id, 0)
        AND COALESCE(r.region_id, 0) = COALESCE(@region_id, r.region_id, 0)
        AND COALESCE(r.product_id, 0) = COALESCE(@product_id, r.product_id, 0)
)

SELECT
    a.code
    , COALESCE(tr.name, a.name) AS name
    , COALESCE(t1.TRANSLATED_NAME, t.name) AS type
    , payments
    , charges
    , cf
    , pl
    , assets
    , vat
    , bs
    , pd.code AS payment_debit
    , pc.code AS payment_credit
    , cd.code AS charge_debit
    , cc.code AS charge_credit
    , vd.code AS vat_debit
    , vc.code AS vat_credit

    , t.payment_debit_type_id AS payment_debit_type_id
    , t.payment_credit_type_id AS payment_credit_type_id
    , t.charge_debit_type_id AS charge_debit_type_id
    , t.charge_credit_type_id AS charge_credit_type_id
    , t.vat_debit_type_id AS vat_debit_type_id
    , t.vat_credit_type_id AS vat_credit_type_id
FROM
    (
        SELECT
            t.account_id

            , SUM(payments01 * m01)
            + SUM(payments02 * m02)
            + SUM(payments03 * m03)
            + SUM(payments04 * m04)
            + SUM(payments05 * m05)
            + SUM(payments06 * m06)
            + SUM(payments07 * m07)
            + SUM(payments08 * m08)
            + SUM(payments09 * m09)
            + SUM(payments10 * m10)
            + SUM(payments11 * m11)
            + SUM(payments12 * m12) AS payments

            , SUM(charges01 * m01)
            + SUM(charges02 * m02)
            + SUM(charges03 * m03)
            + SUM(charges04 * m04)
            + SUM(charges05 * m05)
            + SUM(charges06 * m06)
            + SUM(charges07 * m07)
            + SUM(charges08 * m08)
            + SUM(charges09 * m09)
            + SUM(charges10 * m10)
            + SUM(charges11 * m11)
            + SUM(charges12 * m12) AS charges

            , SUM(cf01 * m01)
            + SUM(cf02 * m02)
            + SUM(cf03 * m03)
            + SUM(cf04 * m04)
            + SUM(cf05 * m05)
            + SUM(cf06 * m06)
            + SUM(cf07 * m07)
            + SUM(cf08 * m08)
            + SUM(cf09 * m09)
            + SUM(cf10 * m10)
            + SUM(cf11 * m11)
            + SUM(cf12 * m12) AS cf

            , SUM(pl01 * m01)
            + SUM(pl02 * m02)
            + SUM(pl03 * m03)
            + SUM(pl04 * m04)
            + SUM(pl05 * m05)
            + SUM(pl06 * m06)
            + SUM(pl07 * m07)
            + SUM(pl08 * m08)
            + SUM(pl09 * m09)
            + SUM(pl10 * m10)
            + SUM(pl11 * m11)
            + SUM(pl12 * m12) AS pl

            , SUM(assets01 * m01)
            + SUM(assets02 * m02)
            + SUM(assets03 * m03)
            + SUM(assets04 * m04)
            + SUM(assets05 * m05)
            + SUM(assets06 * m06)
            + SUM(assets07 * m07)
            + SUM(assets08 * m08)
            + SUM(assets09 * m09)
            + SUM(assets10 * m10)
            + SUM(assets11 * m11)
            + SUM(assets12 * m12) AS assets

            , SUM(vat01 * m01)
            + SUM(vat02 * m02)
            + SUM(vat03 * m03)
            + SUM(vat04 * m04)
            + SUM(vat05 * m05)
            + SUM(vat06 * m06)
            + SUM(vat07 * m07)
            + SUM(vat08 * m08)
            + SUM(vat09 * m09)
            + SUM(vat10 * m10)
            + SUM(vat11 * m11)
            + SUM(vat12 * m12) AS vat

            , SUM(bs01 * m01)
            + SUM(bs02 * m02)
            + SUM(bs03 * m03)
            + SUM(bs04 * m04)
            + SUM(bs05 * m05)
            + SUM(bs06 * m06)
            + SUM(bs07 * m07)
            + SUM(bs08 * m08)
            + SUM(bs09 * m09)
            + SUM(bs10 * m10)
            + SUM(bs11 * m11)
            + SUM(bs12 * m12) AS bs
        FROM
            raw_data t
            CROSS JOIN (VALUES
                ( CASE WHEN @first_month < 2 AND @last_month > 0 THEN @factor ELSE 0 END
                , CASE WHEN @first_month < 3 AND @last_month > 1 THEN @factor ELSE 0 END
                , CASE WHEN @first_month < 4 AND @last_month > 2 THEN @factor ELSE 0 END
                , CASE WHEN @first_month < 5 AND @last_month > 3 THEN @factor ELSE 0 END
                , CASE WHEN @first_month < 6 AND @last_month > 4 THEN @factor ELSE 0 END
                , CASE WHEN @first_month < 7 AND @last_month > 5 THEN @factor ELSE 0 END
                , CASE WHEN @first_month < 8 AND @last_month > 6 THEN @factor ELSE 0 END
                , CASE WHEN @first_month < 9 AND @last_month > 7 THEN @factor ELSE 0 END
                , CASE WHEN @first_month < 10 AND @last_month > 8 THEN @factor ELSE 0 END
                , CASE WHEN @first_month < 11 AND @last_month > 9 THEN @factor ELSE 0 END
                , CASE WHEN @first_month < 12 AND @last_month > 10 THEN @factor ELSE 0 END
                , CASE WHEN @first_month < 13 AND @last_month > 11 THEN @factor ELSE 0 END
                )) p(m01, m02, m03, m04, m05, m06, m07, m08, m09, m10, m11, m12)
        GROUP BY
            t.account_id
    ) d
    INNER JOIN dbo27.members a ON a.id = d.account_id
    LEFT OUTER JOIN dbo27.member_types t ON t.id = a.account_type_id
    LEFT OUTER JOIN dbo27.ledger_accounts pd ON pd.id = a.payment_debit_id
    LEFT OUTER JOIN dbo27.ledger_accounts pc ON pc.id = a.payment_credit_id
    LEFT OUTER JOIN dbo27.ledger_accounts cd ON cd.id = a.charge_debit_id
    LEFT OUTER JOIN dbo27.ledger_accounts cc ON cc.id = a.charge_credit_id
    LEFT OUTER JOIN dbo27.ledger_accounts vd ON vd.id = a.vat_debit_id
    LEFT OUTER JOIN dbo27.ledger_accounts vc ON vc.id = a.vat_credit_id
    LEFT OUTER JOIN dbo27.translations tr ON tr.company_id = @company_id AND tr.table_id = 1 AND tr.member_id = a.id AND tr.language = @data_language
    LEFT OUTER JOIN xls.translations t1 ON t1.TABLE_SCHEMA = 'dbo27' AND t1.TABLE_NAME = 'member_types_name' AND t1.COLUMN_NAME = t.name AND t1.LANGUAGE_NAME = @data_language
ORDER BY
    a.code

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Selects members
-- =============================================

CREATE PROCEDURE [xls27].[usp_budgeting_accounts]
    @company_id int = NULL
    , @account_type_id tinyint = NULL
    , @is_in_budget bit = NULL
    , @is_active bit = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

-- Special accounts (Cash, Net Income, Retained Earnings)

DECLARE @cash_account_id int
DECLARE @vat_account_id int

DECLARE @cash_account_code nvarchar(50)

SELECT TOP 1 @cash_account_id = id FROM dbo27.ledger_accounts WHERE account_type_id = 11
SELECT TOP 1 @vat_account_id = id FROM dbo27.ledger_accounts WHERE account_type_id = 27

SELECT TOP 1 @cash_account_code = code FROM dbo27.ledger_accounts WHERE account_type_id = 11

SELECT
    m.id
    , m.code
    , m.name
    , tr.name AS translated_name
    , CASE WHEN p.parent_id IS NULL THEN 0 ELSE 1 END AS is_parent
    , COALESCE(u.is_currency, 1) AS is_currency
    , m.parent_id
    , m.unit_id
    , m.vat_rate_id
    , m.account_type_id
    , COALESCE(m.payment_debit_id, CASE WHEN t.cf_sign = 1 THEN @cash_account_id ELSE NULL END) AS payment_debit_id
    , COALESCE(m.payment_credit_id, CASE WHEN t.cf_sign = -1 THEN @cash_account_id ELSE NULL END) AS payment_credit_id
    , m.charge_debit_id
    , m.charge_credit_id
    , COALESCE(vat_debit_id, CASE WHEN t.vat_sign = -1 THEN @vat_account_id ELSE NULL END) AS vat_debit_id
    , COALESCE(vat_credit_id, CASE WHEN t.vat_sign = 1 THEN @vat_account_id WHEN t.vat_sign = -1 THEN m.charge_credit_id ELSE NULL END) AS vat_credit_id
    , t.payment_debit_type_id
    , t.payment_credit_type_id
    , t.charge_debit_type_id
    , t.charge_credit_type_id
    , t.vat_debit_type_id
    , t.vat_credit_type_id
    , CASE WHEN p.parent_id IS NULL AND m.is_active = 1 THEN 1 ELSE 0 END AS is_in_budget_request
    , m.is_active
FROM
    dbo27.members m
    LEFT OUTER JOIN (
        SELECT
            DISTINCT
            p.parent_id
        FROM
            dbo27.members p
    ) p ON p.parent_id = m.id
    LEFT OUTER JOIN dbo27.member_types t ON t.id = m.account_type_id
    LEFT OUTER JOIN dbo27.units u ON u.id = m.unit_id
    LEFT OUTER JOIN dbo27.translations tr ON tr.company_id = m.company_id AND tr.table_id = 1 AND tr.member_id = m.id AND tr.language = @data_language
WHERE
    m.dimension_id = 1
    AND m.company_id = @company_id
    AND m.is_active = COALESCE(@is_active, m.is_active)
    AND (CASE WHEN p.parent_id IS NULL AND m.is_active = 1 THEN 1 ELSE 0 END = @is_in_budget OR @is_in_budget IS NULL)
    AND COALESCE(m.account_type_id, 0) = COALESCE(@account_type_id, m.account_type_id, 0)
ORDER BY
    m.dimension_id
    , m.sort_order
    , m.code
    , m.name
    , m.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Insert procedure for usp_budgeting_accounts
-- =============================================

CREATE PROCEDURE [xls27].[usp_budgeting_accounts_insert]
    @company_id int = NULL
    , @code nvarchar(50) = NULL
    , @name nvarchar(100) = NULL
    , @translated_name nvarchar(100) = NULL
    , @parent_id int = NULL
    , @unit_id int = NULL
    , @vat_rate_id int = NULL
    , @account_type_id int = NULL
    , @payment_debit_id int = NULL
    , @payment_credit_id int = NULL
    , @charge_debit_id int = NULL
    , @charge_credit_id int = NULL
    , @vat_debit_id int = NULL
    , @vat_credit_id int = NULL
    , @is_active bit = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

IF @company_id IS NULL
    RETURN

SET NOCOUNT OFF

INSERT INTO dbo27.members
    ( company_id
    , dimension_id
    , sort_order
    , code
    , name
    , parent_id
    , unit_id
    , vat_rate_id
    , account_type_id
    , payment_debit_id
    , payment_credit_id
    , charge_debit_id
    , charge_credit_id
    , vat_debit_id
    , vat_credit_id
    , is_active
    )
VALUES
    ( @company_id
    , 1
    , NULL
    , @code
    , @name
    , @parent_id
    , @unit_id
    , @vat_rate_id
    , @account_type_id
    , @payment_debit_id
    , @payment_credit_id
    , @charge_debit_id
    , @charge_credit_id
    , @vat_debit_id
    , @vat_credit_id
    , @is_active
    )

DECLARE @id int = SCOPE_IDENTITY()

IF @data_language IS NOT NULL AND @translated_name IS NOT NULL
    INSERT INTO dbo27.translations
        (company_id, table_id, member_id, language, name)
    VALUES
        (@company_id, 1, @id, @data_language, @translated_name)

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Update procedure for usp_budgeting_accounts
-- =============================================

CREATE PROCEDURE [xls27].[usp_budgeting_accounts_update]
      @id int = NULL
    , @code nvarchar(50) = NULL
    , @name nvarchar(100) = NULL
    , @translated_name nvarchar(100) = NULL
    , @parent_id int = NULL
    , @unit_id int = NULL
    , @vat_rate_id int = NULL
    , @account_type_id int = NULL
    , @payment_debit_id int = NULL
    , @payment_credit_id int = NULL
    , @charge_debit_id int = NULL
    , @charge_credit_id int = NULL
    , @vat_debit_id int = NULL
    , @vat_credit_id int = NULL
    , @is_active bit = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

DECLARE @company_id int
DECLARE @current_name nvarchar(100)

SELECT TOP 1 @company_id = u.company_id, @current_name = t.name FROM dbo27.members t INNER JOIN dbo27.users u ON u.company_id = t.company_id  WHERE t.id = @id AND u.username = USER_NAME() AND u.is_active = 1

IF @company_id IS NULL
    RETURN

SET @code = LTRIM(RTRIM(@code))
SET @name = LTRIM(RTRIM(@name))

DECLARE @message nvarchar(max)

IF CHARINDEX(@code, ' ') > 0 OR CHARINDEX(@code, '''') > 0 OR CHARINDEX(@code, '"') > 0 OR CHARINDEX(@code, '[') > 0 OR CHARINDEX(@code, ']') > 0
    BEGIN
    SET @message = dbo27.get_translated_string('The code ''%s'' contains prohibited symbols (space, '', ", [ or ])', @data_language)
    RAISERROR (@message, 11, 0, @code)
    RETURN
    END

SET NOCOUNT OFF

UPDATE dbo27.members
SET
    code = @code
    , name = @name
    , parent_id = @parent_id
    , unit_id = @unit_id
    , vat_rate_id = @vat_rate_id
    , account_type_id = @account_type_id
    , payment_debit_id = @payment_debit_id
    , payment_credit_id = @payment_credit_id
    , charge_debit_id = @charge_debit_id
    , charge_credit_id = @charge_credit_id
    , vat_debit_id = @vat_debit_id
    , vat_credit_id = @vat_credit_id
WHERE
    id = @id
    AND NOT (
        COALESCE(code, '-1') = COALESCE(@code, '-2')
        AND COALESCE(name, '-1') = COALESCE(@name, '-2')
        AND COALESCE(parent_id, -1) = COALESCE(@parent_id, -2)
        AND COALESCE(unit_id, -1) = COALESCE(@unit_id, -2)
        AND COALESCE(vat_rate_id, -1) = COALESCE(@vat_rate_id, -2)
        AND COALESCE(account_type_id, -1) = COALESCE(@account_type_id, -2)
        AND COALESCE(payment_debit_id, -1) = COALESCE(@payment_debit_id, -2)
        AND COALESCE(payment_credit_id, -1) = COALESCE(@payment_credit_id, -2)
        AND COALESCE(charge_debit_id, -1) = COALESCE(@charge_debit_id, -2)
        AND COALESCE(charge_credit_id, -1) = COALESCE(@charge_credit_id, -2)
        AND COALESCE(vat_debit_id, -1) = COALESCE(@vat_debit_id, -2)
        AND COALESCE(vat_credit_id, -1) = COALESCE(@vat_credit_id, -2)
        )

IF @data_language IS NOT NULL AND @translated_name IS NOT NULL
    BEGIN
    MERGE dbo27.translations t
    USING
        (
        SELECT company_id = @company_id, 1 AS table_id, @id AS member_id, @data_language AS language, @translated_name AS name
        ) s ON s.company_id = t.company_id AND s.table_id = t.table_id AND s.member_id = t.member_id AND s.language = t.language
    WHEN MATCHED AND NOT COALESCE(t.name, '') = COALESCE(s.name, '') THEN
        UPDATE SET name = s.name
    WHEN NOT MATCHED THEN
        INSERT (company_id, table_id, member_id, language, name) VALUES (s.company_id, s.table_id, s.member_id, s.language, s.name);
    END

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Selects companies
-- =============================================

CREATE PROCEDURE [xls27].[usp_companies]
    @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

SELECT
    c.id
    , c.code
    , c.name
    , tr.name AS translated_name
    , c.default_language
    , c.sort_order
FROM
    dbo27.companies c
    INNER JOIN dbo27.users u ON u.company_id = c.id AND u.username = USER_NAME() AND u.is_active = 1
    LEFT OUTER JOIN dbo27.translations tr ON tr.company_id = c.id AND tr.table_id = 2 AND tr.member_id = c.id AND tr.language = @data_language
ORDER BY
    c.sort_order
    , c.code

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Delete procedure for usp_companies
-- =============================================

CREATE PROCEDURE [xls27].[usp_companies_delete]
    @id int
AS
BEGIN

SET NOCOUNT ON

IF NOT EXISTS (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @id AND username = USER_NAME() AND is_active = 1 AND is_admin = 1)
    RETURN

SET NOCOUNT OFF

DELETE dbo27.companies WHERE id = @id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Insert procedure for usp_companies
-- =============================================

CREATE PROCEDURE [xls27].[usp_companies_insert]
    @code nvarchar(50)
    , @name nvarchar(100)
    , @translated_name nvarchar(100) = NULL
    , @default_language varchar(10) = NULL
    , @sort_order int = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

IF NOT EXISTS (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_admin = 1)
    RETURN

SET @code = LTRIM(RTRIM(@code))
SET @name = LTRIM(RTRIM(@name))

DECLARE @message nvarchar(max)

IF CHARINDEX(@code, ' ') > 0 OR CHARINDEX(@code, '''') > 0 OR CHARINDEX(@code, '"') > 0 OR CHARINDEX(@code, '[') > 0 OR CHARINDEX(@code, ']') > 0
    BEGIN
    SET @message = dbo27.get_translated_string('The code ''%s'' contains prohibited symbols (space, '', ", [ or ])', @data_language)
    RAISERROR (@message, 11, 0, @code)
    RETURN
    END

SET NOCOUNT OFF

INSERT INTO dbo27.companies (code, name, default_language, sort_order) VALUES (@code, @name, COALESCE(@default_language, 'en'), @sort_order)

DECLARE @company_id int = SCOPE_IDENTITY()

INSERT INTO dbo27.users (company_id, username, name, is_admin, is_active) VALUES (@company_id, USER_NAME(), USER_NAME(), 1, 1)

IF @data_language IS NOT NULL AND @translated_name IS NOT NULL
    INSERT INTO dbo27.translations
        (company_id, table_id, member_id, language, name)
    VALUES
        (@company_id, 2, @company_id, @data_language, @translated_name)

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Update procedure for usp_accounts
-- =============================================

CREATE PROCEDURE [xls27].[usp_companies_update]
      @id int
    , @code nvarchar(50)
    , @name nvarchar(100)
    , @translated_name nvarchar(100) = NULL
    , @default_language varchar(10) = NULL
    , @sort_order int = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

DECLARE @company_id int
DECLARE @current_name nvarchar(100)

SELECT TOP 1 @company_id = u.company_id, @current_name = t.name FROM dbo27.companies t INNER JOIN dbo27.users u ON u.company_id = t.id  WHERE t.id = @id AND u.username = USER_NAME() AND u.is_active = 1

IF @company_id IS NULL
    RETURN

SET @code = LTRIM(RTRIM(@code))
SET @name = LTRIM(RTRIM(@name))

DECLARE @message nvarchar(max)

IF CHARINDEX(@code, ' ') > 0 OR CHARINDEX(@code, '''') > 0 OR CHARINDEX(@code, '"') > 0 OR CHARINDEX(@code, '[') > 0 OR CHARINDEX(@code, ']') > 0
    BEGIN
    SET @message = dbo27.get_translated_string('The code ''%s'' contains prohibited symbols (space, '', ", [ or ])', @data_language)
    RAISERROR (@message, 11, 0, @code)
    RETURN
    END

SET NOCOUNT OFF

UPDATE dbo27.companies
SET
    code = @code
    , name = @name
    , default_language = COALESCE(@default_language, 'en')
    , sort_order = @sort_order
FROM
    dbo27.companies
WHERE
    id = @id
    AND NOT (
        COALESCE(code, '-1') = COALESCE(@code, '-2')
        AND COALESCE(name, '-1') = COALESCE(@name, '-2')
        AND COALESCE(default_language, '-1') = COALESCE(@default_language, '-2')
        AND COALESCE(sort_order, -1) = COALESCE(@sort_order, -2)
        )

IF @data_language IS NOT NULL AND @translated_name IS NOT NULL
    BEGIN
    MERGE dbo27.translations t
    USING
        (
        SELECT company_id = @company_id, 2 AS table_id, @id AS member_id, @data_language AS language, @translated_name AS name
        ) s ON s.company_id = t.company_id AND s.table_id = t.table_id AND s.member_id = t.member_id AND s.language = t.language
    WHEN MATCHED AND NOT COALESCE(t.name, '') = COALESCE(s.name, '') THEN
        UPDATE SET name = s.name
    WHEN NOT MATCHED THEN
        INSERT (company_id, table_id, member_id, language, name) VALUES (s.company_id, s.table_id, s.member_id, s.language, s.name);
    END

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Selects dimensions
-- =============================================

CREATE PROCEDURE [xls27].[usp_dimensions]
AS
BEGIN

SET NOCOUNT ON

SELECT
    t.id
    , t.code
    , t.name
FROM
    dbo27.dimensions t
ORDER BY
    t.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Selects entry_sides
-- =============================================

CREATE PROCEDURE [xls27].[usp_entry_sides]
AS
BEGIN

SET NOCOUNT ON

SELECT
    t.id
    , t.code
    , t.name
FROM
    dbo27.entry_sides t
ORDER BY
    t.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Journal
-- =============================================

CREATE PROCEDURE [xls27].[usp_journal]
    @start_year int = NULL
    , @start_month int = NULL
    , @start_day int = NULL
    , @end_year int = NULL
    , @end_month int = NULL
    , @end_day int = NULL
    , @company_id int = NULL
    , @account_id int = NULL
    , @subsidiary_account_id int = NULL
    , @entity_id int = NULL
    , @region_id int = NULL
    , @product_id int = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

DECLARE @start_date date
DECLARE @end_date date

SET @start_date = DATEFROMPARTS(COALESCE(@start_year, YEAR(GETDATE())), COALESCE(@start_month, 1), 1)
SET @end_date = DATEFROMPARTS(COALESCE(@end_year, YEAR(GETDATE())), COALESCE(@end_month, 12), 1)

IF @start_day > 1
    IF DATEADD(DAY, @start_day - 1, @start_date) < DATEADD(MONTH, 1, @start_date)
        SET @start_date = DATEADD(DAY, @start_day - 1, @start_date)
    ELSE
        SET @start_date = DATEADD(DAY, -1, DATEADD(MONTH, 1, @start_date))

IF @end_day > 1 AND DATEADD(DAY, @end_day - 1, @end_date) < DATEADD(MONTH, 1, @end_date)
    SET @end_date = DATEADD(DAY, @end_day - 1, @end_date)
ELSE
    SET @end_date = DATEADD(DAY, -1, DATEADD(MONTH, 1, @end_date))

DECLARE @system_currency nvarchar(50) = (SELECT name FROM dbo27.units WHERE company_id = @company_id AND is_functional_currency = 1)

;WITH parents (id, parent_id) AS (
    SELECT
        a.id
        , a.id
    FROM
        dbo27.ledger_accounts a
    WHERE
        a.company_id = @company_id

    UNION ALL
    SELECT
        p.id
        , a.parent_id
    FROM
        parents p
        INNER JOIN dbo27.ledger_accounts a ON a.id = p.parent_id
    WHERE
        a.parent_id IS NOT NULL
        AND NOT p.id = a.parent_id
)
, filtered_accounts AS (
    SELECT
        p.id
    FROM
        parents p
    WHERE
        p.parent_id = @account_id
)

SELECT
    j.id
    , CAST(j.date AS datetime) AS date
    , j.debit_account_id
    , j.credit_account_id
    , j.amount
    , j.debit_subsidiary_account_id
    , j.credit_subsidiary_account_id
    , j.description
    , COALESCE(dc.name, cc.name) AS currency
    , r.rate
    , j.amount$
    , j.entity_id
    , j.account_id
    , j.region_id
    , j.product_id
    , j.is_draft
    , j.auto_type_id
    , COALESCE(u.name, j.modified_by) AS modified_by
    , j.modified_on
FROM
    dbo27.journals j
    LEFT OUTER JOIN dbo27.members ds ON ds.id = j.debit_subsidiary_account_id
    LEFT OUTER JOIN dbo27.members cs ON cs.id = j.credit_subsidiary_account_id
    LEFT OUTER JOIN dbo27.units dc ON dc.id = ds.id AND dc.is_functional_currency = 0
    LEFT OUTER JOIN dbo27.units cc ON cc.id = cs.id AND cc.is_functional_currency = 0
    LEFT OUTER JOIN dbo27.actual_currency_rates r ON r.currency_id = COALESCE(dc.id, cc.id) AND r.date = j.date
    LEFT OUTER JOIN dbo27.users u ON u.company_id = j.company_id AND u.username = j.modified_by
WHERE
    j.[date] BETWEEN @start_date AND @end_date
    AND j.company_id = @company_id
    AND (COALESCE(j.debit_subsidiary_account_id, 0) = COALESCE(@subsidiary_account_id, j.debit_subsidiary_account_id, 0)
        OR COALESCE(j.credit_subsidiary_account_id, 0) = COALESCE(@subsidiary_account_id, j.credit_subsidiary_account_id, 0)
        )
    AND (@account_id IS NULL
        OR j.debit_account_id IN (SELECT id FROM filtered_accounts)
        OR j.credit_account_id IN (SELECT id FROM filtered_accounts)
        )
    AND COALESCE(j.entity_id, 0) = COALESCE(@entity_id, j.entity_id, 0)
    AND COALESCE(j.region_id, 0) = COALESCE(@region_id, j.region_id, 0)
    AND COALESCE(j.product_id, 0) = COALESCE(@product_id, j.product_id, 0)

ORDER BY
    j.date
    , j.auto_type_id
    , j.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: The procedure deleted data from dbo27.journals
-- =============================================

CREATE PROCEDURE [xls27].[usp_journal_delete]
    @id int
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

DECLARE @company_id int = NULL

SET @company_id = (SELECT TOP 1 j.company_id FROM dbo27.journals j INNER JOIN dbo27.users u ON u.company_id = j.company_id WHERE j.id = @id AND username = USER_NAME() AND is_active = 1)

IF @company_id IS NULL
    RETURN

DECLARE @message nvarchar(max)

IF (SELECT p.is_closed FROM dbo27.journals j INNER JOIN dbo27.actual_closed_periods p ON p.date = DATEADD(D, 1 - DATEPART(d, j.date), j.date) AND p.company_id = j.company_id WHERE j.id = @id) = 1
    BEGIN
    SET @message = dbo27.get_translated_string('The period is closed for changes', @data_language)
    RAISERROR (@message, 11, 0)
    RETURN
    END

SET NOCOUNT OFF

DELETE FROM dbo27.journals WHERE id = @id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: The procedure updates data of dbo27.journals
-- =============================================

CREATE PROCEDURE [xls27].[usp_journal_update]
    @id int
    , @company_id int = NULL
    , @date date = NULL
    , @amount money = NULL
    , @description nvarchar(255) = NULL
    , @debit_account_id int = NULL
    , @debit_subsidiary_account_id int = NULL
    , @credit_account_id int = NULL
    , @credit_subsidiary_account_id int = NULL
    , @entity_id int = NULL
    , @account_id int = NULL
    , @region_id int = NULL
    , @product_id int = NULL
    , @is_draft bit = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    BEGIN

    IF @debit_account_id IS NOT NULL
        SET @company_id = (SELECT TOP 1 company_id FROM dbo27.ledger_accounts WHERE id = @debit_account_id)
    ELSE IF @credit_account_id IS NOT NULL
        SET @company_id = (SELECT TOP 1 company_id FROM dbo27.ledger_accounts WHERE id = @credit_account_id)
    ELSE IF @debit_subsidiary_account_id IS NOT NULL
        SET @company_id = (SELECT TOP 1 company_id FROM dbo27.members WHERE id = @debit_subsidiary_account_id)
    ELSE IF @credit_subsidiary_account_id IS NOT NULL
        SET @company_id = (SELECT TOP 1 company_id FROM dbo27.members WHERE id = @credit_subsidiary_account_id)
    ELSE IF @id IS NOT NULL
        SET @company_id = (SELECT TOP 1 j.company_id FROM dbo27.journals j INNER JOIN dbo27.users u ON u.company_id = j.company_id WHERE j.id = @id AND username = USER_NAME() AND is_active = 1)
    ELSE
        SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)

    IF @company_id IS NULL
        RETURN
    END

IF @debit_account_id IS NOT NULL AND
    NOT EXISTS (SELECT id FROM dbo27.ledger_accounts WHERE id = @debit_account_id AND company_id = @company_id)
    RETURN

IF @credit_account_id IS NOT NULL AND
    NOT EXISTS (SELECT id FROM dbo27.ledger_accounts WHERE id = @credit_account_id AND company_id = @company_id)
    RETURN

IF @debit_subsidiary_account_id IS NOT NULL AND
    NOT EXISTS (SELECT id FROM dbo27.members WHERE id = @debit_subsidiary_account_id AND company_id = @company_id)
    RETURN

IF @credit_subsidiary_account_id IS NOT NULL AND
    NOT EXISTS (SELECT id FROM dbo27.members WHERE id = @credit_subsidiary_account_id AND company_id = @company_id)
    RETURN

IF @entity_id IS NOT NULL AND
    NOT EXISTS (SELECT id FROM dbo27.members WHERE id = @entity_id AND company_id = @company_id)
    RETURN

IF @account_id IS NOT NULL AND
    NOT EXISTS (SELECT id FROM dbo27.members WHERE id = @account_id AND company_id = @company_id)
    RETURN

IF @product_id IS NOT NULL AND
    NOT EXISTS (SELECT id FROM dbo27.members WHERE id = @product_id AND company_id = @company_id)
    RETURN

IF @region_id IS NOT NULL AND
    NOT EXISTS (SELECT id FROM dbo27.members WHERE id = @region_id AND company_id = @company_id)
    RETURN

DECLARE @message nvarchar(max)

IF (SELECT p.is_closed FROM dbo27.journals j INNER JOIN dbo27.actual_closed_periods p ON p.date = j.month AND p.company_id = @company_id WHERE j.id = @id) = 1
    OR (SELECT p.is_closed FROM dbo27.actual_closed_periods p WHERE p.date = DATEADD(D, 1 - DATEPART(d, @date), @date) AND p.company_id = @company_id) = 1
    BEGIN
    SET @message = dbo27.get_translated_string('The period is closed for changes', @data_language)
    RAISERROR (@message, 11, 0)
    RETURN
    END

DECLARE @currency_id int = COALESCE(
    (SELECT m.unit_id FROM dbo27.members m INNER JOIN dbo27.units u ON u.id = m.unit_id WHERE m.id = @debit_subsidiary_account_id AND u.is_currency = 1 AND u.is_functional_currency = 0),
    (SELECT m.unit_id FROM dbo27.members m INNER JOIN dbo27.units u ON u.id = m.unit_id WHERE m.id = @credit_subsidiary_account_id AND u.is_currency = 1 AND u.is_functional_currency = 0))

DECLARE @amount$ float = @amount

DECLARE @rate_date date
DECLARE @rate float

IF @currency_id IS NOT NULL
    BEGIN

    SELECT @rate_date = date, @rate = rate FROM dbo27.actual_currency_rates WHERE currency_id = @currency_id AND date = @date

    IF @rate_date IS NULL
        BEGIN

        SELECT @rate_date = date, @rate = rate FROM dbo27.actual_currency_rates WHERE currency_id = @currency_id
            AND date = (SELECT MAX(date) FROM dbo27.actual_currency_rates WHERE currency_id = @currency_id AND date <= @date)

        INSERT INTO dbo27.actual_currency_rates (currency_id, date, rate)
        VALUES (@currency_id, @date, COALESCE(@rate, 1.0))

        END

    SELECT
        @amount$ = ROUND(@amount * CASE WHEN is_base_currency = 0 OR @rate = 0 THEN COALESCE(@rate, 1.0) ELSE 1.0 / COALESCE(@rate, 1.0) END, 2)
    FROM
        dbo27.units
    WHERE
        id = @currency_id

    END

SET NOCOUNT OFF

IF @id IS NULL
    INSERT INTO dbo27.journals (company_id, date, amount, description, debit_account_id, debit_subsidiary_account_id, credit_account_id, credit_subsidiary_account_id, amount$, entity_id, account_id, product_id, region_id, is_draft, modified_on, modified_by)
    VALUES (@company_id, @date, @amount, @description, @debit_account_id, @debit_subsidiary_account_id, @credit_account_id, @credit_subsidiary_account_id, @amount$, @entity_id, @account_id, @product_id, @region_id, COALESCE(@is_draft, 0), GETDATE(), USER_NAME())
ELSE
    UPDATE dbo27.journals
    SET
        date = @date
        , amount = @amount
        , description = @description
        , debit_account_id = @debit_account_id
        , debit_subsidiary_account_id = @debit_subsidiary_account_id
        , credit_account_id = @credit_account_id
        , credit_subsidiary_account_id = @credit_subsidiary_account_id
        , amount$ = @amount$
        , entity_id = @entity_id
        , account_id = @account_id
        , product_id = @product_id
        , region_id = @region_id
        , is_draft = COALESCE(@is_draft, 0)
        , modified_on = GETDATE()
        , modified_by = USER_NAME()
    WHERE
        id = @id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: The procedure inserts data into dbo27.journals
-- =============================================

CREATE PROCEDURE [xls27].[usp_journal_insert]
    @company_id int = NULL
    , @date date = NULL
    , @amount money = NULL
    , @description nvarchar(255) = NULL
    , @debit_account_id int = NULL
    , @debit_subsidiary_account_id int = NULL
    , @credit_account_id int = NULL
    , @credit_subsidiary_account_id int = NULL
    , @entity_id int = NULL
    , @account_id int = NULL
    , @region_id int = NULL
    , @product_id int = NULL
    , @is_draft bit = NULL
AS
BEGIN

SET NOCOUNT ON

EXEC xls27.usp_journal_update NULL, @company_id, @date, @amount, @description, @debit_account_id, @debit_subsidiary_account_id, @credit_account_id, @credit_subsidiary_account_id, @entity_id, @account_id, @region_id, @product_id, @is_draft

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Selects ledger_account_special_types
-- =============================================

CREATE PROCEDURE [xls27].[usp_ledger_account_special_types]
AS
BEGIN

SET NOCOUNT ON

SELECT
    t.id
    , t.code
    , t.name
FROM
    dbo27.ledger_account_special_types t
ORDER BY
    t.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Selects ledger_account_types
-- =============================================

CREATE PROCEDURE [xls27].[usp_ledger_account_types]
AS
BEGIN

SET NOCOUNT ON

SELECT
    t.id
    , t.code
    , t.name
    , t.bs_section
    , t.bs_sign
    , t.pl_section
    , t.is_pl
    , t.is_da
    , t.cf_section
    , t.specific_type_id
    , d.[1] AS pl_dr, c.[1] AS pl_cr
    , d.[2] AS cf_dr, c.[2] AS cf_cr
    , d.[3] AS bs_dr, c.[3] AS bs_cr
    , d.[4] AS cfd_dr, c.[4] AS cfd_cr
    , d.[5] AS vat_dr, c.[5] AS vat_cr
FROM
    dbo27.ledger_account_types t
    LEFT OUTER JOIN (
        SELECT
            lat.id
            , rst.report_type_id
            , rsa.value_sign AS value
        FROM
            dbo27.report_section_accounts rsa
            INNER JOIN dbo27.ledger_account_types lat ON lat.id = rsa.account_type_id
            INNER JOIN dbo27.report_section_types rst ON rst.id = rsa.section_type_id
        WHERE
            rsa.entry_side_id = 1
    ) s PIVOT (
        SUM(value) FOR report_type_id IN ([1], [2], [3], [4], [5])
    ) d ON d.id = t.id
    LEFT OUTER JOIN (
        SELECT
            lat.id
            , rst.report_type_id
            , rsa.value_sign AS value
        FROM
            dbo27.report_section_accounts rsa
            INNER JOIN dbo27.ledger_account_types lat ON lat.id = rsa.account_type_id
            INNER JOIN dbo27.report_section_types rst ON rst.id = rsa.section_type_id
        WHERE
            rsa.entry_side_id = 2
    ) s PIVOT (
        SUM(value) FOR report_type_id IN ([1], [2], [3], [4], [5])
    ) c ON c.id = t.id
ORDER BY
    t.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Selects ledger accounts
-- =============================================

CREATE PROCEDURE [xls27].[usp_ledger_accounts]
    @company_id int = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

SELECT
    a.id
    , a.code
    , a.name
    , tr.name AS translated_name
    , a.parent_id
    , a.account_type_id
    , a.subsidiary_group_id
    , a.closing_child_account_id
    , a.closing_debit_account_id
    , a.closing_credit_account_id
    , a.ref_number
    , CASE WHEN p.parent_id IS NULL THEN 0 ELSE 1 END AS is_parent
FROM
    dbo27.ledger_accounts a
    LEFT OUTER JOIN (
        SELECT DISTINCT parent_id FROM dbo27.ledger_accounts
    ) p ON p.parent_id = a.id
    LEFT OUTER JOIN dbo27.translations tr ON tr.company_id = a.company_id AND tr.table_id = 11 AND tr.member_id = a.id AND tr.language = @data_language
WHERE
    a.company_id = @company_id
ORDER BY
    a.code

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Delete procedure for usp_ledger_accounts
-- =============================================

CREATE PROCEDURE [xls27].[usp_ledger_accounts_delete]
    @id int
AS
BEGIN

SET NOCOUNT ON

IF NOT EXISTS (SELECT TOP 1 u.company_id FROM dbo27.ledger_accounts t INNER JOIN dbo27.users u ON u.company_id = t.company_id WHERE t.id = @id AND u.username = USER_NAME() AND u.is_active = 1)
    RETURN

SET NOCOUNT OFF

DELETE dbo27.ledger_accounts WHERE id = @id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Insert procedure for usp_ledger_accounts
-- =============================================

CREATE PROCEDURE [xls27].[usp_ledger_accounts_insert]
    @company_id int
    , @code nvarchar(50)
    , @name nvarchar(100)
    , @translated_name nvarchar(100) = NULL
    , @parent_id int = NULL
    , @account_type_id tinyint = NULL
    , @subsidiary_group_id int = NULL
    , @closing_child_account_id int = NULL
    , @closing_debit_account_id int = NULL
    , @closing_credit_account_id int = NULL
    , @ref_number int = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

SET @code = LTRIM(RTRIM(@code))
SET @name = LTRIM(RTRIM(@name))

DECLARE @message nvarchar(max)

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

IF @company_id IS NULL
    RETURN

IF CHARINDEX(@code, ' ') > 0 OR CHARINDEX(@code, '''') > 0 OR CHARINDEX(@code, '"') > 0 OR CHARINDEX(@code, '[') > 0 OR CHARINDEX(@code, ']') > 0
    BEGIN
    SET @message = dbo27.get_translated_string('The code ''%s'' contains prohibited symbols (space, '', ", [ or ])', @data_language)
    RAISERROR (@message, 11, 0, @code)
    RETURN
    END

SET NOCOUNT OFF

INSERT INTO dbo27.ledger_accounts
    ( company_id
    , code
    , name
    , parent_id
    , account_type_id
    , subsidiary_group_id
    , closing_child_account_id
    , closing_debit_account_id
    , closing_credit_account_id
    , ref_number
    )
VALUES
    ( @company_id
    , @code
    , @name
    , @parent_id
    , @account_type_id
    , @subsidiary_group_id
    , @closing_child_account_id
    , @closing_debit_account_id
    , @closing_credit_account_id
    , @ref_number
    )

DECLARE @id int = SCOPE_IDENTITY()

IF @data_language IS NOT NULL AND @translated_name IS NOT NULL
    INSERT INTO dbo27.translations
        (company_id, table_id, member_id, language, name)
    VALUES
        (@company_id, 11, @id, @data_language, @translated_name)

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Update procedure for usp_accounts
-- =============================================

CREATE PROCEDURE [xls27].[usp_ledger_accounts_update]
      @id int
    , @code nvarchar(50)
    , @name nvarchar(100)
    , @translated_name nvarchar(100) = NULL
    , @parent_id int = NULL
    , @account_type_id tinyint = NULL
    , @subsidiary_group_id int = NULL
    , @closing_child_account_id int = NULL
    , @closing_debit_account_id int = NULL
    , @closing_credit_account_id int = NULL
    , @ref_number int = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

DECLARE @company_id int
DECLARE @current_name nvarchar(100)

SELECT TOP 1 @company_id = u.company_id, @current_name = t.name FROM dbo27.ledger_accounts t INNER JOIN dbo27.users u ON u.company_id = t.company_id  WHERE t.id = @id AND u.username = USER_NAME() AND u.is_active = 1

IF @company_id IS NULL
    RETURN

SET @code = LTRIM(RTRIM(@code))
SET @name = LTRIM(RTRIM(@name))

DECLARE @message nvarchar(max)

IF CHARINDEX(@code, ' ') > 0 OR CHARINDEX(@code, '''') > 0 OR CHARINDEX(@code, '"') > 0 OR CHARINDEX(@code, '[') > 0 OR CHARINDEX(@code, ']') > 0
    BEGIN
    SET @message = dbo27.get_translated_string('The code ''%s'' contains prohibited symbols (space, '', ", [ or ])', @data_language)
    RAISERROR (@message, 11, 0, @code)
    RETURN
    END

SET NOCOUNT OFF

UPDATE dbo27.ledger_accounts
SET
    code = @code
    , name = @name
    , parent_id = @parent_id
    , account_type_id = @account_type_id
    , subsidiary_group_id = @subsidiary_group_id
    , closing_child_account_id = @closing_child_account_id
    , closing_debit_account_id = @closing_debit_account_id
    , closing_credit_account_id = @closing_credit_account_id
    , ref_number = @ref_number
WHERE
    id = @id
    AND NOT (
        COALESCE(code, '-1') = COALESCE(@code, '-2')
        AND COALESCE(name, '-1') = COALESCE(@name, '-2')
        AND COALESCE(parent_id, -1) = COALESCE(@parent_id, -2)
        AND COALESCE(account_type_id, -1) = COALESCE(@account_type_id, -2)
        AND COALESCE(subsidiary_group_id, -1) = COALESCE(@subsidiary_group_id, -2)
        AND COALESCE(closing_child_account_id, -1) = COALESCE(@closing_child_account_id, -2)
        AND COALESCE(closing_debit_account_id, -1) = COALESCE(@closing_debit_account_id, -2)
        AND COALESCE(closing_credit_account_id, -1) = COALESCE(@closing_credit_account_id, -2)
        AND COALESCE(ref_number, -1) = COALESCE(@ref_number, -2)
        )

IF @data_language IS NOT NULL AND @translated_name IS NOT NULL
    BEGIN
    MERGE dbo27.translations t
    USING
        (
        SELECT company_id = @company_id, 11 AS table_id, @id AS member_id, @data_language AS language, @translated_name AS name
        ) s ON s.company_id = t.company_id AND s.table_id = t.table_id AND s.member_id = t.member_id AND s.language = t.language
    WHEN MATCHED AND NOT COALESCE(t.name, '') = COALESCE(s.name, '') THEN
        UPDATE SET name = s.name
    WHEN NOT MATCHED THEN
        INSERT (company_id, table_id, member_id, language, name) VALUES (s.company_id, s.table_id, s.member_id, s.language, s.name);
    END

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Selects member permissions
-- =============================================

CREATE PROCEDURE [xls27].[usp_member_permissions]
    @company_id int = NULL
    , @dimension_id tinyint = NULL
    , @username nvarchar(128) = NULL
    , @data_language varchar(10) = NULL
WITH EXECUTE AS OWNER
AS
BEGIN

SET NOCOUNT ON

EXECUTE AS CALLER

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

REVERT

DECLARE @columns nvarchar(max)

IF @company_id IS NOT NULL
    SELECT @columns = STUFF((
        SELECT
            ', [' + CAST(u.username AS nvarchar) + ']'
        FROM
            dbo27.users u
        WHERE
            u.company_id = @company_id
            AND u.is_active = 1
            AND u.is_admin = 0
        ORDER BY
            u.username
        FOR XML PATH(''), TYPE
    ).value('.', 'nvarchar(MAX)'), 1, 2, '')

DECLARE @sql nvarchar(max)

SET @sql = 'SELECT
    m.id
    , m.dimension_id
    , m.sort_order
    , m.code
    , ' + CASE WHEN @data_language IS NULL THEN 'm.name' ELSE 'COALESCE(tr.name, m.name) AS name' END + '
    , CASE WHEN h.parent_id IS NULL AND m.is_active = 1 THEN 1 ELSE 0 END AS is_in_budget_request
    , CAST(NULL AS char(1)) AS data_format'
    + CASE WHEN @columns IS NULL THEN '' ELSE '
    , ' + @columns END + '
    , CAST(NULL AS char(1)) AS last_format_column
FROM
    dbo27.members m'
    + CASE WHEN @columns IS NULL THEN '' ELSE '
    LEFT OUTER JOIN (
        SELECT
            mp.member_id
            , mp.username
            , mp.permission AS value
        FROM
            dbo27.member_permissions mp
    ) s PIVOT (
        MAX(value) FOR username IN (' + @columns + ')
    ) p ON p.member_id = m.id' END + '
    LEFT OUTER JOIN (
        SELECT
            DISTINCT
            p.parent_id
        FROM
            dbo27.members p
    ) h ON h.parent_id = m.id'
    + CASE WHEN @data_language IS NULL THEN '' ELSE '
    LEFT OUTER JOIN dbo27.translations tr ON tr.company_id = m.company_id AND tr.table_id = 1 AND tr.member_id = m.id AND tr.language = ''' + @data_language + ''''
        END    + '
WHERE
    m.company_id = ' + COALESCE(CAST(@company_id AS nvarchar), 'NULL')
    + CASE WHEN @dimension_id IS NULL THEN '' ELSE + '
    AND m.dimension_id = ' + CAST(@dimension_id AS nvarchar) END
    + '
ORDER BY
    m.dimension_id
    , m.sort_order
    , m.code
'

-- PRINT @sql

EXEC (@sql)

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Cell change event handler for usp_member_permissions
-- =============================================

CREATE PROCEDURE [xls27].[usp_member_permissions_change]
    @column_name nvarchar(128) = NULL
    , @cell_value nvarchar(255) = NULL
    , @id int = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

DECLARE @message nvarchar(max)

-- Protecting non-data columns

IF @column_name IN ('data_format')
    BEGIN
    SET @message = dbo27.get_translated_string('The column ''%s'' is not updatable', @data_language)
    RAISERROR (@message, 11, 0, @column_name)
    RETURN
    END

DECLARE @company_id int

SET @company_id = (SELECT TOP 1 u.company_id FROM dbo27.members t INNER JOIN dbo27.users u ON u.company_id = t.company_id WHERE t.id = @id AND u.username = USER_NAME() AND u.is_active = 1)

IF @company_id IS NULL
    RETURN

IF NOT EXISTS (SELECT id FROM dbo27.members WHERE id = @id)
    BEGIN
    SET @message = dbo27.get_translated_string('Cannot find member_id %s', @data_language)
    RAISERROR (@message, 11, 0, @id)
    RETURN
    END

DECLARE @username nvarchar(128) = @column_name

IF NOT EXISTS (SELECT u.username FROM dbo27.users u WHERE u.company_id = @company_id AND u.username = @username)
    BEGIN
    SET @message = dbo27.get_translated_string('Cannot find the principal ''%s'', because it does not exist or you do not have permission.', @data_language)
    RAISERROR (@message, 11, 0, @username)
    RETURN
    END

-- Getting permissions from the cell value

DECLARE @select_permission bit = NULL
DECLARE @update_permission bit = NULL

IF @cell_value IS NULL
    BEGIN
    DELETE FROM dbo27.member_permissions WHERE member_id = @id AND username = @column_name
    RETURN
    END

IF UPPER(@cell_value) = 'D'
    BEGIN
    SET @select_permission = 0
    SET @update_permission = 0
    END
ELSE IF UPPER(@cell_value) = 'R'
    BEGIN
    SET @select_permission = 1
    SET @update_permission = 0
    END
ELSE IF UPPER(@cell_value) = 'W'
    BEGIN
    SET @select_permission = 1
    SET @update_permission = 1
    END
ELSE
    BEGIN
    SET @message = dbo27.get_translated_string('Unknown option: %s (Use R, W, D)', @data_language)
    RAISERROR (@message, 11, 0, @cell_value)
    RETURN
    END

SET NOCOUNT OFF

UPDATE dbo27.member_permissions
SET
    select_permission = @select_permission
    , update_permission = @update_permission
    , is_inherited = 0
WHERE
    member_id = @id
    AND username = @column_name

IF @@ROWCOUNT = 0
    INSERT INTO dbo27.member_permissions (member_id, username, select_permission, update_permission, is_inherited)
    VALUES (@id, @username, @select_permission, @update_permission, 0)

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Selects rows to set member relations
-- =============================================

CREATE PROCEDURE [xls27].[usp_member_relations]
    @company_id int = NULL
    , @member_dimension_id int = NULL
    , @partner_dimension_id int = NULL
    , @data_language varchar(10) = NULL
WITH EXECUTE AS OWNER
AS
BEGIN

SET NOCOUNT ON

EXECUTE AS CALLER

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

REVERT

DECLARE @columns nvarchar(max)

SELECT @columns = STUFF((
        SELECT
            ', [' + CAST(m.code AS nvarchar) + ']'
        FROM
            dbo27.members m
        WHERE
            m.dimension_id = @partner_dimension_id
            AND m.company_id = @company_id
        ORDER BY
            m.sort_order
            , m.code
        FOR XML PATH(''), TYPE
    ).value('.', 'nvarchar(MAX)'), 1, 2, '')

-- PRINT @columns

DECLARE @sql nvarchar(max)

SET @sql = 'SELECT
    m.id
    , m.sort_order
    , m.code
    , ' + CASE WHEN @data_language IS NULL THEN 'm.name' ELSE 'COALESCE(tr.name, m.name) AS name' END + '
    , NULL AS data_format'
    + CASE WHEN @columns IS NULL THEN '' ELSE '
    , ' + @columns END + '
FROM
    dbo27.members m'
    + CASE WHEN @columns IS NULL THEN '' ELSE '
    LEFT OUTER JOIN (
        SELECT
            m.id
            , p.code
            , CAST(mp.select_permission AS tinyint) AS value
        FROM
            dbo27.member_relations mp
            INNER JOIN dbo27.members m ON m.id = mp.member_id
            INNER JOIN dbo27.members p ON p.id = mp.partner_id
        WHERE
            m.dimension_id = ' + COALESCE(CAST(@member_dimension_id AS nvarchar), 'NULL') + '
            AND p.dimension_id = ' + COALESCE(CAST(@partner_dimension_id AS nvarchar), 'NULL') + '
    ) s PIVOT (
        MAX(value) FOR code IN (' + @columns + ')
    ) p ON p.id = m.id'
        END
    + CASE WHEN @data_language IS NULL THEN '' ELSE '
    LEFT OUTER JOIN dbo27.translations tr ON tr.company_id = m.company_id AND tr.table_id = 1 AND tr.member_id = m.id AND tr.language = ''' + @data_language + ''''
        END    + '
WHERE
    m.company_id = ' + COALESCE(CAST(@company_id AS nvarchar), 'NULL')
    + CASE WHEN @member_dimension_id IS NULL THEN '' ELSE ' AND m.dimension_id = ' + CAST(@member_dimension_id AS nvarchar) END
    + '
ORDER BY
    m.dimension_id
    , m.sort_order
    , m.code
'

-- PRINT @sql

EXEC (@sql)

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Cell change event handler for usp_member_relations
-- =============================================

CREATE PROCEDURE [xls27].[usp_member_relations_change]
    @column_name nvarchar(128) = NULL
    , @cell_number_value int = NULL
    , @id int = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

DECLARE @message nvarchar(max)

IF @column_name IN ('id', 'code', 'name', 'sort_order', 'data_format')
    BEGIN
    SET @message = dbo27.get_translated_string('The column ''%s'' is not updatable', @data_language)
    RAISERROR (@message, 11, 0, @column_name)
    RETURN
    END

IF NOT EXISTS (SELECT id FROM dbo27.members WHERE id = @id)
    BEGIN
    SET @message = dbo27.get_translated_string('Cannot find member id %i', @data_language)
    RAISERROR (@message, 11, 0, @id)
    RETURN
    END

DECLARE @partner_id int

SELECT @partner_id = id FROM dbo27.members WHERE code = @column_name

IF @partner_id IS NULL
    BEGIN
    SET @message = dbo27.get_translated_string('Cannot find member id %s', @data_language)
    RAISERROR (@message, 11, 0, @column_name)
    RETURN
    END

DECLARE @value bit = NULL

IF @cell_number_value IS NULL
    BEGIN
    DELETE FROM dbo27.member_relations WHERE member_id = @id AND partner_id = @partner_id
    RETURN
    END
ELSE IF @cell_number_value = 0
    BEGIN
    SET @value = 0
    END
ELSE IF @cell_number_value = 1
    BEGIN
    SET @value = 1
    END
ELSE
    BEGIN
    SET @message = dbo27.get_translated_string('Unknown option: %i (Use 0 or 1)', @data_language)
    RAISERROR (@message, 11, 0, @cell_number_value)
    END

IF EXISTS (SELECT TOP 1 parent_id FROM dbo27.members WHERE parent_id = @id)
    BEGIN
    DECLARE @code nvarchar(128) = (SELECT code FROM dbo27.members WHERE id = @id)
    SET @message = dbo27.get_translated_string('Member %s cannot be editable as it has children', @data_language)
    RAISERROR (@message, 11, 0, @code)
    END

IF EXISTS (SELECT TOP 1 parent_id FROM dbo27.members WHERE parent_id = @partner_id)
    BEGIN
    SET @message = dbo27.get_translated_string('Member %s cannot be editable as it has children', @data_language)
    RAISERROR (@message, 11, 0, @column_name)
    END

SET NOCOUNT OFF

UPDATE dbo27.member_relations
SET
    select_permission = @value
WHERE
    member_id = @id
    AND partner_id = @partner_id

IF @@ROWCOUNT = 0
    INSERT INTO dbo27.member_relations (member_id, partner_id, select_permission) VALUES (@id, @partner_id, @value)

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Selects member_types
-- =============================================

CREATE PROCEDURE [xls27].[usp_member_types]
AS
BEGIN

SET NOCOUNT ON

SELECT
    t.id
    , t.code
    , t.name
    , t.cf_sign
    , t.pl_sign
    , t.asset_sign
    , t.vat_sign
    , t.payment_debit_type_id
    , t.payment_credit_type_id
    , t.charge_debit_type_id
    , t.charge_credit_type_id
    , t.vat_debit_type_id
    , t.vat_credit_type_id
FROM
    dbo27.member_types t
ORDER BY
    t.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Selects members
-- =============================================

CREATE PROCEDURE [xls27].[usp_members]
    @company_id int = NULL
    , @dimension_id tinyint = NULL
    , @is_in_budget bit = NULL
    , @is_active bit = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

SELECT
    m.id
    , m.sort_order
    , m.code
    , m.name
    , tr.name AS translated_name
    , CASE WHEN p.parent_id IS NULL AND m.is_active = 1 THEN 1 ELSE 0 END AS is_in_budget_request
    , m.is_active
FROM
    dbo27.members m
    LEFT OUTER JOIN (
        SELECT
            DISTINCT
            p.parent_id
        FROM
            dbo27.members p
    ) p ON p.parent_id = m.id
    LEFT OUTER JOIN dbo27.member_types t ON t.id = m.account_type_id
    LEFT OUTER JOIN dbo27.units u ON u.id = m.unit_id
    LEFT OUTER JOIN dbo27.translations tr ON tr.company_id = m.company_id AND tr.table_id = 1 AND tr.member_id = m.id AND tr.language = @data_language
WHERE
    m.dimension_id = COALESCE(@dimension_id, m.dimension_id)
    AND m.company_id = @company_id
    AND m.is_active = COALESCE(@is_active, m.is_active)
    AND (CASE WHEN p.parent_id IS NULL AND m.is_active = 1 THEN 1 ELSE 0 END = @is_in_budget OR @is_in_budget IS NULL)
ORDER BY
    m.dimension_id
    , m.sort_order
    , m.code
    , m.name
    , m.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Delete procedure for usp_members
-- =============================================

CREATE PROCEDURE [xls27].[usp_members_delete]
    @id int
AS
BEGIN

SET NOCOUNT ON

IF NOT EXISTS (SELECT TOP 1 u.company_id FROM dbo27.members t INNER JOIN dbo27.users u ON u.company_id = t.company_id  WHERE t.id = @id AND u.username = USER_NAME() AND u.is_active = 1)
    RETURN

SET NOCOUNT OFF

DELETE dbo27.members WHERE id = @id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Delete procedure for usp_budgeting_accounts
-- =============================================

CREATE PROCEDURE [xls27].[usp_budgeting_accounts_delete]
    @id int
AS
BEGIN

SET NOCOUNT ON

EXEC xls27.usp_members_delete @id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Insert procedure for usp_members
-- =============================================

CREATE PROCEDURE [xls27].[usp_members_insert]
    @company_id int = NULL
    , @dimension_id int = NULL
    , @sort_order int = NULL
    , @code nvarchar(50) = NULL
    , @name nvarchar(100) = NULL
    , @translated_name nvarchar(100) = NULL
    , @is_active bit = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

IF @company_id IS NULL
    RETURN

SET NOCOUNT OFF

INSERT INTO dbo27.members
    ( company_id
    , dimension_id
    , sort_order
    , code
    , name
    , is_active
    )
VALUES
    ( @company_id
    , @dimension_id
    , @sort_order
    , @code
    , @name
    , COALESCE(@is_active, 1)
    )

DECLARE @id int = SCOPE_IDENTITY()

IF @data_language IS NOT NULL AND @translated_name IS NOT NULL
    INSERT INTO dbo27.translations
        (company_id, table_id, member_id, language, name)
    VALUES
        (@company_id, 1, @id, @data_language, @translated_name)

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Update procedure for usp_members
-- =============================================

CREATE PROCEDURE [xls27].[usp_members_update]
      @id int
    , @sort_order int = NULL
    , @code nvarchar(50)
    , @name nvarchar(100)
    , @translated_name nvarchar(100) = NULL
    , @is_active bit = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

DECLARE @company_id int
DECLARE @current_name nvarchar(100)

SELECT TOP 1 @company_id = u.company_id, @current_name = t.name FROM dbo27.members t INNER JOIN dbo27.users u ON u.company_id = t.company_id  WHERE t.id = @id AND u.username = USER_NAME() AND u.is_active = 1

IF @company_id IS NULL
    RETURN

SET @code = LTRIM(RTRIM(@code))
SET @name = LTRIM(RTRIM(@name))

DECLARE @message nvarchar(max)

IF CHARINDEX(@code, ' ') > 0 OR CHARINDEX(@code, '''') > 0 OR CHARINDEX(@code, '"') > 0 OR CHARINDEX(@code, '[') > 0 OR CHARINDEX(@code, ']') > 0
    BEGIN
    SET @message = dbo27.get_translated_string('The code ''%s'' contains prohibited symbols (space, '', ", [ or ])', @data_language)
    RAISERROR (@message, 11, 0, @code)
    RETURN
    END

SET NOCOUNT OFF

UPDATE dbo27.members
SET
    code = @code
    , name = @name
    , sort_order = @sort_order
    , is_active = COALESCE(@is_active, 1)
WHERE
    id = @id
    AND NOT (
        code = @code
        AND name = @name
        AND COALESCE(sort_order, -1) = COALESCE(@sort_order, -2)
        AND COALESCE(is_active, -1) = COALESCE(@is_active, -2)
        )

IF @data_language IS NOT NULL AND @translated_name IS NOT NULL
    BEGIN
    MERGE dbo27.translations t
    USING
        (
        SELECT company_id = @company_id, 1 AS table_id, @id AS member_id, @data_language AS language, @translated_name AS name
        ) s ON s.company_id = t.company_id AND s.table_id = t.table_id AND s.member_id = t.member_id AND s.language = t.language
    WHEN MATCHED AND NOT COALESCE(t.name, '') = COALESCE(s.name, '') THEN
        UPDATE SET name = s.name
    WHEN NOT MATCHED THEN
        INSERT (company_id, table_id, member_id, language, name) VALUES (s.company_id, s.table_id, s.member_id, s.language, s.name);
    END

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Selects report_section_accounts
-- =============================================

CREATE PROCEDURE [xls27].[usp_report_section_accounts]
    @report_type_id tinyint = NULL
    , @is_pl bit = NULL
    , @entry_side_id tinyint = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

SELECT
    rsa.id
    , ROW_NUMBER() OVER(ORDER BY rsa.account_type_id, rst.report_type_id, rsa.section_type_id, rsa.entry_side_id) AS sort_order
    , rsa.account_type_id
    , lat.is_pl
    , rsa.entry_side_id
    , COALESCE(tr.TRANSLATED_NAME, rt.name) AS report
    , rsa.section_type_id
    , rsa.value_sign
    , rsa.value_type_id
    , rsa.pair_account_type_id
FROM
    dbo27.report_section_accounts rsa
    INNER JOIN dbo27.ledger_account_types lat ON lat.id = rsa.account_type_id
    INNER JOIN dbo27.report_section_types rst ON rst.id = rsa.section_type_id
    INNER JOIN dbo27.report_types rt ON rt.id = rst.report_type_id
    LEFT OUTER JOIN xls.translations tr ON tr.TABLE_SCHEMA = 'dbo27' AND tr.TABLE_NAME = 'report_types_name' AND tr.COLUMN_NAME = rt.name AND tr.LANGUAGE_NAME = @data_language
WHERE
    rst.report_type_id = COALESCE(@report_type_id, rst.report_type_id)
    AND lat.is_pl = COALESCE(@is_pl, lat.is_pl)
    AND rsa.entry_side_id = COALESCE(@entry_side_id, rsa.entry_side_id)
ORDER BY
    rst.report_type_id
    , rsa.account_type_id
    , rsa.value_type_id
    , rsa.section_type_id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Selects report_section_total_types
-- =============================================

CREATE PROCEDURE [xls27].[usp_report_section_total_types]
AS
BEGIN

SET NOCOUNT ON

SELECT
    t.id
    , t.code
    , t.name
FROM
    dbo27.report_section_total_types t
ORDER BY
    t.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Selects report_section_types
-- =============================================

CREATE PROCEDURE [xls27].[usp_report_section_types]
AS
BEGIN

SET NOCOUNT ON

SELECT
    t.id
    , t.report_type_id
    , t.name
    , t.total_type_id
    , t.hide_accounts
FROM
    dbo27.report_section_types t
ORDER BY
    t.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Selects report_section_value_types
-- =============================================

CREATE PROCEDURE [xls27].[usp_report_section_value_types]
AS
BEGIN

SET NOCOUNT ON

SELECT
    t.id
    , t.code
    , t.name
FROM
    dbo27.report_section_value_types t
ORDER BY
    t.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: The procedure selects data from dbo27.report_sections
-- =============================================

CREATE PROCEDURE [xls27].[usp_report_sections]
    @company_id int = NULL
    , @report_type_id tinyint = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

SELECT
    t.id
    , ROW_NUMBER() OVER(ORDER BY t.company_id, t.report_type_id, t.section, t.id) AS sort_order
    , t.report_type_id
    , t.section
    , t.row_format
    , t.ref_number
    , t.code
    , t.description
    , tr.name AS translated_name
    , t.parent_id
    , t.parent2_id
    , t.section_type_id
    , t.inverse_sign
    , t.hide_items
    , t.show_line
    , t.show_line_before
    , t.show_line_after
    , t.page_break_before
FROM
    dbo27.report_sections t
    LEFT OUTER JOIN dbo27.translations tr ON tr.company_id = t.company_id AND tr.table_id = 9 AND tr.member_id = t.id AND tr.language = @data_language
WHERE
    t.company_id = @company_id
    AND t.report_type_id = COALESCE(@report_type_id, t.report_type_id)
ORDER BY
    t.company_id
    , t.report_type_id
    , t.section
    , t.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: The procedure deleted data from dbo27.report_sections
-- =============================================

CREATE PROCEDURE [xls27].[usp_report_sections_delete]
    @id int
AS
BEGIN

SET NOCOUNT ON

IF NOT EXISTS (SELECT TOP 1 u.company_id FROM dbo27.report_sections t INNER JOIN dbo27.users u ON u.company_id = t.company_id  WHERE t.id = @id AND u.username = USER_NAME() AND u.is_active = 1)
    RETURN

SET NOCOUNT OFF

DELETE FROM dbo27.report_sections WHERE id = @id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: The procedure inserts data into dbo27.report_sections
-- =============================================

CREATE PROCEDURE [xls27].[usp_report_sections_insert]
    @company_id int = NULL
    , @report_type_id tinyint = NULL
    , @section int = NULL
    , @row_format int = NULL
    , @ref_number int = NULL
    , @code nvarchar(50)
    , @description nvarchar(255)
    , @translated_name nvarchar(255)
    , @parent_id int = NULL
    , @parent2_id int = NULL
    , @section_type_id tinyint = NULL
    , @inverse_sign bit = NULL
    , @hide_items bit = NULL
    , @show_line bit = NULL
    , @show_line_before bit = NULL
    , @show_line_after bit = NULL
    , @page_break_before bit = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

IF @company_id IS NULL
    RETURN

SET NOCOUNT OFF

INSERT INTO dbo27.report_sections
    ( company_id
    , report_type_id
    , row_format
    , section
    , ref_number
    , code
    , description
    , parent_id
    , parent2_id
    , section_type_id
    , inverse_sign
    , hide_items
    , show_line
    , show_line_before
    , show_line_after
    , page_break_before
    )
VALUES
    ( @company_id
    , @report_type_id
    , @row_format
    , @section
    , @ref_number
    , @code
    , @description
    , @parent_id
    , @parent2_id
    , @section_type_id
    , COALESCE(@inverse_sign, 0)
    , @hide_items
    , @show_line
    , @show_line_before
    , @show_line_after
    , @page_break_before
    )

DECLARE @id int = SCOPE_IDENTITY()

IF @data_language IS NOT NULL AND @translated_name IS NOT NULL
    INSERT INTO dbo27.translations
        (company_id, table_id, member_id, language, name)
    VALUES
        (@company_id, 9, @id, @data_language, @translated_name)

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: The procedure updates data of dbo27.report_sections
-- =============================================

CREATE PROCEDURE [xls27].[usp_report_sections_update]
    @id int
    , @report_type_id tinyint = NULL
    , @section int = NULL
    , @row_format int = NULL
    , @ref_number int = NULL
    , @code nvarchar(50)
    , @description nvarchar(255)
    , @translated_name nvarchar(255)
    , @parent_id int = NULL
    , @parent2_id int = NULL
    , @section_type_id tinyint = NULL
    , @inverse_sign bit = NULL
    , @hide_items bit = NULL
    , @show_line bit = NULL
    , @show_line_before bit = NULL
    , @show_line_after bit = NULL
    , @page_break_before bit = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

DECLARE @company_id int = (SELECT TOP 1 u.company_id FROM dbo27.report_sections t INNER JOIN dbo27.users u ON u.company_id = t.company_id  WHERE t.id = @id AND u.username = USER_NAME() AND u.is_active = 1)

IF @company_id IS NULL
    RETURN

SET NOCOUNT OFF

UPDATE dbo27.report_sections
SET
    report_type_id = @report_type_id
    , section = @section
    , row_format = @row_format
    , ref_number = @ref_number
    , code = @code
    , description = @description
    , parent_id = @parent_id
    , parent2_id = @parent2_id
    , section_type_id = @section_type_id
    , inverse_sign = COALESCE(@inverse_sign, 0)
    , hide_items = @hide_items
    , show_line = @show_line
    , show_line_before = @show_line_before
    , show_line_after = @show_line_after
    , page_break_before = @page_break_before
WHERE
    id = @id
    AND NOT (
        COALESCE(code, '-1') = COALESCE(@code, '-2')
        AND COALESCE(description, '-1') = COALESCE(@description, '-2')
        AND COALESCE(report_type_id, -1) = COALESCE(@report_type_id, -2)
        AND COALESCE(section, -1) = COALESCE(@section, -2)
        AND COALESCE(row_format, -1) = COALESCE(@row_format, -2)
        AND COALESCE(ref_number, -1) = COALESCE(@ref_number, -2)
        AND COALESCE(parent_id, -1) = COALESCE(@parent_id, -2)
        AND COALESCE(parent2_id, -1) = COALESCE(@parent2_id, -2)
        AND COALESCE(section_type_id, -1) = COALESCE(@section_type_id, -2)
        AND COALESCE(inverse_sign, -1) = COALESCE(@inverse_sign, -2)
        AND COALESCE(hide_items, -1) = COALESCE(@hide_items, -2)
        AND COALESCE(show_line, -1) = COALESCE(@show_line, -2)
        AND COALESCE(show_line_before, -1) = COALESCE(@show_line_before, -2)
        AND COALESCE(show_line_after, -1) = COALESCE(@show_line_after, -2)
        AND COALESCE(page_break_before, -1) = COALESCE(@page_break_before, -2)
        )


IF @data_language IS NOT NULL AND @translated_name IS NOT NULL
    BEGIN
    MERGE dbo27.translations t
    USING
        (
        SELECT company_id = @company_id, 9 AS table_id, @id AS member_id, @data_language AS language, @translated_name AS name
        ) s ON s.company_id = t.company_id AND s.table_id = t.table_id AND s.member_id = t.member_id AND s.language = t.language
    WHEN MATCHED AND NOT COALESCE(t.name, '') = COALESCE(s.name, '') THEN
        UPDATE SET name = s.name
    WHEN NOT MATCHED THEN
        INSERT (company_id, table_id, member_id, language, name) VALUES (s.company_id, s.table_id, s.member_id, s.language, s.name);
    END

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Selects report_types
-- =============================================

CREATE PROCEDURE [xls27].[usp_report_types]
AS
BEGIN

SET NOCOUNT ON

SELECT
    t.id
    , t.code
    , t.name
FROM
    dbo27.report_types t
ORDER BY
    t.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Selects user roles
-- =============================================

CREATE PROCEDURE [xls27].[usp_role_members]
AS
BEGIN

SET NOCOUNT ON;

DECLARE @list varchar(MAX)

SELECT @list = STUFF((
    SELECT ', [' + name + ']' FROM (
        SELECT DISTINCT p.name, p.is_fixed_role FROM sys.database_principals p
            WHERE name NOT IN ('db_owner', 'public') AND p.[type] IN ('R') AND p.is_fixed_role = 0
        ) AS t ORDER BY t.is_fixed_role, t.name
    FOR XML PATH(''), TYPE
    ).value('.', 'nvarchar(MAX)'), 1, 2, '')

IF @list IS NULL
    SELECT
        LOWER(m.type_desc) AS [type]
        , m.name
        , NULL AS format_column
    FROM
        sys.database_principals m
        LEFT JOIN sys.database_role_members rm ON rm.member_principal_id = m.principal_id
        LEFT JOIN sys.database_principals p ON p.principal_id = rm.role_principal_id
    WHERE
        m.[type] IN ('S', 'U', 'R')
        AND m.is_fixed_role = 0
        AND NOT m.name IN ('dbo', 'sys', 'guest', 'public', 'INFORMATION_SCHEMA', 'xls_users', 'xls_developers', 'xls_formats', 'xls_admins', 'doc_readers', 'doc_writers', 'log_app', 'log_admins', 'log_administrators', 'log_users')
    ORDER BY
        m.type_desc
        , m.name
ELSE
    BEGIN
    DECLARE @sql varchar(MAX)
    SET @sql = '
SELECT
    LOWER(p.[type]) AS [type]
    , p.name
    , NULL AS format_column
    , ' + COALESCE(@list, '') + '
    , NULL AS last_format_column
FROM
    (
    SELECT
        p.name AS [role]
        , m.type_desc AS [type]
        , m.name
        , 1 AS [include]
    FROM
        sys.database_principals m
        LEFT JOIN sys.database_role_members rm ON rm.member_principal_id = m.principal_id
        LEFT JOIN sys.database_principals p ON p.principal_id = rm.role_principal_id
    WHERE
        m.[type] IN (''S'', ''U'', ''R'')
        AND m.is_fixed_role = 0
        AND NOT m.name IN (''dbo'', ''sys'', ''guest'', ''public'', ''INFORMATION_SCHEMA'', ''xls_users'', ''xls_developers'', ''xls_formats'', ''xls_admins'', ''doc_readers'', ''doc_writers'', ''log_app'', ''log_admins'', ''log_administrators'', ''log_users'')
    ) s PIVOT (
        SUM([include]) FOR [role] IN ('+ COALESCE(@list, '') + ')
    ) p
ORDER BY
    p.[type]
    , p.[name]
'
    EXEC(@sql)
    -- PRINT @sql
    END

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Cell change event handler for usp_roles
-- =============================================

CREATE PROCEDURE [xls27].[usp_role_members_change]
    @column_name nvarchar(128) = NULL
    , @cell_number_value int = NULL
    , @name nvarchar(128) = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

DECLARE @message nvarchar(max)

IF DATABASE_PRINCIPAL_ID(@column_name) IS NULL
    BEGIN
    SET @message = dbo27.get_translated_string('Role ''%s'' does not exist', @data_language)
    RAISERROR(@message, 11, 0, @column_name);
    RETURN
    END

IF DATABASE_PRINCIPAL_ID(@name) IS NULL
    BEGIN
    SET @message = dbo27.get_translated_string('User ''%s'' does not exist', @data_language)
    RAISERROR(@message, 11, 0, @name);
    RETURN
    END

IF @cell_number_value = 0
    EXEC sp_droprolemember @column_name, @name
ELSE IF @cell_number_value = 1
    EXEC sp_addrolemember @column_name, @name
ELSE
    BEGIN
    SET @message = dbo27.get_translated_string('Set 1 to add and 0 to remove a user from the role', @data_language)
    RAISERROR(@message, 11, 0);
    RETURN
    END

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Selects saved_report_types
-- =============================================

CREATE PROCEDURE [xls27].[usp_saved_report_types]
    @company_id int = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

SELECT
    t.id
    , t.code
    , t.name
    , tr.name AS translated_name
FROM
    dbo27.saved_report_types t
    LEFT OUTER JOIN dbo27.translations tr ON tr.company_id = t.company_id AND tr.table_id = 12 AND tr.member_id = t.id AND tr.language = @data_language
WHERE
    t.company_id = @company_id
ORDER BY
    t.code

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Delete procedure for usp_saved_report_types
-- =============================================

CREATE PROCEDURE [xls27].[usp_saved_report_types_delete]
    @id int = NULL
AS
BEGIN

SET NOCOUNT ON

IF NOT EXISTS (SELECT TOP 1 u.company_id FROM dbo27.saved_report_types t INNER JOIN dbo27.users u ON u.company_id = t.company_id  WHERE t.id = @id AND u.username = USER_NAME() AND u.is_active = 1)
    RETURN

SET NOCOUNT OFF

DELETE dbo27.saved_report_types WHERE id = @id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Insert procedure for usp_saved_report_types
-- =============================================

CREATE PROCEDURE [xls27].[usp_saved_report_types_insert]
    @company_id int = NULL
    , @code nvarchar(50)
    , @name nvarchar(100)
    , @translated_name nvarchar(100) = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

IF @company_id IS NULL
    RETURN

SET @code = LTRIM(RTRIM(@code))
SET @name = LTRIM(RTRIM(@name))

SET NOCOUNT OFF

INSERT INTO dbo27.saved_report_types
    ( company_id
    , code
    , name
    )
VALUES
    ( @company_id
    , @code
    , @name
    )

DECLARE @id int = SCOPE_IDENTITY()

IF @data_language IS NOT NULL AND @translated_name IS NOT NULL
    INSERT INTO dbo27.translations
        (company_id, table_id, member_id, language, name)
    VALUES
        (@company_id, 12, @id, @data_language, @translated_name)

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Update procedure for usp_saved_report_types
-- =============================================

CREATE PROCEDURE [xls27].[usp_saved_report_types_update]
    @id int = NULL
    , @code nvarchar(50)
    , @name nvarchar(100)
    , @translated_name nvarchar(100) = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

DECLARE @company_id int
DECLARE @current_name nvarchar(100)

SELECT TOP 1 @company_id = u.company_id, @current_name = t.name FROM dbo27.saved_report_types t INNER JOIN dbo27.users u ON u.company_id = t.company_id  WHERE t.id = @id AND u.username = USER_NAME() AND u.is_active = 1

IF @company_id IS NULL
    RETURN

SET @code = LTRIM(RTRIM(@code))
SET @name = LTRIM(RTRIM(@name))

SET NOCOUNT OFF

UPDATE dbo27.saved_report_types
SET
    code = @code
    , name = @name
WHERE
    id = @id
    AND NOT (
        COALESCE(code, '-1') = COALESCE(@code, '-2')
        AND COALESCE(name, '-1') = COALESCE(@name, '-2')
        )

IF @data_language IS NOT NULL AND @translated_name IS NOT NULL
    BEGIN
    MERGE dbo27.translations t
    USING
        (
        SELECT company_id = @company_id, 12 AS table_id, @id AS member_id, @data_language AS language, @translated_name AS name
        ) s ON s.company_id = t.company_id AND s.table_id = t.table_id AND s.member_id = t.member_id AND s.language = t.language
    WHEN MATCHED AND NOT COALESCE(t.name, '') = COALESCE(s.name, '') THEN
        UPDATE SET name = s.name
    WHEN NOT MATCHED THEN
        INSERT (company_id, table_id, member_id, language, name) VALUES (s.company_id, s.table_id, s.member_id, s.language, s.name);
    END

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: The procedure selects data from dbo27.saved_reports
-- =============================================

CREATE PROCEDURE [xls27].[usp_saved_reports]
    @company_id int = NULL
    , @category_id int = NULL
    , @time_id int = NULL
    , @type_id int = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.members WHERE id IN (@category_id, @time_id))

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

SET @category_id = (SELECT id FROM dbo27.members WHERE id = @category_id AND company_id = @company_id)

SELECT
    t.row_index AS saved_row_index
    , t.id1
    , t.id2
    , t.ref_number
    , t.account
    , t.report
    , t.page_break
    , t.row_level
    , t.row_format
    , t.hide
    , t.zero
    , t.code1
    , t.code2
    , t.code
    , t.description
    , t.data00
    , t.data01
    , t.data02
    , t.data03
    , t.data04
    , t.data05
    , t.data06
    , t.data07
    , t.data08
    , t.data09
    , t.data10
    , t.data11
    , t.data12
FROM
    dbo27.saved_reports t
WHERE
    t.type_id = @type_id
    AND t.category_id = @category_id
    AND t.time_id = @time_id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: The procedure deleted data from dbo27.saved_reports
-- =============================================

CREATE PROCEDURE [xls27].[usp_saved_reports_delete]
    @category_id int
    , @time_id int
    , @type_id int
    , @saved_row_index int
AS
BEGIN

SET NOCOUNT ON

IF NOT EXISTS (SELECT TOP 1 u.company_id FROM dbo27.members t INNER JOIN dbo27.users u ON u.company_id = t.company_id  WHERE t.id = @category_id AND u.username = USER_NAME() AND u.is_active = 1)
    RETURN

SET NOCOUNT OFF

DELETE FROM dbo27.saved_reports
WHERE
    type_id = @type_id
    AND category_id = @category_id
    AND time_id = @time_id
    AND row_index = @saved_row_index

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: The procedure inserts data into dbo27.saved_reports
-- =============================================

CREATE PROCEDURE [xls27].[usp_saved_reports_insert]
    @category_id int
    , @time_id int
    , @type_id int
    , @rownum int
    , @id1 nvarchar(50) = NULL
    , @id2 int = NULL
    , @ref_number int = NULL
    , @account nvarchar(50) = NULL
    , @report int = NULL
    , @page_break int = NULL
    , @row_level int = NULL
    , @row_format int = NULL
    , @hide int = NULL
    , @zero int = NULL
    , @code1 nvarchar(50) = NULL
    , @code2 nvarchar(50) = NULL
    , @code nvarchar(50) = NULL
    , @description nvarchar(255) = NULL
    , @data00 float = NULL
    , @data01 float = NULL
    , @data02 float = NULL
    , @data03 float = NULL
    , @data04 float = NULL
    , @data05 float = NULL
    , @data06 float = NULL
    , @data07 float = NULL
    , @data08 float = NULL
    , @data09 float = NULL
    , @data10 float = NULL
    , @data11 float = NULL
    , @data12 float = NULL
    , @transaction_start_time datetime = NULL
AS
BEGIN

SET NOCOUNT ON

DECLARE @company_id int = NULL

SELECT TOP 1 @company_id = u.company_id FROM dbo27.members t INNER JOIN dbo27.users u ON u.company_id = t.company_id  WHERE t.id = @category_id AND u.username = USER_NAME() AND u.is_active = 1

IF @company_id IS NULL OR @category_id IS NULL OR @time_id IS NULL
    RETURN

IF NOT EXISTS (SELECT TOP 1 id FROM dbo27.members WHERE id = @time_id AND company_id = @company_id)
    RETURN

SET NOCOUNT OFF

INSERT INTO dbo27.saved_reports
    ( type_id
    , category_id
    , time_id
    , row_index
    , id1
    , id2
    , ref_number
    , account
    , report
    , page_break
    , row_level
    , row_format
    , hide
    , zero
    , code1
    , code2
    , code
    , description
    , data00
    , data01
    , data02
    , data03
    , data04
    , data05
    , data06
    , data07
    , data08
    , data09
    , data10
    , data11
    , data12
    , transaction_start_time
    )
VALUES
    ( @type_id
    , @category_id
    , @time_id
    , @rownum
    , @id1
    , @id2
    , @ref_number
    , @account
    , @report
    , @page_break
    , @row_level
    , @row_format
    , @hide
    , @zero
    , @code1
    , @code2
    , @code
    , @description
    , @data00
    , @data01
    , @data02
    , @data03
    , @data04
    , @data05
    , @data06
    , @data07
    , @data08
    , @data09
    , @data10
    , @data11
    , @data12
    , @transaction_start_time
    )

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: The procedure updates data of dbo27.saved_reports
-- =============================================

CREATE PROCEDURE [xls27].[usp_saved_reports_update]
    @category_id int
    , @time_id int
    , @type_id int
    , @saved_row_index int
    , @rownum int
    , @id1 nvarchar(50) = NULL
    , @id2 int = NULL
    , @ref_number int = NULL
    , @account nvarchar(50) = NULL
    , @report int = NULL
    , @page_break int = NULL
    , @row_level int = NULL
    , @row_format int = NULL
    , @hide int = NULL
    , @zero int = NULL
    , @code1 nvarchar(50) = NULL
    , @code2 nvarchar(50) = NULL
    , @code nvarchar(50) = NULL
    , @description nvarchar(255) = NULL
    , @data00 float = NULL
    , @data01 float = NULL
    , @data02 float = NULL
    , @data03 float = NULL
    , @data04 float = NULL
    , @data05 float = NULL
    , @data06 float = NULL
    , @data07 float = NULL
    , @data08 float = NULL
    , @data09 float = NULL
    , @data10 float = NULL
    , @data11 float = NULL
    , @data12 float = NULL
    , @transaction_start_time datetime = NULL
AS
BEGIN

SET NOCOUNT ON

DECLARE @company_id int = NULL

SELECT TOP 1 @company_id = u.company_id FROM dbo27.members t INNER JOIN dbo27.users u ON u.company_id = t.company_id  WHERE t.id = @category_id AND u.username = USER_NAME() AND u.is_active = 1

IF @company_id IS NULL OR @category_id IS NULL OR @time_id IS NULL
    RETURN

IF NOT EXISTS (SELECT TOP 1 id FROM dbo27.members WHERE id = @time_id AND company_id = @company_id)
    RETURN

SET NOCOUNT OFF

UPDATE dbo27.saved_reports
SET
    row_index = @rownum
    , id1 = @id1
    , id2 = @id2
    , ref_number = @ref_number
    , account = @account
    , report = @report
    , page_break = @page_break
    , row_level = @row_level
    , row_format = @row_format
    , hide = @hide
    , zero = @zero
    , code1 = @code1
    , code2 = @code2
    , code = @code
    , description = @description
    , data00 = @data00
    , data01 = @data01
    , data02 = @data02
    , data03 = @data03
    , data04 = @data04
    , data05 = @data05
    , data06 = @data06
    , data07 = @data07
    , data08 = @data08
    , data09 = @data09
    , data10 = @data10
    , data11 = @data11
    , data12 = @data12
    , transaction_start_time = @transaction_start_time
WHERE
    type_id = @type_id
    AND category_id = @category_id
    AND time_id = @time_id
    AND row_index = @rownum

IF @@ROWCOUNT = 0
UPDATE dbo27.saved_reports
SET
    row_index = @rownum
    , id1 = @id1
    , id2 = @id2
    , ref_number = @ref_number
    , account = @account
    , report = @report
    , page_break = @page_break
    , row_level = @row_level
    , row_format = @row_format
    , hide = @hide
    , zero = @zero
    , code1 = @code1
    , code2 = @code2
    , code = @code
    , description = @description
    , data00 = @data00
    , data01 = @data01
    , data02 = @data02
    , data03 = @data03
    , data04 = @data04
    , data05 = @data05
    , data06 = @data06
    , data07 = @data07
    , data08 = @data08
    , data09 = @data09
    , data10 = @data10
    , data11 = @data11
    , data12 = @data12
    , transaction_start_time = @transaction_start_time
WHERE
    type_id = @type_id
    AND category_id = @category_id
    AND time_id = @time_id
    AND row_index = @saved_row_index

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Selects subsidiary_accounts
-- =============================================

CREATE PROCEDURE [xls27].[usp_subsidiary_accounts]
    @company_id int = NULL
    , @subsidiary_group_id int = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

SELECT
    m.id
    , m.code
    , COALESCE(tr.name, m.name) AS name
    , m.unit_id AS currency_id
    , p.[1] AS group1
    , p.[2] AS group2
    , p.[3] AS group3
FROM
    dbo27.members m
    LEFT OUTER JOIN (
        SELECT
            h.member_id
            , h.group_id
            , ROW_NUMBER() OVER(PARTITION BY h.member_id ORDER BY g.code, g.id) AS R
        FROM
            dbo27.member_groups h
            INNER JOIN dbo27.subsidiary_groups g ON g.id = h.group_id
    ) s PIVOT (
        MAX(group_id) FOR R IN ([1], [2], [3])
    ) p ON p.member_id = m.id
    LEFT OUTER JOIN dbo27.subsidiary_groups g1 ON g1.id = p.[1]
    LEFT OUTER JOIN dbo27.subsidiary_groups g2 ON g2.id = p.[2]
    LEFT OUTER JOIN dbo27.subsidiary_groups g3 ON g3.id = p.[3]
    LEFT OUTER JOIN dbo27.translations tr ON tr.company_id = m.company_id AND tr.table_id = 1 AND tr.member_id = m.id AND tr.language = @data_language
WHERE
    m.company_id = @company_id
    AND (@subsidiary_group_id IS NULL OR m.id IN (SELECT member_id FROM dbo27.member_groups WHERE group_id = @subsidiary_group_id))
    AND m.dimension_id = 7
ORDER BY
    g1.code
    , g2.code
    , g3.code
    , m.code
    , m.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Delete procedure for usp_subsidiary_accounts
-- =============================================

CREATE PROCEDURE [xls27].[usp_subsidiary_accounts_delete]
    @id int
AS
BEGIN

SET NOCOUNT ON

EXEC xls27.usp_members_delete @id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Insert procedure for usp_subsidiary_accounts
-- =============================================

CREATE PROCEDURE [xls27].[usp_subsidiary_accounts_insert]
    @company_id int = NULL
    , @code nvarchar(50)
    , @name nvarchar(100)
    , @currency_id tinyint = NULL
    , @group1 tinyint = NULL
    , @group2 tinyint = NULL
    , @group3 tinyint = NULL
AS
BEGIN

SET NOCOUNT ON

SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

IF @company_id IS NULL
    RETURN

SET NOCOUNT OFF

INSERT INTO dbo27.members
    ( company_id
    , dimension_id
    , sort_order
    , code
    , name
    , unit_id
    )
VALUES
    ( @company_id
    , 7
    , NULL
    , @code
    , @name
    , @currency_id
    )

DECLARE @id int = SCOPE_IDENTITY()

IF @group1 IS NOT NULL OR @group2 IS NOT NULL OR @group3 IS NOT NULL
    BEGIN

    MERGE dbo27.member_groups t
    USING
        (
            SELECT * FROM (VALUES (@id, @group1), (@id, @group2), (@id, @group3)) v(member_id, group_id) WHERE group_id IS NOT NULL
        ) s ON t.member_id = s.member_id AND t.group_id = s.group_id
    WHEN NOT MATCHED THEN
        INSERT (member_id, group_id) VALUES (member_id, group_id)
    WHEN NOT MATCHED BY SOURCE AND t.member_id = @id THEN
        DELETE;
    END

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Update procedure for usp_subsidiary_accounts
-- =============================================

CREATE PROCEDURE [xls27].[usp_subsidiary_accounts_update]
      @id int = NULL
    , @code nvarchar(50) = NULL
    , @name nvarchar(100) = NULL
    , @currency_id tinyint = NULL
    , @group1 tinyint = NULL
    , @group2 tinyint = NULL
    , @group3 tinyint = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

IF NOT EXISTS (SELECT TOP 1 u.company_id FROM dbo27.members t INNER JOIN dbo27.users u ON u.company_id = t.company_id  WHERE t.id = @id AND u.username = USER_NAME() AND u.is_active = 1)
    RETURN

SET @code = LTRIM(RTRIM(@code))
SET @name = LTRIM(RTRIM(@name))

DECLARE @message nvarchar(max)

IF CHARINDEX(@code, ' ') > 0 OR CHARINDEX(@code, '''') > 0 OR CHARINDEX(@code, '"') > 0 OR CHARINDEX(@code, '[') > 0 OR CHARINDEX(@code, ']') > 0
    BEGIN
    SET @message = dbo27.get_translated_string('The code ''%s'' contains prohibited symbols (space, '', ", [ or ])', @data_language)
    RAISERROR (@message, 11, 0, @code)
    RETURN
    END

DECLARE @prev_currency_id int = (SELECT unit_id FROM dbo27.members WHERE id = @id)

IF NOT COALESCE(@prev_currency_id, 0) = COALESCE(@currency_id, 0)
    BEGIN
    IF EXISTS(
        SELECT
            TOP 1 j.id
        FROM
            dbo27.journals j
            INNER JOIN dbo27.actual_closed_periods p ON p.date = j.month
        WHERE
            (j.debit_subsidiary_account_id = @id OR j.credit_subsidiary_account_id = @id)
            AND p.is_closed = 1
        )
        BEGIN
        SET @message = dbo27.get_translated_string('The period is closed for changes', @data_language)
        RAISERROR (@message, 11, 0)
        RETURN
        END

    IF COALESCE(@currency_id, 0) = 0
        BEGIN
        UPDATE dbo27.journals
        SET
            amount$ = amount
        FROM
            dbo27.journals j
        WHERE
            (j.debit_subsidiary_account_id = @id OR j.credit_subsidiary_account_id = @id)
            AND j.auto_type_id = 0
        END
    ELSE
        BEGIN
        DECLARE @is_base_currency bit = (SELECT is_base_currency FROM dbo27.units WHERE id = @currency_id)

        UPDATE dbo27.journals
        SET
            amount$ = ROUND(amount * CASE WHEN @is_base_currency = 0 OR r.rate = 0 THEN COALESCE(r.rate, 1.0) ELSE 1.0 / COALESCE(r.rate, 1.0) END, 2)
        FROM
            dbo27.journals j
            INNER JOIN dbo27.actual_currency_rates r ON r.currency_id = @currency_id AND r.date = j.date
        WHERE
            (j.debit_subsidiary_account_id = @id OR j.credit_subsidiary_account_id = @id)
            AND j.auto_type_id = 0
        END
    END

UPDATE dbo27.members
SET
    code = @code
    , name = @name
    , unit_id = @currency_id
WHERE
    id = @id
    AND NOT (
        COALESCE(code, '-1') = COALESCE(@code, '-2')
        AND COALESCE(name, '-1') = COALESCE(@name, '-2')
        AND COALESCE(unit_id, -1) = COALESCE(@currency_id, -2)
        )

MERGE dbo27.member_groups t
USING
    (
        SELECT * FROM (VALUES (@id, @group1), (@id, @group2), (@id, @group3)) v(member_id, group_id) WHERE group_id IS NOT NULL
    ) s ON t.member_id = s.member_id AND t.group_id = s.group_id
WHEN NOT MATCHED THEN
    INSERT (member_id, group_id) VALUES (member_id, group_id)
WHEN NOT MATCHED BY SOURCE AND t.member_id = @id THEN
    DELETE;

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Selects subsidiary_groups
-- =============================================

CREATE PROCEDURE [xls27].[usp_subsidiary_groups]
    @company_id int = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

SELECT
    t.id
    , t.code
    , t.name
    , tr.name AS translated_name
FROM
    dbo27.subsidiary_groups t
    LEFT OUTER JOIN dbo27.translations tr ON tr.company_id = t.company_id AND tr.table_id = 10 AND tr.member_id = t.id AND tr.language = @data_language
WHERE
    t.company_id = @company_id
ORDER BY
    t.code

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Delete procedure for usp_subsidiary_groups
-- =============================================

CREATE PROCEDURE [xls27].[usp_subsidiary_groups_delete]
    @id int = NULL
AS
BEGIN

SET NOCOUNT ON

IF NOT EXISTS (SELECT TOP 1 u.company_id FROM dbo27.subsidiary_groups t INNER JOIN dbo27.users u ON u.company_id = t.company_id  WHERE t.id = @id AND u.username = USER_NAME() AND u.is_active = 1)
    RETURN

SET NOCOUNT OFF

DELETE dbo27.subsidiary_groups WHERE id = @id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Insert procedure for usp_subsidiary_groups
-- =============================================

CREATE PROCEDURE [xls27].[usp_subsidiary_groups_insert]
    @company_id int = NULL
    , @code nvarchar(50)
    , @name nvarchar(100)
    , @translated_name nvarchar(100) = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

IF @company_id IS NULL
    RETURN

SET @code = LTRIM(RTRIM(@code))
SET @name = LTRIM(RTRIM(@name))

SET NOCOUNT OFF

INSERT INTO dbo27.subsidiary_groups
    ( company_id
    , code
    , name
    )
VALUES
    ( @company_id
    , @code
    , @name
    )

DECLARE @id int = SCOPE_IDENTITY()

IF @data_language IS NOT NULL AND @translated_name IS NOT NULL
    INSERT INTO dbo27.translations
        (company_id, table_id, member_id, language, name)
    VALUES
        (@company_id, 10, @id, @data_language, @translated_name)

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Update procedure for usp_subsidiary_groups
-- =============================================

CREATE PROCEDURE [xls27].[usp_subsidiary_groups_update]
    @id int = NULL
    , @code nvarchar(50)
    , @name nvarchar(100)
    , @translated_name nvarchar(100) = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

DECLARE @company_id int
DECLARE @current_name nvarchar(100)

SELECT TOP 1 @company_id = u.company_id, @current_name = t.name FROM dbo27.subsidiary_groups t INNER JOIN dbo27.users u ON u.company_id = t.company_id  WHERE t.id = @id AND u.username = USER_NAME() AND u.is_active = 1

IF @company_id IS NULL
    RETURN

SET @code = LTRIM(RTRIM(@code))
SET @name = LTRIM(RTRIM(@name))

SET NOCOUNT OFF

UPDATE dbo27.subsidiary_groups
SET
    code = @code
    , name = @name
WHERE
    id = @id
    AND NOT (
        COALESCE(code, '-1') = COALESCE(@code, '-2')
        AND COALESCE(name, '-1') = COALESCE(@name, '-2')
        )

IF @data_language IS NOT NULL AND @translated_name IS NOT NULL
    BEGIN
    MERGE dbo27.translations t
    USING
        (
        SELECT company_id = @company_id, 10 AS table_id, @id AS member_id, @data_language AS language, @translated_name AS name
        ) s ON s.company_id = t.company_id AND s.table_id = t.table_id AND s.member_id = t.member_id AND s.language = t.language
    WHEN MATCHED AND NOT COALESCE(t.name, '') = COALESCE(s.name, '') THEN
        UPDATE SET name = s.name
    WHEN NOT MATCHED THEN
        INSERT (company_id, table_id, member_id, language, name) VALUES (s.company_id, s.table_id, s.member_id, s.language, s.name);
    END

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Selects translations
-- =============================================

CREATE PROCEDURE [xls27].[usp_translations]
    @company_id int = NULL
    , @is_translatable bit = NULL
    , @is_complete bit = NULL
WITH EXECUTE AS OWNER
AS
BEGIN

SET NOCOUNT ON;

EXECUTE AS CALLER

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

REVERT

IF @company_id IS NULL
    BEGIN
    SELECT
        t.table_id
        , t.member_id
        , t.name AS table_name
        , 0 AS is_translatable
        , 0 AS is_complete
        , t.name
        , t.name AS [en]
    FROM
        dbo27.translations t
    WHERE
        t.company_id IS NULL

    RETURN
    END

DECLARE @company_sid nvarchar(max) = CAST(@company_id AS nvarchar(max))
DECLARE @sql nvarchar(max)
DECLARE @languages nvarchar(max)
DECLARE @complete nvarchar(max)

SELECT @languages = STUFF((
    SELECT
        t.name
    FROM
        (
        SELECT
            DISTINCT
            ', [' + t.language + ']' AS name
            , CASE
                WHEN t.language = 'en' THEN '1'
                WHEN t.language = 'fr' THEN '2'
                WHEN t.language = 'it' THEN '3'
                WHEN t.language = 'es' THEN '4'
                WHEN t.language = 'pt' THEN '5'
                WHEN t.language = 'de' THEN '6'
                WHEN t.language = 'ru' THEN '7'
                ELSE t.language
                END AS sort_order
        FROM
            dbo27.translations t
        WHERE
            t.company_id = @company_id
        ) t
    ORDER BY
        t.sort_order
    FOR XML PATH(''), TYPE).value('.', 'nvarchar(MAX)'), 1, 2, '')

IF @languages IS NULL SET @languages = '[en]'

DECLARE @default_language varchar(10) = (SELECT default_language FROM dbo27.companies WHERE id = @company_id)

IF @default_language IS NULL SET @languages = '  '

SELECT @complete = STUFF((
    SELECT
        t.name
    FROM
        (
        SELECT
            DISTINCT
            ' OR [' + t.language + '] IS NULL' AS name
            , CASE
                WHEN t.language = 'en' THEN '1'
                WHEN t.language = 'fr' THEN '2'
                WHEN t.language = 'it' THEN '3'
                WHEN t.language = 'es' THEN '4'
                WHEN t.language = 'pt' THEN '5'
                WHEN t.language = 'de' THEN '6'
                WHEN t.language = 'ru' THEN '7'
                ELSE t.language
                END AS sort_order
        FROM
            dbo27.translations t
        WHERE
            t.company_id = @company_id
            AND NOT t.language = @default_language
        ) t
    ORDER BY
        t.sort_order
    FOR XML PATH(''), TYPE).value('.', 'nvarchar(MAX)'), 1, 4, '')

IF @complete IS NULL SET @complete = '[en] IS NULL'

SET @sql = 'SELECT
    t.table_id
    , t.member_id
    , tt.name AS table_name
    , t.is_translatable
    , CASE WHEN t.is_translatable = 0 THEN 1 WHEN ' + @complete + ' THEN 0 ELSE 1 END AS is_complete
    , t.name
    , ' + @languages + '
FROM
    (
        SELECT
            m.sort_order
            , m.table_id
            , m.member_id
            , m.is_translatable
            , m.name
            , t.language
            , t.name AS translated_name
        FROM
            (
                SELECT 2 AS sort_order, 2 AS table_id, t.id AS member_id, t.name, 1 AS is_translatable FROM dbo27.companies t WHERE t.id = ' + @company_sid + '
                UNION ALL SELECT 3 AS sort_order, 3 AS table_id, t.id AS member_id, t.name, t.is_translatable FROM dbo27.units t WHERE t.company_id = ' + @company_sid + '
                UNION ALL SELECT 4 AS sort_order, 4 AS table_id, t.id AS member_id, t.name, t.is_translatable FROM dbo27.vat_rates t WHERE t.company_id = ' + @company_sid + '
                UNION ALL SELECT 5 AS sort_order, 5 AS table_id, t.id AS member_id, t.name, 1 AS is_translatable FROM dbo27.dimensions t
                UNION ALL SELECT 6 AS sort_order, 9 AS table_id, t.id AS member_id, t.description, 1 AS is_translatable FROM dbo27.report_sections t WHERE t.company_id = ' + @company_sid + '
                UNION ALL SELECT 7 AS sort_order, 10 AS table_id, t.id AS member_id, t.name, 1 AS is_translatable FROM dbo27.subsidiary_groups t WHERE t.company_id = ' + @company_sid + '
                UNION ALL SELECT 8 AS sort_order, 11 AS table_id, t.id AS member_id, t.name, 1 AS is_translatable FROM dbo27.ledger_accounts t WHERE t.company_id = ' + @company_sid + '
                UNION ALL SELECT 9 AS sort_order, 12 AS table_id, t.id AS member_id, t.name, 1 AS is_translatable FROM dbo27.saved_report_types t WHERE t.company_id = ' + @company_sid + '
                UNION ALL SELECT 10 AS sort_order, 1 AS table_id, t.id AS member_id, t.name, t.is_translatable FROM dbo27.members t WHERE t.company_id = ' + @company_sid + '
            ) m
            LEFT OUTER JOIN dbo27.translations t ON t.company_id = ' + @company_sid + ' AND t.table_id = m.table_id AND t.member_id = m.member_id
        WHERE
            m.name IS NOT NULL
    ) s PIVOT (
        MAX(translated_name) FOR language IN (' + @languages + ')
    ) t
    INNER JOIN dbo27.translated_tables tt ON tt.id = t.table_id'
    + CASE WHEN @is_complete IS NULL AND @is_translatable IS NULL THEN '' ELSE '
WHERE'
        + CASE WHEN @is_complete IS NULL THEN '' WHEN @is_complete = 1 THEN '
    NOT (' + @complete + ')'
            ELSE '
    (' + @complete + ')'
            END
        + CASE WHEN @is_translatable IS NULL THEN '' ELSE '
    '        + CASE WHEN @is_complete IS NULL THEN '' ELSE 'AND ' END + 't.is_translatable = ' + CASE WHEN @is_translatable = 1 THEN '1' ELSE '0' END
            END
        END    + '
ORDER BY
    t.sort_order
    , t.name'

-- PRINT @sql

EXEC (@sql)

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Cell change event handler for usp_translations
-- =============================================

CREATE PROCEDURE [xls27].[usp_translations_change]
    @company_id int = NULL
    , @table_id int = NULL
    , @member_id int = NULL
    , @column_name nvarchar(128) = NULL
    , @cell_value nvarchar(400) = NULL
    , @cell_number_value int = NULL
AS
BEGIN

SET NOCOUNT ON

DECLARE @company_id1 int = @company_id
DECLARE @current_name nvarchar(400) = NULL

IF @table_id = 1
    SELECT TOP 1 @company_id = u.company_id FROM dbo27.members t INNER JOIN dbo27.users u ON u.company_id = t.company_id  WHERE t.id = @member_id AND u.username = USER_NAME() AND u.is_active = 1
ELSE IF @table_id = 2
    SELECT TOP 1 @company_id = u.company_id FROM dbo27.companies t INNER JOIN dbo27.users u ON u.company_id = t.id  WHERE t.id = @member_id AND u.username = USER_NAME() AND u.is_active = 1
ELSE IF @table_id = 3
    SELECT TOP 1 @company_id = u.company_id FROM dbo27.units t INNER JOIN dbo27.users u ON u.company_id = t.company_id  WHERE t.id = @member_id AND u.username = USER_NAME() AND u.is_active = 1
ELSE IF @table_id = 4
    SELECT TOP 1 @company_id = u.company_id FROM dbo27.vat_rates t INNER JOIN dbo27.users u ON u.company_id = t.company_id  WHERE t.id = @member_id AND u.username = USER_NAME() AND u.is_active = 1
ELSE IF @table_id = 5
    SELECT TOP 1 @company_id = u.company_id FROM dbo27.companies t INNER JOIN dbo27.users u ON u.company_id = t.id  WHERE t.id = @company_id AND u.username = USER_NAME() AND u.is_active = 1
ELSE IF @table_id = 6
    SELECT TOP 1 @company_id = u.company_id FROM dbo27.companies t INNER JOIN dbo27.users u ON u.company_id = t.id  WHERE t.id = @company_id AND u.username = USER_NAME() AND u.is_active = 1
ELSE IF @table_id = 9
    SELECT TOP 1 @company_id = u.company_id FROM dbo27.report_sections t INNER JOIN dbo27.users u ON u.company_id = t.company_id  WHERE t.id = @member_id AND u.username = USER_NAME() AND u.is_active = 1
ELSE IF @table_id = 10
    SELECT TOP 1 @company_id = u.company_id FROM dbo27.subsidiary_groups t INNER JOIN dbo27.users u ON u.company_id = t.company_id  WHERE t.id = @member_id AND u.username = USER_NAME() AND u.is_active = 1
ELSE IF @table_id = 11
    SELECT TOP 1 @company_id = u.company_id FROM dbo27.ledger_accounts t INNER JOIN dbo27.users u ON u.company_id = t.company_id  WHERE t.id = @member_id AND u.username = USER_NAME() AND u.is_active = 1
ELSE IF @table_id = 12
    SELECT TOP 1 @company_id = u.company_id FROM dbo27.saved_report_types t INNER JOIN dbo27.users u ON u.company_id = t.company_id  WHERE t.id = @member_id AND u.username = USER_NAME() AND u.is_active = 1
ELSE
    RETURN

IF @company_id IS NULL OR @company_id1 IS NOT NULL AND NOT @company_id1 = @company_id
    RETURN

IF @column_name = 'is_translatable'
    BEGIN
    IF NOT @cell_number_value IN (0, 1) AND NOT @cell_number_value IS NULL
        RETURN

    IF @table_id = 1
        UPDATE dbo27.members SET is_translatable = @cell_number_value WHERE id = @member_id
    ELSE IF @table_id = 3
        UPDATE dbo27.units SET is_translatable = @cell_number_value WHERE id = @member_id
    ELSE IF @table_id = 4
        UPDATE dbo27.vat_rates SET is_translatable = @cell_number_value WHERE id = @member_id
    RETURN
    END

IF LEN(@column_name) <> 2
    RETURN

SET NOCOUNT OFF

IF @cell_value IS NULL
    BEGIN
    DELETE dbo27.translations
    WHERE
        company_id = @company_id AND table_id = @table_id AND member_id = @member_id AND language = @column_name
    RETURN
    END

UPDATE dbo27.translations
SET
    name = @cell_value
WHERE
    company_id = @company_id AND table_id = @table_id AND member_id = @member_id AND language = @column_name

IF @@ROWCOUNT > 0
    RETURN

IF @cell_value IS NULL
    RETURN

INSERT INTO dbo27.translations
    (company_id, table_id, member_id, language, name)
VALUES
    (@company_id, @table_id, @member_id, @column_name, @cell_value)

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Selects common elements with translations from xls.translations
-- =============================================

CREATE PROCEDURE [xls27].[usp_translations_common]
    @is_complete bit = NULL
WITH EXECUTE AS OWNER
AS
BEGIN

SET NOCOUNT ON;

DECLARE @sql nvarchar(max)
DECLARE @languages nvarchar(max)
DECLARE @complete nvarchar(max)

SELECT @languages = STUFF((
    SELECT
        t.name
    FROM
        (
        SELECT
            DISTINCT
            ', [' + t.LANGUAGE_NAME + ']' AS name
            , CASE
                WHEN t.LANGUAGE_NAME = 'en' THEN '1'
                WHEN t.LANGUAGE_NAME = 'fr' THEN '2'
                WHEN t.LANGUAGE_NAME = 'it' THEN '3'
                WHEN t.LANGUAGE_NAME = 'es' THEN '4'
                WHEN t.LANGUAGE_NAME = 'pt' THEN '5'
                WHEN t.LANGUAGE_NAME = 'de' THEN '6'
                WHEN t.LANGUAGE_NAME = 'ru' THEN '7'
                ELSE t.LANGUAGE_NAME
                END AS sort_order
        FROM
            xls.translations t
        ) t
    ORDER BY
        t.sort_order
    FOR XML PATH(''), TYPE).value('.', 'nvarchar(MAX)'), 1, 2, '')

IF @languages IS NULL SET @languages = '[en]'

SELECT @complete = STUFF((
    SELECT
        t.name
    FROM
        (
        SELECT
            DISTINCT
            ' OR [' + t.LANGUAGE_NAME + '] IS NULL' AS name
            , CASE
                WHEN t.LANGUAGE_NAME = 'en' THEN '1'
                WHEN t.LANGUAGE_NAME = 'fr' THEN '2'
                WHEN t.LANGUAGE_NAME = 'it' THEN '3'
                WHEN t.LANGUAGE_NAME = 'es' THEN '4'
                WHEN t.LANGUAGE_NAME = 'pt' THEN '5'
                WHEN t.LANGUAGE_NAME = 'de' THEN '6'
                WHEN t.LANGUAGE_NAME = 'ru' THEN '7'
                ELSE t.LANGUAGE_NAME
                END AS sort_order
        FROM
            xls.translations t
        ) t
    ORDER BY
        t.sort_order
    FOR XML PATH(''), TYPE).value('.', 'nvarchar(MAX)'), 1, 4, '')

IF @complete IS NULL SET @complete = '[en] IS NULL'

SET @sql = 'SELECT
    t.TABLE_SCHEMA
    , t.TABLE_NAME
    , CASE WHEN ' + @complete + ' THEN 0 ELSE 1 END AS is_complete
    , t.COLUMN_NAME AS [COLUMN]
    , ' + @languages + '
FROM
    (
        SELECT
            t.sort_order
            , t.TABLE_SCHEMA
            , t.TABLE_NAME
            , t.COLUMN_NAME
            , tr.LANGUAGE_NAME
            , tr.TRANSLATED_NAME AS name
        FROM
            (
                SELECT 1 AS sort_order, code AS COLUMN_NAME, ''dbo27'' AS TABLE_SCHEMA, ''report_types_code'' AS TABLE_NAME FROM dbo27.report_types
                UNION ALL SELECT 2 AS sort_order, name AS COLUMN_NAME, ''dbo27'' AS TABLE_SCHEMA, ''report_types_name'' AS TABLE_NAME FROM dbo27.report_types
                UNION ALL SELECT 3 AS sort_order, name AS COLUMN_NAME, ''dbo27'' AS TABLE_SCHEMA, ''report_section_types_name'' AS TABLE_NAME FROM dbo27.report_section_types
                UNION ALL SELECT 4 AS sort_order, name AS COLUMN_NAME, ''dbo27'' AS TABLE_SCHEMA, ''report_section_value_types_name'' AS TABLE_NAME FROM dbo27.report_section_value_types
                UNION ALL SELECT 5 AS sort_order, name AS COLUMN_NAME, ''dbo27'' AS TABLE_SCHEMA, ''report_section_total_types_name'' AS TABLE_NAME FROM dbo27.report_section_total_types
                UNION ALL SELECT 6 AS sort_order, name AS COLUMN_NAME, ''dbo27'' AS TABLE_SCHEMA, ''entry_sides_name'' AS TABLE_NAME FROM dbo27.entry_sides
                UNION ALL SELECT 7 AS sort_order, name AS COLUMN_NAME, ''dbo27'' AS TABLE_SCHEMA, ''ledger_account_types_name'' AS TABLE_NAME FROM dbo27.ledger_account_types
                UNION ALL SELECT 8 AS sort_order, name AS COLUMN_NAME, ''dbo27'' AS TABLE_SCHEMA, ''ledger_account_special_types_name'' AS TABLE_NAME FROM dbo27.ledger_account_special_types
                UNION ALL SELECT 9 AS sort_order, name AS COLUMN_NAME, ''dbo27'' AS TABLE_SCHEMA, ''member_types_name'' AS TABLE_NAME FROM dbo27.member_types
                UNION ALL SELECT * FROM (
                    SELECT
                        11 AS sort_order
                        , NULL AS COLUMN_NAME
                        , c.TABLE_SCHEMA
                        , c.TABLE_NAME
                    FROM
                        INFORMATION_SCHEMA.TABLES c
                    WHERE
                        c.TABLE_SCHEMA = ''xls27''
                    UNION ALL
                    SELECT
                        11 AS sort_order
                        , NULL AS COLUMN_NAME
                        , p.SPECIFIC_SCHEMA AS TABLE_SCHEMA
                        , p.SPECIFIC_NAME AS TABLE_NAME
                    FROM
                        INFORMATION_SCHEMA.ROUTINES p
                    WHERE
                        p.SPECIFIC_SCHEMA = ''xls27''
                        AND p.ROUTINE_TYPE = ''PROCEDURE''
                        AND NOT p.SPECIFIC_NAME LIKE ''%_insert''
                        AND NOT p.SPECIFIC_NAME LIKE ''%_update''
                        AND NOT p.SPECIFIC_NAME LIKE ''%_delete''
                        AND NOT p.SPECIFIC_NAME LIKE ''%_change''
                        AND NOT p.SPECIFIC_NAME LIKE ''%_merge''
                        AND NOT p.SPECIFIC_NAME LIKE ''usp_import_%''
                        AND NOT p.SPECIFIC_NAME LIKE ''usp_export_%''
                        AND NOT p.SPECIFIC_NAME LIKE ''xl_parameter_values_%''
                        AND NOT p.SPECIFIC_NAME LIKE ''xl_validation_list_%''
                        AND NOT p.SPECIFIC_NAME LIKE ''usp_update_table_format''
                    ) c' + '
                UNION ALL SELECT * FROM (
                    SELECT
                        12 AS sort_order
                        , c.COLUMN_NAME
                        , ''xls27'' AS TABLE_SCHEMA
                        , NULL AS TABLE_NAME
                    FROM
                        INFORMATION_SCHEMA.COLUMNS c
                    WHERE
                        c.TABLE_SCHEMA = ''dbo27''
                        AND NOT c.TABLE_NAME IN (''xl_automatic_handlers'', ''xl_online_help_handlers'')
                        AND NOT c.TABLE_NAME LIKE ''view_query_list%''
                    UNION
                    SELECT
                        12 AS sort_order
                        , SUBSTRING(p.PARAMETER_NAME, 2, 127) AS COLUMN_NAME
                        , p.SPECIFIC_SCHEMA AS TABLE_SCHEMA
                        , NULL AS TABLE_NAME
                    FROM
                        INFORMATION_SCHEMA.PARAMETERS p
                        INNER JOIN INFORMATION_SCHEMA.ROUTINES r ON r.SPECIFIC_SCHEMA = p.SPECIFIC_SCHEMA AND r.SPECIFIC_NAME = p.SPECIFIC_NAME
                    WHERE
                        p.SPECIFIC_SCHEMA = ''xls27''
                        AND r.ROUTINE_TYPE = ''PROCEDURE''
                        AND p.ORDINAL_POSITION > 0
                        AND NOT p.SPECIFIC_NAME LIKE ''%_insert''
                        AND NOT p.SPECIFIC_NAME LIKE ''%_update''
                        AND NOT p.SPECIFIC_NAME LIKE ''%_delete''
                        AND NOT p.SPECIFIC_NAME LIKE ''%_change''
                        AND NOT p.SPECIFIC_NAME LIKE ''%_merge''
                        AND NOT p.SPECIFIC_NAME LIKE ''usp_import_%''
                        AND NOT p.SPECIFIC_NAME LIKE ''usp_export_%''
                        AND NOT p.SPECIFIC_NAME LIKE ''xl_parameter_values_%''
                        AND NOT p.SPECIFIC_NAME LIKE ''xl_validation_list_%''
                        AND NOT p.SPECIFIC_NAME LIKE ''usp_update_table_format''
                        AND NOT p.PARAMETER_NAME IN (''@data_language'')
                    ) c
            ) t
            LEFT OUTER JOIN xls.translations tr ON
                tr.TABLE_SCHEMA = t.TABLE_SCHEMA
                AND (tr.TABLE_NAME = t.TABLE_NAME OR tr.TABLE_NAME IS NULL AND t.TABLE_NAME IS NULL)
                AND (tr.COLUMN_NAME = t.COLUMN_NAME OR tr.COLUMN_NAME IS NULL AND t.COLUMN_NAME IS NULL)
    ) s' + ' PIVOT (
        MAX(name) FOR LANGUAGE_NAME IN (' + @languages + ')
    ) t'
    + CASE WHEN @is_complete IS NULL THEN '' WHEN @is_complete = 1 THEN '
WHERE
    NOT (' + @complete + ')'
    ELSE '
WHERE
    ' + @complete END + '
ORDER BY
    t.sort_order
    , t.TABLE_SCHEMA
    , t.TABLE_NAME
    , t.COLUMN_NAME'

DECLARE @print int = 0

IF @print = 1
    BEGIN
    PRINT SUBSTRING(@sql, 1, 4000)
    IF LEN(@sql) > 4000  PRINT SUBSTRING(@sql, 4001, 4000)
    IF LEN(@sql) > 8000  PRINT SUBSTRING(@sql, 8001, 4000)
    IF LEN(@sql) > 12000 PRINT SUBSTRING(@sql, 12001, 4000)
    END

EXEC (@sql)

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Selects translations from xls.translations
-- =============================================

CREATE PROCEDURE [xls27].[usp_translations_xls]
    @field nvarchar(128) = NULL
    , @schema nvarchar(128) = NULL
    , @is_complete bit = NULL
AS
BEGIN

SET NOCOUNT ON;

IF @field IS NULL
    SET @field = 'TRANSLATED_NAME'
ELSE IF @field NOT IN ('TRANSLATED_NAME', 'TRANSLATED_DESC', 'TRANSLATED_COMMENT')
    BEGIN
    SELECT
        t.TABLE_SCHEMA
        , t.TABLE_NAME
        , 0 AS is_complete
        , t.COLUMN_NAME AS [COLUMN]
    FROM
        xls.translations t
    WHERE
        t.ID IS NULL

    DECLARE @message nvarchar(max) = N'Invalid column name: %s' + CHAR(13) + CHAR(10)
         + 'Use TRANSLATED_NAME, TRANSLATED_DESC, or TRANSLATED_COMMENT'
    RAISERROR(@message, 11, 0, @field);
    RETURN
    END

DECLARE @sql nvarchar(max)
DECLARE @languages nvarchar(max)
DECLARE @complete nvarchar(max)

SELECT @languages = STUFF((
    SELECT
        t.name
    FROM
        (
        SELECT
            DISTINCT
            ', [' + t.LANGUAGE_NAME + ']' AS name
            , CASE
                WHEN t.LANGUAGE_NAME = 'en' THEN '1'
                WHEN t.LANGUAGE_NAME = 'fr' THEN '2'
                WHEN t.LANGUAGE_NAME = 'it' THEN '3'
                WHEN t.LANGUAGE_NAME = 'es' THEN '4'
                WHEN t.LANGUAGE_NAME = 'pt' THEN '5'
                WHEN t.LANGUAGE_NAME = 'de' THEN '6'
                WHEN t.LANGUAGE_NAME = 'ru' THEN '7'
                ELSE t.LANGUAGE_NAME
                END AS sort_order
        FROM
            xls.translations t
        ) t
    ORDER BY
        t.sort_order
    FOR XML PATH(''), TYPE).value('.', 'nvarchar(MAX)'), 1, 2, '')

IF @languages IS NULL SET @languages = '[en]'

SELECT @complete = STUFF((
    SELECT
        t.name
    FROM
        (
        SELECT
            DISTINCT
            ' OR [' + t.LANGUAGE_NAME + '] IS NULL' AS name
            , CASE
                WHEN t.LANGUAGE_NAME = 'en' THEN '1'
                WHEN t.LANGUAGE_NAME = 'fr' THEN '2'
                WHEN t.LANGUAGE_NAME = 'it' THEN '3'
                WHEN t.LANGUAGE_NAME = 'es' THEN '4'
                WHEN t.LANGUAGE_NAME = 'pt' THEN '5'
                WHEN t.LANGUAGE_NAME = 'de' THEN '6'
                WHEN t.LANGUAGE_NAME = 'ru' THEN '7'
                ELSE t.LANGUAGE_NAME
                END AS sort_order
        FROM
            xls.translations t
        ) t
    ORDER BY
        t.sort_order
    FOR XML PATH(''), TYPE).value('.', 'nvarchar(MAX)'), 1, 4, '')

IF @complete IS NULL SET @complete = '[en] IS NULL'

SET @sql = 'SELECT
    t.TABLE_SCHEMA
    , t.TABLE_NAME
    , CASE WHEN ' + @complete + ' THEN 0 ELSE 1 END AS is_complete
    , t.COLUMN_NAME AS [COLUMN]
    , ' + @languages + '
FROM
    (
        SELECT
            t.TABLE_SCHEMA
            , t.TABLE_NAME
            , t.COLUMN_NAME
            , t.LANGUAGE_NAME
            , t.' + @field + ' AS name
        FROM
            xls.translations t'
        + CASE WHEN @schema IS NULL THEN '' ELSE '
        WHERE
            ' + CASE WHEN LEFT(@schema, 1) = '(' AND RIGHT(@schema, 1) = ')' THEN 't.TABLE_SCHEMA IN ' + @schema
                ELSE 'COALESCE(t.TABLE_SCHEMA, '''') = COALESCE(' + COALESCE('''' + @schema + '''', 'NULL') + ', t.TABLE_SCHEMA, '''')'
                END
            END + '
    ) s PIVOT (
        MAX(name) FOR LANGUAGE_NAME IN (' + @languages + ')
    ) t'
    + CASE WHEN @is_complete IS NULL THEN '' WHEN @is_complete = 1 THEN '
WHERE
    NOT (' + @complete + ')'
    ELSE '
WHERE
    ' + @complete END + '
ORDER BY
    t.TABLE_SCHEMA
    , t.TABLE_NAME
    , t.COLUMN_NAME'

-- PRINT @sql

EXEC (@sql)

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Cell change event handler for usp_translations
--
-- @column_name is a column name of the edited cell
-- @cell_value is a new cell value
-- @field is a value of the field parameter of the usp_translations
-- @TABLE_SCHEMA, @TABLE_NAME, and @COLUMN are values of the Excel table columns
-- =============================================

CREATE PROCEDURE [xls27].[usp_translations_xls_change]
    @column_name nvarchar(128) = NULL
    , @cell_value nvarchar(max) = NULL
    , @TABLE_SCHEMA nvarchar(128) = NULL
    , @TABLE_NAME nvarchar(128) = NULL
    , @COLUMN nvarchar(128) = NULL
    , @field nvarchar(128) = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

DECLARE @message nvarchar(max)

IF NOT EXISTS(SELECT TOP 1 ID FROM xls.translations WHERE LANGUAGE_NAME = @column_name)
    RETURN

IF @field IS NULL SET @field = 'TRANSLATED_NAME'

IF @field = 'TRANSLATED_NAME'
    UPDATE xls.translations SET TRANSLATED_NAME = @cell_value
        WHERE COALESCE(TABLE_SCHEMA, '') = COALESCE(@TABLE_SCHEMA, '') AND COALESCE(TABLE_NAME, '') = COALESCE(@TABLE_NAME, '')
            AND COALESCE(COLUMN_NAME, '') = COALESCE(@COLUMN, '') AND LANGUAGE_NAME = @column_name
ELSE IF @field = 'TRANSLATED_DESC'
    UPDATE xls.translations SET TRANSLATED_DESC = @cell_value
        WHERE COALESCE(TABLE_SCHEMA, '') = COALESCE(@TABLE_SCHEMA, '') AND COALESCE(TABLE_NAME, '') = COALESCE(@TABLE_NAME, '')
            AND COALESCE(COLUMN_NAME, '') = COALESCE(@COLUMN, '') AND LANGUAGE_NAME = @column_name
ELSE IF @field = 'TRANSLATED_COMMENT'
    UPDATE xls.translations SET TRANSLATED_COMMENT = @cell_value
        WHERE COALESCE(TABLE_SCHEMA, '') = COALESCE(@TABLE_SCHEMA, '') AND COALESCE(TABLE_NAME, '') = COALESCE(@TABLE_NAME, '')
            AND COALESCE(COLUMN_NAME, '') = COALESCE(@COLUMN, '') AND LANGUAGE_NAME = @column_name
ELSE
    BEGIN
    SET @message = dbo27.get_translated_string('Invalid column name: %s', @data_language)
        + CHAR(13) + CHAR(10)
        + dbo27.get_translated_string('Use TRANSLATED_NAME, TRANSLATED_DESC, or TRANSLATED_COMMENT', @data_language)
    RAISERROR(@message, 11, 0, @field);
    RETURN
    END

IF @@ROWCOUNT > 0 RETURN

IF @cell_value IS NULL RETURN

IF @field = 'TRANSLATED_NAME'
    INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME)
        VALUES (@TABLE_SCHEMA, @TABLE_NAME, @COLUMN, @column_name, @cell_value)
ELSE IF @field = 'TRANSLATED_DESC'
    INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_DESC)
        VALUES (@TABLE_SCHEMA, @TABLE_NAME, @COLUMN, @column_name, @cell_value)
ELSE IF @field = 'TRANSLATED_COMMENT'
    INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_COMMENT)
        VALUES (@TABLE_SCHEMA, @TABLE_NAME, @COLUMN, @column_name, @cell_value)

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Selects units
-- =============================================

CREATE PROCEDURE [xls27].[usp_units]
    @company_id int = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

SELECT
    t.id
    , t.code
    , t.name
    , tr.name AS translated_name
    , t.sort_order
    , t.factor
    , t.is_currency
    , t.is_functional_currency
    , t.is_base_currency
    , t.is_active
FROM
    dbo27.units t
    LEFT OUTER JOIN dbo27.translations tr ON tr.company_id = t.company_id AND tr.table_id = 3 AND tr.member_id = t.id AND tr.language = @data_language
WHERE
    t.company_id = @company_id
ORDER BY
    t.sort_order
    , t.code

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Delete procedure for usp_units
-- =============================================

CREATE PROCEDURE [xls27].[usp_units_delete]
    @id int = NULL
AS
BEGIN

SET NOCOUNT ON

IF NOT EXISTS (SELECT TOP 1 u.company_id FROM dbo27.units t INNER JOIN dbo27.users u ON u.company_id = t.company_id  WHERE t.id = @id AND u.username = USER_NAME() AND u.is_active = 1)
    RETURN

SET NOCOUNT OFF

DELETE dbo27.units WHERE id = @id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Insert procedure for usp_units
-- =============================================

CREATE PROCEDURE [xls27].[usp_units_insert]
    @company_id int = NULL
    , @code nvarchar(50)
    , @name nvarchar(100)
    , @translated_name nvarchar(100) = NULL
    , @sort_order int = NULL
    , @factor float = NULL
    , @is_currency bit = NULL
    , @is_functional_currency bit = NULL
    , @is_base_currency bit = NULL
    , @is_active bit = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

IF @company_id IS NULL
    RETURN

SET @code = LTRIM(RTRIM(@code))
SET @name = LTRIM(RTRIM(@name))

SET NOCOUNT OFF

INSERT INTO dbo27.units
    ( company_id
    , code
    , name
    , sort_order
    , factor
    , is_currency
    , is_functional_currency
    , is_base_currency
    , is_active
    )
VALUES
    ( @company_id
    , @code
    , @name
    , COALESCE(@sort_order, 0)
    , COALESCE(@factor, 1)
    , COALESCE(@is_currency, 1)
    , COALESCE(@is_functional_currency, 1)
    , COALESCE(@is_base_currency, 0)
    , COALESCE(@is_active, 1)
    )

DECLARE @id int = SCOPE_IDENTITY()

IF @data_language IS NOT NULL AND @translated_name IS NOT NULL
    INSERT INTO dbo27.translations
        (company_id, table_id, member_id, language, name)
    VALUES
        (@company_id, 3, @id, @data_language, @translated_name)
END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Update procedure for usp_units
-- =============================================

CREATE PROCEDURE [xls27].[usp_units_update]
    @id int = NULL
    , @code nvarchar(50)
    , @name nvarchar(100)
    , @translated_name nvarchar(100) = NULL
    , @sort_order int = NULL
    , @factor float = NULL
    , @is_currency bit = NULL
    , @is_functional_currency bit = NULL
    , @is_base_currency bit = NULL
    , @is_active bit = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

DECLARE @company_id int
DECLARE @current_name nvarchar(100)

SELECT TOP 1 @company_id = u.company_id, @current_name = t.name FROM dbo27.units t INNER JOIN dbo27.users u ON u.company_id = t.company_id  WHERE t.id = @id AND u.username = USER_NAME() AND u.is_active = 1

IF @company_id IS NULL
    RETURN

SET @code = LTRIM(RTRIM(@code))
SET @name = LTRIM(RTRIM(@name))

SET NOCOUNT OFF

UPDATE dbo27.units
SET
    code = @code
    , name = @name
    , sort_order = COALESCE(@sort_order, 0)
    , factor = COALESCE(@factor, 1)
    , is_currency = COALESCE(@is_currency, 1)
    , is_functional_currency = COALESCE(@is_functional_currency, 0)
    , is_base_currency = COALESCE(@is_base_currency, 0)
    , is_active = COALESCE(@is_active, 1)
WHERE
    id = @id
    AND NOT (
        COALESCE(code, '-1') = COALESCE(@code, '-2')
        AND COALESCE(name, '-1') = COALESCE(@name, '-2')
        AND COALESCE(sort_order, -1) = COALESCE(@sort_order, -2)
        AND COALESCE(factor, -1) = COALESCE(@factor, -2)
        AND COALESCE(is_currency, -1) = COALESCE(@is_currency, -2)
        AND COALESCE(is_functional_currency, -1) = COALESCE(@is_functional_currency, -2)
        AND COALESCE(is_base_currency, -1) = COALESCE(@is_currency, -2)
        AND COALESCE(is_active, -1) = COALESCE(@is_active, -2)
        )

IF @data_language IS NOT NULL AND @translated_name IS NOT NULL
    BEGIN
    MERGE dbo27.translations t
    USING
        (
        SELECT company_id = @company_id, 3 AS table_id, @id AS member_id, @data_language AS language, @translated_name AS name
        ) s ON s.company_id = t.company_id AND s.table_id = t.table_id AND s.member_id = t.member_id AND s.language = t.language
    WHEN MATCHED AND NOT COALESCE(t.name, '') = COALESCE(s.name, '') THEN
        UPDATE SET name = s.name
    WHEN NOT MATCHED THEN
        INSERT (company_id, table_id, member_id, language, name) VALUES (s.company_id, s.table_id, s.member_id, s.language, s.name);
    END

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Selects users
-- =============================================

CREATE PROCEDURE [xls27].[usp_users]
    @company_id int = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

SELECT
    c.username
    , c.name
    , c.is_admin
    , c.is_active
    , c.is_default
FROM
    dbo27.users c
WHERE
    c.company_id = @company_id
ORDER BY
    c.username

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Delete procedure for usp_users
-- =============================================

CREATE PROCEDURE [xls27].[usp_users_delete]
    @company_id int = NULL
    , @username nvarchar(128) = NULL
AS
BEGIN

SET NOCOUNT ON

IF NOT EXISTS (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1 AND is_admin = 1)
    RETURN

SET NOCOUNT OFF

DELETE dbo27.users WHERE company_id = @company_id AND username = @username

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Insert procedure for usp_users
-- =============================================

CREATE PROCEDURE [xls27].[usp_users_insert]
    @company_id int = NULL
    , @username nvarchar(128) = NULL
    , @name nvarchar(100) = NULL
    , @is_admin bit = NULL
    , @is_active bit = NULL
    , @is_default bit = NULL
AS
BEGIN

SET NOCOUNT ON

IF NOT EXISTS (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1 AND is_admin = 1)
    RETURN

SET @username = LTRIM(RTRIM(@username))
SET @name = LTRIM(RTRIM(@name))

IF @is_default IS NULL
    SET @is_default = CASE WHEN EXISTS(SELECT company_id FROM dbo27.users WHERE username = @username) THEN 0 ELSE 1 END

SET NOCOUNT OFF

INSERT INTO dbo27.users (company_id, username, name, is_admin, is_active, is_default) VALUES (@company_id, @username, @name, COALESCE(@is_admin, 0), COALESCE(@is_active, 1), @is_default)

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Update procedure for usp_users
-- =============================================

CREATE PROCEDURE [xls27].[usp_users_update]
    @company_id int = NULL
    , @username nvarchar(128) = NULL
    , @name nvarchar(100) = NULL
    , @is_admin bit = NULL
    , @is_active bit = NULL
    , @is_default bit = NULL
AS
BEGIN

SET NOCOUNT ON

IF NOT EXISTS (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1 AND is_admin = 1)
    RETURN

SET @username = LTRIM(RTRIM(@username))
SET @name = LTRIM(RTRIM(@name))

SET NOCOUNT OFF

UPDATE dbo27.users
SET
    name = @name
    , is_admin = @is_admin
    , is_active = @is_active
    , is_default = @is_default
FROM
    dbo27.users c
WHERE
    c.company_id = @company_id
    AND c.username = @username
    AND NOT (
        COALESCE(name, '-1') = COALESCE(@name, '-2')
        AND COALESCE(is_admin, -1) = COALESCE(@is_admin, -2)
        AND COALESCE(is_active, -1) = COALESCE(@is_active, -2)
        AND COALESCE(is_default, -1) = COALESCE(@is_default, -2)
        )

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Selects vat_rates
-- =============================================

CREATE PROCEDURE [xls27].[usp_vat_rates]
    @company_id int = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

SELECT
    t.id
    , t.code
    , t.name
    , tr.name AS translated_name
    , t.sort_order
    , t.factor
    , t.is_active
FROM
    dbo27.vat_rates t
    LEFT OUTER JOIN dbo27.translations tr ON tr.company_id = t.company_id AND tr.table_id = 4 AND tr.member_id = t.id AND tr.language = @data_language
WHERE
    t.company_id = @company_id
ORDER BY
    t.sort_order
    , t.code

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Delete procedure for usp_vat_rates
-- =============================================

CREATE PROCEDURE [xls27].[usp_vat_rates_delete]
    @id int = NULL
AS
BEGIN

SET NOCOUNT ON

IF NOT EXISTS (SELECT TOP 1 u.company_id FROM dbo27.vat_rates t INNER JOIN dbo27.users u ON u.company_id = t.company_id  WHERE t.id = @id AND u.username = USER_NAME() AND u.is_active = 1)
    RETURN

SET NOCOUNT OFF

DELETE dbo27.vat_rates WHERE id = @id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Insert procedure for usp_vat_rates
-- =============================================

CREATE PROCEDURE [xls27].[usp_vat_rates_insert]
    @company_id int = NULL
    , @code nvarchar(50)
    , @name nvarchar(100)
    , @translated_name nvarchar(100) = NULL
    , @sort_order int = NULL
    , @factor float = NULL
    , @is_active bit = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

IF @company_id IS NULL
    RETURN

SET @code = LTRIM(RTRIM(@code))
SET @name = LTRIM(RTRIM(@name))

SET NOCOUNT OFF

INSERT INTO dbo27.vat_rates
    ( company_id
    , code
    , name
    , sort_order
    , factor
    , is_active
    )
VALUES
    ( @company_id
    , @code
    , @name
    , COALESCE(@sort_order, 0)
    , COALESCE(@factor, 1)
    , COALESCE(@is_active, 1)
    )

DECLARE @id int = SCOPE_IDENTITY()

IF @data_language IS NOT NULL AND @translated_name IS NOT NULL
    INSERT INTO dbo27.translations
        (company_id, table_id, member_id, language, name)
    VALUES
        (@company_id, 4, @id, @data_language, @translated_name)

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Update procedure for usp_vat_rates
-- =============================================

CREATE PROCEDURE [xls27].[usp_vat_rates_update]
    @id int = NULL
    , @code nvarchar(50)
    , @name nvarchar(100)
    , @translated_name nvarchar(100) = NULL
    , @sort_order int = NULL
    , @factor float = NULL
    , @is_active bit = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

DECLARE @company_id int
DECLARE @current_name nvarchar(100)

SELECT TOP 1 @company_id = u.company_id, @current_name = t.name FROM dbo27.vat_rates t INNER JOIN dbo27.users u ON u.company_id = t.id  WHERE t.id = @id AND u.username = USER_NAME() AND u.is_active = 1

IF @company_id IS NULL
    RETURN

SET @code = LTRIM(RTRIM(@code))
SET @name = LTRIM(RTRIM(@name))

SET NOCOUNT OFF

UPDATE dbo27.vat_rates
SET
    code = @code
    , name = @name
    , sort_order = COALESCE(@sort_order, 0)
    , factor = COALESCE(@factor, 1)
    , is_active = COALESCE(@is_active, 1)
WHERE
    id = @id
    AND NOT (
        COALESCE(code, '-1') = COALESCE(@code, '-2')
        AND COALESCE(name, '-1') = COALESCE(@name, '-2')
        AND COALESCE(sort_order, -1) = COALESCE(@sort_order, -2)
        AND COALESCE(factor, -1) = COALESCE(@factor, -2)
        AND COALESCE(is_active, -1) = COALESCE(@is_active, -2)
        )

IF @data_language IS NOT NULL AND @translated_name IS NOT NULL
    BEGIN
    MERGE dbo27.translations t
    USING
        (
        SELECT company_id = @company_id, 4 AS table_id, @id AS member_id, @data_language AS language, @translated_name AS name
        ) s ON s.company_id = t.company_id AND s.table_id = t.table_id AND s.member_id = t.member_id AND s.language = t.language
    WHEN MATCHED AND NOT COALESCE(t.name, '') = COALESCE(s.name, '') THEN
        UPDATE SET name = s.name
    WHEN NOT MATCHED THEN
        INSERT (company_id, table_id, member_id, language, name) VALUES (s.company_id, s.table_id, s.member_id, s.language, s.name);
    END

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: The procedure selects report cell data to an Excel window
-- =============================================

CREATE PROCEDURE [xls27].[xl_actions_actual_report_cell_data]
    @company_id int = NULL
    , @year int = NULL
    , @entity_id int = NULL
    , @report int = NULL
    , @ref_number int = NULL
    , @account nvarchar(50) = NULL
    , @code1 nvarchar(50) = NULL
    , @code2 nvarchar(50) = NULL
    , @column_name nvarchar(128) = NULL
    , @data_language varchar(10) = NULL
WITH EXECUTE AS OWNER
AS
BEGIN

SET NOCOUNT ON

IF @year IS NULL SET @year = YEAR(GETDATE())

-- Checking the company

EXECUTE AS CALLER

SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

REVERT

-- Getting account_id and member_id using code1 and code2

DECLARE @report_type_id int, @account_id int, @member_id int

IF @report IS NOT NULL SELECT @report_type_id = id FROM dbo27.report_types WHERE id = @report

IF @account IS NOT NULL SELECT @account_id = id FROM dbo27.ledger_accounts WHERE company_id = @company_id AND code = @account

IF @code1 IS NOT NULL SELECT @member_id = id FROM dbo27.members WHERE company_id = @company_id AND code = @code1
IF @code2 IS NOT NULL SELECT @member_id = id FROM dbo27.members WHERE company_id = @company_id AND code = @code2

-- If any required value is NULL then return an empty result immediately

IF @company_id IS NULL OR @report_type_id IS NULL
    OR @account_id IS NULL AND @ref_number IS NULL
    BEGIN
    SELECT
        j.id
        , j.date
        , d.code AS debit
        , c.code AS credit
        , j.amount$ AS amount
        , COALESCE(users.name, j.modified_by) AS last_user
        , j.modified_on AS last_update
    FROM
        dbo27.journals j
        INNER JOIN dbo27.ledger_accounts d ON d.id = j.debit_account_id
        INNER JOIN dbo27.ledger_accounts c ON c.id = j.credit_account_id
        LEFT OUTER JOIN dbo27.users users ON users.company_id = j.company_id AND users.username = j.modified_by
    WHERE
        j.id IS NULL
    RETURN
    END

DECLARE @start_date date
DECLARE @end_date date

DECLARE @index int

SET @index = CHARINDEX(@column_name, '       data01, data02, data03, data04, data05, data06, data07, data08, data09, data10, data11')

IF @index > 0
    BEGIN
    SET @start_date = DATEFROMPARTS(@year, @index / 8, 1)
    SET @end_date = DATEADD(D, -1, DATEFROMPARTS(@year, @index / 8 + 1, 1))
    END
ELSE IF @column_name = 'data12'
    BEGIN
    SET @start_date = DATEFROMPARTS(@year, 12, 1)
    SET @end_date = DATEFROMPARTS(@year, 12, 31)
    END
ELSE
    BEGIN
    SET @start_date = DATEFROMPARTS(@year, 1, 1)
    SET @end_date = DATEFROMPARTS(@year, 12, 31)
    END

IF @account_id IS NOT NULL
    BEGIN
    SELECT
        j.id
        , CAST(j.date AS datetime) AS date
        , d.code AS debit
        , c.code AS credit
        , CAST(j.amount AS float) AS amount
        , ds.name AS debit_subsidiary_account
        , dc.name AS credit_subsidiary_account
        , j.description
        , COALESCE(dc.name, cc.name) AS currency
        , cr.rate
        , CAST(j.amount$ AS float) AS amount$
        , m4.code AS entity
        , m1.code AS account
        , m5.code AS region
        , m6.code AS product
        , COALESCE(users.name, j.modified_by) AS last_user
        , j.modified_on AS last_update
    FROM
        dbo27.journals j
        INNER JOIN dbo27.ledger_accounts d ON d.id = j.debit_account_id
        INNER JOIN dbo27.ledger_accounts c ON c.id = j.credit_account_id
        LEFT OUTER JOIN dbo27.members ds ON ds.id = j.debit_subsidiary_account_id
        LEFT OUTER JOIN dbo27.members cs ON cs.id = j.credit_subsidiary_account_id
        LEFT OUTER JOIN dbo27.units dc ON dc.id = ds.id AND dc.is_functional_currency = 0
        LEFT OUTER JOIN dbo27.units cc ON cc.id = cs.id AND cc.is_functional_currency = 0
        LEFT OUTER JOIN dbo27.actual_currency_rates cr ON cr.currency_id = COALESCE(dc.id, cc.id) AND cr.date = j.date
        INNER JOIN dbo27.report_section_accounts rsa ON rsa.account_type_id = d.account_type_id AND rsa.entry_side_id = 1 AND (rsa.pair_account_type_id IS NULL OR rsa.pair_account_type_id = c.account_type_id)
        INNER JOIN dbo27.report_sections rs ON rs.company_id = j.company_id AND rs.section_type_id = rsa.section_type_id
        INNER JOIN dbo27.report_section_types rst ON rst.id = rs.section_type_id
        LEFT OUTER JOIN dbo27.members m1 ON m1.id = j.account_id
        LEFT OUTER JOIN dbo27.members m4 ON m4.id = j.[entity_id]
        LEFT OUTER JOIN dbo27.members m5 ON m5.id = j.region_id
        LEFT OUTER JOIN dbo27.members m6 ON m6.id = j.product_id
        LEFT OUTER JOIN dbo27.members m7 ON m7.id = j.debit_subsidiary_account_id
        LEFT OUTER JOIN dbo27.users users ON users.company_id = m1.company_id AND users.username = j.modified_by
    WHERE
        rs.company_id = @company_id
        AND rst.report_type_id = @report_type_id
        AND d.id = @account_id
        AND rs.ref_number + COALESCE(d.ref_number, 0) = @ref_number
        AND COALESCE(j.entity_id, -1) = COALESCE(@entity_id, j.entity_id, -1)
        AND j.date <= @end_date
        AND (rsa.value_type_id = 1 AND j.date >= @start_date OR NOT rsa.value_type_id = 1)
        AND NOT c.account_type_id = 150
    UNION ALL
    SELECT
        j.id
        , CAST(j.date AS datetime) AS date
        , d.code AS debit
        , c.code AS credit
        , CAST(j.amount AS float) AS amount
        , ds.name AS debit_subsidiary_account
        , dc.name AS credit_subsidiary_account
        , j.description
        , COALESCE(dc.name, cc.name) AS currency
        , cr.rate
        , CAST(j.amount$ AS float) AS amount$
        , m4.code AS entity
        , m1.code AS account
        , m5.code AS region
        , m6.code AS product
        , COALESCE(users.name, j.modified_by) AS last_user
        , j.modified_on AS last_update
    FROM
        dbo27.journals j
        INNER JOIN dbo27.ledger_accounts d ON d.id = j.debit_account_id
        INNER JOIN dbo27.ledger_accounts c ON c.id = j.credit_account_id
        LEFT OUTER JOIN dbo27.members ds ON ds.id = j.debit_subsidiary_account_id
        LEFT OUTER JOIN dbo27.members cs ON cs.id = j.credit_subsidiary_account_id
        LEFT OUTER JOIN dbo27.units dc ON dc.id = ds.id AND dc.is_functional_currency = 0
        LEFT OUTER JOIN dbo27.units cc ON cc.id = cs.id AND cc.is_functional_currency = 0
        LEFT OUTER JOIN dbo27.actual_currency_rates cr ON cr.currency_id = COALESCE(dc.id, cc.id) AND cr.date = j.date
        INNER JOIN dbo27.report_section_accounts rsa ON rsa.account_type_id = c.account_type_id AND rsa.entry_side_id = 2 AND (rsa.pair_account_type_id IS NULL OR rsa.pair_account_type_id = d.account_type_id)
        INNER JOIN dbo27.report_sections rs ON rs.company_id = j.company_id AND rs.section_type_id = rsa.section_type_id
        INNER JOIN dbo27.report_section_types rst ON rst.id = rs.section_type_id
        LEFT OUTER JOIN dbo27.members m1 ON m1.id = j.account_id
        LEFT OUTER JOIN dbo27.members m4 ON m4.id = j.[entity_id]
        LEFT OUTER JOIN dbo27.members m5 ON m5.id = j.region_id
        LEFT OUTER JOIN dbo27.members m6 ON m6.id = j.product_id
        LEFT OUTER JOIN dbo27.members m7 ON m7.id = j.debit_subsidiary_account_id
        LEFT OUTER JOIN dbo27.users users ON users.company_id = m1.company_id AND users.username = j.modified_by
    WHERE
        rs.company_id = @company_id
        AND rst.report_type_id = @report_type_id
        AND c.id = @account_id
        AND rs.ref_number + COALESCE(c.ref_number, 0) = @ref_number
        AND COALESCE(j.entity_id, -1) = COALESCE(@entity_id, j.entity_id, -1)
        AND j.date <= @end_date
        AND (rsa.value_type_id = 1 AND j.date >= @start_date OR NOT rsa.value_type_id = 1)
        AND NOT d.account_type_id = 150
    UNION ALL
    SELECT
        NULL AS id
        , NULL AS date
        , CASE WHEN s.id = 1 THEN a.code ELSE NULL END AS debit
        , CASE WHEN s.id = 1 THEN NULL ELSE a.code END AS credit
        , CAST(CASE WHEN s.id = 1 AND r.balance > 0 THEN r.balance WHEN s.id = 2 AND r.balance < 0 THEN -r.balance ELSE NULL END AS float) AS amount
        , CASE WHEN s.id = 1 THEN sa.name ELSE NULL END AS debit_subsidiary_account
        , CASE WHEN s.id = 1 THEN NULL ELSE sa.name END AS credit_subsidiary_account
        , 'Opening Balance' AS description
        , c.name AS currency
        , cr.rate
        , CAST(CASE WHEN s.id = 1 AND r.balance$ > 0 THEN r.balance$ WHEN s.id = 2 AND r.balance$ < 0 THEN -r.balance$ ELSE NULL END AS float) AS amount$
        , NULL AS entity
        , NULL AS account
        , NULL AS region
        , NULL AS product
        , COALESCE(users.name, r.modified_by) AS last_user
        , r.modified_on AS last_update
    FROM
        dbo27.actual_balances r
        INNER JOIN dbo27.ledger_accounts a ON a.id = r.account_id
        LEFT OUTER JOIN dbo27.members sa ON sa.id = r.subsidiary_account_id
        LEFT OUTER JOIN dbo27.units c ON c.id = sa.id AND c.is_functional_currency = 0
        CROSS JOIN dbo27.entry_sides s
        INNER JOIN dbo27.report_section_accounts rsa ON rsa.account_type_id = a.account_type_id AND rsa.entry_side_id = s.id AND rsa.pair_account_type_id IS NULL
        INNER JOIN dbo27.report_sections rs ON rs.company_id = a.company_id AND rs.section_type_id = rsa.section_type_id
        LEFT OUTER JOIN dbo27.users users ON users.company_id = a.company_id AND users.username = r.modified_by
        LEFT OUTER JOIN (SELECT currency_id, MIN(date) AS date FROM dbo27.actual_currency_rates GROUP BY currency_id) cd ON cd.currency_id = c.id
        LEFT OUTER JOIN dbo27.actual_currency_rates cr ON cr.currency_id = c.id AND cr.date = cd.date
    WHERE
        a.company_id = @company_id
        AND (r.debit IS NOT NULL OR r.credit IS NOT NULL)
        AND rsa.value_type_id IN (2, 3, 4)
        AND rs.ref_number + COALESCE(a.ref_number, 0) = @ref_number
        AND (s.id = 1 AND r.balance$ > 0 OR s.id = 2 AND r.balance$ < 0)
    ORDER BY
        date
        , id
        , debit
        , credit
    END
ELSE
    BEGIN
    WITH factors (id, parent_id, is_parent) AS (
        SELECT
            rs.id
            , rs.id AS parent_id
            , COALESCE(rs.hide_items, 0) AS is_parent
        FROM
            dbo27.report_sections rs
        WHERE
            rs.company_id = @company_id
            AND rs.report_type_id = @report_type_id
        UNION ALL
        SELECT
            rs.id
            , rs.parent2_id
            , 1 AS is_parent
        FROM
            dbo27.report_sections rs
        WHERE
            rs.company_id = @company_id
            AND rs.report_type_id = @report_type_id
            AND rs.parent2_id IS NOT NULL
        UNION ALL
        SELECT
            f.id
            , rs.parent_id
            , 1 AS is_parent
        FROM
            factors f
            INNER JOIN dbo27.report_sections rs ON rs.id = f.parent_id
        WHERE
            rs.parent_id IS NOT NULL
            AND NOT f.id = rs.parent_id
    )
    SELECT
        j.id
        , CAST(j.date AS datetime) AS date
        , d.code AS debit
        , c.code AS credit
        , CAST(j.amount AS float) AS amount
        , ds.name AS debit_subsidiary_account
        , dc.name AS credit_subsidiary_account
        , j.description
        , COALESCE(dc.name, cc.name) AS currency
        , cr.rate
        , CAST(j.amount$ AS float) AS amount$
        , m4.code AS entity
        , m1.code AS account
        , m5.code AS region
        , m6.code AS product
        , COALESCE(users.name, j.modified_by) AS last_user
        , j.modified_on AS last_update
    FROM
        dbo27.journals j
        INNER JOIN dbo27.ledger_accounts d ON d.id = j.debit_account_id
        INNER JOIN dbo27.ledger_accounts c ON c.id = j.credit_account_id
        LEFT OUTER JOIN dbo27.members ds ON ds.id = j.debit_subsidiary_account_id
        LEFT OUTER JOIN dbo27.members cs ON cs.id = j.credit_subsidiary_account_id
        LEFT OUTER JOIN dbo27.units dc ON dc.id = ds.id AND dc.is_functional_currency = 0
        LEFT OUTER JOIN dbo27.units cc ON cc.id = cs.id AND cc.is_functional_currency = 0
        LEFT OUTER JOIN dbo27.actual_currency_rates cr ON cr.currency_id = COALESCE(dc.id, cc.id) AND cr.date = j.date
        INNER JOIN dbo27.report_section_accounts rsa ON rsa.account_type_id = d.account_type_id AND rsa.entry_side_id = 1 AND (rsa.pair_account_type_id IS NULL OR rsa.pair_account_type_id = c.account_type_id)
        INNER JOIN dbo27.report_sections rs ON rs.company_id = j.company_id AND rs.section_type_id = rsa.section_type_id
        INNER JOIN factors f ON f.id = rs.id
        INNER JOIN dbo27.report_sections frs ON frs.id = f.parent_id AND COALESCE(frs.show_line, 1) = 1
        INNER JOIN dbo27.report_section_types rst ON rst.id = rs.section_type_id
        LEFT OUTER JOIN dbo27.members m1 ON m1.id = j.account_id
        LEFT OUTER JOIN dbo27.members m4 ON m4.id = j.[entity_id]
        LEFT OUTER JOIN dbo27.members m5 ON m5.id = j.region_id
        LEFT OUTER JOIN dbo27.members m6 ON m6.id = j.product_id
        LEFT OUTER JOIN dbo27.members m7 ON m7.id = j.debit_subsidiary_account_id
        LEFT OUTER JOIN dbo27.users users ON users.company_id = m1.company_id AND users.username = j.modified_by
    WHERE
        rs.company_id = @company_id
        AND rst.report_type_id = @report_type_id
        AND frs.ref_number = @ref_number
        AND COALESCE(j.entity_id, -1) = COALESCE(@entity_id, j.entity_id, -1)
        AND j.date <= @end_date
        AND (rsa.value_type_id = 1 AND j.date >= @start_date OR NOT rsa.value_type_id = 1)
        AND NOT (rst.total_type_id = 2 AND @column_name = 'data00')
        AND NOT c.account_type_id = 150
    UNION ALL
    SELECT
        j.id
        , CAST(j.date AS datetime) AS date
        , d.code AS debit
        , c.code AS credit
        , CAST(j.amount AS float) AS amount
        , ds.name AS debit_subsidiary_account
        , dc.name AS credit_subsidiary_account
        , j.description
        , COALESCE(dc.name, cc.name) AS currency
        , cr.rate
        , CAST(j.amount$ AS float) AS amount$
        , m4.code AS entity
        , m1.code AS account
        , m5.code AS region
        , m6.code AS product
        , COALESCE(users.name, j.modified_by) AS last_user
        , j.modified_on AS last_update
    FROM
        dbo27.journals j
        INNER JOIN dbo27.ledger_accounts d ON d.id = j.debit_account_id
        INNER JOIN dbo27.ledger_accounts c ON c.id = j.credit_account_id
        LEFT OUTER JOIN dbo27.members ds ON ds.id = j.debit_subsidiary_account_id
        LEFT OUTER JOIN dbo27.members cs ON cs.id = j.credit_subsidiary_account_id
        LEFT OUTER JOIN dbo27.units dc ON dc.id = ds.id AND dc.is_functional_currency = 0
        LEFT OUTER JOIN dbo27.units cc ON cc.id = cs.id AND cc.is_functional_currency = 0
        LEFT OUTER JOIN dbo27.actual_currency_rates cr ON cr.currency_id = COALESCE(dc.id, cc.id) AND cr.date = j.date
        INNER JOIN dbo27.report_section_accounts rsa ON rsa.account_type_id = c.account_type_id AND rsa.entry_side_id = 2 AND (rsa.pair_account_type_id IS NULL OR rsa.pair_account_type_id = d.account_type_id)
        INNER JOIN dbo27.report_sections rs ON rs.company_id = j.company_id AND rs.section_type_id = rsa.section_type_id
        INNER JOIN factors f ON f.id = rs.id
        INNER JOIN dbo27.report_sections frs ON frs.id = f.parent_id AND COALESCE(frs.show_line, 1) = 1
        INNER JOIN dbo27.report_section_types rst ON rst.id = rs.section_type_id
        LEFT OUTER JOIN dbo27.members m1 ON m1.id = j.account_id
        LEFT OUTER JOIN dbo27.members m4 ON m4.id = j.[entity_id]
        LEFT OUTER JOIN dbo27.members m5 ON m5.id = j.region_id
        LEFT OUTER JOIN dbo27.members m6 ON m6.id = j.product_id
        LEFT OUTER JOIN dbo27.members m7 ON m7.id = j.debit_subsidiary_account_id
        LEFT OUTER JOIN dbo27.users users ON users.company_id = m1.company_id AND users.username = j.modified_by
    WHERE
        rs.company_id = @company_id
        AND rst.report_type_id = @report_type_id
        AND frs.ref_number = @ref_number
        AND COALESCE(j.entity_id, -1) = COALESCE(@entity_id, j.entity_id, -1)
        AND j.date <= @end_date
        AND (rsa.value_type_id = 1 AND j.date >= @start_date OR NOT rsa.value_type_id = 1)
        AND NOT (rst.total_type_id = 2 AND @column_name = 'data00')
        AND NOT d.account_type_id = 150
    UNION ALL
    SELECT
        NULL AS id
        , NULL AS date
        , CASE WHEN s.id = 1 THEN a.code ELSE NULL END AS debit
        , CASE WHEN s.id = 1 THEN NULL ELSE a.code END AS credit
        , CAST(CASE WHEN s.id = 1 AND r.balance > 0 THEN r.balance WHEN s.id = 2 AND r.balance < 0 THEN -r.balance ELSE NULL END AS float) AS amount
        , CASE WHEN s.id = 1 THEN sa.name ELSE NULL END AS debit_subsidiary_account
        , CASE WHEN s.id = 1 THEN NULL ELSE sa.name END AS credit_subsidiary_account
        , 'Opening Balance' AS description
        , c.name AS currency
        , cr.rate
        , CAST(CASE WHEN s.id = 1 AND r.balance$ > 0 THEN r.balance$ WHEN s.id = 2 AND r.balance$ < 0 THEN -r.balance$ ELSE NULL END AS float) AS amount$
        , NULL AS entity
        , NULL AS account
        , NULL AS region
        , NULL AS product
        , COALESCE(users.name, r.modified_by) AS last_user
        , r.modified_on AS last_update
    FROM
        dbo27.actual_balances r
        INNER JOIN dbo27.ledger_accounts a ON a.id = r.account_id
        LEFT OUTER JOIN dbo27.members sa ON sa.id = r.subsidiary_account_id
        LEFT OUTER JOIN dbo27.units c ON c.id = sa.id AND c.is_functional_currency = 0
        CROSS JOIN dbo27.entry_sides s
        INNER JOIN dbo27.report_section_accounts rsa ON rsa.account_type_id = a.account_type_id AND rsa.entry_side_id = s.id AND rsa.pair_account_type_id IS NULL
        INNER JOIN dbo27.report_sections rs ON rs.company_id = a.company_id AND rs.section_type_id = rsa.section_type_id
        INNER JOIN factors f ON f.id = rs.id
        INNER JOIN dbo27.report_sections frs ON frs.id = f.parent_id
        LEFT OUTER JOIN dbo27.users users ON users.company_id = a.company_id AND users.username = r.modified_by
        LEFT OUTER JOIN (SELECT currency_id, MIN(date) AS date FROM dbo27.actual_currency_rates GROUP BY currency_id) cd ON cd.currency_id = c.id
        LEFT OUTER JOIN dbo27.actual_currency_rates cr ON cr.currency_id = c.id AND cr.date = cd.date
    WHERE
        a.company_id = @company_id
        AND (r.debit IS NOT NULL OR r.credit IS NOT NULL)
        AND rsa.value_type_id IN (2, 3, 4)
        AND frs.ref_number = @ref_number
        AND COALESCE(frs.show_line, 1) = 1
        AND (s.id = 1 AND r.balance$ > 0 OR s.id = 2 AND r.balance$ < 0)
    ORDER BY
        date
        , id
        , debit
        , credit
    END

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Adds time members for a year
-- =============================================

CREATE PROCEDURE [xls27].[xl_actions_add_language]
    @company_id int
    , @language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

SELECT TOP 1 @company_id = company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1

IF @company_id IS NULL
    RETURN

IF EXISTS (SELECT TOP 1 t.company_id FROM dbo27.translations t WHERE t.company_id = @company_id AND t.language = @language)
    RETURN

SET NOCOUNT OFF

INSERT INTO dbo27.translations (company_id, table_id, member_id, language, name)
SELECT
    c.id, 2, c.id, @language, c.name
FROM
    dbo27.companies c
WHERE
    c.id = @company_id


END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Closes account actual_balances
-- =============================================

CREATE PROCEDURE [xls27].[xl_actions_auto_close_accounts]
    @company_id int = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

IF @company_id IS NULL
    RETURN

-- balances by accounts and months

;WITH balances AS (
    SELECT
        j.account_id
        , date
        , SUM(debit) - SUM(credit) AS balance
    FROM
        (
            SELECT
                j.debit_account_id AS account_id
                , DATEADD(M, 1, DATEADD(D, -DATEPART(D, j.date), j.date)) AS date
                , j.amount$ AS debit
                , 0 AS credit
            FROM
                dbo27.journals j
            WHERE
                j.company_id = @company_id
                AND NOT j.auto_type_id = 30
            UNION ALL
            SELECT
                j.credit_account_id AS account_id
                , DATEADD(M, 1, DATEADD(D, -DATEPART(D, j.date), j.date)) AS date
                , 0 AS debit
                , j.amount$ AS credit
            FROM
                dbo27.journals j
            WHERE
                j.company_id = @company_id
                AND NOT j.auto_type_id = 30
        ) j
    GROUP BY
        account_id
        , date
)

-- Account-level entries

, entries1 AS (
    SELECT
        CASE WHEN balance < 0 AND a.closing_credit_account_id IS NOT NULL THEN a.id ELSE a.closing_debit_account_id END AS debit_account_id
        , CASE WHEN balance < 0 AND a.closing_credit_account_id IS NOT NULL THEN a.closing_credit_account_id ELSE a.id END AS credit_account_id
        , date
        , ROUND(CASE WHEN balance < 0 AND a.closing_credit_account_id IS NOT NULL THEN -balance ELSE balance END, 2) AS amount
    FROM
        balances b
        INNER JOIN dbo27.ledger_accounts a ON a.id = b.account_id
        LEFT OUTER JOIN dbo27.ledger_accounts d ON d.id = a.closing_debit_account_id
        LEFT OUTER JOIN dbo27.ledger_accounts c ON c.id = a.closing_credit_account_id
    WHERE
        (a.closing_debit_account_id IS NOT NULL OR a.closing_credit_account_id IS NOT NULL)
        AND a.subsidiary_group_id IS NULL
)

-- SELECT * FROM entries1

-- Account parents

, parents (id, parent_id) AS (
    SELECT
        a.id
        , a.parent_id
    FROM
        dbo27.ledger_accounts a
    WHERE
        a.parent_id IS NOT NULL

    UNION ALL
    SELECT
        p.id
        , a.parent_id
    FROM
        parents p
        INNER JOIN dbo27.ledger_accounts a ON a.id = p.parent_id
    WHERE
        a.parent_id IS NOT NULL
        AND NOT p.id = a.parent_id
)

-- SELECT * FROM parents

, entries (debit_account_id, credit_account_id, date, amount) AS (

    -- Account-level entries

    SELECT
        debit_account_id, credit_account_id, date, amount
    FROM
        entries1

    UNION ALL

    -- Parent-level entries

    SELECT
        CASE WHEN balance < 0 AND a.closing_credit_account_id IS NOT NULL THEN h.id ELSE a.closing_debit_account_id END AS debit_account_id
        , CASE WHEN balance < 0 AND a.closing_credit_account_id IS NOT NULL THEN a.closing_credit_account_id ELSE h.id END AS credit_account_id
        , date
        , ROUND(CASE WHEN balance < 0 AND a.closing_credit_account_id IS NOT NULL THEN -balance ELSE balance END, 2) AS amount
    FROM
        (
            SELECT
                account_id
                , date
                , SUM(balance) AS balance
            FROM
                (
                    -- Balances as is

                    SELECT
                        p.parent_id AS account_id
                        , date
                        , balance
                    FROM
                        balances b
                        INNER JOIN parents p ON p.id = b.account_id

                    -- Automatic entries on debit

                    UNION ALL
                    SELECT
                        p.parent_id AS account_id
                        , date
                        , amount
                    FROM
                        entries1 e
                        INNER JOIN parents p ON p.id = e.debit_account_id

                    -- Automatic entries on credit

                    UNION ALL
                    SELECT
                        p.parent_id AS account_id
                        , date
                        , -amount
                    FROM
                        entries1 e
                        INNER JOIN parents p ON p.id = e.credit_account_id
                ) p
            GROUP BY
                account_id
                , date
        ) b
        INNER JOIN dbo27.ledger_accounts a ON a.id = b.account_id
        INNER JOIN dbo27.ledger_accounts h ON h.id = a.closing_child_account_id
        LEFT OUTER JOIN dbo27.ledger_accounts d ON d.id = a.closing_debit_account_id
        LEFT OUTER JOIN dbo27.ledger_accounts c ON c.id = a.closing_credit_account_id
    WHERE
        (a.closing_debit_account_id IS NOT NULL OR a.closing_credit_account_id IS NOT NULL)
)

-- Testing entries
-- SELECT t.id, s.date, s.debit_account_id, s.credit_account_id, s.amount FROM entries s
-- LEFT OUTER JOIN dbo27.journals t ON t.debit_account_id = s.debit_account_id AND t.credit_account_id = s.credit_account_id AND t.date = s.date AND t.auto_type_id = 30

-- Merge entries

MERGE dbo27.journals t
USING
    (
        SELECT e.date, e.debit_account_id, e.credit_account_id, SUM(e.amount) AS amount FROM entries e GROUP BY e.date, e.debit_account_id, e.credit_account_id
    ) s ON t.auto_type_id = 30
        AND t.date = s.date
        AND t.debit_account_id = s.debit_account_id
        AND t.credit_account_id = s.credit_account_id
WHEN MATCHED AND (NOT COALESCE(t.amount, 0) = s.amount OR NOT t.modified_by = 'auto') THEN
    UPDATE SET amount = s.amount, amount$ = s.amount, t.modified_by = 'auto'
WHEN NOT MATCHED THEN
    INSERT (company_id, date, amount, amount$, debit_account_id, credit_account_id, auto_type_id, created_by, created_on)
    VALUES (@company_id, date, amount, amount, debit_account_id, credit_account_id, 30, 'auto', GETDATE())
WHEN NOT MATCHED BY SOURCE AND company_id = @company_id AND auto_type_id = 30 THEN
    DELETE
    ;

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Calculates gains and losses from currency transactions
--
-- Dr    Cr    Amount Amount$    Dr    Cr    Amount Amount$
-- Conv  Cash  1000   1100        Conv  Cash  1000   1100
-- Cash  Conv  1120   1120        Cash  Conv  1080   1080
-- Conv  Gain     0     20        Loss  Conv     0     20
-- =============================================

CREATE PROCEDURE [xls27].[xl_actions_auto_currency_transactions]
    @company_id int = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

IF @company_id IS NULL
    RETURN

DECLARE @gain_account_id int
DECLARE @loss_account_id int

SELECT TOP 1 @gain_account_id = a.id FROM dbo27.ledger_accounts a INNER JOIN dbo27.ledger_account_types t ON t.id = a.account_type_id WHERE a.company_id = @company_id AND t.specific_type_id = 5
SELECT TOP 1 @loss_account_id = a.id FROM dbo27.ledger_accounts a INNER JOIN dbo27.ledger_account_types t ON t.id = a.account_type_id WHERE a.company_id = @company_id AND t.specific_type_id = 6

IF @gain_account_id IS NULL OR @loss_account_id IS NULL
    RETURN

;WITH entries AS (
SELECT
    p.id AS ref_record_id
    , j.date

    -- Dr    Cr    Amount Amount$    Dr    Cr    Amount Amount$
    -- Conv  Cash  1000   1100        Conv  Cash  1000   1100        p.amount$
    -- Cash  Conv  1120   1120        Cash  Conv  1080   1080        j.amount$
    -- Conv  Gain     0     20        Loss  Conv     0     20

    , CASE WHEN p.amount$ < j.amount$ THEN p.debit_account_id ELSE @loss_account_id END AS debit_account_id
    , CASE WHEN p.amount$ < j.amount$ THEN @gain_account_id ELSE j.credit_account_id END AS credit_account_id
    , CASE WHEN p.amount$ < j.amount$ THEN p.debit_subsidiary_account_id ELSE NULL END AS debit_subsidiary_account_id
    , CASE WHEN p.amount$ < j.amount$ THEN NULL ELSE j.credit_subsidiary_account_id END AS credit_subsidiary_account_id
    , CASE WHEN p.amount$ < j.amount$ THEN j.amount$ - p.amount$ ELSE p.amount$ - j.amount$ END AS amount
FROM
    dbo27.journals j
    INNER JOIN dbo27.journals p ON p.id = j.id - 1 AND p.debit_account_id = j.credit_account_id
    INNER JOIN dbo27.members cs ON cs.id = p.credit_subsidiary_account_id
    INNER JOIN dbo27.members ds ON ds.id = j.debit_subsidiary_account_id
WHERE
    j.company_id = @company_id
    AND NOT cs.unit_id = ds.unit_id
)
-- SELECT * FROM entries

MERGE dbo27.journals t
USING
    (
        SELECT * FROM entries e
    ) s ON t.ref_record_id = s.ref_record_id
        AND t.auto_type_id = 10
        AND t.date = s.date
        AND t.debit_account_id = s.debit_account_id
        AND t.credit_account_id = s.credit_account_id
        AND COALESCE(t.debit_subsidiary_account_id, -1) = COALESCE(s.debit_subsidiary_account_id, -1)
        AND COALESCE(t.credit_subsidiary_account_id, -1) = COALESCE(s.credit_subsidiary_account_id, -1)
WHEN MATCHED AND NOT COALESCE(t.amount, 0) = s.amount THEN
    UPDATE SET amount = s.amount, amount$ = s.amount
WHEN NOT MATCHED THEN
    INSERT (company_id, date, amount, amount$, debit_account_id, credit_account_id, ref_record_id, auto_type_id, created_by, created_on)
    VALUES (@company_id, date, amount, amount,  debit_account_id, credit_account_id, ref_record_id, 10, 'auto', GETDATE())
WHEN NOT MATCHED BY SOURCE AND company_id = @company_id AND t.auto_type_id = 10 THEN
    DELETE;

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Calculates gains and losses from currency translation
-- =============================================

CREATE PROCEDURE [xls27].[xl_actions_auto_currency_translation]
    @company_id int = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

IF @company_id IS NULL
    RETURN

DECLARE @gain_account_id int
DECLARE @loss_account_id int

SELECT TOP 1 @gain_account_id = a.id FROM dbo27.ledger_accounts a INNER JOIN dbo27.ledger_account_types t ON t.id = a.account_type_id WHERE a.company_id = @company_id AND t.specific_type_id = 7
SELECT TOP 1 @loss_account_id = a.id FROM dbo27.ledger_accounts a INNER JOIN dbo27.ledger_account_types t ON t.id = a.account_type_id WHERE a.company_id = @company_id AND t.specific_type_id = 8

IF @gain_account_id IS NULL OR @loss_account_id IS NULL
    RETURN

-- Balance and turnover by accounts and months

;WITH balances (account_id, subsidiary_account_id, date, rate, balance, balance$, new_balance$, delta$) AS (
    SELECT
        account_id
        , subsidiary_account_id
        , date
        , MAX(rate) AS rate
        , SUM(debit) - SUM(credit) AS balance
        , SUM(debit$) - SUM(credit$) AS balance$
        , ROUND((SUM(debit) - SUM(credit)) * MAX(rate), 2) AS new_balance$
        , ROUND((SUM(debit) - SUM(credit)) * MAX(rate), 2) - ROUND((SUM(debit$) - SUM(credit$)), 2) AS delta$
    FROM
        (
            SELECT
                b.account_id
                , b.subsidiary_account_id
                , r.date
                , r.rate
                , b.balance AS debit
                , b.balance$ AS debit$
                , 0 AS credit
                , 0 AS credit$
            FROM
                dbo27.actual_balances b
                INNER JOIN dbo27.members s ON s.id = b.subsidiary_account_id
                INNER JOIN dbo27.units u ON u.id = s.unit_id
                INNER JOIN dbo27.actual_currency_rates r ON r.currency_id = s.unit_id AND r.is_calc_date = 1
            WHERE
                s.company_id = @company_id
                AND NOT u.is_functional_currency = 1

            UNION ALL
            SELECT
                j.debit_account_id AS account_id
                , j.debit_subsidiary_account_id AS subsidiary_account_id
                , r.date
                , r.rate
                , j.amount AS debit
                , j.amount$ AS debit$
                , 0 AS credit
                , 0 AS credit$
            FROM
                dbo27.journals j
                INNER JOIN dbo27.members ds ON ds.id = j.debit_subsidiary_account_id
                INNER JOIN dbo27.units u ON u.id = ds.unit_id
                INNER JOIN dbo27.actual_currency_rates r ON r.currency_id = ds.unit_id AND r.is_calc_date = 1 AND r.date >= j.date
            WHERE
                j.company_id = @company_id
                AND NOT u.is_functional_currency = 1
                AND NOT j.auto_type_id = 20

            UNION ALL
            SELECT
                j.credit_account_id AS account_id
                , j.credit_subsidiary_account_id AS subsidiary_account_id
                , r.date
                , r.rate
                , 0 AS debit
                , 0 AS debit$
                , j.amount AS credit
                , j.amount$ AS credit$
            FROM
                dbo27.journals j
                INNER JOIN dbo27.members cs ON cs.id = j.credit_subsidiary_account_id
                INNER JOIN dbo27.units u ON u.id = cs.unit_id
                INNER JOIN dbo27.actual_currency_rates r ON r.currency_id = cs.unit_id AND r.is_calc_date = 1 AND r.date >= j.date
            WHERE
                j.company_id = @company_id
                AND NOT u.is_functional_currency = 1
                AND NOT j.auto_type_id = 20
        ) j
    GROUP BY
        account_id
        , subsidiary_account_id
        , date
)

-- SELECT * FROM balances

, balances2 (account_id, subsidiary_account_id, date, rate, balance, balance$, new_balance$, delta$, amount$) AS (
    SELECT
        account_id
        , subsidiary_account_id
        , date
        , rate
        , balance
        , balance$
        , new_balance$
        , delta$
        , delta$ - LAG(delta$, 1, 0) OVER (PARTITION BY account_id, subsidiary_account_id ORDER BY date) AS amount$
    FROM
        balances b
)

-- SELECT * FROM balances2

, entries (date, debit_account_id, debit_subsidiary_account_id, credit_account_id, credit_subsidiary_account_id, amount, amount$) AS (
    SELECT
        b.date
        , CASE WHEN amount$ < 0 THEN @loss_account_id ELSE b.account_id END AS debit_account_id
        , CASE WHEN amount$ < 0 THEN NULL ELSE b.subsidiary_account_id END AS debit_subsidiary_account_id
        , CASE WHEN amount$ < 0 THEN b.account_id ELSE @gain_account_id END AS credit_account_id
        , CASE WHEN amount$ < 0 THEN b.subsidiary_account_id ELSE NULL END AS credit_subsidiary_account_id
        , 0
        , CASE WHEN amount$ < 0 THEN ROUND(-amount$, 2) ELSE ROUND(amount$, 2) END AS amount$
    FROM
        balances2 b
        INNER JOIN dbo27.members s ON s.id = b.subsidiary_account_id
        INNER JOIN dbo27.actual_currency_rates r ON r.currency_id = s.unit_id AND r.date = b.date
    WHERE
        NOT b.amount$ = 0
)

-- SELECT * FROM entries

MERGE dbo27.journals t
USING
    (
        SELECT * FROM entries e
    ) s ON t.auto_type_id = 20
        AND t.date = s.date
        AND t.debit_account_id = s.debit_account_id
        AND t.credit_account_id = s.credit_account_id
        AND (t.debit_account_id = s.debit_account_id OR t.credit_account_id = s.credit_account_id)
WHEN MATCHED AND NOT COALESCE(t.amount$, 0) = s.amount$ THEN
    UPDATE SET amount$ = s.amount$
WHEN NOT MATCHED THEN
    INSERT (company_id, date, amount, amount$, debit_account_id, credit_account_id, debit_subsidiary_account_id, credit_subsidiary_account_id, auto_type_id, created_by, created_on)
    VALUES (@company_id, date, amount, amount$, debit_account_id, credit_account_id, debit_subsidiary_account_id, credit_subsidiary_account_id, 20, 'auto', GETDATE())
WHEN NOT MATCHED BY SOURCE AND company_id = @company_id AND t.auto_type_id = 20 THEN
    DELETE;

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Calculates all automatic values
-- =============================================

CREATE PROCEDURE [xls27].[xl_actions_auto_calc_all]
    @company_id int = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

IF @company_id IS NULL
    RETURN

EXEC xls27.xl_actions_auto_currency_transactions @company_id;

EXEC xls27.xl_actions_auto_currency_translation @company_id;

EXEC xls27.xl_actions_auto_close_accounts @company_id;

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: The procedure selects report cell data to an Excel window
-- =============================================

CREATE PROCEDURE [xls27].[xl_actions_budget_report_cell_data]
    @company_id int = NULL
    , @category_id int = NULL
    , @time_id int = NULL
    , @entity_id int = NULL
    , @year int = NULL
    , @report int = NULL
    , @ref_number int = NULL
    , @account nvarchar(50) = NULL
    , @code1 nvarchar(50) = NULL
    , @code2 nvarchar(50) = NULL
    , @column_name nvarchar(128) = NULL
    , @data_language varchar(10) = NULL
WITH EXECUTE AS OWNER
AS
BEGIN

SET NOCOUNT ON

-- Checking the company

EXECUTE AS CALLER

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 u.company_id FROM dbo27.members t INNER JOIN dbo27.users u ON u.company_id = t.company_id  WHERE t.id = @category_id AND u.username = USER_NAME() AND u.is_active = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

REVERT

-- Replace values calculated by Excel formulas

IF @ref_number = 0 SET @ref_number = NULL
IF @entity_id = 0 SET @entity_id = NULL
IF @account IN ('0', '') SET @account = NULL
IF @code1 IN ('0', '') SET @code1 = NULL
IF @code2 IN ('0', '') SET @code2 = NULL

-- Getting account_id and member_id using code1 and code2

DECLARE @report_type_id int, @account_id int, @member_id1 int, @member_id2 int

IF @report IS NOT NULL SELECT @report_type_id = id FROM dbo27.report_types WHERE id = @report

IF @account IS NOT NULL SELECT @account_id = id FROM dbo27.ledger_accounts WHERE company_id = @company_id AND code = @account

IF @code1 IS NOT NULL SELECT @member_id1 = id FROM dbo27.members WHERE company_id = @company_id AND code = @code1
IF @code2 IS NOT NULL SELECT @member_id2 = id FROM dbo27.members WHERE company_id = @company_id AND code = @code2

DECLARE @search_by_account bit = CASE WHEN @ref_number IS NOT NULL OR @account IS NOT NULL OR @report_type_id NOT IN (1, 4) THEN 1 ELSE 0 END

-- Find max value and total types

DECLARE @value_type_id tinyint = NULL
DECLARE @total_type_id tinyint = NULL

IF @search_by_account = 0
    BEGIN
    SET @value_type_id = 1
    SET @total_type_id = 1
    END
ELSE IF @account_id IS NOT NULL
    BEGIN
    SELECT
        @value_type_id = MAX(rsa.value_type_id)
        , @total_type_id = MAX(rst.total_type_id)
    FROM
        dbo27.report_sections rs
        INNER JOIN dbo27.report_section_accounts rsa ON rsa.section_type_id = rs.section_type_id
        INNER JOIN dbo27.ledger_accounts a ON a.company_id = rs.company_id AND a.account_type_id = rsa.account_type_id
        INNER JOIN dbo27.report_section_types rst ON rst.id = rs.section_type_id
    WHERE
        rs.company_id = @company_id
        AND a.id = @account_id
        AND rs.ref_number + COALESCE(a.ref_number, 0) = @ref_number
    END
ELSE IF @ref_number IS NOT NULL
    BEGIN
    WITH factors (id, parent_id, is_parent) AS (
        SELECT

            rs.id
            , rs.id AS parent_id
            , COALESCE(rs.hide_items, 0) AS is_parent
        FROM
            dbo27.report_sections rs
        WHERE
            rs.company_id = @company_id
            AND rs.report_type_id = @report_type_id
        UNION ALL
        SELECT
            rs.id
            , rs.parent2_id
            , 1 AS is_parent
        FROM
            dbo27.report_sections rs
        WHERE
            rs.company_id = @company_id
            AND rs.report_type_id = @report_type_id
            AND rs.parent2_id IS NOT NULL
        UNION ALL
        SELECT
            f.id
            , rs.parent_id
            , 1 AS is_parent
        FROM
            factors f
            INNER JOIN dbo27.report_sections rs ON rs.id = f.parent_id
        WHERE
            rs.parent_id IS NOT NULL
            AND NOT f.id = rs.parent_id
    )
    SELECT
        @value_type_id = MAX(rsa.value_type_id)
        , @total_type_id = MAX(rst.total_type_id)
    FROM
        dbo27.report_sections rs
        INNER JOIN factors f ON f.id = rs.id
        INNER JOIN dbo27.report_sections frs ON frs.id = f.parent_id
        INNER JOIN dbo27.report_section_accounts rsa ON rsa.section_type_id = rs.section_type_id
        INNER JOIN dbo27.report_section_types rst ON rst.id = rs.section_type_id
    WHERE
        rs.company_id = @company_id
        AND frs.ref_number = @ref_number
    END

-- If any required value is NULL then return an empty result immediately

IF @company_id IS NULL OR @report_type_id IS NULL OR @category_id IS NULL OR @time_id IS NULL
    OR @account_id IS NULL AND @ref_number IS NULL AND @member_id1 IS NULL
    OR @value_type_id IS NULL OR @total_type_id IS NULL
    BEGIN
    SELECT
        CAST(NULL AS nvarchar(50)) AS entity
        , CAST(NULL AS nvarchar(50)) AS description
        , CAST(NULL AS nvarchar(50)) AS account
        , CAST(NULL AS nvarchar(50)) AS subaccount
        , CAST(NULL AS nvarchar(50)) AS region
        , CAST(NULL AS nvarchar(50)) AS product
        , CAST(NULL AS nvarchar(50)) AS vat
        , CAST(NULL AS nvarchar(50)) AS unit
    FROM
        dbo27.budget_requests
    WHERE
        id IS NULL
    RETURN
    END

-- String identifiers

DECLARE @company_sid nvarchar(50) = CAST(@company_id AS nvarchar(50))
DECLARE @report_type_sid nvarchar(50) = CAST(@report_type_id AS nvarchar(50))
DECLARE @category_sid nvarchar(50) = CAST(@category_id AS nvarchar(50))
DECLARE @time_sid nvarchar(50) = CAST(@time_id AS nvarchar(50))
DECLARE @entity_sid nvarchar(50) = COALESCE(CAST(@entity_id AS nvarchar(50)), 'NULL')
DECLARE @account_sid nvarchar(50) = COALESCE(CAST(@account_id AS nvarchar(50)), 'NULL')
DECLARE @member_sid1 nvarchar(50) = COALESCE(CAST(@member_id1 AS nvarchar(50)), 'NULL')
DECLARE @member_sid2 nvarchar(50) = COALESCE(CAST(@member_id2 AS nvarchar(50)), 'NULL')

DECLARE @sql nvarchar(max) = ''

-- Select rows of all requests of the specified category, period, and entity

IF @search_by_account = 0
    SET @sql = @sql + 'WITH members (id, parent_id) AS (
    SELECT
        m.id
        , m.id AS parent_id
    FROM
        dbo27.members m
    WHERE
        m.company_id = ' + @company_sid + '
        AND m.dimension_id = 1
    UNION ALL
    SELECT
        f.id
        , m.parent_id
    FROM
        members f
        INNER JOIN dbo27.members m ON m.id = f.parent_id
    WHERE
        m.parent_id IS NOT NULL
        AND NOT f.id = m.parent_id
)
, '
    ELSE
    SET @sql = @sql + 'WITH '

SET @sql = @sql + 'e1 AS (
    SELECT
        r.id
        , m1.is_charge_net
        , m1.payment_debit_id, m1.payment_credit_id, m1.charge_debit_id, m1.charge_credit_id, m1.vat_debit_id, m1.vat_credit_id
        , r.subsidiary_account_id
        , t.cf_sign, t.pl_sign, t.vat_sign
    FROM
        dbo27.budget_requests r
        INNER JOIN dbo27.members m1 ON m1.id = r.account_id
        INNER JOIN dbo27.member_types t ON t.id = m1.account_type_id'
        + CASE WHEN @search_by_account = 1 THEN '' ELSE '
        INNER JOIN members f ON f.id = r.account_id'
            END + '
    WHERE
        r.category_id = ' + @category_sid + '
        AND r.time_id = ' + @time_sid + '
        AND m1.company_id = ' + @company_sid + CASE WHEN @entity_id IS NULL THEN '' ELSE '
        AND r.[entity_id] = ' + @entity_sid END
        + CASE WHEN @search_by_account = 1 THEN '' ELSE '
        AND f.parent_id = ' + @member_sid1
            END + '
)'

-- Transform three pair of accounts into six records

IF @search_by_account = 1
    SET @sql = @sql + '
, e2 AS (
    SELECT id, is_charge_net, 1 AS entry_id, 1 AS entry_side_id, payment_debit_id AS ledger_account_id, subsidiary_account_id, payment_credit_id AS pair_account_id FROM e1 WHERE payment_debit_id IS NOT NULL AND payment_credit_id IS NOT NULL
    UNION ALL
    SELECT id, is_charge_net, 1 AS entry_id, 2 AS entry_side_id, payment_credit_id AS ledger_account_id, subsidiary_account_id, payment_debit_id AS pair_account_id FROM e1 WHERE payment_debit_id IS NOT NULL AND payment_credit_id IS NOT NULL
    UNION ALL
    SELECT id, is_charge_net, 2 AS entry_id, 1 AS entry_side_id, charge_debit_id AS ledger_account_id, subsidiary_account_id, charge_credit_id AS pair_account_id FROM e1 WHERE charge_debit_id IS NOT NULL AND charge_credit_id IS NOT NULL
    UNION ALL
    SELECT id, is_charge_net, 2 AS entry_id, 2 AS entry_side_id, charge_credit_id AS ledger_account_id, subsidiary_account_id, charge_debit_id AS pair_account_id FROM e1 WHERE charge_debit_id IS NOT NULL AND charge_credit_id IS NOT NULL
    UNION ALL
    SELECT id, is_charge_net, 3 AS entry_id, 1 AS entry_side_id, vat_debit_id AS ledger_account_id, subsidiary_account_id, vat_credit_id AS pair_account_id FROM e1 WHERE vat_debit_id IS NOT NULL AND vat_credit_id IS NOT NULL
    UNION ALL
    SELECT id, is_charge_net, 3 AS entry_id, 2 AS entry_side_id, vat_credit_id AS ledger_account_id, subsidiary_account_id, vat_debit_id AS pair_account_id FROM e1 WHERE vat_debit_id IS NOT NULL AND vat_credit_id IS NOT NULL
)'
    ELSE IF @report_type_id = 4
    SET @sql = @sql + '
, e2 AS (
    SELECT id, is_charge_net, 1 AS entry_id, 1 AS entry_side_id, payment_debit_id AS ledger_account_id, subsidiary_account_id, payment_credit_id AS pair_account_id, 1 AS value_sign FROM e1 WHERE cf_sign IN (0, 1)
    UNION ALL
    SELECT id, is_charge_net, 1 AS entry_id, 2 AS entry_side_id, payment_credit_id AS ledger_account_id, subsidiary_account_id, payment_debit_id AS pair_account_id, -1 AS value_sign FROM e1 WHERE cf_sign = -1
)'
    ELSE
    SET @sql = @sql + '
, e2 AS (
    SELECT id, is_charge_net, 2 AS entry_id, 1 AS entry_side_id, charge_debit_id AS ledger_account_id, subsidiary_account_id, charge_credit_id AS pair_account_id, 1 AS value_sign FROM e1 WHERE cf_sign IN (0, 1)
    UNION ALL
    SELECT id, is_charge_net, 2 AS entry_id, 2 AS entry_side_id, charge_credit_id AS ledger_account_id, subsidiary_account_id, charge_debit_id AS pair_account_id, -1 AS value_sign FROM e1 WHERE cf_sign = -1
    UNION ALL
    SELECT id, is_charge_net, 3 AS entry_id, 1 AS entry_side_id, vat_debit_id AS ledger_account_id, subsidiary_account_id, vat_credit_id AS pair_account_id, -1 AS value_sign FROM e1 WHERE vat_sign = 1 AND is_charge_net = 0
    UNION ALL
    SELECT id, is_charge_net, 3 AS entry_id, 2 AS entry_side_id, vat_credit_id AS ledger_account_id, subsidiary_account_id, vat_debit_id AS pair_account_id, 1 AS value_sign FROM e1 WHERE vat_sign = -1 AND is_charge_net = 0
)'

-- Expand rows to section types

IF @search_by_account = 1
    SET @sql = @sql + '
, e3 AS (
    SELECT
        r.id
        , r.is_charge_net
        , r.entry_id
        , r.entry_side_id
        , r.ledger_account_id
        , r.subsidiary_account_id
        , pair_account_id
        , rsa.section_type_id
        , rsa.value_type_id
        , rsa.value_sign
        , a.ref_number
    FROM
        e2 r
        INNER JOIN dbo27.ledger_accounts a ON a.id = r.ledger_account_id
        INNER JOIN dbo27.report_section_accounts rsa ON rsa.account_type_id = a.account_type_id AND rsa.entry_side_id = r.entry_side_id
        INNER JOIN dbo27.report_section_types rst ON rst.id = rsa.section_type_id
        LEFT OUTER JOIN dbo27.ledger_accounts c ON c.id = r.pair_account_id
    WHERE
        rst.report_type_id = ' + @report_type_sid + '
        AND rsa.pair_account_type_id IS NULL OR rsa.pair_account_type_id = c.account_type_id
)'

-- Select report sections id->parent_id to get aggregated values

IF @search_by_account = 1
    SET @sql = @sql + '
, factors (id, parent_id, is_parent) AS (
    SELECT
        rs.id
        , rs.id AS parent_id
        , COALESCE(rs.hide_items, 0) AS is_parent
    FROM
        dbo27.report_sections rs
    WHERE
        rs.company_id = ' + @company_sid + '
        AND rs.report_type_id = ' + @report_type_sid + '
    UNION ALL
    SELECT
        rs.id
        , rs.parent2_id
        , 1 AS is_parent
    FROM
        dbo27.report_sections rs
    WHERE
        rs.company_id = ' + @company_sid + '
        AND rs.report_type_id = ' + @report_type_sid + '
        AND rs.parent2_id IS NOT NULL
    UNION ALL
    SELECT
        f.id
        , rs.parent_id
        , 1 AS is_parent
    FROM
        factors f
        INNER JOIN dbo27.report_sections rs ON rs.id = f.parent_id
    WHERE
        rs.parent_id IS NOT NULL
        AND NOT f.id = rs.parent_id
)'

-- Filter rows of the row to get details by ref_number or ref_number and account

IF @search_by_account = 1
    SET @sql = @sql + '
, e4 AS (
    SELECT
        r.id
        , r.is_charge_net
        , r.entry_id
        , r.entry_side_id
        , r.ledger_account_id
        , r.subsidiary_account_id
        , r.pair_account_id
        , r.section_type_id
        , r.value_type_id
        , r.value_sign
        , r.ref_number
        , rst.total_type_id
    FROM
        e3 r
        INNER JOIN dbo27.report_sections rs ON rs.section_type_id = r.section_type_id
        INNER JOIN dbo27.report_section_types rst ON rst.id = rs.section_type_id'
        + CASE WHEN @account_id IS NOT NULL THEN '' ELSE '
        INNER JOIN factors f ON f.id = rs.id
        INNER JOIN dbo27.report_sections frs ON frs.id = f.parent_id AND COALESCE(frs.show_line, 1) = 1'
            END + '
    WHERE
        rs.company_id = ' + @company_sid + '
        AND rs.report_type_id = ' + @report_type_sid
        + CASE WHEN @account_id IS NOT NULL THEN '
        AND r.ledger_account_id = ' + @account_sid + '
        AND rs.ref_number + COALESCE(r.ref_number, 0) = ' + CAST(@ref_number AS nvarchar(50))
            ELSE '
        AND frs.ref_number = ' + CAST(@ref_number AS nvarchar(50))
            END + '
)'
ELSE
    SET @sql = @sql + '
, e4 AS (
    SELECT
        r.id
        , r.is_charge_net
        , r.entry_id
        , r.entry_side_id
        , r.ledger_account_id
        , r.subsidiary_account_id
        , r.pair_account_id
        , NULL AS section_type_id
        , 1 AS value_type_id
        , r.value_sign
        , NULL AS ref_number
        , 1 AS total_type_id
    FROM
        e2 r
)'

-- Calculated payments, charges, and VAT for selected rows of budget requests

SET @sql = @sql + '
, a1 AS (

    SELECT
        s.id
        , s.is_charge_net
        , s.entry_id
        , s.entry_side_id
        , s.ledger_account_id
        , s.subsidiary_account_id
        , s.pair_account_id
        , s.section_type_id
        , s.value_type_id
        , s.value_sign
        , s.ref_number
        , s.total_type_id

        , COALESCE(CAST(r.balance00 * COALESCE(cr.balance00, 1) AS numeric(15,2)), 0) AS balance00
        ' + '
        , COALESCE(CAST(r.payments01 * COALESCE(cr.period01, 1) AS numeric(15,2)), 0) AS payments01
        , COALESCE(CAST(r.payments02 * COALESCE(cr.period02, 1) AS numeric(15,2)), 0) AS payments02
        , COALESCE(CAST(r.payments03 * COALESCE(cr.period03, 1) AS numeric(15,2)), 0) AS payments03
        , COALESCE(CAST(r.payments04 * COALESCE(cr.period04, 1) AS numeric(15,2)), 0) AS payments04
        , COALESCE(CAST(r.payments05 * COALESCE(cr.period05, 1) AS numeric(15,2)), 0) AS payments05
        , COALESCE(CAST(r.payments06 * COALESCE(cr.period06, 1) AS numeric(15,2)), 0) AS payments06
        , COALESCE(CAST(r.payments07 * COALESCE(cr.period07, 1) AS numeric(15,2)), 0) AS payments07
        , COALESCE(CAST(r.payments08 * COALESCE(cr.period08, 1) AS numeric(15,2)), 0) AS payments08
        , COALESCE(CAST(r.payments09 * COALESCE(cr.period09, 1) AS numeric(15,2)), 0) AS payments09
        , COALESCE(CAST(r.payments10 * COALESCE(cr.period10, 1) AS numeric(15,2)), 0) AS payments10
        , COALESCE(CAST(r.payments11 * COALESCE(cr.period11, 1) AS numeric(15,2)), 0) AS payments11
        , COALESCE(CAST(r.payments12 * COALESCE(cr.period12, 1) AS numeric(15,2)), 0) AS payments12
        ' + '
        , COALESCE(CAST(r.charges01 * COALESCE(cr.period01, 1) AS numeric(15,2)), 0) AS charges01
        , COALESCE(CAST(r.charges02 * COALESCE(cr.period02, 1) AS numeric(15,2)), 0) AS charges02
        , COALESCE(CAST(r.charges03 * COALESCE(cr.period03, 1) AS numeric(15,2)), 0) AS charges03
        , COALESCE(CAST(r.charges04 * COALESCE(cr.period04, 1) AS numeric(15,2)), 0) AS charges04
        , COALESCE(CAST(r.charges05 * COALESCE(cr.period05, 1) AS numeric(15,2)), 0) AS charges05
        , COALESCE(CAST(r.charges06 * COALESCE(cr.period06, 1) AS numeric(15,2)), 0) AS charges06
        , COALESCE(CAST(r.charges07 * COALESCE(cr.period07, 1) AS numeric(15,2)), 0) AS charges07
        , COALESCE(CAST(r.charges08 * COALESCE(cr.period08, 1) AS numeric(15,2)), 0) AS charges08
        , COALESCE(CAST(r.charges09 * COALESCE(cr.period09, 1) AS numeric(15,2)), 0) AS charges09
        , COALESCE(CAST(r.charges10 * COALESCE(cr.period10, 1) AS numeric(15,2)), 0) AS charges10
        , COALESCE(CAST(r.charges11 * COALESCE(cr.period11, 1) AS numeric(15,2)), 0) AS charges11
        , COALESCE(CAST(r.charges12 * COALESCE(cr.period12, 1) AS numeric(15,2)), 0) AS charges12
        ' + '
        , COALESCE(CAST(r.charges01 * COALESCE(cr.period01, 1) * COALESCE(vr.factor, 0) AS numeric(15,2)), 0) AS vat01
        , COALESCE(CAST(r.charges02 * COALESCE(cr.period02, 1) * COALESCE(vr.factor, 0) AS numeric(15,2)), 0) AS vat02
        , COALESCE(CAST(r.charges03 * COALESCE(cr.period03, 1) * COALESCE(vr.factor, 0) AS numeric(15,2)), 0) AS vat03
        , COALESCE(CAST(r.charges04 * COALESCE(cr.period04, 1) * COALESCE(vr.factor, 0) AS numeric(15,2)), 0) AS vat04
        , COALESCE(CAST(r.charges05 * COALESCE(cr.period05, 1) * COALESCE(vr.factor, 0) AS numeric(15,2)), 0) AS vat05
        , COALESCE(CAST(r.charges06 * COALESCE(cr.period06, 1) * COALESCE(vr.factor, 0) AS numeric(15,2)), 0) AS vat06
        , COALESCE(CAST(r.charges07 * COALESCE(cr.period07, 1) * COALESCE(vr.factor, 0) AS numeric(15,2)), 0) AS vat07
        , COALESCE(CAST(r.charges08 * COALESCE(cr.period08, 1) * COALESCE(vr.factor, 0) AS numeric(15,2)), 0) AS vat08
        , COALESCE(CAST(r.charges09 * COALESCE(cr.period09, 1) * COALESCE(vr.factor, 0) AS numeric(15,2)), 0) AS vat09
        , COALESCE(CAST(r.charges10 * COALESCE(cr.period10, 1) * COALESCE(vr.factor, 0) AS numeric(15,2)), 0) AS vat10
        , COALESCE(CAST(r.charges11 * COALESCE(cr.period11, 1) * COALESCE(vr.factor, 0) AS numeric(15,2)), 0) AS vat11
        , COALESCE(CAST(r.charges12 * COALESCE(cr.period12, 1) * COALESCE(vr.factor, 0) AS numeric(15,2)), 0) AS vat12
    FROM
        e4 s
        INNER JOIN dbo27.budget_requests r ON r.id = s.id
        INNER JOIN dbo27.members m1 ON m1.id = r.account_id
        LEFT OUTER JOIN dbo27.vat_rates vr ON vr.id = r.vat_rate_id
        LEFT OUTER JOIN dbo27.budget_currency_rates cr ON cr.category_id = r.category_id AND cr.time_id = r.time_id AND cr.unit_id = r.unit_id
)'

-- Transform payments, charges, and VAT to data01 - data12 depending on entry_id

SET @sql = @sql + '
, b1 AS (
    SELECT
        s.id
        , s.is_charge_net
        , s.entry_id
        , s.entry_side_id
        , s.ledger_account_id
        , s.subsidiary_account_id
        , s.pair_account_id
        , s.section_type_id
        , s.value_type_id
        , s.ref_number
        , s.total_type_id
        , ' + CASE WHEN @entity_id IS NULL THEN 'NULL' ELSE 'CASE WHEN entry_id = 1 THEN balance00 * value_sign * -1 ELSE NULL END' END + ' AS data00
        , CASE WHEN entry_id = 1 THEN payments01 WHEN entry_id = 3 THEN vat01 ELSE charges01 - is_charge_net * vat01 END * value_sign AS data01
        , CASE WHEN entry_id = 1 THEN payments02 WHEN entry_id = 3 THEN vat02 ELSE charges02 - is_charge_net * vat02 END * value_sign AS data02
        , CASE WHEN entry_id = 1 THEN payments03 WHEN entry_id = 3 THEN vat03 ELSE charges03 - is_charge_net * vat03 END * value_sign AS data03
        , CASE WHEN entry_id = 1 THEN payments04 WHEN entry_id = 3 THEN vat04 ELSE charges04 - is_charge_net * vat04 END * value_sign AS data04
        , CASE WHEN entry_id = 1 THEN payments05 WHEN entry_id = 3 THEN vat05 ELSE charges05 - is_charge_net * vat05 END * value_sign AS data05
        , CASE WHEN entry_id = 1 THEN payments06 WHEN entry_id = 3 THEN vat06 ELSE charges06 - is_charge_net * vat06 END * value_sign AS data06
        , CASE WHEN entry_id = 1 THEN payments07 WHEN entry_id = 3 THEN vat07 ELSE charges07 - is_charge_net * vat07 END * value_sign AS data07
        , CASE WHEN entry_id = 1 THEN payments08 WHEN entry_id = 3 THEN vat08 ELSE charges08 - is_charge_net * vat08 END * value_sign AS data08
        , CASE WHEN entry_id = 1 THEN payments09 WHEN entry_id = 3 THEN vat09 ELSE charges09 - is_charge_net * vat09 END * value_sign AS data09
        , CASE WHEN entry_id = 1 THEN payments10 WHEN entry_id = 3 THEN vat10 ELSE charges10 - is_charge_net * vat10 END * value_sign AS data10
        , CASE WHEN entry_id = 1 THEN payments11 WHEN entry_id = 3 THEN vat11 ELSE charges11 - is_charge_net * vat11 END * value_sign AS data11
        , CASE WHEN entry_id = 1 THEN payments12 WHEN entry_id = 3 THEN vat12 ELSE charges12 - is_charge_net * vat12 END * value_sign AS data12
    FROM
        a1 s
)'

SET @sql = @sql + '
, b2 AS (
    SELECT
        s.id
        , m4.code AS entity
        , r.description
        , m1.code AS account
        , m7.name AS sub_account
        , m5.code AS region
        , m6.code AS product
        , t.name AS vat
        , u.name AS unit
        , CASE WHEN s.entry_side_id = 1 THEN a.code ELSE c.code END AS debit
        , CASE WHEN s.entry_side_id = 1 THEN c.code ELSE a.code END AS credit
        , CASE s.entry_id WHEN 1 THEN ''Payments'' WHEN 2 THEN ''Charges'' WHEN 3 THEN ''VAT'' ELSE NULL END AS section
        , data00, data01, data02, data03, data04, data05, data06, data07, data08, data09, data10, data11, data12
        , COALESCE(users.name, r.modified_by) AS last_user
        , r.modified_on AS last_update
        , m4.sort_order AS entity_sort_order
        , r.row_index
        , s.entry_id
        , s.entry_side_id
    FROM
        b1 s
        INNER JOIN dbo27.budget_requests r ON r.id = s.id
        INNER JOIN dbo27.ledger_accounts a ON a.id = s.ledger_account_id
        INNER JOIN dbo27.ledger_accounts c ON c.id = s.pair_account_id
        INNER JOIN dbo27.members m1 ON m1.id = r.account_id
        INNER JOIN dbo27.members m4 ON m4.id = r.[entity_id]
        LEFT OUTER JOIN dbo27.members m5 ON m5.id = r.region_id
        LEFT OUTER JOIN dbo27.members m6 ON m6.id = r.product_id
        LEFT OUTER JOIN dbo27.members m7 ON m7.id = r.subsidiary_account_id
        LEFT OUTER JOIN dbo27.vat_rates t ON t.id = r.vat_rate_id
        LEFT OUTER JOIN dbo27.units u ON u.id = r.unit_id
        LEFT OUTER JOIN dbo27.users users ON users.company_id = m1.company_id AND users.username = r.modified_by
)'

IF NOT (@value_type_id = 1 AND @total_type_id = 1) AND @entity_id IS NULL
    SET @sql = @sql + '
, f1 AS (
    SELECT
        NULL AS id
        , NULL AS entity
        , ''' + N'Opening Balance' + ''' AS description
        , NULL AS account
        , NULL AS sub_account
        , NULL AS region
        , NULL AS product
        , NULL AS vat
        , NULL AS unit
        , CASE WHEN s.id = 1 THEN a.code ELSE NULL END AS debit
        , CASE WHEN s.id = 1 THEN NULL ELSE a.code END AS credit
        , NULL AS section
        , CASE WHEN s.id = 1 THEN r.debit ELSE r.credit END AS data00
        , NULL AS data01, NULL AS data02, NULL AS data03, NULL AS data04, NULL AS data05, NULL AS data06, NULL AS data07, NULL AS data08, NULL AS data09, NULL AS data10, NULL AS data11, NULL AS data12
        , COALESCE(users.name, r.modified_by) AS last_user
        , r.modified_on AS last_update
        , NULL AS entity_sort_order
        , NULL AS row_index
        , NULL AS entry_id
        , s.id AS entry_side_id
    FROM
        dbo27.budget_balances r
        INNER JOIN dbo27.ledger_accounts a ON a.id = r.account_id
        CROSS JOIN dbo27.entry_sides s
        INNER JOIN dbo27.report_section_accounts rsa ON rsa.account_type_id = a.account_type_id AND rsa.entry_side_id = s.id
        INNER JOIN dbo27.report_sections rs ON rs.company_id = a.company_id AND rs.section_type_id = rsa.section_type_id'
        + CASE WHEN @account_id IS NOT NULL THEN '' ELSE '
        INNER JOIN factors f ON f.id = rs.id
        INNER JOIN dbo27.report_sections frs ON frs.id = f.parent_id'
            END + '
        LEFT OUTER JOIN dbo27.users users ON users.company_id = a.company_id AND users.username = r.modified_by
    WHERE
        r.category_id = ' + @category_sid + '
        AND r.time_id = ' + @time_sid + '
        AND (r.debit IS NOT NULL OR r.credit IS NOT NULL)
        AND rsa.value_type_id IN (2, 3, 4)'
        + CASE WHEN @account_id IS NOT NULL THEN '
        AND rs.ref_number + COALESCE(a.ref_number, 0) = ' + CAST(@ref_number AS nvarchar(50))
            ELSE '
        AND frs.ref_number = ' + CAST(@ref_number AS nvarchar(50)) + '
        AND COALESCE(frs.show_line, 1) = 1'
            END + '
)'

-- SET @sql = @sql + 'SELECT * FROM b1'

-- Build output columns

SET @sql = @sql + '
SELECT
    id
    , entity
    , description
    , account
    , sub_account
    , region
    , product
    , vat
    , unit
    , debit
    , credit
    , section'

DECLARE @index int

IF @value_type_id = 1 AND @total_type_id = 1
    BEGIN
    IF @column_name IN ('data01', 'data02', 'data03', 'data04', 'data05', 'data06', 'data07', 'data08', 'data09', 'data10', 'data11', 'data12')
        SET @sql = @sql + '
        , ' + @column_name
    ELSE
        SET @sql = @sql + '
        , COALESCE(data01, 0) + COALESCE(data02, 0) + COALESCE(data03, 0) + COALESCE(data04, 0) + COALESCE(data05, 0) + COALESCE(data06, 0) + COALESCE(data07, 0) + COALESCE(data08, 0) + COALESCE(data09, 0) + COALESCE(data10, 0) + COALESCE(data11, 0) + COALESCE(data12, 0) AS data00
        , data01, data02, data03, data04, data05, data06, data07, data08, data09, data10, data11, data12'
    END
ELSE IF @total_type_id = 3 AND @column_name = 'data00'
        SET @sql = @sql + '
        , data00, data01, data02, data03, data04, data05, data06, data07, data08, data09, data10, data11, data12'
ELSE
    BEGIN
    SET @index = CHARINDEX(@column_name, ', data00, data01, data02, data03, data04, data05, data06, data07, data08, data09, data10, data11, data12')
    IF @index = 0
        SET @sql = @sql + '
        , data00, data01, data02, data03, data04, data05, data06, data07, data08, data09, data10, data11, data12'
    ELSE
        SET @sql = @sql + '
        ' + SUBSTRING(', data00, data01, data02, data03, data04, data05, data06, data07, data08, data09, data10, data11, data12', 1, @index + 5)
    END

SET @sql = @sql + '
    , last_user
    , last_update'

-- Build the FROM clause

IF NOT (@value_type_id = 1 AND @total_type_id = 1) AND @entity_id IS NULL
    SET @sql = @sql + '
FROM
    (
    SELECT * FROM f1
    UNION ALL
    SELECT * FROM b2
    ) s'
ELSE
    SET @sql = @sql + '
FROM
    b2 s'

-- Build the WHERE clause

    SET @sql = @sql + '
WHERE'

IF @value_type_id = 1 AND @total_type_id = 1
    BEGIN
    IF @column_name IN ('data01', 'data02', 'data03', 'data04', 'data05', 'data06', 'data07', 'data08', 'data09', 'data10', 'data11', 'data12')
        SET @sql = @sql + '
        NOT COALESCE(' + @column_name + ', 0) = 0'
    ELSE
        SET @sql = @sql + '
        NOT COALESCE(data01, 0) = 0 OR NOT COALESCE(data02, 0) = 0 OR NOT COALESCE(data03, 0) = 0 OR NOT COALESCE(data04, 0) = 0 OR NOT COALESCE(data05, 0) = 0 OR NOT COALESCE(data06, 0) = 0 OR NOT COALESCE(data07, 0) = 0 OR NOT COALESCE(data08, 0) = 0 OR NOT COALESCE(data09, 0) = 0 OR NOT COALESCE(data10, 0) = 0 OR NOT COALESCE(data11, 0) = 0 OR NOT COALESCE(data12, 0) = 0'
    END
ELSE IF @total_type_id = 3 AND @column_name = 'data00'
        SET @sql = @sql + '
        NOT COALESCE(data00, 0) = 0 OR NOT COALESCE(data01, 0) = 0 OR NOT COALESCE(data02, 0) = 0 OR NOT COALESCE(data03, 0) = 0 OR NOT COALESCE(data04, 0) = 0 OR NOT COALESCE(data05, 0) = 0 OR NOT COALESCE(data06, 0) = 0 OR NOT COALESCE(data07, 0) = 0 OR NOT COALESCE(data08, 0) = 0 OR NOT COALESCE(data09, 0) = 0 OR NOT COALESCE(data10, 0) = 0 OR NOT COALESCE(data11, 0) = 0 OR NOT COALESCE(data12, 0) = 0'
ELSE
    BEGIN
    SET @index = CHARINDEX(@column_name, 'NOT COALESCE(data00, 0) = 0 OR NOT COALESCE(data01, 0) = 0 OR NOT COALESCE(data02, 0) = 0 OR NOT COALESCE(data03, 0) = 0 OR NOT COALESCE(data04, 0) = 0 OR NOT COALESCE(data05, 0) = 0 OR NOT COALESCE(data06, 0) = 0 OR NOT COALESCE(data07, 0) = 0 OR NOT COALESCE(data08, 0) = 0 OR NOT COALESCE(data09, 0) = 0 OR NOT COALESCE(data10, 0) = 0 OR NOT COALESCE(data11, 0) = 0 OR NOT COALESCE(data12, 0) = 0')
    IF @index = 0
        SET @sql = @sql + '
        NOT COALESCE(data00, 0) = 0 OR NOT COALESCE(data01, 0) = 0 OR NOT COALESCE(data02, 0) = 0 OR NOT COALESCE(data03, 0) = 0 OR NOT COALESCE(data04, 0) = 0 OR NOT COALESCE(data05, 0) = 0 OR NOT COALESCE(data06, 0) = 0 OR NOT COALESCE(data07, 0) = 0 OR NOT COALESCE(data08, 0) = 0 OR NOT COALESCE(data09, 0) = 0 OR NOT COALESCE(data10, 0) = 0 OR NOT COALESCE(data11, 0) = 0 OR NOT COALESCE(data12, 0) = 0'
    ELSE
        SET @sql = @sql + '
        ' + SUBSTRING('NOT COALESCE(data00, 0) = 0 OR NOT COALESCE(data01, 0) = 0 OR NOT COALESCE(data02, 0) = 0 OR NOT COALESCE(data03, 0) = 0 OR NOT COALESCE(data04, 0) = 0 OR NOT COALESCE(data05, 0) = 0 OR NOT COALESCE(data06, 0) = 0 OR NOT COALESCE(data07, 0) = 0 OR NOT COALESCE(data08, 0) = 0 OR NOT COALESCE(data09, 0) = 0 OR NOT COALESCE(data10, 0) = 0 OR NOT COALESCE(data11, 0) = 0 OR NOT COALESCE(data12, 0) = 0', 1, @index + 13)
    END

-- Build the ORDER BY clause

SET @sql = @sql + '
ORDER BY
    entity_sort_order
    , entity
    , row_index
    , entry_id
    , entry_side_id
'

-- Execute the dynamic SQL

DECLARE @print int = 1

IF @print = 1
    BEGIN
    PRINT SUBSTRING(@sql, 1, 4000)
    IF LEN(@sql) > 4000  PRINT SUBSTRING(@sql, 4001, 4000)
    IF LEN(@sql) > 8000  PRINT SUBSTRING(@sql, 8001, 4000)
    IF LEN(@sql) > 12000 PRINT SUBSTRING(@sql, 12001, 4000)
    END

EXEC (@sql)

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Selects member index
-- =============================================

CREATE PROCEDURE [xls27].[xl_actions_select_members]
    @company_id int = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

SELECT
    d.name AS dimension
    , m.code
    , COALESCE(tr.name, m.name) AS name
FROM
    dbo27.members m
    INNER JOIN dbo27.dimensions d ON d.id = m.dimension_id
    LEFT OUTER JOIN dbo27.member_permissions mp ON mp.member_id = m.id AND mp.username = USER_NAME()
    LEFT OUTER JOIN dbo27.translations tr ON tr.company_id = m.company_id AND tr.table_id = 2 AND tr.member_id = m.id AND tr.language = @data_language
WHERE
    m.is_active = 1
    AND m.company_id = @company_id
    AND (COALESCE(mp.update_permission, 0) = 1 OR COALESCE(mp.select_permission, 0) = 1 OR NOT EXISTS (
        SELECT
            p.name
        FROM
            sys.database_principals p
            INNER JOIN sys.database_role_members rm ON rm.member_principal_id = p.principal_id
        WHERE
            p.name = USER_NAME()
            AND rm.role_principal_id = USER_ID('budgeting_app_users')
        ))
ORDER BY
    d.id
    , m.sort_order
    , m.code
    , m.name

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Parameter values of category_id
-- =============================================

CREATE PROCEDURE [xls27].[xl_parameter_values_category_id]
    @company_id int = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

SELECT id, name FROM (
    SELECT NULL AS id, NULL AS name, NULL AS sort_order UNION ALL
    SELECT
        m.id
        , COALESCE(tr.name, m.name) AS name
        , m.sort_order
    FROM
        dbo27.members m
        LEFT OUTER JOIN dbo27.member_permissions mp ON mp.member_id = m.id AND mp.username = USER_NAME()
        LEFT OUTER JOIN dbo27.translations tr ON tr.company_id = m.company_id AND tr.table_id = 1 AND tr.member_id = m.id AND tr.language = @data_language
    WHERE
        m.dimension_id = 3
        AND m.is_active = 1
        AND m.company_id = @company_id
        AND (COALESCE(mp.update_permission, 0) = 1 OR COALESCE(mp.select_permission, 0) = 1 OR NOT EXISTS (
            SELECT
                p.name
            FROM
                sys.database_principals p
                INNER JOIN sys.database_role_members rm ON rm.member_principal_id = p.principal_id
            WHERE
                p.name = USER_NAME()
                AND rm.role_principal_id = USER_ID('budgeting_app_users')
            ))
) t
ORDER BY
    sort_order
    , name

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Parameter values of category_id
-- =============================================

CREATE PROCEDURE [xls27].[xl_parameter_values_category_id_not_null]
    @company_id int = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

SELECT id, name FROM (
    -- SELECT NULL AS id, NULL AS name, NULL AS sort_order UNION ALL
    SELECT
        m.id
        , COALESCE(tr.name, m.name) AS name
        , m.sort_order
    FROM
        dbo27.members m
        LEFT OUTER JOIN dbo27.member_permissions mp ON mp.member_id = m.id AND mp.username = USER_NAME()
        LEFT OUTER JOIN dbo27.translations tr ON tr.company_id = m.company_id AND tr.table_id = 1 AND tr.member_id = m.id AND tr.language = @data_language
    WHERE
        m.dimension_id = 3
        AND m.is_active = 1
        AND m.company_id = @company_id
        AND (COALESCE(mp.update_permission, 0) = 1 OR COALESCE(mp.select_permission, 0) = 1 OR NOT EXISTS (
            SELECT
                p.name
            FROM
                sys.database_principals p
                INNER JOIN sys.database_role_members rm ON rm.member_principal_id = p.principal_id
            WHERE
                p.name = USER_NAME()
                AND rm.role_principal_id = USER_ID('budgeting_app_users')
            ))
) t
ORDER BY
    sort_order
    , name

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Parameter values of company_id
-- =============================================

CREATE PROCEDURE [xls27].[xl_parameter_values_company_id]
    @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

SELECT
    t.id
    , COALESCE(tr.name, t.name) AS name
FROM
    dbo27.companies t
    INNER JOIN dbo27.users u ON u.company_id = t.id AND u.username = USER_NAME() AND u.is_active = 1
    LEFT OUTER JOIN dbo27.translations tr ON tr.company_id = t.id AND tr.table_id = 2 AND tr.member_id = t.id AND tr.language = @data_language
ORDER BY
    t.sort_order
    , t.name

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Parameter values of currency_id
-- =============================================

CREATE PROCEDURE [xls27].[xl_parameter_values_currency_id]
    @company_id int = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

SELECT NULL AS id, NULL AS name UNION ALL
SELECT
    t.id
    , COALESCE(tr.name, t.name) AS name
FROM
    dbo27.units t
    LEFT OUTER JOIN dbo27.translations tr ON tr.company_id = t.company_id AND tr.table_id = 3 AND tr.member_id = t.id AND tr.language = @data_language
WHERE
    t.is_currency = 1
    AND t.company_id = @company_id
ORDER BY
    name

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Day parameter values
-- =============================================

CREATE PROCEDURE [xls27].[xl_parameter_values_day]
AS
BEGIN

SET NOCOUNT ON

SELECT
    d.[day]
FROM
    (VALUES (NULL),
            (1), (2), (3), (4), (5), (6), (7), (8), (9), (10),
            (11), (12), (13), (14), (15), (16), (17), (18), (19), (20),
            (21), (22), (23), (24), (25), (26), (27), (28), (29), (30),
            (31)) d([day])

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Parameter values of dimension_id
-- =============================================

CREATE PROCEDURE [xls27].[xl_parameter_values_dimension_id]
    @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

SELECT id, name FROM (
    SELECT NULL AS id, NULL AS name UNION ALL
    SELECT
        t.id
        , COALESCE(tr.TRANSLATED_NAME, t.name) AS name
    FROM
        dbo27.dimensions t
        LEFT OUTER JOIN xls.translations tr ON tr.TABLE_SCHEMA = 'dbo27' AND tr.TABLE_NAME = 'dimensions_name' AND tr.COLUMN_NAME = t.name AND tr.LANGUAGE_NAME = @data_language
) t
ORDER BY
    id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Parameter values of dimension_id
-- =============================================

CREATE PROCEDURE [xls27].[xl_parameter_values_dimension_id_not_null]
    @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

SELECT
    t.id
    , COALESCE(tr.TRANSLATED_NAME, t.name) AS name
FROM
    dbo27.dimensions t
    LEFT OUTER JOIN xls.translations tr ON tr.TABLE_SCHEMA = 'dbo27' AND tr.TABLE_NAME = 'dimensions_name' AND tr.COLUMN_NAME = t.name AND tr.LANGUAGE_NAME = @data_language
ORDER BY
    t.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Parameter values of entity_id
-- =============================================

CREATE PROCEDURE [xls27].[xl_parameter_values_entity_id]
    @company_id int = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

SELECT id, name FROM (
    SELECT NULL AS id, NULL AS name, NULL AS sort_order UNION ALL
    SELECT
        m.id
        , COALESCE(tr.name, m.name) AS name
        , m.sort_order
    FROM
        dbo27.members m
        LEFT OUTER JOIN dbo27.member_permissions mp ON mp.member_id = m.id AND mp.username = USER_NAME()
        LEFT OUTER JOIN dbo27.translations tr ON tr.company_id = m.company_id AND tr.table_id = 1 AND tr.member_id = m.id AND tr.language = @data_language
    WHERE
        m.dimension_id = 4
        AND m.is_active = 1
        AND m.company_id = @company_id
        AND (COALESCE(mp.update_permission, 0) = 1 OR COALESCE(mp.select_permission, 0) = 1 OR NOT EXISTS (
            SELECT
                p.name
            FROM
                sys.database_principals p
                INNER JOIN sys.database_role_members rm ON rm.member_principal_id = p.principal_id
            WHERE
                p.name = USER_NAME()
                AND rm.role_principal_id = USER_ID('budgeting_app_users')
            ))
) t
ORDER BY
    sort_order
    , name

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Parameter values of entity_id
-- =============================================

CREATE PROCEDURE [xls27].[xl_parameter_values_entity_id_not_null]
    @company_id int = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

SELECT id, name FROM (
    -- SELECT NULL AS id, NULL AS name, NULL AS sort_order UNION ALL
    SELECT
        m.id
        , COALESCE(tr.name, m.name) AS name
        , m.sort_order
    FROM
        dbo27.members m
        LEFT OUTER JOIN dbo27.member_permissions mp ON mp.member_id = m.id AND mp.username = USER_NAME()
        LEFT OUTER JOIN dbo27.translations tr ON tr.company_id = m.company_id AND tr.table_id = 1 AND tr.member_id = m.id AND tr.language = @data_language
    WHERE
        m.dimension_id = 4
        AND m.is_active = 1
        AND m.company_id = @company_id
        AND (COALESCE(mp.update_permission, 0) = 1 OR COALESCE(mp.select_permission, 0) = 1 OR NOT EXISTS (
            SELECT
                p.name
            FROM
                sys.database_principals p
                INNER JOIN sys.database_role_members rm ON rm.member_principal_id = p.principal_id
            WHERE
                p.name = USER_NAME()
                AND rm.role_principal_id = USER_ID('budgeting_app_users')
            ))
) t
ORDER BY
    sort_order
    , name

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Parameter values of entry_side_id
-- =============================================

CREATE PROCEDURE [xls27].[xl_parameter_values_entry_side_id]
    @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

SELECT id, name FROM (
    SELECT NULL AS id, NULL AS name UNION ALL
    SELECT
        r.id
        , COALESCE(tr.TRANSLATED_NAME, r.name) AS name
    FROM
        dbo27.entry_sides r
        LEFT OUTER JOIN xls.translations tr ON tr.TABLE_SCHEMA = 'dbo27' AND tr.TABLE_NAME = 'entry_sides_name' AND tr.COLUMN_NAME = r.name AND tr.LANGUAGE_NAME = @data_language
) t
ORDER BY
    id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Parameter values of ledger account_id
-- =============================================

CREATE PROCEDURE [xls27].[xl_parameter_values_ledger_account_id_code]
    @company_id int = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

SELECT NULL AS id, NULL AS code
UNION ALL
SELECT
    t.id
    , t.code
FROM
    dbo27.ledger_accounts t
WHERE
    t.company_id = @company_id
ORDER BY
    code

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Parameter values of member_types.type_id
-- =============================================

CREATE PROCEDURE [xls27].[xl_parameter_values_member_type_id]
    @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

SELECT id, name FROM (
    SELECT NULL AS id, NULL AS name UNION ALL
    SELECT
        mt.id
        , COALESCE(tr.TRANSLATED_NAME, mt.name) AS name
    FROM
        dbo27.member_types mt
        LEFT OUTER JOIN xls.translations tr ON tr.TABLE_SCHEMA = 'dbo27' AND tr.TABLE_NAME = 'member_types_name' AND tr.COLUMN_NAME = mt.name AND tr.LANGUAGE_NAME = @data_language
) t
ORDER BY
    id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Parameter values of month numbers
-- =============================================

CREATE PROCEDURE [xls27].[xl_parameter_values_month]
    @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

SELECT
    m.id
    , COALESCE(tr.TRANSLATED_NAME, DATENAME(M, DATEADD(M, m.id, '2019-12-31'))) AS name
FROM
    (VALUES (1), (2), (3), (4), (5), (6), (7), (8), (9), (10), (11), (12)) m(id)
    LEFT OUTER JOIN xls.translations tr ON tr.TABLE_SCHEMA = 'xls27' AND tr.TABLE_NAME = 'xl_parameter_values_month_name' AND tr.COLUMN_NAME = DATENAME(M, DATEADD(M, m.id, '2019-12-31')) AND tr.LANGUAGE_NAME = @data_language

ORDER BY
    m.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Parameter values of report_type_id
-- =============================================

CREATE PROCEDURE [xls27].[xl_parameter_values_report_type_id]
    @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

SELECT id, name FROM (
    SELECT NULL AS id, NULL AS name UNION ALL
    SELECT
        r.id
        , COALESCE(tr.TRANSLATED_NAME, r.name) AS name
    FROM
        dbo27.report_types r
        LEFT OUTER JOIN xls.translations tr ON tr.TABLE_SCHEMA = 'dbo27' AND tr.TABLE_NAME = 'report_types_name' AND tr.COLUMN_NAME = r.name AND tr.LANGUAGE_NAME = @data_language
) t
ORDER BY
    id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Parameter values of report_type_id
-- =============================================

CREATE PROCEDURE [xls27].[xl_parameter_values_report_type_id_code]
    @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

SELECT id, code FROM (
    SELECT NULL AS id, NULL AS code UNION ALL
    SELECT
        r.id
        , COALESCE(tr.TRANSLATED_NAME, r.code) AS code
    FROM
        dbo27.report_types r
        LEFT OUTER JOIN xls.translations tr ON tr.TABLE_SCHEMA = 'dbo27' AND tr.TABLE_NAME = 'report_types_code' AND tr.COLUMN_NAME = r.code AND tr.LANGUAGE_NAME = @data_language
) t
ORDER BY
    id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Parameter values of saved_report_type_id
-- =============================================

CREATE PROCEDURE [xls27].[xl_parameter_values_saved_report_type_id]
    @company_id int = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

SELECT id, name FROM (
    SELECT NULL AS id, NULL AS name UNION ALL
    SELECT
        m.id
        , COALESCE(tr.name, m.name) AS name
    FROM
        dbo27.saved_report_types m
        LEFT OUTER JOIN dbo27.translations tr ON tr.company_id = m.company_id AND tr.table_id = 12 AND tr.member_id = m.id AND tr.language = @data_language
    WHERE
        m.company_id = @company_id
) t
ORDER BY
    name

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Parameter values of account_id
-- =============================================

CREATE PROCEDURE [xls27].[xl_parameter_values_subsidiary_account_id]
    @company_id int = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

SELECT NULL AS id, NULL AS name
UNION ALL
SELECT
    t.id
    , COALESCE(tr.name, t.name) AS name
FROM
    dbo27.members t
    LEFT OUTER JOIN dbo27.translations tr ON tr.company_id = t.company_id AND tr.table_id = 1 AND tr.member_id = t.id AND tr.language = @data_language
WHERE
    t.dimension_id = 7
    AND t.company_id = @company_id
ORDER BY
    name

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Parameter values of subsidiary_group_id
-- =============================================

CREATE PROCEDURE [xls27].[xl_parameter_values_subsidiary_group_id]
    @company_id int = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

SELECT NULL AS id, NULL AS name
UNION ALL
SELECT
    t.id
    , COALESCE(tr.name, t.name) AS name
FROM
    dbo27.subsidiary_groups t
    LEFT OUTER JOIN dbo27.translations tr ON tr.company_id = t.company_id AND tr.table_id = 10 AND tr.member_id = t.id AND tr.language = @data_language
WHERE
    t.company_id = @company_id
ORDER BY
    id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Parameter values of time_id
-- =============================================

CREATE PROCEDURE [xls27].[xl_parameter_values_time_id]
    @company_id int = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

SELECT id, name FROM (
    SELECT NULL AS id, NULL AS name, NULL AS sort_order UNION ALL
    SELECT
        m.id
        , COALESCE(tr.name, m.name) AS name
        , m.sort_order
    FROM
        dbo27.members m
        LEFT OUTER JOIN dbo27.member_permissions mp ON mp.member_id = m.id AND mp.username = USER_NAME()
        LEFT OUTER JOIN dbo27.translations tr ON tr.company_id = m.company_id AND tr.table_id = 1 AND tr.member_id = m.id AND tr.language = @data_language
    WHERE
        m.dimension_id = 2
        AND m.is_active = 1
        AND m.company_id = @company_id
        AND (COALESCE(mp.update_permission, 0) = 1 OR COALESCE(mp.select_permission, 0) = 1 OR NOT EXISTS (
            SELECT
                p.name
            FROM
                sys.database_principals p
                INNER JOIN sys.database_role_members rm ON rm.member_principal_id = p.principal_id
            WHERE
                p.name = USER_NAME()
                AND rm.role_principal_id = USER_ID('budgeting_app_users')
            ))
) t
ORDER BY
    sort_order
    , name

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Parameter values of time_id
-- =============================================

CREATE PROCEDURE [xls27].[xl_parameter_values_time_id_not_null]
    @company_id int = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

SELECT id, name FROM (
    -- SELECT NULL AS id, NULL AS name, NULL AS sort_order UNION ALL
    SELECT
        m.id
        , COALESCE(tr.name, m.name) AS name
        , m.sort_order
    FROM
        dbo27.members m
        LEFT OUTER JOIN dbo27.member_permissions mp ON mp.member_id = m.id AND mp.username = USER_NAME()
        LEFT OUTER JOIN dbo27.translations tr ON tr.company_id = m.company_id AND tr.table_id = 1 AND tr.member_id = m.id AND tr.language = @data_language
    WHERE
        m.dimension_id = 2
        AND m.is_active = 1
        AND m.company_id = @company_id
        AND (COALESCE(mp.update_permission, 0) = 1 OR COALESCE(mp.select_permission, 0) = 1 OR NOT EXISTS (
            SELECT
                p.name
            FROM
                sys.database_principals p
                INNER JOIN sys.database_role_members rm ON rm.member_principal_id = p.principal_id
            WHERE
                p.name = USER_NAME()
                AND rm.role_principal_id = USER_ID('budgeting_app_users')
            ))
) t
ORDER BY
    sort_order
    , name

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Parameter values of username
-- =============================================

CREATE PROCEDURE [xls27].[xl_parameter_values_username]
    @company_id int = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

SELECT NULL AS name UNION ALL
SELECT
    u.username AS name
FROM
    dbo27.users u
WHERE
    u.company_id = @company_id
    AND u.is_active = 1
    AND u.is_admin = 0
ORDER BY
    name

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Year parameter values
-- =============================================

CREATE PROCEDURE [xls27].[xl_parameter_values_year]
AS
BEGIN

SET NOCOUNT ON

SELECT
    y.[year]
FROM
    (VALUES (2025), (2024), (2023), (2022), (2021), (2020), (2019), (2018), (2017), (2016), (2015)) y([year])
WHERE
    y.[year] BETWEEN (SELECT YEAR(MIN([date])) FROM dbo27.journals) AND (SELECT YEAR(MAX([date])) FROM dbo27.journals)
    OR y.[year] = YEAR(GETDATE())

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Validation list of budgeting account_id
-- =============================================

CREATE PROCEDURE [xls27].[xl_validation_list_budgeting_account_id_code]
    @company_id int = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

SELECT id, name FROM (
    SELECT NULL AS id, NULL AS name, NULL AS sort_order
    UNION ALL
    SELECT
        m.id
        , m.code AS name
        , m.sort_order
    FROM
        dbo27.members m
        LEFT OUTER JOIN dbo27.member_permissions mp ON mp.member_id = m.id AND mp.username = USER_NAME()
    WHERE
        m.dimension_id = 1
        AND m.is_active = 1
        AND m.company_id = @company_id
        AND (COALESCE(mp.update_permission, 0) = 1 OR COALESCE(mp.select_permission, 0) = 1 OR NOT EXISTS (
            SELECT
                p.name
            FROM
                sys.database_principals p
                INNER JOIN sys.database_role_members rm ON rm.member_principal_id = p.principal_id
            WHERE
                p.name = USER_NAME()
                AND rm.role_principal_id = USER_ID('budgeting_app_users')
            ))
) t
ORDER BY
    sort_order
    , name

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Validation list of budgeting account_type_id
-- =============================================

CREATE PROCEDURE [xls27].[xl_validation_list_budgeting_account_type_id]
    @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

SELECT id, name FROM (
    SELECT NULL AS id, NULL AS name UNION ALL
    SELECT
        a.id
        , COALESCE(tr.TRANSLATED_NAME, a.name) AS name
    FROM
        dbo27.member_types a
        LEFT OUTER JOIN xls.translations tr ON tr.TABLE_SCHEMA = 'dbo27' AND tr.TABLE_NAME = 'member_types_name' AND tr.COLUMN_NAME = a.name AND tr.LANGUAGE_NAME = @data_language
) t
ORDER BY
    id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Validation list of members.parent_id
-- =============================================

CREATE PROCEDURE [xls27].[xl_validation_list_budgeting_parent_id_code]
    @company_id int = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

SELECT id, code FROM (
    SELECT NULL AS id, NULL AS code
    UNION ALL
    SELECT
        m.id
        , m.code
    FROM
        dbo27.members m
    WHERE
        m.dimension_id = 1
        AND m.payment_debit_id IS NULL
        AND m.payment_credit_id IS NULL
        AND m.charge_debit_id IS NULL
        AND m.charge_credit_id IS NULL
        AND m.vat_debit_id IS NULL
        AND m.vat_credit_id IS NULL
        AND m.company_id = @company_id
) t
ORDER BY
    code

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Validation list of account_id
-- =============================================

CREATE PROCEDURE [xls27].[xl_validation_list_credit_account_id_code]
    @company_id int = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

SELECT id, code FROM (
    SELECT NULL AS id, NULL AS code
    UNION ALL
    SELECT
        t.id
        , t.code
    FROM
        dbo27.ledger_accounts t
    WHERE
        t.company_id = @company_id
) t
ORDER BY
    code

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Validation list of subsidiary_account_id
-- =============================================

CREATE PROCEDURE [xls27].[xl_validation_list_credit_subsidiary_account_id]
    @company_id int = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

SELECT id, name, credit_account_id FROM (
    SELECT NULL AS id, NULL AS name, NULL AS credit_account_id
    UNION ALL
    SELECT
        t.id
        , COALESCE(tr.name, t.name) AS name
        , a.id AS credit_account_id
    FROM
        dbo27.members t
        LEFT OUTER JOIN dbo27.member_groups g ON g.member_id = t.id
        LEFT OUTER JOIN dbo27.ledger_accounts a ON a.subsidiary_group_id = g.group_id
        LEFT OUTER JOIN dbo27.translations tr ON tr.company_id = t.company_id AND tr.table_id = 1 AND tr.member_id = t.id AND tr.language = @data_language
    WHERE
        t.dimension_id = 7
        AND t.company_id = @company_id
) t
ORDER BY
    credit_account_id
    , name
    , id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Validation list of currency_id
-- =============================================

CREATE PROCEDURE [xls27].[xl_validation_list_currency_id]
    @company_id int = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

SELECT
    t.id
    , COALESCE(tr.name, t.name) AS name
FROM
    dbo27.units t
    LEFT OUTER JOIN dbo27.translations tr ON tr.company_id = t.company_id AND tr.table_id = 3 AND tr.member_id = t.id AND tr.language = @data_language
WHERE
    t.is_currency = 1
    AND t.company_id = @company_id
ORDER BY
    t.name

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Validation list of currency_id
-- =============================================

CREATE PROCEDURE [xls27].[xl_validation_list_currency_id_code]
    @company_id int = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

SELECT
    t.id
    , t.code
FROM
    dbo27.units t
WHERE
    t.is_currency = 1
    AND t.company_id = @company_id
ORDER BY
    t.code

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Validation list of account_id
-- =============================================

CREATE PROCEDURE [xls27].[xl_validation_list_debit_account_id_code]
    @company_id int = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

SELECT id, code FROM (
    SELECT NULL AS id, NULL AS code
    UNION ALL
    SELECT
        t.id
        , t.code
    FROM
        dbo27.ledger_accounts t
    WHERE
        t.company_id = @company_id
) t
ORDER BY
    code

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Validation list of subsidiary_account_id
-- =============================================

CREATE PROCEDURE [xls27].[xl_validation_list_debit_subsidiary_account_id]
    @company_id int = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

SELECT id, name, debit_account_id FROM (
    SELECT NULL AS id, NULL AS name, NULL AS debit_account_id
    UNION ALL
    SELECT
        t.id
        , COALESCE(tr.name, t.name) AS name
        , a.id AS debit_account_id
    FROM
        dbo27.members t
        LEFT OUTER JOIN dbo27.member_groups g ON g.member_id = t.id
        LEFT OUTER JOIN dbo27.ledger_accounts a ON a.subsidiary_group_id = g.group_id
        LEFT OUTER JOIN dbo27.translations tr ON tr.company_id = t.company_id AND tr.table_id = 1 AND tr.member_id = t.id AND tr.language = @data_language
    WHERE
        t.dimension_id = 7
        AND t.company_id = @company_id
) t
ORDER BY
    debit_account_id
    , name
    , id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Validation list of dimension_id
-- =============================================

CREATE PROCEDURE [xls27].[xl_validation_list_dimension_id]
    @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

SELECT
    t.id
    , COALESCE(tr.TRANSLATED_NAME, t.name) AS name
FROM
    dbo27.dimensions t
    LEFT OUTER JOIN xls.translations tr ON tr.TABLE_SCHEMA = 'dbo27' AND tr.TABLE_NAME = 'dimensions_name' AND tr.COLUMN_NAME = t.name AND tr.LANGUAGE_NAME = @data_language
ORDER BY
    t.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Validation list of entity_id
-- =============================================

CREATE PROCEDURE [xls27].[xl_validation_list_entity_id]
    @company_id int = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

SELECT id, name FROM (
    SELECT NULL AS id, NULL AS name, NULL AS sort_order
    UNION ALL
    SELECT
        m.id
        , COALESCE(tr.name, m.name) AS name
        , m.sort_order
    FROM
        dbo27.members m
        LEFT OUTER JOIN dbo27.member_permissions mp ON mp.member_id = m.id AND mp.username = USER_NAME()
        LEFT OUTER JOIN dbo27.translations tr ON tr.company_id = m.company_id AND tr.table_id = 1 AND tr.member_id = m.id AND tr.language = @data_language
    WHERE
        m.dimension_id = 4
        AND m.is_active = 1
        AND m.company_id = @company_id
        AND (COALESCE(mp.update_permission, 0) = 1 OR COALESCE(mp.select_permission, 0) = 1 OR NOT EXISTS (
            SELECT
                p.name
            FROM
                sys.database_principals p
                INNER JOIN sys.database_role_members rm ON rm.member_principal_id = p.principal_id
            WHERE
                p.name = USER_NAME()
                AND rm.role_principal_id = USER_ID('budgeting_app_users')
            ))
) t
ORDER BY
    sort_order
    , name

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Validation list of entity_id
-- =============================================

CREATE PROCEDURE [xls27].[xl_validation_list_entity_id_code]
    @company_id int = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

SELECT id, name FROM (
    SELECT NULL AS id, NULL AS name, NULL AS sort_order
    UNION ALL
    SELECT
        m.id
        , m.code AS name
        , m.sort_order
    FROM
        dbo27.members m
        LEFT OUTER JOIN dbo27.member_permissions mp ON mp.member_id = m.id AND mp.username = USER_NAME()
    WHERE
        m.dimension_id = 4
        AND m.is_active = 1
        AND m.company_id = @company_id
        AND (COALESCE(mp.update_permission, 0) = 1 OR COALESCE(mp.select_permission, 0) = 1 OR NOT EXISTS (
            SELECT
                p.name
            FROM
                sys.database_principals p
                INNER JOIN sys.database_role_members rm ON rm.member_principal_id = p.principal_id
            WHERE
                p.name = USER_NAME()
                AND rm.role_principal_id = USER_ID('budgeting_app_users')
            ))
) t
ORDER BY
    sort_order
    , name

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Validation list of entry_side_id
-- =============================================

CREATE PROCEDURE [xls27].[xl_validation_list_entry_side_id]
    @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

SELECT id, name FROM (
    SELECT NULL AS id, NULL AS name UNION ALL
    SELECT
        a.id
        , COALESCE(tr.TRANSLATED_NAME, a.name) AS name
    FROM
        dbo27.entry_sides a
        LEFT OUTER JOIN xls.translations tr ON tr.TABLE_SCHEMA = 'dbo27' AND tr.TABLE_NAME = 'entry_sides_name' AND tr.COLUMN_NAME = a.name AND tr.LANGUAGE_NAME = @data_language
) t
ORDER BY
    id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Validation list of account_id
-- =============================================

CREATE PROCEDURE [xls27].[xl_validation_list_ledger_account_id]
    @company_id int = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

SELECT
    t.id
    , COALESCE(tr.name, t.name) AS name
FROM
    dbo27.ledger_accounts t
    LEFT OUTER JOIN dbo27.translations tr ON tr.company_id = t.company_id AND tr.table_id = 11 AND tr.member_id = t.id AND tr.language = @data_language
WHERE
    t.company_id = @company_id
ORDER BY
    t.code

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Validation list of ledger account_id
-- =============================================

CREATE PROCEDURE [xls27].[xl_validation_list_ledger_account_id_code]
    @company_id int = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

SELECT
    m.id
    , m.code
FROM
    dbo27.ledger_accounts m
WHERE
    m.company_id = @company_id
ORDER BY
    code

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Validation list of ledger_account_special_type_id
-- =============================================

CREATE PROCEDURE [xls27].[xl_validation_list_ledger_account_special_type_id]
    @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

SELECT id, name FROM (
    SELECT NULL AS id, NULL AS name UNION ALL
    SELECT
        a.id
        , COALESCE(tr.TRANSLATED_NAME, a.name) AS name
    FROM
        dbo27.ledger_account_special_types a
        LEFT OUTER JOIN xls.translations tr ON tr.TABLE_SCHEMA = 'dbo27' AND tr.TABLE_NAME = 'ledger_account_special_types_name' AND tr.COLUMN_NAME = a.name AND tr.LANGUAGE_NAME = @data_language
) t
ORDER BY
    id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Validation list of account_type_id
-- =============================================

CREATE PROCEDURE [xls27].[xl_validation_list_ledger_account_type_id]
    @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

SELECT id, name FROM (
    SELECT NULL AS id, NULL AS name UNION ALL
    SELECT
        a.id
        , COALESCE(tr.TRANSLATED_NAME, a.name) AS name
    FROM
        dbo27.ledger_account_types a
        LEFT OUTER JOIN xls.translations tr ON tr.TABLE_SCHEMA = 'dbo27' AND tr.TABLE_NAME = 'ledger_account_types_name' AND tr.COLUMN_NAME = a.name AND tr.LANGUAGE_NAME = @data_language
) t
ORDER BY
    id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Validation list of member_types.type_id
-- =============================================

CREATE PROCEDURE [xls27].[xl_validation_list_member_type_id]
    @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

SELECT id, name FROM (
    SELECT NULL AS id, NULL AS name UNION ALL
    SELECT
        mt.id
        , COALESCE(tr.TRANSLATED_NAME, mt.name) AS name
    FROM
        dbo27.member_types mt
        LEFT OUTER JOIN xls.translations tr ON tr.TABLE_SCHEMA = 'dbo27' AND tr.TABLE_NAME = 'member_types_name' AND tr.COLUMN_NAME = mt.name AND tr.LANGUAGE_NAME = @data_language
) t
ORDER BY
    id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Validation list of product_id
-- =============================================

CREATE PROCEDURE [xls27].[xl_validation_list_product_id]
    @company_id int = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

SELECT id, name FROM (
    SELECT NULL AS id, NULL AS name, NULL AS sort_order
    UNION ALL
    SELECT
        m.id
        , COALESCE(tr.name, m.name) AS name
        , m.sort_order
    FROM
        dbo27.members m
        LEFT OUTER JOIN dbo27.member_permissions mp ON mp.member_id = m.id AND mp.username = USER_NAME()
        LEFT OUTER JOIN dbo27.translations tr ON tr.company_id = m.company_id AND tr.table_id = 1 AND tr.member_id = m.id AND tr.language = @data_language
    WHERE
        m.dimension_id = 6
        AND m.is_active = 1
        AND m.company_id = @company_id
        AND (COALESCE(mp.update_permission, 0) = 1 OR COALESCE(mp.select_permission, 0) = 1 OR NOT EXISTS (
            SELECT
                p.name
            FROM
                sys.database_principals p
                INNER JOIN sys.database_role_members rm ON rm.member_principal_id = p.principal_id
            WHERE
                p.name = USER_NAME()
                AND rm.role_principal_id = USER_ID('budgeting_app_users')
            ))
) t
ORDER BY
    sort_order
    , name

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Validation list of product_id
-- =============================================

CREATE PROCEDURE [xls27].[xl_validation_list_product_id_code]
    @company_id int = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

SELECT id, name FROM (
    SELECT NULL AS id, NULL AS name, NULL AS sort_order
    UNION ALL
    SELECT
        m.id
        , m.code AS name
        , m.sort_order
    FROM
        dbo27.members m
        LEFT OUTER JOIN dbo27.member_permissions mp ON mp.member_id = m.id AND mp.username = USER_NAME()
    WHERE
        m.dimension_id = 6
        AND m.is_active = 1
        AND m.company_id = @company_id
        AND (COALESCE(mp.update_permission, 0) = 1 OR COALESCE(mp.select_permission, 0) = 1 OR NOT EXISTS (
            SELECT
                p.name
            FROM
                sys.database_principals p
                INNER JOIN sys.database_role_members rm ON rm.member_principal_id = p.principal_id
            WHERE
                p.name = USER_NAME()
                AND rm.role_principal_id = USER_ID('budgeting_app_users')
            ))
) t
ORDER BY
    sort_order
    , name

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Validation list of region_id
-- =============================================

CREATE PROCEDURE [xls27].[xl_validation_list_region_id]
    @company_id int = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

SELECT id, name FROM (
    SELECT NULL AS id, NULL AS name, NULL AS sort_order
    UNION ALL
    SELECT
        m.id
        , COALESCE(tr.name, m.name) AS name
        , m.sort_order
    FROM
        dbo27.members m
        LEFT OUTER JOIN dbo27.member_permissions mp ON mp.member_id = m.id AND mp.username = USER_NAME()
        LEFT OUTER JOIN dbo27.translations tr ON tr.company_id = m.company_id AND tr.table_id = 1 AND tr.member_id = m.id AND tr.language = @data_language
    WHERE
        m.dimension_id = 5
        AND m.is_active = 1
        AND m.company_id = @company_id
        AND (COALESCE(mp.update_permission, 0) = 1 OR COALESCE(mp.select_permission, 0) = 1 OR NOT EXISTS (
            SELECT
                p.name
            FROM
                sys.database_principals p
                INNER JOIN sys.database_role_members rm ON rm.member_principal_id = p.principal_id
            WHERE
                p.name = USER_NAME()
                AND rm.role_principal_id = USER_ID('budgeting_app_users')
            ))
) t
ORDER BY
    sort_order
    , name

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Validation list of region_id
-- =============================================

CREATE PROCEDURE [xls27].[xl_validation_list_region_id_code]
    @company_id int = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

SELECT id, name FROM (
    SELECT NULL AS id, NULL AS name, NULL AS sort_order
    UNION ALL
    SELECT
        m.id
        , m.code AS name
        , m.sort_order
    FROM
        dbo27.members m
        LEFT OUTER JOIN dbo27.member_permissions mp ON mp.member_id = m.id AND mp.username = USER_NAME()
    WHERE
        m.dimension_id = 5
        AND m.is_active = 1
        AND m.company_id = @company_id
        AND (COALESCE(mp.update_permission, 0) = 1 OR COALESCE(mp.select_permission, 0) = 1 OR NOT EXISTS (
            SELECT
                p.name
            FROM
                sys.database_principals p
                INNER JOIN sys.database_role_members rm ON rm.member_principal_id = p.principal_id
            WHERE
                p.name = USER_NAME()
                AND rm.role_principal_id = USER_ID('budgeting_app_users')
            ))
) t
ORDER BY
    sort_order
    , name

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Validation list of report_section_id
-- =============================================

CREATE PROCEDURE [xls27].[xl_validation_list_report_section_id]
    @company_id int = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

SELECT
    t.id
    , COALESCE(tr.name, t.description) AS name
FROM
    dbo27.report_sections t
    LEFT OUTER JOIN dbo27.translations tr ON tr.company_id = t.company_id AND tr.table_id = 9 AND tr.member_id = t.id AND tr.language = @data_language
WHERE
    t.company_id = @company_id
ORDER BY
    t.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Validation list of report_section_total_type_id
-- =============================================

CREATE PROCEDURE [xls27].[xl_validation_list_report_section_total_type_id]
    @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

SELECT
    t.id
    , COALESCE(tr.TRANSLATED_NAME, t.name) AS name
FROM
    dbo27.report_section_total_types t
    LEFT OUTER JOIN xls.translations tr ON tr.TABLE_SCHEMA = 'dbo27' AND tr.TABLE_NAME = 'report_section_total_types_name' AND tr.COLUMN_NAME = t.name AND tr.LANGUAGE_NAME = @data_language
ORDER BY
    t.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Validation list of report_section_type_id
-- =============================================

CREATE PROCEDURE [xls27].[xl_validation_list_report_section_type_id]
    @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

SELECT
    t.id
    , COALESCE(tr.TRANSLATED_NAME, t.name) AS name
FROM
    dbo27.report_section_types t
    LEFT OUTER JOIN xls.translations tr ON tr.TABLE_SCHEMA = 'dbo27' AND tr.TABLE_NAME = 'report_section_types_name' AND tr.COLUMN_NAME = t.name AND tr.LANGUAGE_NAME = @data_language
ORDER BY
    t.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Validation list of report_section_value_type_id
-- =============================================

CREATE PROCEDURE [xls27].[xl_validation_list_report_section_value_type_id]
    @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

SELECT
    t.id
    , COALESCE(tr.TRANSLATED_NAME, t.name) AS name
FROM
    dbo27.report_section_value_types t
    LEFT OUTER JOIN xls.translations tr ON tr.TABLE_SCHEMA = 'dbo27' AND tr.TABLE_NAME = 'report_section_value_types_name' AND tr.COLUMN_NAME = t.name AND tr.LANGUAGE_NAME = @data_language
ORDER BY
    t.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Validation list of report_type_id
-- =============================================

CREATE PROCEDURE [xls27].[xl_validation_list_report_type_id_code]
    @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

SELECT
    t.id
    , COALESCE(tr.TRANSLATED_NAME, t.code) AS code
FROM
    dbo27.report_types t
    LEFT OUTER JOIN xls.translations tr ON tr.TABLE_SCHEMA = 'dbo27' AND tr.TABLE_NAME = 'report_types_code' AND tr.COLUMN_NAME = t.code AND tr.LANGUAGE_NAME = @data_language
ORDER BY
    t.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Validation list of subsidiary account_id
-- =============================================

CREATE PROCEDURE [xls27].[xl_validation_list_subsidiary_account_id]
    @company_id int = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

SELECT id, name FROM (
    SELECT NULL AS id, NULL AS name, NULL AS sort_order
    UNION ALL
    SELECT
        m.id
        , COALESCE(tr.name, m.name) AS name
        , m.sort_order
    FROM
        dbo27.members m
        LEFT OUTER JOIN dbo27.member_permissions mp ON mp.member_id = m.id AND mp.username = USER_NAME()
        LEFT OUTER JOIN dbo27.translations tr ON tr.company_id = m.company_id AND tr.table_id = 1 AND tr.member_id = m.id AND tr.language = @data_language
    WHERE
        m.dimension_id = 7
        AND m.is_active = 1
        AND m.company_id = @company_id
        AND (COALESCE(mp.update_permission, 0) = 1 OR COALESCE(mp.select_permission, 0) = 1 OR NOT EXISTS (
            SELECT
                p.name
            FROM
                sys.database_principals p
                INNER JOIN sys.database_role_members rm ON rm.member_principal_id = p.principal_id
            WHERE
                p.name = USER_NAME()
                AND rm.role_principal_id = USER_ID('budgeting_app_users')
            ))
) t
ORDER BY
    sort_order
    , name

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Validation list of subsidiary account_id
-- =============================================

CREATE PROCEDURE [xls27].[xl_validation_list_subsidiary_account_id_code]
    @company_id int = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

SELECT id, name FROM (
    SELECT NULL AS id, NULL AS name, NULL AS sort_order
    UNION ALL
    SELECT
        m.id
        , m.code AS name
        , m.sort_order
    FROM
        dbo27.members m
        LEFT OUTER JOIN dbo27.member_permissions mp ON mp.member_id = m.id AND mp.username = USER_NAME()
    WHERE
        m.dimension_id = 7
        AND m.is_active = 1
        AND m.company_id = @company_id
        AND (COALESCE(mp.update_permission, 0) = 1 OR COALESCE(mp.select_permission, 0) = 1 OR NOT EXISTS (
            SELECT
                p.name
            FROM
                sys.database_principals p
                INNER JOIN sys.database_role_members rm ON rm.member_principal_id = p.principal_id
            WHERE
                p.name = USER_NAME()
                AND rm.role_principal_id = USER_ID('budgeting_app_users')
            ))
) t
ORDER BY
    sort_order
    , name

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Validation list of subsidiary_group_id
-- =============================================

CREATE PROCEDURE [xls27].[xl_validation_list_subsidiary_group_id]
    @company_id int = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

SELECT
    t.id
    , COALESCE(tr.name, t.name) AS name
FROM
    dbo27.subsidiary_groups t
    LEFT OUTER JOIN dbo27.translations tr ON tr.company_id = t.company_id AND tr.table_id = 10 AND tr.member_id = t.id AND tr.language = @data_language
WHERE
    t.company_id = @company_id
ORDER BY
    t.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Validation list of unit_id
-- =============================================

CREATE PROCEDURE [xls27].[xl_validation_list_unit_id]
    @company_id int = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

SELECT
    t.id
    , COALESCE(tr.name, t.name) AS name
FROM
    dbo27.units t
    LEFT OUTER JOIN dbo27.translations tr ON tr.company_id = t.company_id AND tr.table_id = 3 AND tr.member_id = t.id AND tr.language = @data_language
WHERE
    t.is_active = 1
    AND t.company_id = @company_id
ORDER BY
    t.sort_order
    , t.name

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Validation list of unit_id
-- =============================================

CREATE PROCEDURE [xls27].[xl_validation_list_unit_id_code]
    @company_id int = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

SELECT
    t.id
    , t.code
FROM
    dbo27.units t
WHERE
    t.is_active = 1
    AND t.company_id = @company_id
ORDER BY
    t.sort_order
    , t.code

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: Validation list of vat_rate_id
-- =============================================

CREATE PROCEDURE [xls27].[xl_validation_list_vat_rate_id]
    @company_id int = NULL
    , @data_language varchar(10) = NULL
AS
BEGIN

SET NOCOUNT ON

IF @company_id IS NULL
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE username = USER_NAME() AND is_active = 1 AND is_default = 1)
ELSE
    SET @company_id = (SELECT TOP 1 company_id FROM dbo27.users WHERE company_id = @company_id AND username = USER_NAME() AND is_active = 1)

SELECT
    t.id
    , COALESCE(tr.name, t.name) AS name
FROM
    dbo27.vat_rates t
    LEFT OUTER JOIN dbo27.translations tr ON tr.company_id = t.company_id AND tr.table_id = 4 AND tr.member_id = t.id AND tr.language = @data_language
WHERE
    t.is_active = 1
    AND t.company_id = @company_id
ORDER BY
    t.sort_order
    , t.name

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: This trigger fires on insert into dbo27.actual_balances
-- =============================================

CREATE TRIGGER [dbo27].[tr_actual_balances_insert]
   ON  [dbo27].[actual_balances]
   AFTER INSERT
AS
BEGIN

SET NOCOUNT ON;

UPDATE dbo27.actual_balances
SET
    created_by = USER_NAME()
    , created_on = CAST(GETDATE() AS datetime2(0))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.actual_balances t INNER JOIN inserted ON t.id = inserted.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: This trigger fires on update of dbo27.actual_balances
-- =============================================

CREATE TRIGGER [dbo27].[tr_actual_balances_update]
   ON  [dbo27].[actual_balances]
   AFTER UPDATE
AS
BEGIN

SET NOCOUNT ON;

IF TRIGGER_NESTLEVEL() > 1
    RETURN

UPDATE dbo27.actual_balances
SET
    created_by = COALESCE(deleted.created_by, t.created_by, USER_NAME())
    , created_on = COALESCE(deleted.created_on, t.created_on, CAST(GETDATE() AS datetime2(0)))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.actual_balances t INNER JOIN deleted ON t.id = deleted.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: This trigger fires on insert into dbo27.closed_periods
-- =============================================

CREATE TRIGGER [dbo27].[tr_actual_closed_periods_insert]
   ON  [dbo27].[actual_closed_periods]
   AFTER INSERT
AS
BEGIN

SET NOCOUNT ON;

UPDATE dbo27.actual_closed_periods
SET
    created_by = USER_NAME()
    , created_on = CAST(GETDATE() AS datetime2(0))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.actual_closed_periods t INNER JOIN inserted ON t.date = inserted.date

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: This trigger fires on update of dbo27.closed_periods
-- =============================================

CREATE TRIGGER [dbo27].[tr_actual_closed_periods_update]
   ON  [dbo27].[actual_closed_periods]
   AFTER UPDATE
AS
BEGIN

SET NOCOUNT ON;

IF TRIGGER_NESTLEVEL() > 1
    RETURN

UPDATE dbo27.actual_closed_periods
SET
    created_by = COALESCE(deleted.created_by, t.created_by, USER_NAME())
    , created_on = COALESCE(deleted.created_on, t.created_on, CAST(GETDATE() AS datetime2(0)))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.actual_closed_periods t INNER JOIN deleted ON t.date = deleted.date

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: This trigger fires on insert into dbo27.actual_currency_rates
-- =============================================

CREATE TRIGGER [dbo27].[tr_actual_currency_rates_insert]
   ON  [dbo27].[actual_currency_rates]
   AFTER INSERT
AS
BEGIN

SET NOCOUNT ON;

UPDATE dbo27.actual_currency_rates
SET
    created_by = USER_NAME()
    , created_on = CAST(GETDATE() AS datetime2(0))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.actual_currency_rates t INNER JOIN inserted ON t.currency_id = inserted.currency_id AND t.date = inserted.date

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: This trigger fires on update of dbo27.actual_currency_rates
-- =============================================

CREATE TRIGGER [dbo27].[tr_actual_currency_rates_update]
   ON  [dbo27].[actual_currency_rates]
   AFTER UPDATE
AS
BEGIN

SET NOCOUNT ON;

IF TRIGGER_NESTLEVEL() > 1
    RETURN

UPDATE dbo27.actual_currency_rates
SET
    created_by = COALESCE(deleted.created_by, t.created_by, USER_NAME())
    , created_on = COALESCE(deleted.created_on, t.created_on, CAST(GETDATE() AS datetime2(0)))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.actual_currency_rates t INNER JOIN deleted ON t.currency_id = deleted.currency_id AND t.date = deleted.date

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: This trigger fires on insert into dbo27.budget_balances
-- =============================================

CREATE TRIGGER [dbo27].[tr_budget_balances_insert]
   ON  [dbo27].[budget_balances]
   AFTER INSERT
AS
BEGIN

SET NOCOUNT ON;

UPDATE dbo27.budget_balances
SET
    created_by = USER_NAME()
    , created_on = CAST(GETDATE() AS datetime2(0))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.budget_balances t INNER JOIN inserted ON t.id = inserted.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: This trigger fires on update of dbo27.budget_balances
-- =============================================

CREATE TRIGGER [dbo27].[tr_budget_balances_update]
   ON  [dbo27].[budget_balances]
   AFTER UPDATE
AS
BEGIN

SET NOCOUNT ON;

IF TRIGGER_NESTLEVEL() > 1
    RETURN

UPDATE dbo27.budget_balances
SET
    created_by = COALESCE(deleted.created_by, t.created_by, USER_NAME())
    , created_on = COALESCE(deleted.created_on, t.created_on, CAST(GETDATE() AS datetime2(0)))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.budget_balances t INNER JOIN deleted ON t.id = deleted.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: This trigger fires on insert into dbo27.budget_currency_rates
-- =============================================

CREATE TRIGGER [dbo27].[tr_budget_currency_rates_insert]
   ON  [dbo27].[budget_currency_rates]
   AFTER INSERT
AS
BEGIN

SET NOCOUNT ON;

UPDATE dbo27.budget_currency_rates
SET
    created_by = USER_NAME()
    , created_on = CAST(GETDATE() AS datetime2(0))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.budget_currency_rates t INNER JOIN deleted ON t.category_id = deleted.category_id AND t.time_id = deleted.time_id AND t.unit_id = deleted.unit_id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: This trigger fires on update of dbo27.budget_currency_rates
-- =============================================

CREATE TRIGGER [dbo27].[tr_budget_currency_rates_update]
   ON  [dbo27].[budget_currency_rates]
   AFTER UPDATE
AS
BEGIN

SET NOCOUNT ON;

IF TRIGGER_NESTLEVEL() > 1
    RETURN

UPDATE dbo27.budget_currency_rates
SET
    created_by = COALESCE(deleted.created_by, t.created_by, USER_NAME())
    , created_on = COALESCE(deleted.created_on, t.created_on, CAST(GETDATE() AS datetime2(0)))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.budget_currency_rates t INNER JOIN deleted ON t.category_id = deleted.category_id AND t.time_id = deleted.time_id AND t.unit_id = deleted.unit_id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: This trigger fires on insert into dbo27.budget_requests
-- =============================================

CREATE TRIGGER [dbo27].[tr_budget_requests_insert]
   ON  [dbo27].[budget_requests]
   AFTER INSERT
AS
BEGIN

SET NOCOUNT ON;

UPDATE dbo27.budget_requests
SET
    created_by = USER_NAME()
    , created_on = CAST(GETDATE() AS datetime2(0))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.budget_requests t INNER JOIN inserted ON t.id = inserted.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: This trigger fires on update of dbo27.budget_requests
-- =============================================

CREATE TRIGGER [dbo27].[tr_budget_requests_update]
   ON  [dbo27].[budget_requests]
   AFTER UPDATE
AS
BEGIN

SET NOCOUNT ON;

IF TRIGGER_NESTLEVEL() > 1
    RETURN

UPDATE dbo27.budget_requests
SET
    created_by = COALESCE(deleted.created_by, t.created_by, USER_NAME())
    , created_on = COALESCE(deleted.created_on, t.created_on, CAST(GETDATE() AS datetime2(0)))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.budget_requests t INNER JOIN deleted ON t.id = deleted.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: This trigger fires on insert into dbo27.companies
-- =============================================

CREATE TRIGGER [dbo27].[tr_companies_insert]
   ON  [dbo27].[companies]
   AFTER INSERT
AS
BEGIN

SET NOCOUNT ON;

UPDATE dbo27.companies
SET
    created_by = USER_NAME()
    , created_on = CAST(GETDATE() AS datetime2(0))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.companies t INNER JOIN inserted ON t.id = inserted.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.1, 2022-10-14
-- Description: This trigger fires on update of dbo27.companies
-- =============================================

CREATE TRIGGER [dbo27].[tr_companies_update]
   ON  [dbo27].[companies]
   AFTER UPDATE
AS
BEGIN

SET NOCOUNT ON;

IF TRIGGER_NESTLEVEL() > 1
    RETURN

UPDATE dbo27.companies
SET
    created_by = COALESCE(deleted.created_by, t.created_by, USER_NAME())
    , created_on = COALESCE(deleted.created_on, t.created_on, CAST(GETDATE() AS datetime2(0)))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.companies t INNER JOIN deleted ON t.id = deleted.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: This trigger fires on insert into dbo27.dimensions
-- =============================================

CREATE TRIGGER [dbo27].[tr_dimensions_insert]
   ON  [dbo27].[dimensions]
   AFTER INSERT
AS
BEGIN

SET NOCOUNT ON;

UPDATE dbo27.dimensions
SET
    created_by = USER_NAME()
    , created_on = CAST(GETDATE() AS datetime2(0))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.dimensions t INNER JOIN inserted ON t.id = inserted.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: This trigger fires on update of dbo27.dimensions
-- =============================================

CREATE TRIGGER [dbo27].[tr_dimensions_update]
   ON  [dbo27].[dimensions]
   AFTER UPDATE
AS
BEGIN

SET NOCOUNT ON;

IF TRIGGER_NESTLEVEL() > 1
    RETURN

UPDATE dbo27.dimensions
SET
    created_by = COALESCE(deleted.created_by, t.created_by, USER_NAME())
    , created_on = COALESCE(deleted.created_on, t.created_on, CAST(GETDATE() AS datetime2(0)))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.dimensions t INNER JOIN deleted ON t.id = deleted.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: This trigger fires on insert into dbo27.entry_sides
-- =============================================

CREATE TRIGGER [dbo27].[tr_entry_sides_insert]
   ON  [dbo27].[entry_sides]
   AFTER INSERT
AS
BEGIN

SET NOCOUNT ON;

UPDATE dbo27.entry_sides
SET
    created_by = USER_NAME()
    , created_on = CAST(GETDATE() AS datetime2(0))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.entry_sides t INNER JOIN inserted ON t.id = inserted.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: This trigger fires on update of dbo27.entry_sides
-- =============================================

CREATE TRIGGER [dbo27].[tr_entry_sides_update]
   ON  [dbo27].[entry_sides]
   AFTER UPDATE
AS
BEGIN

SET NOCOUNT ON;

IF TRIGGER_NESTLEVEL() > 1
    RETURN

UPDATE dbo27.entry_sides
SET
    created_by = COALESCE(deleted.created_by, t.created_by, USER_NAME())
    , created_on = COALESCE(deleted.created_on, t.created_on, CAST(GETDATE() AS datetime2(0)))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.entry_sides t INNER JOIN deleted ON t.id = deleted.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: This trigger fires on insert into dbo27.journal
-- =============================================

CREATE TRIGGER [dbo27].[tr_journals_insert]
   ON  [dbo27].[journals]
   AFTER INSERT
AS
BEGIN

SET NOCOUNT ON;

UPDATE dbo27.journals
SET
    created_by = USER_NAME()
    , created_on = CAST(GETDATE() AS datetime2(0))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.journals t INNER JOIN inserted ON t.id = inserted.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: This trigger fires on update of dbo27.journal
-- =============================================

CREATE TRIGGER [dbo27].[tr_journals_update]
   ON  [dbo27].[journals]
   AFTER UPDATE
AS
BEGIN

SET NOCOUNT ON;

IF TRIGGER_NESTLEVEL() > 1
    RETURN

UPDATE dbo27.journals
SET
    created_by = COALESCE(deleted.created_by, t.created_by, USER_NAME())
    , created_on = COALESCE(deleted.created_on, t.created_on, CAST(GETDATE() AS datetime2(0)))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.journals t INNER JOIN deleted ON t.id = deleted.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: This trigger fires on insert into dbo27.ledger_account_special_types
-- =============================================

CREATE TRIGGER [dbo27].[tr_ledger_account_special_types_insert]
   ON  [dbo27].[ledger_account_special_types]
   AFTER INSERT
AS
BEGIN

SET NOCOUNT ON;

UPDATE dbo27.ledger_account_special_types
SET
    created_by = USER_NAME()
    , created_on = CAST(GETDATE() AS datetime2(0))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.ledger_account_special_types t INNER JOIN inserted ON t.id = inserted.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: This trigger fires on update of dbo27.ledger_account_special_types
-- =============================================

CREATE TRIGGER [dbo27].[tr_ledger_account_special_types_update]
   ON  [dbo27].[ledger_account_special_types]
   AFTER UPDATE
AS
BEGIN

SET NOCOUNT ON;

IF TRIGGER_NESTLEVEL() > 1
    RETURN

UPDATE dbo27.ledger_account_special_types
SET
    created_by = COALESCE(deleted.created_by, t.created_by, USER_NAME())
    , created_on = COALESCE(deleted.created_on, t.created_on, CAST(GETDATE() AS datetime2(0)))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.ledger_account_special_types t INNER JOIN deleted ON t.id = deleted.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: This trigger fires on insert into dbo27.ledger_account_types
-- =============================================

CREATE TRIGGER [dbo27].[tr_ledger_account_types_insert]
   ON  [dbo27].[ledger_account_types]
   AFTER INSERT
AS
BEGIN

SET NOCOUNT ON;

UPDATE dbo27.ledger_account_types
SET
    created_by = USER_NAME()
    , created_on = CAST(GETDATE() AS datetime2(0))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.ledger_account_types t INNER JOIN inserted ON t.id = inserted.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: This trigger fires on update of dbo27.ledger_account_types
-- =============================================

CREATE TRIGGER [dbo27].[tr_ledger_account_types_update]
   ON  [dbo27].[ledger_account_types]
   AFTER UPDATE
AS
BEGIN

SET NOCOUNT ON;

IF TRIGGER_NESTLEVEL() > 1
    RETURN

UPDATE dbo27.ledger_account_types
SET
    created_by = COALESCE(deleted.created_by, t.created_by, USER_NAME())
    , created_on = COALESCE(deleted.created_on, t.created_on, CAST(GETDATE() AS datetime2(0)))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.ledger_account_types t INNER JOIN deleted ON t.id = deleted.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.1, 2022-10-14
-- Description: This trigger fires on delete from dbo27.accounts
-- =============================================

CREATE TRIGGER [dbo27].[tr_ledger_accounts_delete]
   ON  [dbo27].[ledger_accounts]
   AFTER DELETE
AS
BEGIN

SET NOCOUNT ON;

UPDATE dbo27.ledger_accounts SET parent_id = NULL                 FROM deleted INNER JOIN dbo27.ledger_accounts m ON m.parent_id = deleted.id
UPDATE dbo27.ledger_accounts SET closing_child_account_id = NULL  FROM deleted INNER JOIN dbo27.ledger_accounts m ON m.closing_child_account_id = deleted.id
UPDATE dbo27.ledger_accounts SET closing_debit_account_id = NULL  FROM deleted INNER JOIN dbo27.ledger_accounts m ON m.closing_debit_account_id = deleted.id
UPDATE dbo27.ledger_accounts SET closing_credit_account_id = NULL FROM deleted INNER JOIN dbo27.ledger_accounts m ON m.closing_credit_account_id = deleted.id

DELETE dbo27.translations FROM deleted INNER JOIN dbo27.translations t ON t.company_id = deleted.company_id AND t.table_id = 11 AND t.member_id = deleted.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: This trigger fires on insert into dbo27.accounts
-- =============================================

CREATE TRIGGER [dbo27].[tr_ledger_accounts_insert]
   ON  [dbo27].[ledger_accounts]
   AFTER INSERT
AS
BEGIN

SET NOCOUNT ON;

UPDATE dbo27.ledger_accounts
SET
    created_by = USER_NAME()
    , created_on = CAST(GETDATE() AS datetime2(0))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.ledger_accounts t INNER JOIN inserted ON t.id = inserted.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.1, 2022-10-14
-- Description: This trigger fires on update of dbo27.accounts
-- =============================================

CREATE TRIGGER [dbo27].[tr_ledger_accounts_update]
   ON  [dbo27].[ledger_accounts]
   AFTER UPDATE
AS
BEGIN

SET NOCOUNT ON;

IF TRIGGER_NESTLEVEL() > 1
    RETURN

UPDATE dbo27.ledger_accounts
SET
    created_by = COALESCE(deleted.created_by, t.created_by, USER_NAME())
    , created_on = COALESCE(deleted.created_on, t.created_on, CAST(GETDATE() AS datetime2(0)))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.ledger_accounts t INNER JOIN deleted ON t.id = deleted.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: This trigger fires on insert into dbo27.subsidiary_account_groups
-- =============================================

CREATE TRIGGER [dbo27].[tr_member_groups_insert]
   ON  [dbo27].[member_groups]
   AFTER INSERT
AS
BEGIN

SET NOCOUNT ON;

UPDATE dbo27.member_groups
SET
    created_by = USER_NAME()
    , created_on = CAST(GETDATE() AS datetime2(0))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.member_groups t INNER JOIN inserted ON t.member_id = inserted.member_id AND t.group_id = inserted.group_id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: This trigger fires on update of dbo27.subsidiary_account_groups
-- =============================================

CREATE TRIGGER [dbo27].[tr_member_groups_update]
   ON  [dbo27].[member_groups]
   AFTER UPDATE
AS
BEGIN

SET NOCOUNT ON;

IF TRIGGER_NESTLEVEL() > 1
    RETURN

UPDATE dbo27.member_groups
SET
    created_by = COALESCE(deleted.created_by, t.created_by, USER_NAME())
    , created_on = COALESCE(deleted.created_on, t.created_on, CAST(GETDATE() AS datetime2(0)))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.member_groups t INNER JOIN deleted ON t.member_id = deleted.member_id AND t.group_id = deleted.group_id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: This trigger fires on insert into dbo27.member_permissions
-- =============================================

CREATE TRIGGER [dbo27].[tr_member_permissions_insert]
   ON  [dbo27].[member_permissions]
   AFTER INSERT
AS
BEGIN

SET NOCOUNT ON;

UPDATE dbo27.member_permissions
SET
    created_by = USER_NAME()
    , created_on = CAST(GETDATE() AS datetime2(0))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.member_permissions t INNER JOIN inserted ON t.member_id = inserted.member_id AND t.username = inserted.username

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: This trigger fires on update of dbo27.member_permissions
-- =============================================

CREATE TRIGGER [dbo27].[tr_member_permissions_update]
   ON  [dbo27].[member_permissions]
   AFTER UPDATE
AS
BEGIN

SET NOCOUNT ON;

IF TRIGGER_NESTLEVEL() > 1
    RETURN

UPDATE dbo27.member_permissions
SET
    created_by = COALESCE(deleted.created_by, t.created_by, USER_NAME())
    , created_on = COALESCE(deleted.created_on, t.created_on, CAST(GETDATE() AS datetime2(0)))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.member_permissions t INNER JOIN deleted ON t.member_id = deleted.member_id AND t.username = deleted.username

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: This trigger fires on insert into dbo27.member_relations
-- =============================================

CREATE TRIGGER [dbo27].[tr_member_relations_insert]
   ON  [dbo27].[member_relations]
   AFTER INSERT
AS
BEGIN

SET NOCOUNT ON;

UPDATE dbo27.member_relations
SET
    created_by = USER_NAME()
    , created_on = CAST(GETDATE() AS datetime2(0))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.member_relations t INNER JOIN inserted ON t.member_id = inserted.member_id AND t.partner_id = inserted.partner_id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: This trigger fires on update of dbo27.member_relations
-- =============================================

CREATE TRIGGER [dbo27].[tr_member_relations_update]
   ON  [dbo27].[member_relations]
   AFTER UPDATE
AS
BEGIN

SET NOCOUNT ON;

IF TRIGGER_NESTLEVEL() > 1
    RETURN

UPDATE dbo27.member_relations
SET
    created_by = COALESCE(deleted.created_by, t.created_by, USER_NAME())
    , created_on = COALESCE(deleted.created_on, t.created_on, CAST(GETDATE() AS datetime2(0)))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.member_relations t INNER JOIN deleted ON t.member_id = deleted.member_id AND t.partner_id = deleted.partner_id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: This trigger fires on insert into dbo27.member_types
-- =============================================

CREATE TRIGGER [dbo27].[tr_member_types_insert]
   ON  [dbo27].[member_types]
   AFTER INSERT
AS
BEGIN

SET NOCOUNT ON;

UPDATE dbo27.member_types
SET
    created_by = USER_NAME()
    , created_on = CAST(GETDATE() AS datetime2(0))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.member_types t INNER JOIN inserted ON t.id = inserted.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: This trigger fires on update of dbo27.member_types
-- =============================================

CREATE TRIGGER [dbo27].[tr_member_types_update]
   ON  [dbo27].[member_types]
   AFTER UPDATE
AS
BEGIN

SET NOCOUNT ON;

IF TRIGGER_NESTLEVEL() > 1
    RETURN

UPDATE dbo27.member_types
SET
    created_by = COALESCE(deleted.created_by, t.created_by, USER_NAME())
    , created_on = COALESCE(deleted.created_on, t.created_on, CAST(GETDATE() AS datetime2(0)))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.member_types t INNER JOIN deleted ON t.id = deleted.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.1, 2022-10-14
-- Description: This trigger fires on delete from dbo27.members
-- =============================================

CREATE TRIGGER [dbo27].[tr_members_delete]
   ON  [dbo27].[members]
   AFTER DELETE
AS
BEGIN

SET NOCOUNT ON;

UPDATE dbo27.members SET parent_id = NULL FROM deleted INNER JOIN dbo27.members m ON m.parent_id = deleted.id

DELETE dbo27.translations FROM deleted INNER JOIN dbo27.translations t ON t.company_id = deleted.company_id AND t.table_id = 1 AND t.member_id = deleted.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: This trigger fires on insert into dbo27.members
-- =============================================

CREATE TRIGGER [dbo27].[tr_members_insert]
   ON  [dbo27].[members]
   AFTER INSERT
AS
BEGIN

SET NOCOUNT ON;

UPDATE dbo27.members
SET
    created_by = USER_NAME()
    , created_on = CAST(GETDATE() AS datetime2(0))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.members t INNER JOIN inserted ON t.id = inserted.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.1, 2022-10-14
-- Description: This trigger fires on update of dbo27.members
-- =============================================

CREATE TRIGGER [dbo27].[tr_members_update]
   ON  [dbo27].[members]
   AFTER UPDATE
AS
BEGIN

SET NOCOUNT ON;

IF TRIGGER_NESTLEVEL() > 1
    RETURN

UPDATE dbo27.members
SET
    created_by = COALESCE(deleted.created_by, t.created_by, USER_NAME())
    , created_on = COALESCE(deleted.created_on, t.created_on, CAST(GETDATE() AS datetime2(0)))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.members t INNER JOIN deleted ON t.id = deleted.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: This trigger fires on insert into dbo27.report_section_accounts
-- =============================================

CREATE TRIGGER [dbo27].[tr_report_section_accounts_insert]
   ON  [dbo27].[report_section_accounts]
   AFTER INSERT
AS
BEGIN

SET NOCOUNT ON;

UPDATE dbo27.report_section_accounts
SET
    created_by = USER_NAME()
    , created_on = CAST(GETDATE() AS datetime2(0))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.report_section_accounts t INNER JOIN inserted ON t.id = inserted.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: This trigger fires on update of dbo27.report_section_accounts
-- =============================================

CREATE TRIGGER [dbo27].[tr_report_section_accounts_update]
   ON  [dbo27].[report_section_accounts]
   AFTER UPDATE
AS
BEGIN

SET NOCOUNT ON;

IF TRIGGER_NESTLEVEL() > 1
    RETURN

UPDATE dbo27.report_section_accounts
SET
    created_by = COALESCE(deleted.created_by, t.created_by, USER_NAME())
    , created_on = COALESCE(deleted.created_on, t.created_on, CAST(GETDATE() AS datetime2(0)))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.report_section_accounts t INNER JOIN deleted ON t.id = deleted.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: This trigger fires on insert into dbo27.report_section_total_types
-- =============================================

CREATE TRIGGER [dbo27].[tr_report_section_total_types_insert]
   ON  [dbo27].[report_section_total_types]
   AFTER INSERT
AS
BEGIN

SET NOCOUNT ON;

UPDATE dbo27.report_section_total_types
SET
    created_by = USER_NAME()
    , created_on = CAST(GETDATE() AS datetime2(0))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.report_section_total_types t INNER JOIN inserted ON t.id = inserted.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: This trigger fires on update of dbo27.report_section_total_types
-- =============================================

CREATE TRIGGER [dbo27].[tr_report_section_total_types_update]
   ON  [dbo27].[report_section_total_types]
   AFTER UPDATE
AS
BEGIN

SET NOCOUNT ON;

IF TRIGGER_NESTLEVEL() > 1
    RETURN

UPDATE dbo27.report_section_total_types
SET
    created_by = COALESCE(deleted.created_by, t.created_by, USER_NAME())
    , created_on = COALESCE(deleted.created_on, t.created_on, CAST(GETDATE() AS datetime2(0)))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.report_section_total_types t INNER JOIN deleted ON t.id = deleted.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: This trigger fires on insert into dbo27.report_section_types
-- =============================================

CREATE TRIGGER [dbo27].[tr_report_section_types_insert]
   ON  [dbo27].[report_section_types]
   AFTER INSERT
AS
BEGIN

SET NOCOUNT ON;

UPDATE dbo27.report_section_types
SET
    created_by = USER_NAME()
    , created_on = CAST(GETDATE() AS datetime2(0))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.report_section_types t INNER JOIN inserted ON t.id = inserted.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: This trigger fires on update of dbo27.report_section_types
-- =============================================

CREATE TRIGGER [dbo27].[tr_report_section_types_update]
   ON  [dbo27].[report_section_types]
   AFTER UPDATE
AS
BEGIN

SET NOCOUNT ON;

IF TRIGGER_NESTLEVEL() > 1
    RETURN

UPDATE dbo27.report_section_types
SET
    created_by = COALESCE(deleted.created_by, t.created_by, USER_NAME())
    , created_on = COALESCE(deleted.created_on, t.created_on, CAST(GETDATE() AS datetime2(0)))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.report_section_types t INNER JOIN deleted ON t.id = deleted.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: This trigger fires on insert into dbo27.report_section_value_types
-- =============================================

CREATE TRIGGER [dbo27].[tr_report_section_value_types_insert]
   ON  [dbo27].[report_section_value_types]
   AFTER INSERT
AS
BEGIN

SET NOCOUNT ON;

UPDATE dbo27.report_section_value_types
SET
    created_by = USER_NAME()
    , created_on = CAST(GETDATE() AS datetime2(0))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.report_section_value_types t INNER JOIN inserted ON t.id = inserted.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: This trigger fires on update of dbo27.report_section_value_types
-- =============================================

CREATE TRIGGER [dbo27].[tr_report_section_value_types_update]
   ON  [dbo27].[report_section_value_types]
   AFTER UPDATE
AS
BEGIN

SET NOCOUNT ON;

IF TRIGGER_NESTLEVEL() > 1
    RETURN

UPDATE dbo27.report_section_value_types
SET
    created_by = COALESCE(deleted.created_by, t.created_by, USER_NAME())
    , created_on = COALESCE(deleted.created_on, t.created_on, CAST(GETDATE() AS datetime2(0)))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.report_section_value_types t INNER JOIN deleted ON t.id = deleted.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.1, 2022-10-14
-- Description: This trigger fires on delete from dbo27.report_sections
-- =============================================

CREATE TRIGGER [dbo27].[tr_report_sections_delete]
   ON  [dbo27].[report_sections]
   AFTER DELETE
AS
BEGIN

SET NOCOUNT ON;

UPDATE dbo27.report_sections SET parent_id = NULL FROM deleted INNER JOIN dbo27.report_sections m ON m.parent_id = deleted.id
UPDATE dbo27.report_sections SET parent2_id = NULL FROM deleted INNER JOIN dbo27.report_sections m ON m.parent2_id = deleted.id

DELETE dbo27.translations FROM deleted INNER JOIN dbo27.translations t ON t.company_id = deleted.company_id AND t.table_id = 9 AND t.member_id = deleted.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: This trigger fires on insert into dbo27.report_sections
-- =============================================

CREATE TRIGGER [dbo27].[tr_report_sections_insert]
   ON  [dbo27].[report_sections]
   AFTER INSERT
AS
BEGIN

SET NOCOUNT ON;

UPDATE dbo27.report_sections
SET
    created_by = USER_NAME()
    , created_on = CAST(GETDATE() AS datetime2(0))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.report_sections t INNER JOIN inserted ON t.id = inserted.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.1, 2022-10-14
-- Description: This trigger fires on update of dbo27.report_sections
-- =============================================

CREATE TRIGGER [dbo27].[tr_report_sections_update]
   ON  [dbo27].[report_sections]
   AFTER UPDATE
AS
BEGIN

SET NOCOUNT ON;

IF TRIGGER_NESTLEVEL() > 1
    RETURN

UPDATE dbo27.report_sections
SET
    created_by = COALESCE(deleted.created_by, t.created_by, USER_NAME())
    , created_on = COALESCE(deleted.created_on, t.created_on, CAST(GETDATE() AS datetime2(0)))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.report_sections t INNER JOIN deleted ON t.id = deleted.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: This trigger fires on insert into dbo27.report_types
-- =============================================

CREATE TRIGGER [dbo27].[tr_report_types_insert]
   ON  [dbo27].[report_types]
   AFTER INSERT
AS
BEGIN

SET NOCOUNT ON;

UPDATE dbo27.report_types
SET
    created_by = USER_NAME()
    , created_on = CAST(GETDATE() AS datetime2(0))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.report_types t INNER JOIN inserted ON t.id = inserted.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: This trigger fires on update of dbo27.report_types
-- =============================================

CREATE TRIGGER [dbo27].[tr_report_types_update]
   ON  [dbo27].[report_types]
   AFTER UPDATE
AS
BEGIN

SET NOCOUNT ON;

IF TRIGGER_NESTLEVEL() > 1
    RETURN

UPDATE dbo27.report_types
SET
    created_by = COALESCE(deleted.created_by, t.created_by, USER_NAME())
    , created_on = COALESCE(deleted.created_on, t.created_on, CAST(GETDATE() AS datetime2(0)))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.report_types t INNER JOIN deleted ON t.id = deleted.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.1, 2022-10-14
-- Description: This trigger fires on delete from dbo27.saved_report_types
-- =============================================

CREATE TRIGGER [dbo27].[tr_saved_report_types_delete]
   ON  [dbo27].[saved_report_types]
   AFTER DELETE
AS
BEGIN

SET NOCOUNT ON;

DELETE dbo27.translations FROM deleted INNER JOIN dbo27.translations t ON t.company_id = deleted.company_id AND t.table_id = 12 AND t.member_id = deleted.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: This trigger fires on insert into dbo27.saved_report_types
-- =============================================

CREATE TRIGGER [dbo27].[tr_saved_report_types_insert]
   ON  [dbo27].[saved_report_types]
   AFTER INSERT
AS
BEGIN

SET NOCOUNT ON;

UPDATE dbo27.saved_report_types
SET
    created_by = USER_NAME()
    , created_on = CAST(GETDATE() AS datetime2(0))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.saved_report_types t INNER JOIN inserted ON t.id = inserted.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.1, 2022-10-14
-- Description: This trigger fires on update of dbo27.saved_report_types
-- =============================================

CREATE TRIGGER [dbo27].[tr_saved_report_types_update]
   ON  [dbo27].[saved_report_types]
   AFTER UPDATE
AS
BEGIN

SET NOCOUNT ON;

IF TRIGGER_NESTLEVEL() > 1
    RETURN

UPDATE dbo27.saved_report_types
SET
    created_by = COALESCE(deleted.created_by, t.created_by, USER_NAME())
    , created_on = COALESCE(deleted.created_on, t.created_on, CAST(GETDATE() AS datetime2(0)))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.saved_report_types t INNER JOIN deleted ON t.id = deleted.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: This trigger fires on insert into dbo27.saved_reports
-- =============================================

CREATE TRIGGER [dbo27].[tr_saved_reports_insert]
   ON  [dbo27].[saved_reports]
   AFTER INSERT
AS
BEGIN

SET NOCOUNT ON;

UPDATE dbo27.saved_reports
SET
    created_by = USER_NAME()
    , created_on = CAST(GETDATE() AS datetime2(0))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.saved_reports t INNER JOIN deleted ON t.category_id = deleted.category_id AND t.time_id = deleted.time_id AND t.row_index = deleted.row_index

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: This trigger fires on update of dbo27.saved_reports
-- =============================================

CREATE TRIGGER [dbo27].[tr_saved_reports_update]
   ON  [dbo27].[saved_reports]
   AFTER UPDATE
AS
BEGIN

SET NOCOUNT ON;

IF TRIGGER_NESTLEVEL() > 1
    RETURN

UPDATE dbo27.saved_reports
SET
    created_by = COALESCE(deleted.created_by, t.created_by, USER_NAME())
    , created_on = COALESCE(deleted.created_on, t.created_on, CAST(GETDATE() AS datetime2(0)))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.saved_reports t INNER JOIN deleted ON t.category_id = deleted.category_id AND t.time_id = deleted.time_id AND t.row_index = deleted.row_index

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.1, 2022-10-14
-- Description: This trigger fires on delete from dbo27.subsidiary_groups
-- =============================================

CREATE TRIGGER [dbo27].[tr_subsidiary_groups_delete]
   ON  [dbo27].[subsidiary_groups]
   AFTER DELETE
AS
BEGIN

SET NOCOUNT ON;

DELETE dbo27.translations FROM deleted INNER JOIN dbo27.translations t ON t.company_id = deleted.company_id AND t.table_id = 10 AND t.member_id = deleted.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: This trigger fires on insert into dbo27.subsidiary_groups
-- =============================================

CREATE TRIGGER [dbo27].[tr_subsidiary_groups_insert]
   ON  [dbo27].[subsidiary_groups]
   AFTER INSERT
AS
BEGIN

SET NOCOUNT ON;

UPDATE dbo27.subsidiary_groups
SET
    created_by = USER_NAME()
    , created_on = CAST(GETDATE() AS datetime2(0))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.subsidiary_groups t INNER JOIN inserted ON t.id = inserted.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.1, 2022-10-14
-- Description: This trigger fires on update of dbo27.subsidiary_groups
-- =============================================

CREATE TRIGGER [dbo27].[tr_subsidiary_groups_update]
   ON  [dbo27].[subsidiary_groups]
   AFTER UPDATE
AS
BEGIN

SET NOCOUNT ON;

IF TRIGGER_NESTLEVEL() > 1
    RETURN

UPDATE dbo27.subsidiary_groups
SET
    created_by = COALESCE(deleted.created_by, t.created_by, USER_NAME())
    , created_on = COALESCE(deleted.created_on, t.created_on, CAST(GETDATE() AS datetime2(0)))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.subsidiary_groups t INNER JOIN deleted ON t.id = deleted.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: This trigger fires on insert into dbo27.translated_tables
-- =============================================

CREATE TRIGGER [dbo27].[tr_translated_tables_insert]
   ON  [dbo27].[translated_tables]
   AFTER INSERT
AS
BEGIN

SET NOCOUNT ON;

UPDATE dbo27.translated_tables
SET
    created_by = USER_NAME()
    , created_on = CAST(GETDATE() AS datetime2(0))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.translated_tables t INNER JOIN inserted ON t.id = inserted.id

END

SET ANSI_NULLS ON


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: This trigger fires on update of dbo27.translated_tables
-- =============================================

CREATE TRIGGER [dbo27].[tr_translated_tables_update]
   ON  [dbo27].[translated_tables]
   AFTER UPDATE
AS
BEGIN

SET NOCOUNT ON;

IF TRIGGER_NESTLEVEL() > 1
    RETURN

UPDATE dbo27.translated_tables
SET
    created_by = COALESCE(deleted.created_by, t.created_by, USER_NAME())
    , created_on = COALESCE(deleted.created_on, t.created_on, CAST(GETDATE() AS datetime2(0)))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.translated_tables t INNER JOIN deleted ON t.id = deleted.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: This trigger fires on insert into dbo27.translations
-- =============================================

CREATE TRIGGER [dbo27].[tr_translations_insert]
   ON  [dbo27].[translations]
   AFTER INSERT
AS
BEGIN

SET NOCOUNT ON;

UPDATE dbo27.translations
SET
    created_by = USER_NAME()
    , created_on = CAST(GETDATE() AS datetime2(0))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.translations t INNER JOIN inserted ON t.member_id = inserted.member_id AND t.language = inserted.language

END

SET ANSI_NULLS ON


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: This trigger fires on update of dbo27.translations
-- =============================================

CREATE TRIGGER [dbo27].[tr_translations_update]
   ON  [dbo27].[translations]
   AFTER UPDATE
AS
BEGIN

SET NOCOUNT ON;

IF TRIGGER_NESTLEVEL() > 1
    RETURN

UPDATE dbo27.translations
SET
    created_by = COALESCE(deleted.created_by, t.created_by, USER_NAME())
    , created_on = COALESCE(deleted.created_on, t.created_on, CAST(GETDATE() AS datetime2(0)))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.translations t INNER JOIN deleted ON t.member_id = deleted.member_id AND t.language = deleted.language

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.1, 2022-10-14
-- Description: This trigger fires on delete from dbo27.units
-- =============================================

CREATE TRIGGER [dbo27].[tr_units_delete]
   ON  [dbo27].[units]
   AFTER DELETE
AS
BEGIN

SET NOCOUNT ON;

DELETE dbo27.translations FROM deleted INNER JOIN dbo27.translations t ON t.company_id = deleted.company_id AND t.table_id = 3 AND t.member_id = deleted.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: This trigger fires on insert into dbo27.units
-- =============================================

CREATE TRIGGER [dbo27].[tr_units_insert]
   ON  [dbo27].[units]
   AFTER INSERT
AS
BEGIN

SET NOCOUNT ON;

UPDATE dbo27.units
SET
    created_by = USER_NAME()
    , created_on = CAST(GETDATE() AS datetime2(0))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.units t INNER JOIN inserted ON t.id = inserted.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.1, 2022-10-14
-- Description: This trigger fires on update of dbo27.units
-- =============================================

CREATE TRIGGER [dbo27].[tr_units_update]
   ON  [dbo27].[units]
   AFTER UPDATE
AS
BEGIN

SET NOCOUNT ON;

IF TRIGGER_NESTLEVEL() > 1
    RETURN

UPDATE dbo27.units
SET
    created_by = COALESCE(deleted.created_by, t.created_by, USER_NAME())
    , created_on = COALESCE(deleted.created_on, t.created_on, CAST(GETDATE() AS datetime2(0)))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.units t INNER JOIN deleted ON t.id = deleted.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: This trigger fires on insert into dbo27.users
-- =============================================

CREATE TRIGGER [dbo27].[tr_users_insert]
   ON  [dbo27].[users]
   AFTER INSERT
AS
BEGIN

SET NOCOUNT ON;

UPDATE dbo27.users
SET
    created_by = USER_NAME()
    , created_on = CAST(GETDATE() AS datetime2(0))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.users t INNER JOIN inserted ON t.id = inserted.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: This trigger fires on update of dbo27.users
-- =============================================

CREATE TRIGGER [dbo27].[tr_users_update]
   ON  [dbo27].[users]
   AFTER UPDATE
AS
BEGIN

SET NOCOUNT ON;

IF TRIGGER_NESTLEVEL() > 1
    RETURN

UPDATE dbo27.users
SET
    created_by = COALESCE(deleted.created_by, t.created_by, USER_NAME())
    , created_on = COALESCE(deleted.created_on, t.created_on, CAST(GETDATE() AS datetime2(0)))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.users t INNER JOIN deleted ON t.id = deleted.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.1, 2022-10-14
-- Description: This trigger fires on delete from dbo27.vat_rates
-- =============================================

CREATE TRIGGER [dbo27].[tr_vat_rates_delete]
   ON  [dbo27].[vat_rates]
   AFTER DELETE
AS
BEGIN

SET NOCOUNT ON;

DELETE dbo27.translations FROM deleted INNER JOIN dbo27.translations t ON t.company_id = deleted.company_id AND t.table_id = 4 AND t.member_id = deleted.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.0, 2022-07-05
-- Description: This trigger fires on insert into dbo27.vat_rates
-- =============================================

CREATE TRIGGER [dbo27].[tr_vat_rates_insert]
   ON  [dbo27].[vat_rates]
   AFTER INSERT
AS
BEGIN

SET NOCOUNT ON;

UPDATE dbo27.vat_rates
SET
    created_by = USER_NAME()
    , created_on = CAST(GETDATE() AS datetime2(0))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.vat_rates t INNER JOIN inserted ON t.id = inserted.id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     3.1, 2022-10-14
-- Description: This trigger fires on update of dbo27.vat_rates
-- =============================================

CREATE TRIGGER [dbo27].[tr_vat_rates_update]
   ON  [dbo27].[vat_rates]
   AFTER UPDATE
AS
BEGIN

SET NOCOUNT ON;

IF TRIGGER_NESTLEVEL() > 1
    RETURN

UPDATE dbo27.vat_rates
SET
    created_by = COALESCE(deleted.created_by, t.created_by, USER_NAME())
    , created_on = COALESCE(deleted.created_on, t.created_on, CAST(GETDATE() AS datetime2(0)))
    , modified_by = USER_NAME()
    , modified_on = CAST(GETDATE() AS datetime2(0))
FROM
    dbo27.vat_rates t INNER JOIN deleted ON t.id = deleted.id

END


GO

INSERT INTO [dbo27].[dimensions] ([id], [code], [name]) VALUES (1, N'accounts', N'Accounts');
INSERT INTO [dbo27].[dimensions] ([id], [code], [name]) VALUES (2, N'times', N'Times');
INSERT INTO [dbo27].[dimensions] ([id], [code], [name]) VALUES (3, N'categories', N'Categories');
INSERT INTO [dbo27].[dimensions] ([id], [code], [name]) VALUES (4, N'entities', N'Entities');
INSERT INTO [dbo27].[dimensions] ([id], [code], [name]) VALUES (5, N'regions', N'Regions');
INSERT INTO [dbo27].[dimensions] ([id], [code], [name]) VALUES (6, N'products', N'Products');
INSERT INTO [dbo27].[dimensions] ([id], [code], [name]) VALUES (7, N'sub_accounts', N'Sub.Accounts');
GO

INSERT INTO [dbo27].[entry_sides] ([id], [code], [name]) VALUES (1, N'Dr', N'Debit');
INSERT INTO [dbo27].[entry_sides] ([id], [code], [name]) VALUES (2, N'Cr', N'Credit');
GO

INSERT INTO [dbo27].[ledger_account_special_types] ([id], [code], [name]) VALUES (1, N'cash', N'Cash');
INSERT INTO [dbo27].[ledger_account_special_types] ([id], [code], [name]) VALUES (2, N'net_income', N'Net Income (BS)');
INSERT INTO [dbo27].[ledger_account_special_types] ([id], [code], [name]) VALUES (3, N'vat', N'VAT Payable');
INSERT INTO [dbo27].[ledger_account_special_types] ([id], [code], [name]) VALUES (4, N'input_vat', N'VAT Receivable');
INSERT INTO [dbo27].[ledger_account_special_types] ([id], [code], [name]) VALUES (5, N'currency_exchange_gains', N'Currency Exchange Gains');
INSERT INTO [dbo27].[ledger_account_special_types] ([id], [code], [name]) VALUES (6, N'currency_exchange_losses', N'Currency Exchange Losses');
INSERT INTO [dbo27].[ledger_account_special_types] ([id], [code], [name]) VALUES (7, N'currency_translation_gains', N'Currency Translation Gains');
INSERT INTO [dbo27].[ledger_account_special_types] ([id], [code], [name]) VALUES (8, N'currency_translation_losses', N'Currency Translation Losses');
INSERT INTO [dbo27].[ledger_account_special_types] ([id], [code], [name]) VALUES (9, N'calculation', N'Calculation');
GO

INSERT INTO [dbo27].[member_types] ([id], [code], [name], [cf_sign], [pl_sign], [asset_sign], [vat_sign], [payment_debit_type_id], [payment_credit_type_id], [charge_debit_type_id], [charge_credit_type_id], [vat_debit_type_id], [vat_credit_type_id]) VALUES (0, N'none', N'None', 0, 0, 0, 0, 0, 0, 0, 0, 0, 0);
INSERT INTO [dbo27].[member_types] ([id], [code], [name], [cf_sign], [pl_sign], [asset_sign], [vat_sign], [payment_debit_type_id], [payment_credit_type_id], [charge_debit_type_id], [charge_credit_type_id], [vat_debit_type_id], [vat_credit_type_id]) VALUES (1, N'calculated', N'Calculated', 0, 0, 0, 0, 0, 0, 0, 0, 0, 0);
INSERT INTO [dbo27].[member_types] ([id], [code], [name], [cf_sign], [pl_sign], [asset_sign], [vat_sign], [payment_debit_type_id], [payment_credit_type_id], [charge_debit_type_id], [charge_credit_type_id], [vat_debit_type_id], [vat_credit_type_id]) VALUES (2, N'income', N'Income', 1, 1, 0, 1, 1, 2, 2, 3, 3, 4);
INSERT INTO [dbo27].[member_types] ([id], [code], [name], [cf_sign], [pl_sign], [asset_sign], [vat_sign], [payment_debit_type_id], [payment_credit_type_id], [charge_debit_type_id], [charge_credit_type_id], [vat_debit_type_id], [vat_credit_type_id]) VALUES (3, N'income_no_vat', N'Income, no VAT', 1, 1, 0, 0, 1, 2, 2, 3, 0, 0);
INSERT INTO [dbo27].[member_types] ([id], [code], [name], [cf_sign], [pl_sign], [asset_sign], [vat_sign], [payment_debit_type_id], [payment_credit_type_id], [charge_debit_type_id], [charge_credit_type_id], [vat_debit_type_id], [vat_credit_type_id]) VALUES (4, N'expense', N'Expense', -1, -1, 0, -1, 2, 1, 3, 2, 4, 2);
INSERT INTO [dbo27].[member_types] ([id], [code], [name], [cf_sign], [pl_sign], [asset_sign], [vat_sign], [payment_debit_type_id], [payment_credit_type_id], [charge_debit_type_id], [charge_credit_type_id], [vat_debit_type_id], [vat_credit_type_id]) VALUES (5, N'expense_no_vat', N'Expense, no VAT', -1, -1, 0, 0, 2, 1, 3, 2, 0, 0);
INSERT INTO [dbo27].[member_types] ([id], [code], [name], [cf_sign], [pl_sign], [asset_sign], [vat_sign], [payment_debit_type_id], [payment_credit_type_id], [charge_debit_type_id], [charge_credit_type_id], [vat_debit_type_id], [vat_credit_type_id]) VALUES (6, N'purchase', N'Purchase', -1, 0, 1, -1, 2, 1, 3, 2, 4, 2);
INSERT INTO [dbo27].[member_types] ([id], [code], [name], [cf_sign], [pl_sign], [asset_sign], [vat_sign], [payment_debit_type_id], [payment_credit_type_id], [charge_debit_type_id], [charge_credit_type_id], [vat_debit_type_id], [vat_credit_type_id]) VALUES (7, N'purchase_no_vat', N'Purchase, no VAT', -1, 0, 1, 0, 2, 1, 3, 2, 0, 0);
INSERT INTO [dbo27].[member_types] ([id], [code], [name], [cf_sign], [pl_sign], [asset_sign], [vat_sign], [payment_debit_type_id], [payment_credit_type_id], [charge_debit_type_id], [charge_credit_type_id], [vat_debit_type_id], [vat_credit_type_id]) VALUES (8, N'cost', N'Cost', 0, -1, -1, 0, 0, 0, 3, 3, 0, 0);
INSERT INTO [dbo27].[member_types] ([id], [code], [name], [cf_sign], [pl_sign], [asset_sign], [vat_sign], [payment_debit_type_id], [payment_credit_type_id], [charge_debit_type_id], [charge_credit_type_id], [vat_debit_type_id], [vat_credit_type_id]) VALUES (9, N'depreciation', N'Depreciation', 0, -1, -1, 0, 0, 0, 3, 3, 0, 0);
INSERT INTO [dbo27].[member_types] ([id], [code], [name], [cf_sign], [pl_sign], [asset_sign], [vat_sign], [payment_debit_type_id], [payment_credit_type_id], [charge_debit_type_id], [charge_credit_type_id], [vat_debit_type_id], [vat_credit_type_id]) VALUES (10, N'amortization', N'Amortization', 0, -1, -1, 0, 0, 0, 3, 3, 0, 0);
INSERT INTO [dbo27].[member_types] ([id], [code], [name], [cf_sign], [pl_sign], [asset_sign], [vat_sign], [payment_debit_type_id], [payment_credit_type_id], [charge_debit_type_id], [charge_credit_type_id], [vat_debit_type_id], [vat_credit_type_id]) VALUES (11, N'withholding', N'Withholding', -1, 0, 0, 0, 2, 1, 2, 2, 0, 0);
INSERT INTO [dbo27].[member_types] ([id], [code], [name], [cf_sign], [pl_sign], [asset_sign], [vat_sign], [payment_debit_type_id], [payment_credit_type_id], [charge_debit_type_id], [charge_credit_type_id], [vat_debit_type_id], [vat_credit_type_id]) VALUES (12, N'inflow', N'Inflow', 1, 0, 0, 0, 1, 2, 0, 0, 0, 0);
INSERT INTO [dbo27].[member_types] ([id], [code], [name], [cf_sign], [pl_sign], [asset_sign], [vat_sign], [payment_debit_type_id], [payment_credit_type_id], [charge_debit_type_id], [charge_credit_type_id], [vat_debit_type_id], [vat_credit_type_id]) VALUES (13, N'outflow', N'Outflow', -1, 0, 0, 0, 2, 1, 0, 0, 0, 0);
INSERT INTO [dbo27].[member_types] ([id], [code], [name], [cf_sign], [pl_sign], [asset_sign], [vat_sign], [payment_debit_type_id], [payment_credit_type_id], [charge_debit_type_id], [charge_credit_type_id], [vat_debit_type_id], [vat_credit_type_id]) VALUES (14, N'cash_transfer', N'Cash Transfer', 0, 0, 0, 0, 1, 1, 0, 0, 0, 0);
INSERT INTO [dbo27].[member_types] ([id], [code], [name], [cf_sign], [pl_sign], [asset_sign], [vat_sign], [payment_debit_type_id], [payment_credit_type_id], [charge_debit_type_id], [charge_credit_type_id], [vat_debit_type_id], [vat_credit_type_id]) VALUES (15, N'setoff', N'Setoff', 0, 0, 0, 0, 0, 0, 2, 2, 0, 0);
GO

INSERT INTO [dbo27].[report_section_total_types] ([id], [code], [name]) VALUES (1, N'total', N'Total');
INSERT INTO [dbo27].[report_section_total_types] ([id], [code], [name]) VALUES (2, N'opening_balance', N'Opening Balance');
INSERT INTO [dbo27].[report_section_total_types] ([id], [code], [name]) VALUES (3, N'closing_balance', N'Closing Balance');
GO

INSERT INTO [dbo27].[report_section_value_types] ([id], [code], [name]) VALUES (1, N'flow', N'Flow');
INSERT INTO [dbo27].[report_section_value_types] ([id], [code], [name]) VALUES (2, N'balance', N'Balance');
INSERT INTO [dbo27].[report_section_value_types] ([id], [code], [name]) VALUES (3, N'debit_balance', N'Debit Balance');
INSERT INTO [dbo27].[report_section_value_types] ([id], [code], [name]) VALUES (4, N'credit_balance', N'Credit Balance');
GO

INSERT INTO [dbo27].[report_types] ([id], [code], [name]) VALUES (1, N'PL', N'Income Statement');
INSERT INTO [dbo27].[report_types] ([id], [code], [name]) VALUES (2, N'CF', N'Cash Flow');
INSERT INTO [dbo27].[report_types] ([id], [code], [name]) VALUES (3, N'BS', N'Balance Sheet');
INSERT INTO [dbo27].[report_types] ([id], [code], [name]) VALUES (4, N'DCF', N'Direct Cash Flow');
INSERT INTO [dbo27].[report_types] ([id], [code], [name]) VALUES (5, N'VAT', N'VAT');
GO

INSERT INTO [dbo27].[translated_tables] ([id], [code], [name]) VALUES (1, N'members', N'members');
INSERT INTO [dbo27].[translated_tables] ([id], [code], [name]) VALUES (2, N'companies', N'companies');
INSERT INTO [dbo27].[translated_tables] ([id], [code], [name]) VALUES (3, N'units', N'units');
INSERT INTO [dbo27].[translated_tables] ([id], [code], [name]) VALUES (4, N'vat_rates', N'vat_rates');
INSERT INTO [dbo27].[translated_tables] ([id], [code], [name]) VALUES (9, N'report_sections', N'report_sections');
INSERT INTO [dbo27].[translated_tables] ([id], [code], [name]) VALUES (10, N'subsidiary_groups', N'subsidiary_groups');
INSERT INTO [dbo27].[translated_tables] ([id], [code], [name]) VALUES (11, N'ledger_accounts', N'ledger_accounts');
INSERT INTO [dbo27].[translated_tables] ([id], [code], [name]) VALUES (12, N'saved_report_types', N'saved_report_types');
GO

INSERT INTO [dbo27].[ledger_account_types] ([id], [code], [name], [bs_section], [bs_sign], [pl_section], [is_pl], [is_da], [cf_section], [specific_type_id]) VALUES (11, N'non_current_assets', N'Non-current Assets', 1, 1, 0, 0, 0, 2, NULL);
INSERT INTO [dbo27].[ledger_account_types] ([id], [code], [name], [bs_section], [bs_sign], [pl_section], [is_pl], [is_da], [cf_section], [specific_type_id]) VALUES (12, N'depreciation', N'Non-current Assets - Depreciation', 1, 1, 0, 0, 0, 2, NULL);
INSERT INTO [dbo27].[ledger_account_types] ([id], [code], [name], [bs_section], [bs_sign], [pl_section], [is_pl], [is_da], [cf_section], [specific_type_id]) VALUES (13, N'amortization', N'Non-current Assets - Amortization', 1, 1, 0, 0, 0, 2, NULL);
INSERT INTO [dbo27].[ledger_account_types] ([id], [code], [name], [bs_section], [bs_sign], [pl_section], [is_pl], [is_da], [cf_section], [specific_type_id]) VALUES (14, N'non_current_financial_assets', N'Non-current Financial Assets', 1, 1, 0, 0, 0, 3, NULL);
INSERT INTO [dbo27].[ledger_account_types] ([id], [code], [name], [bs_section], [bs_sign], [pl_section], [is_pl], [is_da], [cf_section], [specific_type_id]) VALUES (15, N'non_current_financial_assets_net', N'Non-current Financial Assets Net', 1, 1, 0, 0, 0, 3, NULL);
INSERT INTO [dbo27].[ledger_account_types] ([id], [code], [name], [bs_section], [bs_sign], [pl_section], [is_pl], [is_da], [cf_section], [specific_type_id]) VALUES (21, N'current_assets', N'Current Assets', 2, 1, 0, 0, 0, 1, NULL);
INSERT INTO [dbo27].[ledger_account_types] ([id], [code], [name], [bs_section], [bs_sign], [pl_section], [is_pl], [is_da], [cf_section], [specific_type_id]) VALUES (22, N'cash', N'Current Assets - Cash', 2, 1, 0, 0, 0, 0, 1);
INSERT INTO [dbo27].[ledger_account_types] ([id], [code], [name], [bs_section], [bs_sign], [pl_section], [is_pl], [is_da], [cf_section], [specific_type_id]) VALUES (23, N'cash_equivalents', N'Current Assets - Cash Equivalents', 2, 1, 0, 0, 0, 0, NULL);
INSERT INTO [dbo27].[ledger_account_types] ([id], [code], [name], [bs_section], [bs_sign], [pl_section], [is_pl], [is_da], [cf_section], [specific_type_id]) VALUES (24, N'current_assets_receivable', N'Current Assets - Receivable', 2, 1, 0, 0, 0, 1, NULL);
INSERT INTO [dbo27].[ledger_account_types] ([id], [code], [name], [bs_section], [bs_sign], [pl_section], [is_pl], [is_da], [cf_section], [specific_type_id]) VALUES (25, N'input_vat', N'Current Assets - VAT Receivable', 2, 1, 0, 0, 0, 1, 4);
INSERT INTO [dbo27].[ledger_account_types] ([id], [code], [name], [bs_section], [bs_sign], [pl_section], [is_pl], [is_da], [cf_section], [specific_type_id]) VALUES (26, N'current_financial_assets', N'Current Financial Assets', 2, 1, 0, 0, 0, 3, NULL);
INSERT INTO [dbo27].[ledger_account_types] ([id], [code], [name], [bs_section], [bs_sign], [pl_section], [is_pl], [is_da], [cf_section], [specific_type_id]) VALUES (27, N'current_financial_assets_net', N'Current Financial Assets Net', 2, 1, 0, 0, 0, 3, NULL);
INSERT INTO [dbo27].[ledger_account_types] ([id], [code], [name], [bs_section], [bs_sign], [pl_section], [is_pl], [is_da], [cf_section], [specific_type_id]) VALUES (28, N'current_investing_assets', N'Current Investing Assets', 2, 1, 0, 0, 0, 2, NULL);
INSERT INTO [dbo27].[ledger_account_types] ([id], [code], [name], [bs_section], [bs_sign], [pl_section], [is_pl], [is_da], [cf_section], [specific_type_id]) VALUES (31, N'equty', N'Equity', 3, -1, 0, 0, 0, 3, NULL);
INSERT INTO [dbo27].[ledger_account_types] ([id], [code], [name], [bs_section], [bs_sign], [pl_section], [is_pl], [is_da], [cf_section], [specific_type_id]) VALUES (32, N'retained_earnings', N'Equity - Retained Earnings', 3, -1, 0, 0, 0, 3, NULL);
INSERT INTO [dbo27].[ledger_account_types] ([id], [code], [name], [bs_section], [bs_sign], [pl_section], [is_pl], [is_da], [cf_section], [specific_type_id]) VALUES (33, N'net_income', N'Equity - Net Income', 3, -1, 0, 0, 0, 1, 2);
INSERT INTO [dbo27].[ledger_account_types] ([id], [code], [name], [bs_section], [bs_sign], [pl_section], [is_pl], [is_da], [cf_section], [specific_type_id]) VALUES (41, N'non_current_liabilities', N'Non-current Liabilities', 4, -1, 0, 0, 0, 1, NULL);
INSERT INTO [dbo27].[ledger_account_types] ([id], [code], [name], [bs_section], [bs_sign], [pl_section], [is_pl], [is_da], [cf_section], [specific_type_id]) VALUES (42, N'non_current_financial_liabilities', N'Non-current Financial Liabilities', 4, -1, 0, 0, 0, 3, NULL);
INSERT INTO [dbo27].[ledger_account_types] ([id], [code], [name], [bs_section], [bs_sign], [pl_section], [is_pl], [is_da], [cf_section], [specific_type_id]) VALUES (43, N'non_current_financial_liabilities_net', N'Non-current Financial Liabilities Net', 4, -1, 0, 0, 0, 3, NULL);
INSERT INTO [dbo27].[ledger_account_types] ([id], [code], [name], [bs_section], [bs_sign], [pl_section], [is_pl], [is_da], [cf_section], [specific_type_id]) VALUES (51, N'current_liabilities', N'Current Liabilities', 5, -1, 0, 0, 0, 1, NULL);
INSERT INTO [dbo27].[ledger_account_types] ([id], [code], [name], [bs_section], [bs_sign], [pl_section], [is_pl], [is_da], [cf_section], [specific_type_id]) VALUES (52, N'current_liabilities_payable', N'Current Liabilities - Payable', 5, -1, 0, 0, 0, 1, NULL);
INSERT INTO [dbo27].[ledger_account_types] ([id], [code], [name], [bs_section], [bs_sign], [pl_section], [is_pl], [is_da], [cf_section], [specific_type_id]) VALUES (53, N'vat', N'Current Liabilities - VAT Payable', 5, -1, 0, 0, 0, 1, 3);
INSERT INTO [dbo27].[ledger_account_types] ([id], [code], [name], [bs_section], [bs_sign], [pl_section], [is_pl], [is_da], [cf_section], [specific_type_id]) VALUES (54, N'current_financial_liabilities', N'Current Financial Liabilities', 5, -1, 0, 0, 0, 3, NULL);
INSERT INTO [dbo27].[ledger_account_types] ([id], [code], [name], [bs_section], [bs_sign], [pl_section], [is_pl], [is_da], [cf_section], [specific_type_id]) VALUES (55, N'current_financial_liabilities_net', N'Current Financial Liabilities Net', 5, -1, 0, 0, 0, 3, NULL);
INSERT INTO [dbo27].[ledger_account_types] ([id], [code], [name], [bs_section], [bs_sign], [pl_section], [is_pl], [is_da], [cf_section], [specific_type_id]) VALUES (56, N'current_investing_liabilities', N'Current Investing Liabilities', 5, -1, 0, 0, 0, 2, NULL);
INSERT INTO [dbo27].[ledger_account_types] ([id], [code], [name], [bs_section], [bs_sign], [pl_section], [is_pl], [is_da], [cf_section], [specific_type_id]) VALUES (57, N'assets_or_liabilities', N'Current Assets/Liabilities', 5, 0, 0, 0, 0, 1, NULL);
INSERT INTO [dbo27].[ledger_account_types] ([id], [code], [name], [bs_section], [bs_sign], [pl_section], [is_pl], [is_da], [cf_section], [specific_type_id]) VALUES (60, N'revenue', N'Revenue', 3, -1, 1, 1, 0, 1, NULL);
INSERT INTO [dbo27].[ledger_account_types] ([id], [code], [name], [bs_section], [bs_sign], [pl_section], [is_pl], [is_da], [cf_section], [specific_type_id]) VALUES (61, N'cost_of_revenue', N'Cost of Revenue', 3, -1, 2, 1, 0, 1, NULL);
INSERT INTO [dbo27].[ledger_account_types] ([id], [code], [name], [bs_section], [bs_sign], [pl_section], [is_pl], [is_da], [cf_section], [specific_type_id]) VALUES (62, N'cost_of_revenue_depreciation', N'Cost of Revenue - Depreciation', 3, -1, 2, 1, 1, 1, NULL);
INSERT INTO [dbo27].[ledger_account_types] ([id], [code], [name], [bs_section], [bs_sign], [pl_section], [is_pl], [is_da], [cf_section], [specific_type_id]) VALUES (63, N'cost_of_revenue_amortization', N'Cost of Revenue - Amortization', 3, -1, 2, 1, 1, 1, NULL);
INSERT INTO [dbo27].[ledger_account_types] ([id], [code], [name], [bs_section], [bs_sign], [pl_section], [is_pl], [is_da], [cf_section], [specific_type_id]) VALUES (71, N'rd_expenses', N'R&D Expenses', 3, -1, 3, 1, 0, 1, NULL);
INSERT INTO [dbo27].[ledger_account_types] ([id], [code], [name], [bs_section], [bs_sign], [pl_section], [is_pl], [is_da], [cf_section], [specific_type_id]) VALUES (72, N'rd_expenses_depreciation', N'R&D Expenses - Depreciation', 3, -1, 3, 1, 1, 1, NULL);
INSERT INTO [dbo27].[ledger_account_types] ([id], [code], [name], [bs_section], [bs_sign], [pl_section], [is_pl], [is_da], [cf_section], [specific_type_id]) VALUES (73, N'rd_expenses_amortization', N'R&D Expenses - Amortization', 3, -1, 3, 1, 1, 1, NULL);
INSERT INTO [dbo27].[ledger_account_types] ([id], [code], [name], [bs_section], [bs_sign], [pl_section], [is_pl], [is_da], [cf_section], [specific_type_id]) VALUES (81, N'selling_expenses', N'Selling Expenses', 3, -1, 4, 1, 0, 1, NULL);
INSERT INTO [dbo27].[ledger_account_types] ([id], [code], [name], [bs_section], [bs_sign], [pl_section], [is_pl], [is_da], [cf_section], [specific_type_id]) VALUES (82, N'selling_expenses_depreciation', N'Selling Expenses - Depreciation', 3, -1, 4, 1, 1, 1, NULL);
INSERT INTO [dbo27].[ledger_account_types] ([id], [code], [name], [bs_section], [bs_sign], [pl_section], [is_pl], [is_da], [cf_section], [specific_type_id]) VALUES (83, N'selling_expenses_amortization', N'Selling Expenses - Amortization', 3, -1, 4, 1, 1, 1, NULL);
INSERT INTO [dbo27].[ledger_account_types] ([id], [code], [name], [bs_section], [bs_sign], [pl_section], [is_pl], [is_da], [cf_section], [specific_type_id]) VALUES (91, N'general_expenses', N'General Expenses', 3, -1, 5, 1, 0, 1, NULL);
INSERT INTO [dbo27].[ledger_account_types] ([id], [code], [name], [bs_section], [bs_sign], [pl_section], [is_pl], [is_da], [cf_section], [specific_type_id]) VALUES (92, N'general_expenses_depreciation', N'General Expenses - Depreciation', 3, -1, 5, 1, 1, 1, NULL);
INSERT INTO [dbo27].[ledger_account_types] ([id], [code], [name], [bs_section], [bs_sign], [pl_section], [is_pl], [is_da], [cf_section], [specific_type_id]) VALUES (93, N'general_expenses_amortization', N'General Expenses - Amortization', 3, -1, 5, 1, 1, 1, NULL);
INSERT INTO [dbo27].[ledger_account_types] ([id], [code], [name], [bs_section], [bs_sign], [pl_section], [is_pl], [is_da], [cf_section], [specific_type_id]) VALUES (101, N'administrative_expenses', N'Administrative Expenses', 3, -1, 6, 1, 0, 1, NULL);
INSERT INTO [dbo27].[ledger_account_types] ([id], [code], [name], [bs_section], [bs_sign], [pl_section], [is_pl], [is_da], [cf_section], [specific_type_id]) VALUES (102, N'administrative_expenses_depreciation', N'Administrative Expenses - Depreciation', 3, -1, 6, 1, 1, 1, NULL);
INSERT INTO [dbo27].[ledger_account_types] ([id], [code], [name], [bs_section], [bs_sign], [pl_section], [is_pl], [is_da], [cf_section], [specific_type_id]) VALUES (103, N'administrative_expenses_amortization', N'Administrative Expenses - Amortization', 3, -1, 6, 1, 1, 1, NULL);
INSERT INTO [dbo27].[ledger_account_types] ([id], [code], [name], [bs_section], [bs_sign], [pl_section], [is_pl], [is_da], [cf_section], [specific_type_id]) VALUES (111, N'interest_expenses', N'Interest Expenses', 3, -1, 8, 1, 0, 1, NULL);
INSERT INTO [dbo27].[ledger_account_types] ([id], [code], [name], [bs_section], [bs_sign], [pl_section], [is_pl], [is_da], [cf_section], [specific_type_id]) VALUES (121, N'other_income', N'Other Income', 3, -1, 9, 1, 0, 1, NULL);
INSERT INTO [dbo27].[ledger_account_types] ([id], [code], [name], [bs_section], [bs_sign], [pl_section], [is_pl], [is_da], [cf_section], [specific_type_id]) VALUES (122, N'other_investing_income', N'Other Investing Income', 3, -1, 9, 1, 0, 2, NULL);
INSERT INTO [dbo27].[ledger_account_types] ([id], [code], [name], [bs_section], [bs_sign], [pl_section], [is_pl], [is_da], [cf_section], [specific_type_id]) VALUES (123, N'other_financial_income', N'Other Financial Income', 3, -1, 9, 1, 0, 3, NULL);
INSERT INTO [dbo27].[ledger_account_types] ([id], [code], [name], [bs_section], [bs_sign], [pl_section], [is_pl], [is_da], [cf_section], [specific_type_id]) VALUES (124, N'currency_exchange_gains', N'Currency Exchange Gains', 3, -1, 9, 1, 0, 1, 5);
INSERT INTO [dbo27].[ledger_account_types] ([id], [code], [name], [bs_section], [bs_sign], [pl_section], [is_pl], [is_da], [cf_section], [specific_type_id]) VALUES (125, N'currency_translation_gains', N'Currency Translation Gains', 3, -1, 9, 1, 0, 1, 7);
INSERT INTO [dbo27].[ledger_account_types] ([id], [code], [name], [bs_section], [bs_sign], [pl_section], [is_pl], [is_da], [cf_section], [specific_type_id]) VALUES (131, N'other_expenses', N'Other Expenses', 3, -1, 10, 1, 0, 1, NULL);
INSERT INTO [dbo27].[ledger_account_types] ([id], [code], [name], [bs_section], [bs_sign], [pl_section], [is_pl], [is_da], [cf_section], [specific_type_id]) VALUES (132, N'other_investing_expenses', N'Other Investing Expenses', 3, -1, 10, 1, 0, 2, NULL);
INSERT INTO [dbo27].[ledger_account_types] ([id], [code], [name], [bs_section], [bs_sign], [pl_section], [is_pl], [is_da], [cf_section], [specific_type_id]) VALUES (133, N'other_financial_expenses', N'Other Financial Expenses', 3, -1, 10, 1, 0, 3, NULL);
INSERT INTO [dbo27].[ledger_account_types] ([id], [code], [name], [bs_section], [bs_sign], [pl_section], [is_pl], [is_da], [cf_section], [specific_type_id]) VALUES (134, N'currency_exchange_losses', N'Currency Exchange Losses', 3, -1, 10, 1, 0, 1, 6);
INSERT INTO [dbo27].[ledger_account_types] ([id], [code], [name], [bs_section], [bs_sign], [pl_section], [is_pl], [is_da], [cf_section], [specific_type_id]) VALUES (135, N'currency_translation_losses', N'Currency Translation Losses', 3, -1, 10, 1, 0, 1, 8);
INSERT INTO [dbo27].[ledger_account_types] ([id], [code], [name], [bs_section], [bs_sign], [pl_section], [is_pl], [is_da], [cf_section], [specific_type_id]) VALUES (141, N'income_tax_expense', N'Income Tax Expense', 3, -1, 12, 1, 0, 1, NULL);
INSERT INTO [dbo27].[ledger_account_types] ([id], [code], [name], [bs_section], [bs_sign], [pl_section], [is_pl], [is_da], [cf_section], [specific_type_id]) VALUES (150, N'calculation', N'Calculation', 3, -1, 13, 1, 0, 1, 9);
GO

INSERT INTO [dbo27].[report_section_types] ([id], [report_type_id], [name], [total_type_id], [hide_accounts]) VALUES (10, 1, N'Revenue', 1, 0);
INSERT INTO [dbo27].[report_section_types] ([id], [report_type_id], [name], [total_type_id], [hide_accounts]) VALUES (11, 1, N'Cost of Revenue', 1, 0);
INSERT INTO [dbo27].[report_section_types] ([id], [report_type_id], [name], [total_type_id], [hide_accounts]) VALUES (12, 1, N'R&D Expenses', 1, 0);
INSERT INTO [dbo27].[report_section_types] ([id], [report_type_id], [name], [total_type_id], [hide_accounts]) VALUES (13, 1, N'Selling Expenses', 1, 0);
INSERT INTO [dbo27].[report_section_types] ([id], [report_type_id], [name], [total_type_id], [hide_accounts]) VALUES (14, 1, N'General Expenses', 1, 0);
INSERT INTO [dbo27].[report_section_types] ([id], [report_type_id], [name], [total_type_id], [hide_accounts]) VALUES (15, 1, N'Administrative Expenses', 1, 0);
INSERT INTO [dbo27].[report_section_types] ([id], [report_type_id], [name], [total_type_id], [hide_accounts]) VALUES (16, 1, N'Interest Expenses', 1, 0);
INSERT INTO [dbo27].[report_section_types] ([id], [report_type_id], [name], [total_type_id], [hide_accounts]) VALUES (17, 1, N'Other Income', 1, 0);
INSERT INTO [dbo27].[report_section_types] ([id], [report_type_id], [name], [total_type_id], [hide_accounts]) VALUES (18, 1, N'Other Expenses', 1, 0);
INSERT INTO [dbo27].[report_section_types] ([id], [report_type_id], [name], [total_type_id], [hide_accounts]) VALUES (19, 1, N'Income Tax Expense', 1, 0);
INSERT INTO [dbo27].[report_section_types] ([id], [report_type_id], [name], [total_type_id], [hide_accounts]) VALUES (21, 2, N'Net Income (CF)', 1, 1);
INSERT INTO [dbo27].[report_section_types] ([id], [report_type_id], [name], [total_type_id], [hide_accounts]) VALUES (22, 2, N'Depreciation (CF)', 1, 1);
INSERT INTO [dbo27].[report_section_types] ([id], [report_type_id], [name], [total_type_id], [hide_accounts]) VALUES (23, 2, N'Operating Cash Flows (CF)', 1, 0);
INSERT INTO [dbo27].[report_section_types] ([id], [report_type_id], [name], [total_type_id], [hide_accounts]) VALUES (24, 2, N'Investing Cash Flows (CF)', 1, 0);
INSERT INTO [dbo27].[report_section_types] ([id], [report_type_id], [name], [total_type_id], [hide_accounts]) VALUES (25, 2, N'Financing Cash Flows (CF)', 1, 0);
INSERT INTO [dbo27].[report_section_types] ([id], [report_type_id], [name], [total_type_id], [hide_accounts]) VALUES (26, 2, N'Financing Cash Inflows (CF)', 1, 0);
INSERT INTO [dbo27].[report_section_types] ([id], [report_type_id], [name], [total_type_id], [hide_accounts]) VALUES (27, 2, N'Financing Cash Outflows (CF)', 1, 0);
INSERT INTO [dbo27].[report_section_types] ([id], [report_type_id], [name], [total_type_id], [hide_accounts]) VALUES (28, 2, N'Cash at the Beginning (CF)', 2, 0);
INSERT INTO [dbo27].[report_section_types] ([id], [report_type_id], [name], [total_type_id], [hide_accounts]) VALUES (29, 2, N'Cash at the End (CF)', 3, 0);
INSERT INTO [dbo27].[report_section_types] ([id], [report_type_id], [name], [total_type_id], [hide_accounts]) VALUES (31, 3, N'Current Assets', 2, 0);
INSERT INTO [dbo27].[report_section_types] ([id], [report_type_id], [name], [total_type_id], [hide_accounts]) VALUES (32, 3, N'Non-Current Assets', 2, 0);
INSERT INTO [dbo27].[report_section_types] ([id], [report_type_id], [name], [total_type_id], [hide_accounts]) VALUES (33, 3, N'Current Liabilities', 2, 0);
INSERT INTO [dbo27].[report_section_types] ([id], [report_type_id], [name], [total_type_id], [hide_accounts]) VALUES (34, 3, N'Non-Current Liabilities', 2, 0);
INSERT INTO [dbo27].[report_section_types] ([id], [report_type_id], [name], [total_type_id], [hide_accounts]) VALUES (35, 3, N'Stockholders'' Equity', 2, 0);
INSERT INTO [dbo27].[report_section_types] ([id], [report_type_id], [name], [total_type_id], [hide_accounts]) VALUES (36, 3, N'Stockholders'' Equity - Net Income', 2, 1);
INSERT INTO [dbo27].[report_section_types] ([id], [report_type_id], [name], [total_type_id], [hide_accounts]) VALUES (41, 4, N'Operating Inflows', 1, 0);
INSERT INTO [dbo27].[report_section_types] ([id], [report_type_id], [name], [total_type_id], [hide_accounts]) VALUES (42, 4, N'Investing Inflows', 1, 0);
INSERT INTO [dbo27].[report_section_types] ([id], [report_type_id], [name], [total_type_id], [hide_accounts]) VALUES (43, 4, N'Financing Inflows', 1, 0);
INSERT INTO [dbo27].[report_section_types] ([id], [report_type_id], [name], [total_type_id], [hide_accounts]) VALUES (44, 4, N'Operating Outflows', 1, 0);
INSERT INTO [dbo27].[report_section_types] ([id], [report_type_id], [name], [total_type_id], [hide_accounts]) VALUES (45, 4, N'Investing Outflows', 1, 0);
INSERT INTO [dbo27].[report_section_types] ([id], [report_type_id], [name], [total_type_id], [hide_accounts]) VALUES (46, 4, N'Financing Outflows', 1, 0);
INSERT INTO [dbo27].[report_section_types] ([id], [report_type_id], [name], [total_type_id], [hide_accounts]) VALUES (47, 4, N'Cash at the Beginning (DCF)', 2, 0);
INSERT INTO [dbo27].[report_section_types] ([id], [report_type_id], [name], [total_type_id], [hide_accounts]) VALUES (48, 4, N'Cash at the End (DCF)', 3, 0);
INSERT INTO [dbo27].[report_section_types] ([id], [report_type_id], [name], [total_type_id], [hide_accounts]) VALUES (51, 5, N'Income VAT', 1, 0);
INSERT INTO [dbo27].[report_section_types] ([id], [report_type_id], [name], [total_type_id], [hide_accounts]) VALUES (52, 5, N'Expense VAT', 1, 0);
INSERT INTO [dbo27].[report_section_types] ([id], [report_type_id], [name], [total_type_id], [hide_accounts]) VALUES (53, 5, N'VAT Set-Offs', 1, 0);
INSERT INTO [dbo27].[report_section_types] ([id], [report_type_id], [name], [total_type_id], [hide_accounts]) VALUES (54, 5, N'VAT Paid', 1, 0);
INSERT INTO [dbo27].[report_section_types] ([id], [report_type_id], [name], [total_type_id], [hide_accounts]) VALUES (101, 1, N'Disabled', 1, 0);
GO

SET IDENTITY_INSERT [dbo27].[report_section_accounts] ON;
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (1, 11, 24, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (2, 11, 24, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (3, 11, 32, 1, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (4, 11, 32, 2, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (5, 11, 45, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (6, 11, 42, 2, 1, 1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (7, 12, 24, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (8, 12, 22, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (9, 12, 32, 1, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (10, 12, 32, 2, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (11, 13, 24, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (12, 13, 22, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (13, 13, 32, 1, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (14, 13, 32, 2, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (15, 14, 25, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (16, 14, 25, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (17, 14, 32, 1, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (18, 14, 32, 2, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (20, 14, 43, 2, 1, 1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (21, 14, 46, 1, 1, -1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (23, 15, 25, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (24, 15, 25, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (25, 15, 32, 1, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (26, 15, 32, 2, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (28, 15, 43, 2, 1, 1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (29, 15, 46, 1, 1, -1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (31, 21, 23, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (32, 21, 23, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (33, 21, 31, 1, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (34, 21, 31, 2, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (36, 21, 41, 2, 1, 1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (37, 21, 44, 1, 1, -1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (39, 22, 28, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (42, 22, 28, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (45, 22, 29, 1, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (46, 22, 29, 2, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (47, 22, 31, 1, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (48, 22, 31, 2, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (49, 22, 47, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (52, 22, 47, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (55, 22, 47, 1, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (56, 22, 47, 2, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (57, 23, 23, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (58, 23, 23, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (59, 23, 31, 1, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (60, 23, 31, 2, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (62, 23, 41, 2, 1, 1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (63, 23, 44, 1, 1, -1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (65, 24, 23, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (66, 24, 23, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (67, 24, 31, 1, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (68, 24, 31, 2, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (70, 24, 41, 2, 1, 1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (71, 24, 44, 1, 1, -1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (73, 25, 23, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (74, 25, 23, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (75, 25, 31, 1, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (76, 25, 31, 2, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (77, 25, 52, 1, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (80, 25, 53, 2, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (83, 26, 27, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (84, 26, 25, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (85, 26, 31, 1, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (86, 26, 31, 2, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (88, 26, 43, 2, 1, 1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (89, 26, 46, 1, 1, -1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (91, 27, 25, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (92, 27, 25, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (93, 27, 31, 1, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (94, 27, 31, 2, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (96, 27, 43, 2, 1, 1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (97, 27, 46, 1, 1, -1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (99, 31, 25, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (100, 31, 25, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (101, 31, 35, 1, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (102, 31, 35, 2, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (104, 31, 43, 2, 1, 1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (105, 31, 46, 1, 1, -1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (107, 32, 25, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (108, 32, 25, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (109, 32, 35, 1, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (110, 32, 35, 2, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (112, 32, 43, 2, 1, 1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (113, 32, 46, 1, 1, -1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (115, 33, 21, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (116, 33, 21, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (117, 33, 35, 1, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (118, 33, 35, 2, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (120, 33, 43, 2, 1, 1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (121, 33, 46, 1, 1, -1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (123, 41, 23, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (124, 41, 23, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (125, 41, 34, 1, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (126, 41, 34, 2, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (128, 41, 41, 2, 1, 1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (129, 41, 44, 1, 1, -1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (131, 42, 27, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (132, 42, 26, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (135, 42, 34, 1, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (136, 42, 34, 2, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (138, 42, 43, 2, 1, 1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (139, 42, 46, 1, 1, -1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (141, 43, 25, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (142, 43, 25, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (143, 43, 34, 1, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (144, 43, 34, 2, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (146, 43, 43, 2, 1, 1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (147, 43, 46, 1, 1, -1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (149, 51, 23, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (150, 51, 23, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (151, 51, 33, 1, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (152, 51, 33, 2, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (154, 51, 41, 2, 1, 1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (155, 51, 44, 1, 1, -1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (157, 52, 23, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (158, 52, 23, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (159, 52, 33, 1, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (160, 52, 33, 2, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (162, 52, 41, 2, 1, 1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (163, 52, 44, 1, 1, -1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (165, 53, 23, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (166, 53, 23, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (167, 53, 33, 1, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (168, 53, 33, 2, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (170, 53, 41, 2, 1, 1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (171, 53, 44, 1, 1, -1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (174, 53, 51, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (175, 53, 54, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (178, 54, 26, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (179, 54, 27, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (181, 54, 33, 1, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (182, 54, 33, 2, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (184, 54, 43, 2, 1, 1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (185, 54, 46, 1, 1, -1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (187, 55, 25, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (188, 55, 25, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (189, 55, 33, 1, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (190, 55, 33, 2, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (192, 55, 43, 2, 1, 1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (193, 55, 46, 1, 1, -1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (195, 57, 23, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (196, 57, 23, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (197, 57, 31, 1, 3, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (198, 57, 31, 2, 3, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (199, 57, 33, 1, 4, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (200, 57, 33, 2, 4, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (202, 57, 41, 2, 1, 1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (203, 57, 44, 1, 1, -1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (205, 60, 10, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (206, 60, 10, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (207, 60, 21, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (208, 60, 21, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (209, 60, 36, 1, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (210, 60, 36, 2, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (212, 60, 41, 2, 1, 1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (213, 61, 11, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (214, 61, 11, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (215, 61, 21, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (216, 61, 21, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (217, 61, 36, 1, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (218, 61, 36, 2, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (219, 61, 44, 1, 1, -1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (220, 61, 44, 2, 1, 1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (221, 62, 11, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (222, 62, 11, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (223, 62, 21, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (224, 62, 21, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (225, 62, 36, 1, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (226, 62, 36, 2, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (227, 63, 11, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (228, 63, 11, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (229, 63, 21, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (230, 63, 21, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (231, 63, 36, 1, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (232, 63, 36, 2, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (233, 71, 12, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (234, 71, 12, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (235, 71, 21, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (236, 71, 21, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (237, 71, 36, 1, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (238, 71, 36, 2, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (239, 71, 44, 1, 1, -1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (240, 71, 44, 2, 1, 1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (241, 72, 12, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (242, 72, 12, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (243, 72, 21, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (244, 72, 21, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (245, 72, 36, 1, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (246, 72, 36, 2, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (247, 73, 12, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (248, 73, 12, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (249, 73, 21, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (250, 73, 21, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (251, 73, 36, 1, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (252, 73, 36, 2, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (253, 81, 13, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (254, 81, 13, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (255, 81, 21, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (256, 81, 21, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (257, 81, 36, 1, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (258, 81, 36, 2, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (259, 81, 44, 1, 1, -1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (260, 81, 44, 2, 1, 1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (261, 82, 13, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (262, 82, 13, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (263, 82, 21, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (264, 82, 21, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (265, 82, 36, 1, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (266, 82, 36, 2, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (267, 83, 13, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (268, 83, 13, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (269, 83, 21, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (270, 83, 21, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (271, 83, 36, 1, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (272, 83, 36, 2, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (273, 91, 14, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (274, 91, 14, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (275, 91, 21, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (276, 91, 21, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (277, 91, 36, 1, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (278, 91, 36, 2, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (279, 91, 44, 1, 1, -1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (280, 91, 44, 2, 1, 1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (281, 92, 14, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (282, 92, 14, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (283, 92, 21, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (284, 92, 21, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (285, 92, 36, 1, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (286, 92, 36, 2, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (287, 93, 14, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (288, 93, 14, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (289, 93, 21, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (290, 93, 21, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (291, 93, 36, 1, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (292, 93, 36, 2, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (293, 101, 15, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (294, 101, 15, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (295, 101, 21, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (296, 101, 21, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (297, 101, 36, 1, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (298, 101, 36, 2, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (299, 101, 44, 1, 1, -1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (300, 101, 44, 2, 1, 1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (301, 102, 15, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (302, 102, 15, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (303, 102, 21, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (304, 102, 21, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (305, 102, 36, 1, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (306, 102, 36, 2, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (307, 103, 15, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (308, 103, 15, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (309, 103, 21, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (310, 103, 21, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (311, 103, 36, 1, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (312, 103, 36, 2, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (313, 111, 16, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (314, 111, 16, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (315, 111, 21, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (316, 111, 21, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (317, 111, 36, 1, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (318, 111, 36, 2, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (319, 111, 44, 1, 1, -1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (320, 111, 44, 2, 1, 1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (321, 121, 17, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (322, 121, 17, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (323, 121, 21, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (324, 121, 21, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (325, 121, 36, 1, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (326, 121, 36, 2, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (327, 121, 41, 1, 1, -1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (328, 121, 41, 2, 1, 1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (329, 122, 17, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (330, 122, 17, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (331, 122, 21, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (332, 122, 21, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (333, 122, 36, 1, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (334, 122, 36, 2, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (335, 122, 42, 1, 1, -1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (336, 122, 42, 2, 1, 1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (337, 123, 17, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (338, 123, 17, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (339, 123, 21, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (340, 123, 21, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (341, 123, 36, 1, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (342, 123, 36, 2, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (343, 123, 43, 1, 1, -1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (344, 123, 43, 2, 1, 1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (345, 131, 18, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (346, 131, 18, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (347, 131, 21, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (348, 131, 21, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (349, 131, 36, 1, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (350, 131, 36, 2, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (351, 131, 44, 1, 1, -1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (352, 131, 44, 2, 1, 1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (353, 132, 18, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (354, 132, 18, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (355, 132, 21, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (356, 132, 21, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (357, 132, 36, 1, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (358, 132, 36, 2, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (359, 132, 45, 1, 1, -1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (360, 132, 45, 2, 1, 1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (361, 133, 18, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (362, 133, 18, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (363, 133, 21, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (364, 133, 21, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (365, 133, 36, 1, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (366, 133, 36, 2, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (367, 133, 46, 1, 1, -1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (368, 133, 46, 2, 1, 1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (369, 141, 19, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (370, 141, 19, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (371, 141, 21, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (372, 141, 21, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (373, 141, 36, 1, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (374, 141, 36, 2, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (375, 141, 44, 1, 1, -1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (376, 141, 44, 2, 1, 1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (387, 22, 48, 1, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (388, 22, 48, 2, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (389, 22, 28, 1, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (390, 22, 28, 2, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (391, 25, 54, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (392, 11, 44, 1, 1, -1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (393, 11, 44, 1, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (404, 28, 24, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (405, 28, 26, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (406, 28, 31, 1, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (407, 28, 31, 2, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (408, 28, 42, 2, 1, 1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (409, 28, 45, 1, 1, -1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (410, 56, 24, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (411, 56, 25, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (412, 56, 33, 1, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (413, 56, 33, 2, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (414, 56, 42, 2, 1, 1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (415, 56, 45, 1, 1, -1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (416, 124, 17, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (417, 124, 17, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (418, 124, 21, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (419, 124, 21, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (420, 124, 36, 1, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (421, 124, 36, 2, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (422, 124, 41, 1, 1, -1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (423, 124, 41, 2, 1, 1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (424, 125, 17, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (425, 125, 17, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (426, 125, 21, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (427, 125, 21, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (428, 125, 36, 1, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (429, 125, 36, 2, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (430, 125, 41, 1, 1, -1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (431, 125, 41, 2, 1, 1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (432, 134, 18, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (433, 134, 18, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (434, 134, 21, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (435, 134, 21, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (436, 134, 36, 1, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (437, 134, 36, 2, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (438, 134, 44, 1, 1, -1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (439, 134, 44, 2, 1, 1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (440, 135, 18, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (441, 135, 18, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (442, 135, 21, 1, 1, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (443, 135, 21, 2, 1, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (444, 135, 36, 1, 2, -1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (445, 135, 36, 2, 2, 1, NULL);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (446, 135, 44, 1, 1, -1, 22);
INSERT INTO [dbo27].[report_section_accounts] ([id], [account_type_id], [section_type_id], [entry_side_id], [value_type_id], [value_sign], [pair_account_type_id]) VALUES (447, 135, 44, 2, 1, 1, 22);
SET IDENTITY_INSERT [dbo27].[report_section_accounts] OFF;
GO

INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N'xls27', N'usp_account_totals', N'<table name="xls27.usp_account_totals"><columnFormats><column name="" property="ListObjectName" value="account_totals" type="String" /><column name="" property="ShowTotals" value="True" type="Boolean" /><column name="cf" property="TotalsCalculation" value="1" type="Double" /><column name="pl" property="TotalsCalculation" value="1" type="Double" /><column name="assets" property="TotalsCalculation" value="1" type="Double" /><column name="vat" property="TotalsCalculation" value="1" type="Double" /><column name="bs" property="TotalsCalculation" value="1" type="Double" /><column name="vat_credit" property="TotalsCalculation" value="3" type="Double" /><column name="vat_credit_format" property="TotalsCalculation" value="1" type="Double" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="Address" value="$C$4" type="String" /><column name="code" property="ColumnWidth" value="6.86" type="Double" /><column name="code" property="NumberFormat" value="General" type="String" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="Address" value="$D$4" type="String" /><column name="name" property="ColumnWidth" value="55.86" type="Double" /><column name="name" property="NumberFormat" value="General" type="String" /><column name="type" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="type" property="Address" value="$E$4" type="String" /><column name="type" property="ColumnWidth" value="15.14" type="Double" /><column name="type" property="NumberFormat" value="General" type="String" /><column name="payments" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments" property="Address" value="$F$4" type="String" /><column name="payments" property="ColumnWidth" value="12.43" type="Double" /><column name="payments" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="charges" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges" property="Address" value="$G$4" type="String" /><column name="charges" property="ColumnWidth" value="12.43" type="Double" /><column name="charges" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="cf" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf" property="Address" value="$H$4" type="String" /><column name="cf" property="ColumnWidth" value="12.43" type="Double" /><column name="cf" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="pl" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl" property="Address" value="$I$4" type="String" /><column name="pl" property="ColumnWidth" value="12.43" type="Double" /><column name="pl" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="assets" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="assets" property="Address" value="$J$4" type="String" /><column name="assets" property="ColumnWidth" value="10.86" type="Double" /><column name="assets" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="vat" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat" property="Address" value="$K$4" type="String" /><column name="vat" property="ColumnWidth" value="11.57" type="Double" /><column name="vat" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="bs" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bs" property="Address" value="$L$4" type="String" /><column name="bs" property="ColumnWidth" value="11.57" type="Double" /><column name="bs" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="payment_debit" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payment_debit" property="Address" value="$M$4" type="String" /><column name="payment_debit" property="ColumnWidth" value="6.43" type="Double" /><column name="payment_debit" property="NumberFormat" value="General" type="String" /><column name="payment_credit" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payment_credit" property="Address" value="$N$4" type="String" /><column name="payment_credit" property="ColumnWidth" value="6.43" type="Double" /><column name="payment_credit" property="NumberFormat" value="General" type="String" /><column name="charge_debit" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charge_debit" property="Address" value="$O$4" type="String" /><column name="charge_debit" property="ColumnWidth" value="6.43" type="Double" /><column name="charge_debit" property="NumberFormat" value="General" type="String" /><column name="charge_credit" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charge_credit" property="Address" value="$P$4" type="String" /><column name="charge_credit" property="ColumnWidth" value="6.43" type="Double" /><column name="charge_credit" property="NumberFormat" value="General" type="String" /><column name="vat_debit" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat_debit" property="Address" value="$Q$4" type="String" /><column name="vat_debit" property="ColumnWidth" value="6.43" type="Double" /><column name="vat_debit" property="NumberFormat" value="General" type="String" /><column name="vat_credit" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat_credit" property="Address" value="$R$4" type="String" /><column name="vat_credit" property="ColumnWidth" value="6.43" type="Double" /><column name="vat_credit" property="NumberFormat" value="General" type="String" /><column name="payment_debit_format" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payment_debit_format" property="Address" value="$S$4" type="String" /><column name="payment_debit_format" property="NumberFormat" value="General" type="String" /><column name="payment_credit_format" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payment_credit_format" property="Address" value="$T$4" type="String" /><column name="payment_credit_format" property="NumberFormat" value="General" type="String" /><column name="charge_debit_format" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charge_debit_format" property="Address" value="$U$4" type="String" /><column name="charge_debit_format" property="NumberFormat" value="General" type="String" /><column name="charge_credit_format" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charge_credit_format" property="Address" value="$V$4" type="String" /><column name="charge_credit_format" property="NumberFormat" value="General" type="String" /><column name="vat_debit_format" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat_debit_format" property="Address" value="$W$4" type="String" /><column name="vat_debit_format" property="NumberFormat" value="General" type="String" /><column name="vat_credit_format" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat_credit_format" property="Address" value="$X$4" type="String" /><column name="vat_credit_format" property="NumberFormat" value="General" type="String" /><column name="payment_debit" property="FormatConditions(1).AppliesTo.Address" value="$M$4:$M$33" type="String" /><column name="payment_debit" property="FormatConditions(1).Type" value="2" type="Double" /><column name="payment_debit" property="FormatConditions(1).Priority" value="16" type="Double" /><column name="payment_debit" property="FormatConditions(1).StopIfTrue" value="True" type="Boolean" /><column name="payment_debit" property="FormatConditions(1).Formula1" value="=AND($S4=0,$M4&lt;&gt;&quot;&quot;)" type="String" /><column name="payment_debit" property="FormatConditions(1).Interior.Color" value="255" type="Double" /><column name="payment_debit" property="FormatConditions(2).AppliesTo.Address" value="$M$4:$M$33" type="String" /><column name="payment_debit" property="FormatConditions(2).Type" value="2" type="Double" /><column name="payment_debit" property="FormatConditions(2).Priority" value="19" type="Double" /><column name="payment_debit" property="FormatConditions(2).StopIfTrue" value="True" type="Boolean" /><column name="payment_debit" property="FormatConditions(2).Formula1" value="=$S4=2" type="String" /><column name="payment_debit" property="FormatConditions(2).Interior.Color" value="10284031" type="Double" /><column name="payment_debit" property="FormatConditions(3).AppliesTo.Address" value="$M$4:$M$33" type="String" /><column name="payment_debit" property="FormatConditions(3).Type" value="2" type="Double" /><column name="payment_debit" property="FormatConditions(3).Priority" value="20" type="Double" /><column name="payment_debit" property="FormatConditions(3).StopIfTrue" value="True" type="Boolean" /><column name="payment_debit" property="FormatConditions(3).Formula1" value="=$S4=1" type="String" /><column name="payment_debit" property="FormatConditions(3).Interior.Color" value="13561798" type="Double" /><column name="payment_credit" property="FormatConditions(1).AppliesTo.Address" value="$N$4:$N$33" type="String" /><column name="payment_credit" property="FormatConditions(1).Type" value="2" type="Double" /><column name="payment_credit" property="FormatConditions(1).Priority" value="15" type="Double" /><column name="payment_credit" property="FormatConditions(1).StopIfTrue" value="True" type="Boolean" /><column name="payment_credit" property="FormatConditions(1).Formula1" value="=AND($T4=0,$N4&lt;&gt;&quot;&quot;)" type="String" /><column name="payment_credit" property="FormatConditions(1).Interior.Color" value="255" type="Double" /><column name="payment_credit" property="FormatConditions(2).AppliesTo.Address" value="$N$4:$N$33" type="String" /><column name="payment_credit" property="FormatConditions(2).Type" value="2" type="Double" /><column name="payment_credit" property="FormatConditions(2).Priority" value="17" type="Double" /><column name="payment_credit" property="FormatConditions(2).StopIfTrue" value="True" type="Boolean" /><column name="payment_credit" property="FormatConditions(2).Formula1" value="=$S4=1" type="String" /><column name="payment_credit" property="FormatConditions(2).Interior.Color" value="10284031" type="Double" /><column name="payment_credit" property="FormatConditions(3).AppliesTo.Address" value="$N$4:$N$33" type="String" /><column name="payment_credit" property="FormatConditions(3).Type" value="2" type="Double" /><column name="payment_credit" property="FormatConditions(3).Priority" value="18" type="Double" /><column name="payment_credit" property="FormatConditions(3).StopIfTrue" value="True" type="Boolean" /><column name="payment_credit" property="FormatConditions(3).Formula1" value="=$S4=2" type="String" /><column name="payment_credit" property="FormatConditions(3).Interior.Color" value="13561798" type="Double" /><column name="charge_debit" property="FormatConditions(1).AppliesTo.Address" value="$O$4:$O$33" type="String" /><column name="charge_debit" property="FormatConditions(1).Type" value="2" type="Double" /><column name="charge_debit" property="FormatConditions(1).Priority" value="12" type="Double" /><column name="charge_debit" property="FormatConditions(1).StopIfTrue" value="True" type="Boolean" /><column name="charge_debit" property="FormatConditions(1).Formula1" value="=AND($U4=0,$O4&lt;&gt;&quot;&quot;)" type="String" /><column name="charge_debit" property="FormatConditions(1).Interior.Color" value="255" type="Double" /><column name="charge_debit" property="FormatConditions(2).AppliesTo.Address" value="$O$4:$O$33" type="String" /><column name="charge_debit" property="FormatConditions(2).Type" value="2" type="Double" /><column name="charge_debit" property="FormatConditions(2).Priority" value="13" type="Double" /><column name="charge_debit" property="FormatConditions(2).StopIfTrue" value="True" type="Boolean" /><column name="charge_debit" property="FormatConditions(2).Formula1" value="=$U4=2" type="String" /><column name="charge_debit" property="FormatConditions(2).Interior.Color" value="10284031" type="Double" /><column name="charge_debit" property="FormatConditions(3).AppliesTo.Address" value="$O$4:$O$33" type="String" /><column name="charge_debit" property="FormatConditions(3).Type" value="2" type="Double" /><column name="charge_debit" property="FormatConditions(3).Priority" value="14" type="Double" /><column name="charge_debit" property="FormatConditions(3).StopIfTrue" value="True" type="Boolean" /><column name="charge_debit" property="FormatConditions(3).Formula1" value="=$U4=3" type="String" /><column name="charge_debit" property="FormatConditions(3).Interior.Color" value="13551615" type="Double" /><column name="charge_credit" property="FormatConditions(1).AppliesTo.Address" value="$P$4:$P$33" type="String" /><column name="charge_credit" property="FormatConditions(1).Type" value="2" type="Double" /><column name="charge_credit" property="FormatConditions(1).Priority" value="9" type="Double" /><column name="charge_credit" property="FormatConditions(1).StopIfTrue" value="True" type="Boolean" /><column name="charge_credit" property="FormatConditions(1).Formula1" value="=AND($U4=0,$P4&lt;&gt;&quot;&quot;)" type="String" /><column name="charge_credit" property="FormatConditions(1).Interior.Color" value="255" type="Double" /><column name="charge_credit" property="FormatConditions(2).AppliesTo.Address" value="$P$4:$P$33" type="String" /><column name="charge_credit" property="FormatConditions(2).Type" value="2" type="Double" /><column name="charge_credit" property="FormatConditions(2).Priority" value="10" type="Double" /><column name="charge_credit" property="FormatConditions(2).StopIfTrue" value="True" type="Boolean" /><column name="charge_credit" property="FormatConditions(2).Formula1" value="=$V4=2" type="String" /><column name="charge_credit" property="FormatConditions(2).Interior.Color" value="10284031" type="Double" /><column name="charge_credit" property="FormatConditions(3).AppliesTo.Address" value="$P$4:$P$33" type="String" /><column name="charge_credit" property="FormatConditions(3).Type" value="2" type="Double" /><column name="charge_credit" property="FormatConditions(3).Priority" value="11" type="Double" /><column name="charge_credit" property="FormatConditions(3).StopIfTrue" value="True" type="Boolean" /><column name="charge_credit" property="FormatConditions(3).Formula1" value="=$V4=3" type="String" /><column name="charge_credit" property="FormatConditions(3).Interior.Color" value="13551615" type="Double" /><column name="vat_debit" property="FormatConditions(1).AppliesTo.Address" value="$Q$4:$Q$33" type="String" /><column name="vat_debit" property="FormatConditions(1).Type" value="2" type="Double" /><column name="vat_debit" property="FormatConditions(1).Priority" value="5" type="Double" /><column name="vat_debit" property="FormatConditions(1).StopIfTrue" value="True" type="Boolean" /><column name="vat_debit" property="FormatConditions(1).Formula1" value="=$W4=4" type="String" /><column name="vat_debit" property="FormatConditions(1).Interior.Color" value="15987674" type="Double" /><column name="vat_debit" property="FormatConditions(2).AppliesTo.Address" value="$Q$4:$Q$33" type="String" /><column name="vat_debit" property="FormatConditions(2).Type" value="2" type="Double" /><column name="vat_debit" property="FormatConditions(2).Priority" value="6" type="Double" /><column name="vat_debit" property="FormatConditions(2).StopIfTrue" value="True" type="Boolean" /><column name="vat_debit" property="FormatConditions(2).Formula1" value="=AND($W4=0,$Q4&lt;&gt;&quot;&quot;)" type="String" /><column name="vat_debit" property="FormatConditions(2).Interior.Color" value="255" type="Double" /><column name="vat_debit" property="FormatConditions(3).AppliesTo.Address" value="$Q$4:$Q$33" type="String" /><column name="vat_debit" property="FormatConditions(3).Type" value="2" type="Double" /><column name="vat_debit" property="FormatConditions(3).Priority" value="7" type="Double" /><column name="vat_debit" property="FormatConditions(3).StopIfTrue" value="True" type="Boolean" /><column name="vat_debit" property="FormatConditions(3).Formula1" value="=$W4=2" type="String" /><column name="vat_debit" property="FormatConditions(3).Interior.Color" value="10284031" type="Double" /><column name="vat_debit" property="FormatConditions(4).AppliesTo.Address" value="$Q$4:$Q$33" type="String" /><column name="vat_debit" property="FormatConditions(4).Type" value="2" type="Double" /><column name="vat_debit" property="FormatConditions(4).Priority" value="8" type="Double" /><column name="vat_debit" property="FormatConditions(4).StopIfTrue" value="True" type="Boolean" /><column name="vat_debit" property="FormatConditions(4).Formula1" value="=$W4=3" type="String" /><column name="vat_debit" property="FormatConditions(4).Interior.Color" value="13551615" type="Double" /><column name="vat_credit" property="FormatConditions(1).AppliesTo.Address" value="$R$4:$R$33" type="String" /><column name="vat_credit" property="FormatConditions(1).Type" value="2" type="Double" /><column name="vat_credit" property="FormatConditions(1).Priority" value="1" type="Double" /><column name="vat_credit" property="FormatConditions(1).StopIfTrue" value="True" type="Boolean" /><column name="vat_credit" property="FormatConditions(1).Formula1" value="=$X4=4" type="String" /><column name="vat_credit" property="FormatConditions(1).Interior.Color" value="15987674" type="Double" /><column name="vat_credit" property="FormatConditions(2).AppliesTo.Address" value="$R$4:$R$33" type="String" /><column name="vat_credit" property="FormatConditions(2).Type" value="2" type="Double" /><column name="vat_credit" property="FormatConditions(2).Priority" value="2" type="Double" /><column name="vat_credit" property="FormatConditions(2).StopIfTrue" value="True" type="Boolean" /><column name="vat_credit" property="FormatConditions(2).Formula1" value="=AND($X4=0,$R4&lt;&gt;&quot;&quot;)" type="String" /><column name="vat_credit" property="FormatConditions(2).Interior.Color" value="255" type="Double" /><column name="vat_credit" property="FormatConditions(3).AppliesTo.Address" value="$R$4:$R$33" type="String" /><column name="vat_credit" property="FormatConditions(3).Type" value="2" type="Double" /><column name="vat_credit" property="FormatConditions(3).Priority" value="3" type="Double" /><column name="vat_credit" property="FormatConditions(3).StopIfTrue" value="True" type="Boolean" /><column name="vat_credit" property="FormatConditions(3).Formula1" value="=$X4=2" type="String" /><column name="vat_credit" property="FormatConditions(3).Interior.Color" value="10284031" type="Double" /><column name="vat_credit" property="FormatConditions(4).AppliesTo.Address" value="$R$4:$R$33" type="String" /><column name="vat_credit" property="FormatConditions(4).Type" value="2" type="Double" /><column name="vat_credit" property="FormatConditions(4).Priority" value="4" type="Double" /><column name="vat_credit" property="FormatConditions(4).StopIfTrue" value="True" type="Boolean" /><column name="vat_credit" property="FormatConditions(4).Formula1" value="=$X4=3" type="String" /><column name="vat_credit" property="FormatConditions(4).Interior.Color" value="13551615" type="Double" /><column name="" property="Tab.Color" value="5287936" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N'xls27', N'usp_actual_balances', N'<table name="xls27.usp_actual_balances"><columnFormats><column name="" property="ListObjectName" value="actual_balances" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="id" property="Address" value="$C$4" type="String" /><column name="id" property="NumberFormat" value="General" type="String" /><column name="account_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="account_id" property="Address" value="$D$4" type="String" /><column name="account_id" property="NumberFormat" value="General" type="String" /><column name="subsidiary_account_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="subsidiary_account_id" property="Address" value="$E$4" type="String" /><column name="subsidiary_account_id" property="NumberFormat" value="General" type="String" /><column name="is_debit_editable" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="is_debit_editable" property="Address" value="$F$4" type="String" /><column name="is_debit_editable" property="NumberFormat" value="General" type="String" /><column name="is_credit_editable" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="is_credit_editable" property="Address" value="$G$4" type="String" /><column name="is_credit_editable" property="NumberFormat" value="General" type="String" /><column name="is_parent" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="is_parent" property="Address" value="$H$4" type="String" /><column name="is_parent" property="NumberFormat" value="General" type="String" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="Address" value="$I$4" type="String" /><column name="code" property="ColumnWidth" value="8.43" type="Double" /><column name="code" property="NumberFormat" value="General" type="String" /><column name="subsidiary_name" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="subsidiary_name" property="Address" value="$J$4" type="String" /><column name="subsidiary_name" property="NumberFormat" value="General" type="String" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="Address" value="$K$4" type="String" /><column name="name" property="ColumnWidth" value="56.57" type="Double" /><column name="name" property="NumberFormat" value="#,##0.00" type="String" /><column name="currency" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="currency" property="Address" value="$L$4" type="String" /><column name="currency" property="ColumnWidth" value="10.43" type="Double" /><column name="currency" property="NumberFormat" value="General" type="String" /><column name="debit" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="debit" property="Address" value="$M$4" type="String" /><column name="debit" property="ColumnWidth" value="15.29" type="Double" /><column name="debit" property="NumberFormat" value="#,##0.00" type="String" /><column name="credit" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="credit" property="Address" value="$N$4" type="String" /><column name="credit" property="ColumnWidth" value="14.29" type="Double" /><column name="credit" property="NumberFormat" value="#,##0.00" type="String" /><column name="debit$" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="debit$" property="Address" value="$O$4" type="String" /><column name="debit$" property="ColumnWidth" value="16" type="Double" /><column name="debit$" property="NumberFormat" value="#,##0.00" type="String" /><column name="credit$" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="credit$" property="Address" value="$P$4" type="String" /><column name="credit$" property="ColumnWidth" value="15.29" type="Double" /><column name="credit$" property="NumberFormat" value="#,##0.00" type="String" /><column name="_RowNum" property="FormatConditions(1).AppliesToTable" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(1).AppliesTo.Address" value="$B$4:$P$109" type="String" /><column name="_RowNum" property="FormatConditions(1).Type" value="2" type="Double" /><column name="_RowNum" property="FormatConditions(1).Priority" value="1" type="Double" /><column name="_RowNum" property="FormatConditions(1).Formula1" value="=$H4=1" type="String" /><column name="_RowNum" property="FormatConditions(1).Font.Bold" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(1).Interior.Color" value="16247774" type="Double" /><column name="debit" property="FormatConditions(1).AppliesTo.Address" value="$M$4:$M$109" type="String" /><column name="debit" property="FormatConditions(1).Type" value="2" type="Double" /><column name="debit" property="FormatConditions(1).Priority" value="3" type="Double" /><column name="debit" property="FormatConditions(1).Formula1" value="=$F4=1" type="String" /><column name="debit" property="FormatConditions(1).Interior.Color" value="15592942" type="Double" /><column name="credit" property="FormatConditions(1).AppliesTo.Address" value="$N$4:$N$109" type="String" /><column name="credit" property="FormatConditions(1).Type" value="2" type="Double" /><column name="credit" property="FormatConditions(1).Priority" value="2" type="Double" /><column name="credit" property="FormatConditions(1).Formula1" value="=$G4=1" type="String" /><column name="credit" property="FormatConditions(1).Interior.Color" value="15592942" type="Double" /><column name="" property="Tab.Color" value="6968388" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats><views><view name="Form"><column name="" property="ListObjectName" value="actual_balances" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="account_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="subsidiary_account_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="is_debit_editable" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="is_credit_editable" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="is_parent" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="subsidiary_name" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="currency" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="debit" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="credit" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="debit$" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="credit$" property="EntireColumn.Hidden" value="False" type="Boolean" /></view><view name="All Columns"><column name="" property="ListObjectName" value="balances" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="subsidiary_account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="is_debit_editable" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="is_credit_editable" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="is_parent" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="subsidiary_account" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="currency" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="debit" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="credit" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="debit$" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="credit$" property="EntireColumn.Hidden" value="False" type="Boolean" /></view></views></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N'xls27', N'usp_actual_closed_periods', N'<table name="xls27.usp_actual_closed_periods"><columnFormats><column name="" property="ListObjectName" value="actual_closed_periods" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="date" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="date" property="Address" value="$C$4" type="String" /><column name="date" property="ColumnWidth" value="9.71" type="Double" /><column name="date" property="NumberFormat" value="General" type="String" /><column name="is_closed" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="is_closed" property="Address" value="$D$4" type="String" /><column name="is_closed" property="ColumnWidth" value="10.71" type="Double" /><column name="is_closed" property="NumberFormat" value="General" type="String" /><column name="is_closed" property="HorizontalAlignment" value="-4108" type="Double" /><column name="is_closed" property="Font.Size" value="9" type="Double" /><column name="is_closed" property="FormatConditions(1).AppliesTo.Address" value="$D$4:$D$9" type="String" /><column name="is_closed" property="FormatConditions(1).Type" value="6" type="Double" /><column name="is_closed" property="FormatConditions(1).Priority" value="1" type="Double" /><column name="is_closed" property="FormatConditions(1).ShowIconOnly" value="True" type="Boolean" /><column name="is_closed" property="FormatConditions(1).IconSet.ID" value="8" type="Double" /><column name="is_closed" property="FormatConditions(1).IconCriteria(1).Type" value="3" type="Double" /><column name="is_closed" property="FormatConditions(1).IconCriteria(1).Operator" value="7" type="Double" /><column name="is_closed" property="FormatConditions(1).IconCriteria(2).Type" value="0" type="Double" /><column name="is_closed" property="FormatConditions(1).IconCriteria(2).Value" value="0.5" type="Double" /><column name="is_closed" property="FormatConditions(1).IconCriteria(2).Operator" value="7" type="Double" /><column name="is_closed" property="FormatConditions(1).IconCriteria(3).Type" value="0" type="Double" /><column name="is_closed" property="FormatConditions(1).IconCriteria(3).Value" value="1" type="Double" /><column name="is_closed" property="FormatConditions(1).IconCriteria(3).Operator" value="7" type="Double" /><column name="" property="Tab.Color" value="6968388" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N'xls27', N'usp_actual_currency_rates', N'<table name="xls27.usp_actual_currency_rates"><columnFormats><column name="" property="ListObjectName" value="actual_currency_rates" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="date" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="date" property="Address" value="$C$4" type="String" /><column name="date" property="ColumnWidth" value="12.14" type="Double" /><column name="date" property="NumberFormat" value="General" type="String" /><column name="rate" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="rate" property="Address" value="$D$4" type="String" /><column name="rate" property="ColumnWidth" value="15" type="Double" /><column name="rate" property="NumberFormat" value="0.0000" type="String" /><column name="is_checked" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="is_checked" property="Address" value="$E$4" type="String" /><column name="is_checked" property="ColumnWidth" value="13.57" type="Double" /><column name="is_checked" property="NumberFormat" value="General" type="String" /><column name="is_checked" property="HorizontalAlignment" value="-4108" type="Double" /><column name="is_checked" property="Font.Size" value="10" type="Double" /><column name="is_checked" property="FormatConditions(1).AppliesTo.Address" value="$E$4" type="String" /><column name="is_checked" property="FormatConditions(1).Type" value="6" type="Double" /><column name="is_checked" property="FormatConditions(1).Priority" value="1" type="Double" /><column name="is_checked" property="FormatConditions(1).ShowIconOnly" value="True" type="Boolean" /><column name="is_checked" property="FormatConditions(1).IconSet.ID" value="8" type="Double" /><column name="is_checked" property="FormatConditions(1).IconCriteria(1).Type" value="3" type="Double" /><column name="is_checked" property="FormatConditions(1).IconCriteria(1).Operator" value="7" type="Double" /><column name="is_checked" property="FormatConditions(1).IconCriteria(2).Type" value="0" type="Double" /><column name="is_checked" property="FormatConditions(1).IconCriteria(2).Value" value="0.5" type="Double" /><column name="is_checked" property="FormatConditions(1).IconCriteria(2).Operator" value="7" type="Double" /><column name="is_checked" property="FormatConditions(1).IconCriteria(3).Type" value="0" type="Double" /><column name="is_checked" property="FormatConditions(1).IconCriteria(3).Value" value="1" type="Double" /><column name="is_checked" property="FormatConditions(1).IconCriteria(3).Operator" value="7" type="Double" /><column name="" property="Tab.Color" value="6968388" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N'xls27', N'usp_actual_reports', N'<table name="xls27.usp_actual_reports"><columnFormats><column name="" property="ListObjectName" value="actual_reports" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="row_index" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_index" property="Address" value="$C$4" type="String" /><column name="row_index" property="NumberFormat" value="General" type="String" /><column name="ref_number" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="ref_number" property="Address" value="$D$4" type="String" /><column name="ref_number" property="ColumnWidth" value="6.86" type="Double" /><column name="ref_number" property="NumberFormat" value="General" type="String" /><column name="ref_number" property="HorizontalAlignment" value="-4131" type="Double" /><column name="account" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="account" property="Address" value="$E$4" type="String" /><column name="account" property="NumberFormat" value="General" type="String" /><column name="account" property="HorizontalAlignment" value="-4131" type="Double" /><column name="report" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="report" property="Address" value="$F$4" type="String" /><column name="report" property="NumberFormat" value="General" type="String" /><column name="page_break" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="page_break" property="Address" value="$G$4" type="String" /><column name="page_break" property="NumberFormat" value="General" type="String" /><column name="row_level" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_level" property="Address" value="$H$4" type="String" /><column name="row_level" property="NumberFormat" value="General" type="String" /><column name="row_format" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_format" property="Address" value="$I$4" type="String" /><column name="row_format" property="NumberFormat" value="General" type="String" /><column name="hide" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="hide" property="Address" value="$J$4" type="String" /><column name="hide" property="NumberFormat" value="General" type="String" /><column name="zero" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="zero" property="Address" value="$K$4" type="String" /><column name="zero" property="NumberFormat" value="General" type="String" /><column name="code1" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="code1" property="Address" value="$L$4" type="String" /><column name="code1" property="NumberFormat" value="General" type="String" /><column name="code2" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="code2" property="Address" value="$M$4" type="String" /><column name="code2" property="NumberFormat" value="General" type="String" /><column name="code" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="code" property="Address" value="$N$4" type="String" /><column name="code" property="NumberFormat" value="General" type="String" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="Address" value="$O$4" type="String" /><column name="name" property="ColumnWidth" value="55.57" type="Double" /><column name="name" property="NumberFormat" value="General" type="String" /><column name="data00" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data00" property="Address" value="$P$4" type="String" /><column name="data00" property="ColumnWidth" value="13.29" type="Double" /><column name="data00" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="data01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data01" property="Address" value="$Q$4" type="String" /><column name="data01" property="ColumnWidth" value="12.71" type="Double" /><column name="data01" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="data02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data02" property="Address" value="$R$4" type="String" /><column name="data02" property="ColumnWidth" value="12.71" type="Double" /><column name="data02" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="data03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data03" property="Address" value="$S$4" type="String" /><column name="data03" property="ColumnWidth" value="12.71" type="Double" /><column name="data03" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="data04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data04" property="Address" value="$T$4" type="String" /><column name="data04" property="ColumnWidth" value="12.71" type="Double" /><column name="data04" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="data05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data05" property="Address" value="$U$4" type="String" /><column name="data05" property="ColumnWidth" value="12.71" type="Double" /><column name="data05" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="data06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data06" property="Address" value="$V$4" type="String" /><column name="data06" property="ColumnWidth" value="12.71" type="Double" /><column name="data06" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="data07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data07" property="Address" value="$W$4" type="String" /><column name="data07" property="ColumnWidth" value="12.71" type="Double" /><column name="data07" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="data08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data08" property="Address" value="$X$4" type="String" /><column name="data08" property="ColumnWidth" value="12.71" type="Double" /><column name="data08" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="data09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data09" property="Address" value="$Y$4" type="String" /><column name="data09" property="ColumnWidth" value="12.71" type="Double" /><column name="data09" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="data10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data10" property="Address" value="$Z$4" type="String" /><column name="data10" property="ColumnWidth" value="12.71" type="Double" /><column name="data10" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="data11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data11" property="Address" value="$AA$4" type="String" /><column name="data11" property="ColumnWidth" value="12.71" type="Double" /><column name="data11" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="data12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data12" property="Address" value="$AB$4" type="String" /><column name="data12" property="ColumnWidth" value="12.71" type="Double" /><column name="data12" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="_RowNum" property="FormatConditions(1).AppliesToTable" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(1).AppliesTo.Address" value="$B$4:$AB$169" type="String" /><column name="_RowNum" property="FormatConditions(1).Type" value="2" type="Double" /><column name="_RowNum" property="FormatConditions(1).Priority" value="5" type="Double" /><column name="_RowNum" property="FormatConditions(1).Formula1" value="=$I4=8" type="String" /><column name="_RowNum" property="FormatConditions(2).AppliesToTable" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(2).AppliesTo.Address" value="$B$4:$AB$169" type="String" /><column name="_RowNum" property="FormatConditions(2).Type" value="2" type="Double" /><column name="_RowNum" property="FormatConditions(2).Priority" value="6" type="Double" /><column name="_RowNum" property="FormatConditions(2).Formula1" value="=$I4=2" type="String" /><column name="_RowNum" property="FormatConditions(2).Font.Bold" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(3).AppliesToTable" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(3).AppliesTo.Address" value="$B$4:$AB$169" type="String" /><column name="_RowNum" property="FormatConditions(3).Type" value="2" type="Double" /><column name="_RowNum" property="FormatConditions(3).Priority" value="7" type="Double" /><column name="_RowNum" property="FormatConditions(3).Formula1" value="=$I4=1" type="String" /><column name="_RowNum" property="FormatConditions(3).Font.Bold" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(3).Font.Color" value="16777215" type="Double" /><column name="_RowNum" property="FormatConditions(3).Font.ThemeColor" value="1" type="Double" /><column name="_RowNum" property="FormatConditions(3).Font.TintAndShade" value="0" type="Double" /><column name="_RowNum" property="FormatConditions(3).Interior.Color" value="6773025" type="Double" /><column name="_RowNum" property="FormatConditions(4).AppliesToTable" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(4).AppliesTo.Address" value="$B$4:$AB$169" type="String" /><column name="_RowNum" property="FormatConditions(4).Type" value="2" type="Double" /><column name="_RowNum" property="FormatConditions(4).Priority" value="8" type="Double" /><column name="_RowNum" property="FormatConditions(4).Formula1" value="=$I4=9" type="String" /><column name="_RowNum" property="FormatConditions(4).Font.Bold" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(4).Font.Color" value="16777215" type="Double" /><column name="_RowNum" property="FormatConditions(4).Font.ThemeColor" value="1" type="Double" /><column name="_RowNum" property="FormatConditions(4).Font.TintAndShade" value="0" type="Double" /><column name="_RowNum" property="FormatConditions(4).Interior.Color" value="6299904" type="Double" /><column name="" property="AutoFilter.Off" value="True" type="Boolean" /><column name="" property="Tab.Color" value="5287936" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats><views><view name="All Columns"><column name="" property="ListObjectName" value="actual_reports" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="row_index" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="ref_number" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="report" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="page_break" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="row_level" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="row_format" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="hide" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="zero" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code1" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code2" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data00" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="" property="AutoFilter.Off" value="True" type="Boolean" /></view><view name="Reports with Accounts"><column name="" property="ListObjectName" value="actual_reports" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_index" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="ref_number" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="account" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="report" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="page_break" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_level" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_format" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="hide" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="zero" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="code1" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="code2" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data00" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="" property="AutoFilter.Off" value="True" type="Boolean" /></view><view name="Reports with References"><column name="" property="ListObjectName" value="actual_reports" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_index" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="ref_number" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="report" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="page_break" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_level" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_format" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="hide" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="zero" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="code1" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="code2" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data00" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="" property="AutoFilter.Off" value="True" type="Boolean" /></view></views></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N'xls27', N'usp_balance_sheet_trial', N'<table name="xls27.usp_balance_sheet_trial"><columnFormats><column name="" property="ListObjectName" value="trial_balance" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="account_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="account_id" property="Address" value="$C$4" type="String" /><column name="account_id" property="NumberFormat" value="General" type="String" /><column name="account_id" property="Validation.Type" value="1" type="Double" /><column name="account_id" property="Validation.Operator" value="1" type="Double" /><column name="account_id" property="Validation.Formula1" value="-2147483648" type="String" /><column name="account_id" property="Validation.Formula2" value="2147483647" type="String" /><column name="account_id" property="Validation.AlertStyle" value="1" type="Double" /><column name="account_id" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="account_id" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="account_id" property="Validation.ShowInput" value="True" type="Boolean" /><column name="account_id" property="Validation.ShowError" value="True" type="Boolean" /><column name="subsidiary_account_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="subsidiary_account_id" property="Address" value="$D$4" type="String" /><column name="subsidiary_account_id" property="NumberFormat" value="General" type="String" /><column name="row_format" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_format" property="Address" value="$E$4" type="String" /><column name="row_format" property="NumberFormat" value="General" type="String" /><column name="level" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="level" property="Address" value="$F$4" type="String" /><column name="level" property="NumberFormat" value="General" type="String" /><column name="line" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="line" property="Address" value="$G$4" type="String" /><column name="line" property="NumberFormat" value="General" type="String" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="Address" value="$H$4" type="String" /><column name="code" property="ColumnWidth" value="8.43" type="Double" /><column name="code" property="NumberFormat" value="General" type="String" /><column name="subsidiary_name" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="subsidiary_name" property="Address" value="$I$4" type="String" /><column name="subsidiary_name" property="NumberFormat" value="General" type="String" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="Address" value="$J$4" type="String" /><column name="name" property="ColumnWidth" value="49.43" type="Double" /><column name="name" property="NumberFormat" value="General" type="String" /><column name="currency" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="currency" property="Address" value="$K$4" type="String" /><column name="currency" property="ColumnWidth" value="10.14" type="Double" /><column name="currency" property="NumberFormat" value="General" type="String" /><column name="opening_balance" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="opening_balance" property="Address" value="$L$4" type="String" /><column name="opening_balance" property="ColumnWidth" value="17.86" type="Double" /><column name="opening_balance" property="NumberFormat" value="#,##0.00" type="String" /><column name="opening_debit" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="opening_debit" property="Address" value="$M$4" type="String" /><column name="opening_debit" property="NumberFormat" value="#,##0.00" type="String" /><column name="opening_credit" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="opening_credit" property="Address" value="$N$4" type="String" /><column name="opening_credit" property="NumberFormat" value="#,##0.00" type="String" /><column name="debit_turnover" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="debit_turnover" property="Address" value="$O$4" type="String" /><column name="debit_turnover" property="ColumnWidth" value="16.14" type="Double" /><column name="debit_turnover" property="NumberFormat" value="#,##0.00" type="String" /><column name="credit_turnover" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="credit_turnover" property="Address" value="$P$4" type="String" /><column name="credit_turnover" property="ColumnWidth" value="16.57" type="Double" /><column name="credit_turnover" property="NumberFormat" value="#,##0.00" type="String" /><column name="closing_balance" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="closing_balance" property="Address" value="$Q$4" type="String" /><column name="closing_balance" property="ColumnWidth" value="16.71" type="Double" /><column name="closing_balance" property="NumberFormat" value="#,##0.00" type="String" /><column name="closing_debit" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="closing_debit" property="Address" value="$R$4" type="String" /><column name="closing_debit" property="NumberFormat" value="#,##0.00" type="String" /><column name="closing_credit" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="closing_credit" property="Address" value="$S$4" type="String" /><column name="closing_credit" property="NumberFormat" value="#,##0.00" type="String" /><column name="_RowNum" property="FormatConditions(1).AppliesToTable" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(1).AppliesTo.Address" value="$B$4:$S$84" type="String" /><column name="_RowNum" property="FormatConditions(1).Type" value="2" type="Double" /><column name="_RowNum" property="FormatConditions(1).Priority" value="1" type="Double" /><column name="_RowNum" property="FormatConditions(1).Formula1" value="=$E4=1" type="String" /><column name="_RowNum" property="FormatConditions(1).Font.Bold" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(1).Interior.Color" value="15853276" type="Double" /><column name="_RowNum" property="FormatConditions(1).Interior.ThemeColor" value="5" type="Double" /><column name="_RowNum" property="FormatConditions(1).Interior.TintAndShade" value="0.799981688894314" type="Double" /><column name="" property="Tab.Color" value="5287936" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats><views><view name="Short"><column name="" property="ListObjectName" value="trial_balance" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="account_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="subsidiary_account_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_format" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="level" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="line" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="subsidiary_name" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="currency" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="opening_balance" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="opening_debit" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="opening_credit" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="debit_turnover" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="credit_turnover" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="closing_balance" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="closing_debit" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="closing_credit" property="EntireColumn.Hidden" value="True" type="Boolean" /></view><view name="Wide"><column name="" property="ListObjectName" value="trial_balance" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="account_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="subsidiary_account_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_format" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="level" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="line" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="subsidiary_name" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="currency" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="opening_balance" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="opening_debit" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="opening_credit" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="debit_turnover" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="credit_turnover" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="closing_balance" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="closing_debit" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="closing_credit" property="EntireColumn.Hidden" value="False" type="Boolean" /></view><view name="All Columns" /></views></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N'xls27', N'usp_balances', N'<table name="xls27.usp_balances"><columnFormats><column name="" property="ListObjectName" value="balances" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="id" property="Address" value="$C$4" type="String" /><column name="id" property="NumberFormat" value="General" type="String" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="Address" value="$D$4" type="String" /><column name="code" property="ColumnWidth" value="10.14" type="Double" /><column name="code" property="NumberFormat" value="General" type="String" /><column name="account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account_id" property="Address" value="$E$4" type="String" /><column name="account_id" property="ColumnWidth" value="12.14" type="Double" /><column name="account_id" property="NumberFormat" value="General" type="String" /><column name="account_id" property="Validation.Type" value="3" type="Double" /><column name="account_id" property="Validation.Operator" value="1" type="Double" /><column name="account_id" property="Validation.Formula1" value="=INDIRECT(&quot;vl_xls27_xl_validation_list_balance_account_id[name]&quot;)" type="String" /><column name="account_id" property="Validation.Formula2" value="" type="String" /><column name="account_id" property="Validation.AlertStyle" value="1" type="Double" /><column name="account_id" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="account_id" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="account_id" property="Validation.ShowInput" value="True" type="Boolean" /><column name="account_id" property="Validation.ShowError" value="True" type="Boolean" /><column name="account" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account" property="Address" value="$F$4" type="String" /><column name="account" property="ColumnWidth" value="55.86" type="Double" /><column name="account" property="NumberFormat" value="General" type="String" /><column name="subaccount_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="subaccount_id" property="Address" value="$G$4" type="String" /><column name="subaccount_id" property="ColumnWidth" value="15.43" type="Double" /><column name="subaccount_id" property="NumberFormat" value="General" type="String" /><column name="subaccount_id" property="Validation.Type" value="3" type="Double" /><column name="subaccount_id" property="Validation.Operator" value="1" type="Double" /><column name="subaccount_id" property="Validation.Formula1" value="=INDIRECT(&quot;vl_xls27_xl_validation_list_subaccount_id[name]&quot;)" type="String" /><column name="subaccount_id" property="Validation.Formula2" value="" type="String" /><column name="subaccount_id" property="Validation.AlertStyle" value="1" type="Double" /><column name="subaccount_id" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="subaccount_id" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="subaccount_id" property="Validation.ShowInput" value="True" type="Boolean" /><column name="subaccount_id" property="Validation.ShowError" value="True" type="Boolean" /><column name="subaccount" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="subaccount" property="Address" value="$H$4" type="String" /><column name="subaccount" property="ColumnWidth" value="12.57" type="Double" /><column name="subaccount" property="NumberFormat" value="General" type="String" /><column name="unit_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="unit_id" property="Address" value="$I$4" type="String" /><column name="unit_id" property="ColumnWidth" value="8.86" type="Double" /><column name="unit_id" property="NumberFormat" value="General" type="String" /><column name="unit_id" property="Validation.Type" value="3" type="Double" /><column name="unit_id" property="Validation.Operator" value="1" type="Double" /><column name="unit_id" property="Validation.Formula1" value="=INDIRECT(&quot;vl_xls27_xl_validation_list_unit_id[name]&quot;)" type="String" /><column name="unit_id" property="Validation.Formula2" value="" type="String" /><column name="unit_id" property="Validation.AlertStyle" value="1" type="Double" /><column name="unit_id" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="unit_id" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="unit_id" property="Validation.ShowInput" value="True" type="Boolean" /><column name="unit_id" property="Validation.ShowError" value="True" type="Boolean" /><column name="balance" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance" property="Address" value="$J$4" type="String" /><column name="balance" property="ColumnWidth" value="12.43" type="Double" /><column name="balance" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" /><column name="row_formulas" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="row_formulas" property="Address" value="$K$4" type="String" /><column name="row_formulas" property="ColumnWidth" value="15" type="Double" /><column name="row_formulas" property="NumberFormat" value="General" type="String" /><column name="" property="Tab.Color" value="6299648" type="Double" /><column name="" property="Tab.Color" value="6299648" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N'xls27', N'usp_budget_balances', N'<table name="xls27.usp_budget_balances"><columnFormats><column name="" property="ListObjectName" value="budget_balances" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="id" property="Address" value="$C$4" type="String" /><column name="id" property="NumberFormat" value="General" type="String" /><column name="account_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="account_id" property="Address" value="$D$4" type="String" /><column name="account_id" property="NumberFormat" value="General" type="String" /><column name="is_debit_editable" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="is_debit_editable" property="Address" value="$E$4" type="String" /><column name="is_debit_editable" property="NumberFormat" value="General" type="String" /><column name="is_credit_editable" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="is_credit_editable" property="Address" value="$F$4" type="String" /><column name="is_credit_editable" property="NumberFormat" value="General" type="String" /><column name="is_parent" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="is_parent" property="Address" value="$G$4" type="String" /><column name="is_parent" property="NumberFormat" value="General" type="String" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="Address" value="$H$4" type="String" /><column name="code" property="ColumnWidth" value="6.86" type="Double" /><column name="code" property="NumberFormat" value="@" type="String" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="Address" value="$I$4" type="String" /><column name="name" property="ColumnWidth" value="56.43" type="Double" /><column name="name" property="NumberFormat" value="General" type="String" /><column name="debit" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="debit" property="Address" value="$J$4" type="String" /><column name="debit" property="ColumnWidth" value="15.29" type="Double" /><column name="debit" property="NumberFormat" value="#,##0.00" type="String" /><column name="credit" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="credit" property="Address" value="$K$4" type="String" /><column name="credit" property="ColumnWidth" value="16" type="Double" /><column name="credit" property="NumberFormat" value="#,##0.00" type="String" /><column name="_RowNum" property="FormatConditions(1).AppliesToTable" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(1).AppliesTo.Address" value="$B$4:$K$49" type="String" /><column name="_RowNum" property="FormatConditions(1).Type" value="2" type="Double" /><column name="_RowNum" property="FormatConditions(1).Priority" value="3" type="Double" /><column name="_RowNum" property="FormatConditions(1).Formula1" value="=$G4=1" type="String" /><column name="_RowNum" property="FormatConditions(1).Font.Bold" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(1).Interior.Color" value="15787741" type="Double" /><column name="debit" property="FormatConditions(1).AppliesTo.Address" value="$J$4:$J$49" type="String" /><column name="debit" property="FormatConditions(1).Type" value="2" type="Double" /><column name="debit" property="FormatConditions(1).Priority" value="2" type="Double" /><column name="debit" property="FormatConditions(1).Formula1" value="=$E4=1" type="String" /><column name="debit" property="FormatConditions(1).Interior.Color" value="15592942" type="Double" /><column name="credit" property="FormatConditions(1).AppliesTo.Address" value="$K$4:$K$49" type="String" /><column name="credit" property="FormatConditions(1).Type" value="2" type="Double" /><column name="credit" property="FormatConditions(1).Priority" value="1" type="Double" /><column name="credit" property="FormatConditions(1).Formula1" value="=$F4=1" type="String" /><column name="credit" property="FormatConditions(1).Interior.Color" value="15592942" type="Double" /><column name="" property="Tab.Color" value="12874308" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats><views><view name="Form"><column name="" property="ListObjectName" value="budget_balances" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="account_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="is_debit_editable" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="is_credit_editable" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="is_parent" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="debit" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="credit" property="EntireColumn.Hidden" value="False" type="Boolean" /></view><view name="All Columns"><column name="" property="ListObjectName" value="budget_balances" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="is_debit_editable" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="is_credit_editable" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="is_parent" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="debit" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="credit" property="EntireColumn.Hidden" value="False" type="Boolean" /></view></views></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N'xls27', N'usp_budget_closed_periods', N'<table name="xls27.usp_budget_closed_periods"><columnFormats><column name="" property="ListObjectName" value="budget_closed_periods" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="id" property="Address" value="$C$4" type="String" /><column name="id" property="NumberFormat" value="General" type="String" /><column name="sort_order" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="sort_order" property="Address" value="$D$4" type="String" /><column name="sort_order" property="NumberFormat" value="General" type="String" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="Address" value="$E$4" type="String" /><column name="code" property="ColumnWidth" value="13.57" type="Double" /><column name="code" property="NumberFormat" value="General" type="String" /><column name="name" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="name" property="Address" value="$F$4" type="String" /><column name="name" property="NumberFormat" value="General" type="String" /><column name="data_format" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="data_format" property="Address" value="$G$4" type="String" /><column name="data_format" property="NumberFormat" value="General" type="String" /><column name="data_format" property="HorizontalAlignment" value="-4108" type="Double" /><column name="data_format" property="Font.Size" value="10" type="Double" /><column name="BUDGET" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="BUDGET" property="Address" value="$H$4" type="String" /><column name="BUDGET" property="ColumnWidth" value="13.43" type="Double" /><column name="BUDGET" property="NumberFormat" value="General" type="String" /><column name="BUDGET" property="HorizontalAlignment" value="-4108" type="Double" /><column name="BUDGET" property="Font.Size" value="10" type="Double" /><column name="FORECAST" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="FORECAST" property="Address" value="$I$4" type="String" /><column name="FORECAST" property="ColumnWidth" value="13.43" type="Double" /><column name="FORECAST" property="NumberFormat" value="General" type="String" /><column name="FORECAST" property="HorizontalAlignment" value="-4108" type="Double" /><column name="FORECAST" property="Font.Size" value="10" type="Double" /><column name="data_format" property="FormatConditions(1).ColumnsCount" value="3" type="Double" /><column name="data_format" property="FormatConditions(1).AppliesTo.Address" value="$G$3:$I$5" type="String" /><column name="data_format" property="FormatConditions(1).Type" value="6" type="Double" /><column name="data_format" property="FormatConditions(1).Priority" value="1555" type="Double" /><column name="data_format" property="FormatConditions(1).ShowIconOnly" value="True" type="Boolean" /><column name="data_format" property="FormatConditions(1).IconSet.ID" value="8" type="Double" /><column name="data_format" property="FormatConditions(1).IconCriteria(1).Type" value="3" type="Double" /><column name="data_format" property="FormatConditions(1).IconCriteria(1).Operator" value="7" type="Double" /><column name="data_format" property="FormatConditions(1).IconCriteria(2).Type" value="0" type="Double" /><column name="data_format" property="FormatConditions(1).IconCriteria(2).Value" value="0.5" type="Double" /><column name="data_format" property="FormatConditions(1).IconCriteria(2).Operator" value="7" type="Double" /><column name="data_format" property="FormatConditions(1).IconCriteria(3).Type" value="0" type="Double" /><column name="data_format" property="FormatConditions(1).IconCriteria(3).Value" value="1" type="Double" /><column name="data_format" property="FormatConditions(1).IconCriteria(3).Operator" value="7" type="Double" /><column name="" property="Tab.Color" value="12874308" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N'xls27', N'usp_budget_currency_rates', N'<table name="xls27.usp_budget_currency_rates"><columnFormats><column name="" property="ListObjectName" value="budget_currency_rates" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="category_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="category_id" property="Address" value="$C$4" type="String" /><column name="category_id" property="NumberFormat" value="General" type="String" /><column name="time_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="time_id" property="Address" value="$D$4" type="String" /><column name="time_id" property="NumberFormat" value="General" type="String" /><column name="unit_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="unit_id" property="Address" value="$E$4" type="String" /><column name="unit_id" property="NumberFormat" value="General" type="String" /><column name="unit_id" property="Validation.Type" value="1" type="Double" /><column name="unit_id" property="Validation.Operator" value="1" type="Double" /><column name="unit_id" property="Validation.Formula1" value="0" type="String" /><column name="unit_id" property="Validation.Formula2" value="255" type="String" /><column name="unit_id" property="Validation.AlertStyle" value="1" type="Double" /><column name="unit_id" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="unit_id" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="unit_id" property="Validation.ShowInput" value="True" type="Boolean" /><column name="unit_id" property="Validation.ShowError" value="True" type="Boolean" /><column name="category_name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="category_name" property="Address" value="$F$4" type="String" /><column name="category_name" property="ColumnWidth" value="11.57" type="Double" /><column name="category_name" property="NumberFormat" value="General" type="String" /><column name="period_name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="period_name" property="Address" value="$G$4" type="String" /><column name="period_name" property="ColumnWidth" value="10.71" type="Double" /><column name="period_name" property="NumberFormat" value="General" type="String" /><column name="pair" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pair" property="Address" value="$H$4" type="String" /><column name="pair" property="ColumnWidth" value="11.43" type="Double" /><column name="pair" property="NumberFormat" value="0.0000" type="String" /><column name="balance00" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance00" property="Address" value="$I$4" type="String" /><column name="balance00" property="ColumnWidth" value="11.43" type="Double" /><column name="balance00" property="NumberFormat" value="0.0000" type="String" /><column name="period01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="period01" property="Address" value="$J$4" type="String" /><column name="period01" property="ColumnWidth" value="11.71" type="Double" /><column name="period01" property="NumberFormat" value="0.0000" type="String" /><column name="balance01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance01" property="Address" value="$K$4" type="String" /><column name="balance01" property="ColumnWidth" value="11.29" type="Double" /><column name="balance01" property="NumberFormat" value="0.0000" type="String" /><column name="period02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="period02" property="Address" value="$L$4" type="String" /><column name="period02" property="ColumnWidth" value="11.71" type="Double" /><column name="period02" property="NumberFormat" value="0.0000" type="String" /><column name="balance02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance02" property="Address" value="$M$4" type="String" /><column name="balance02" property="ColumnWidth" value="11.29" type="Double" /><column name="balance02" property="NumberFormat" value="0.0000" type="String" /><column name="period03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="period03" property="Address" value="$N$4" type="String" /><column name="period03" property="ColumnWidth" value="11.71" type="Double" /><column name="period03" property="NumberFormat" value="0.0000" type="String" /><column name="balance03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance03" property="Address" value="$O$4" type="String" /><column name="balance03" property="ColumnWidth" value="11.29" type="Double" /><column name="balance03" property="NumberFormat" value="0.0000" type="String" /><column name="period04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="period04" property="Address" value="$P$4" type="String" /><column name="period04" property="ColumnWidth" value="11.71" type="Double" /><column name="period04" property="NumberFormat" value="0.0000" type="String" /><column name="balance04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance04" property="Address" value="$Q$4" type="String" /><column name="balance04" property="ColumnWidth" value="11.29" type="Double" /><column name="balance04" property="NumberFormat" value="0.0000" type="String" /><column name="period05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="period05" property="Address" value="$R$4" type="String" /><column name="period05" property="ColumnWidth" value="11.71" type="Double" /><column name="period05" property="NumberFormat" value="0.0000" type="String" /><column name="balance05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance05" property="Address" value="$S$4" type="String" /><column name="balance05" property="ColumnWidth" value="11.29" type="Double" /><column name="balance05" property="NumberFormat" value="0.0000" type="String" /><column name="period06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="period06" property="Address" value="$T$4" type="String" /><column name="period06" property="ColumnWidth" value="11.71" type="Double" /><column name="period06" property="NumberFormat" value="0.0000" type="String" /><column name="balance06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance06" property="Address" value="$U$4" type="String" /><column name="balance06" property="ColumnWidth" value="11.29" type="Double" /><column name="balance06" property="NumberFormat" value="0.0000" type="String" /><column name="period07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="period07" property="Address" value="$V$4" type="String" /><column name="period07" property="ColumnWidth" value="11.71" type="Double" /><column name="period07" property="NumberFormat" value="0.0000" type="String" /><column name="balance07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance07" property="Address" value="$W$4" type="String" /><column name="balance07" property="ColumnWidth" value="11.29" type="Double" /><column name="balance07" property="NumberFormat" value="0.0000" type="String" /><column name="period08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="period08" property="Address" value="$X$4" type="String" /><column name="period08" property="ColumnWidth" value="11.71" type="Double" /><column name="period08" property="NumberFormat" value="0.0000" type="String" /><column name="balance08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance08" property="Address" value="$Y$4" type="String" /><column name="balance08" property="ColumnWidth" value="11.29" type="Double" /><column name="balance08" property="NumberFormat" value="0.0000" type="String" /><column name="period09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="period09" property="Address" value="$Z$4" type="String" /><column name="period09" property="ColumnWidth" value="11.71" type="Double" /><column name="period09" property="NumberFormat" value="0.0000" type="String" /><column name="balance09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance09" property="Address" value="$AA$4" type="String" /><column name="balance09" property="ColumnWidth" value="11.29" type="Double" /><column name="balance09" property="NumberFormat" value="0.0000" type="String" /><column name="period10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="period10" property="Address" value="$AB$4" type="String" /><column name="period10" property="ColumnWidth" value="11.71" type="Double" /><column name="period10" property="NumberFormat" value="0.0000" type="String" /><column name="balance10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance10" property="Address" value="$AC$4" type="String" /><column name="balance10" property="ColumnWidth" value="11.29" type="Double" /><column name="balance10" property="NumberFormat" value="0.0000" type="String" /><column name="period11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="period11" property="Address" value="$AD$4" type="String" /><column name="period11" property="ColumnWidth" value="11.71" type="Double" /><column name="period11" property="NumberFormat" value="0.0000" type="String" /><column name="balance11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance11" property="Address" value="$AE$4" type="String" /><column name="balance11" property="ColumnWidth" value="11.29" type="Double" /><column name="balance11" property="NumberFormat" value="0.0000" type="String" /><column name="period12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="period12" property="Address" value="$AF$4" type="String" /><column name="period12" property="ColumnWidth" value="11.71" type="Double" /><column name="period12" property="NumberFormat" value="0.0000" type="String" /><column name="balance12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance12" property="Address" value="$AG$4" type="String" /><column name="balance12" property="ColumnWidth" value="11.29" type="Double" /><column name="balance12" property="NumberFormat" value="0.0000" type="String" /><column name="row_formulas" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_formulas" property="Address" value="$AH$4" type="String" /><column name="row_formulas" property="NumberFormat" value="General" type="String" /><column name="" property="Tab.Color" value="12419407" type="Double" /><column name="" property="Tab.ThemeColor" value="5" type="Double" /><column name="" property="Tab.TintAndShade" value="0" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N'xls27', N'usp_budget_data', N'<table name="xls27.usp_budget_data"><columnFormats><column name="" property="ListObjectName" value="data" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="key" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="key" property="Address" value="$B$4" type="String" /><column name="key" property="ColumnWidth" value="11.71" type="Double" /><column name="key" property="NumberFormat" value="General" type="String" /><column name="section" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="section" property="Address" value="$C$4" type="String" /><column name="section" property="ColumnWidth" value="25.29" type="Double" /><column name="section" property="NumberFormat" value="#,##0" type="String" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="Address" value="$D$4" type="String" /><column name="code" property="ColumnWidth" value="14.86" type="Double" /><column name="code" property="NumberFormat" value="General" type="String" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="Address" value="$E$4" type="String" /><column name="name" property="ColumnWidth" value="48.43" type="Double" /><column name="name" property="NumberFormat" value="#,##0" type="String" /><column name="payments01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments01" property="Address" value="$F$4" type="String" /><column name="payments01" property="ColumnWidth" value="11.71" type="Double" /><column name="payments01" property="NumberFormat" value="#,##0" type="String" /><column name="payments02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments02" property="Address" value="$G$4" type="String" /><column name="payments02" property="ColumnWidth" value="10.14" type="Double" /><column name="payments02" property="NumberFormat" value="#,##0" type="String" /><column name="payments03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments03" property="Address" value="$H$4" type="String" /><column name="payments03" property="ColumnWidth" value="10.14" type="Double" /><column name="payments03" property="NumberFormat" value="#,##0" type="String" /><column name="payments04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments04" property="Address" value="$I$4" type="String" /><column name="payments04" property="ColumnWidth" value="10.14" type="Double" /><column name="payments04" property="NumberFormat" value="#,##0" type="String" /><column name="payments05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments05" property="Address" value="$J$4" type="String" /><column name="payments05" property="ColumnWidth" value="10.14" type="Double" /><column name="payments05" property="NumberFormat" value="#,##0" type="String" /><column name="payments06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments06" property="Address" value="$K$4" type="String" /><column name="payments06" property="ColumnWidth" value="10.14" type="Double" /><column name="payments06" property="NumberFormat" value="#,##0" type="String" /><column name="payments07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments07" property="Address" value="$L$4" type="String" /><column name="payments07" property="ColumnWidth" value="10.14" type="Double" /><column name="payments07" property="NumberFormat" value="#,##0" type="String" /><column name="payments08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments08" property="Address" value="$M$4" type="String" /><column name="payments08" property="ColumnWidth" value="10.14" type="Double" /><column name="payments08" property="NumberFormat" value="#,##0" type="String" /><column name="payments09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments09" property="Address" value="$N$4" type="String" /><column name="payments09" property="ColumnWidth" value="10.14" type="Double" /><column name="payments09" property="NumberFormat" value="#,##0" type="String" /><column name="payments10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments10" property="Address" value="$O$4" type="String" /><column name="payments10" property="ColumnWidth" value="10.14" type="Double" /><column name="payments10" property="NumberFormat" value="#,##0" type="String" /><column name="payments11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments11" property="Address" value="$P$4" type="String" /><column name="payments11" property="ColumnWidth" value="10.14" type="Double" /><column name="payments11" property="NumberFormat" value="#,##0" type="String" /><column name="payments12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments12" property="Address" value="$Q$4" type="String" /><column name="payments12" property="ColumnWidth" value="10.14" type="Double" /><column name="payments12" property="NumberFormat" value="#,##0" type="String" /><column name="charges01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges01" property="Address" value="$R$4" type="String" /><column name="charges01" property="ColumnWidth" value="10.14" type="Double" /><column name="charges01" property="NumberFormat" value="#,##0" type="String" /><column name="charges02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges02" property="Address" value="$S$4" type="String" /><column name="charges02" property="ColumnWidth" value="10.14" type="Double" /><column name="charges02" property="NumberFormat" value="#,##0" type="String" /><column name="charges03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges03" property="Address" value="$T$4" type="String" /><column name="charges03" property="ColumnWidth" value="10.14" type="Double" /><column name="charges03" property="NumberFormat" value="#,##0" type="String" /><column name="charges04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges04" property="Address" value="$U$4" type="String" /><column name="charges04" property="ColumnWidth" value="10.14" type="Double" /><column name="charges04" property="NumberFormat" value="#,##0" type="String" /><column name="charges05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges05" property="Address" value="$V$4" type="String" /><column name="charges05" property="ColumnWidth" value="10.14" type="Double" /><column name="charges05" property="NumberFormat" value="#,##0" type="String" /><column name="charges06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges06" property="Address" value="$W$4" type="String" /><column name="charges06" property="ColumnWidth" value="10.14" type="Double" /><column name="charges06" property="NumberFormat" value="#,##0" type="String" /><column name="charges07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges07" property="Address" value="$X$4" type="String" /><column name="charges07" property="ColumnWidth" value="10.14" type="Double" /><column name="charges07" property="NumberFormat" value="#,##0" type="String" /><column name="charges08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges08" property="Address" value="$Y$4" type="String" /><column name="charges08" property="ColumnWidth" value="10.14" type="Double" /><column name="charges08" property="NumberFormat" value="#,##0" type="String" /><column name="charges09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges09" property="Address" value="$Z$4" type="String" /><column name="charges09" property="ColumnWidth" value="10.14" type="Double" /><column name="charges09" property="NumberFormat" value="#,##0" type="String" /><column name="charges10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges10" property="Address" value="$AA$4" type="String" /><column name="charges10" property="ColumnWidth" value="10.14" type="Double" /><column name="charges10" property="NumberFormat" value="#,##0" type="String" /><column name="charges11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges11" property="Address" value="$AB$4" type="String" /><column name="charges11" property="ColumnWidth" value="10.14" type="Double" /><column name="charges11" property="NumberFormat" value="#,##0" type="String" /><column name="charges12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges12" property="Address" value="$AC$4" type="String" /><column name="charges12" property="ColumnWidth" value="10.14" type="Double" /><column name="charges12" property="NumberFormat" value="#,##0" type="String" /><column name="cf01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf01" property="Address" value="$AD$4" type="String" /><column name="cf01" property="ColumnWidth" value="10.86" type="Double" /><column name="cf01" property="NumberFormat" value="#,##0" type="String" /><column name="cf02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf02" property="Address" value="$AE$4" type="String" /><column name="cf02" property="ColumnWidth" value="10.86" type="Double" /><column name="cf02" property="NumberFormat" value="#,##0" type="String" /><column name="cf03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf03" property="Address" value="$AF$4" type="String" /><column name="cf03" property="ColumnWidth" value="10.86" type="Double" /><column name="cf03" property="NumberFormat" value="#,##0" type="String" /><column name="cf04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf04" property="Address" value="$AG$4" type="String" /><column name="cf04" property="ColumnWidth" value="10.86" type="Double" /><column name="cf04" property="NumberFormat" value="#,##0" type="String" /><column name="cf05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf05" property="Address" value="$AH$4" type="String" /><column name="cf05" property="ColumnWidth" value="10.86" type="Double" /><column name="cf05" property="NumberFormat" value="#,##0" type="String" /><column name="cf06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf06" property="Address" value="$AI$4" type="String" /><column name="cf06" property="ColumnWidth" value="10.86" type="Double" /><column name="cf06" property="NumberFormat" value="#,##0" type="String" /><column name="cf07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf07" property="Address" value="$AJ$4" type="String" /><column name="cf07" property="ColumnWidth" value="10.86" type="Double" /><column name="cf07" property="NumberFormat" value="#,##0" type="String" /><column name="cf08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf08" property="Address" value="$AK$4" type="String" /><column name="cf08" property="ColumnWidth" value="10.86" type="Double" /><column name="cf08" property="NumberFormat" value="#,##0" type="String" /><column name="cf09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf09" property="Address" value="$AL$4" type="String" /><column name="cf09" property="ColumnWidth" value="10.86" type="Double" /><column name="cf09" property="NumberFormat" value="#,##0" type="String" /><column name="cf10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf10" property="Address" value="$AM$4" type="String" /><column name="cf10" property="ColumnWidth" value="10.86" type="Double" /><column name="cf10" property="NumberFormat" value="#,##0" type="String" /><column name="cf11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf11" property="Address" value="$AN$4" type="String" /><column name="cf11" property="ColumnWidth" value="10.86" type="Double" /><column name="cf11" property="NumberFormat" value="#,##0" type="String" /><column name="cf12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf12" property="Address" value="$AO$4" type="String" /><column name="cf12" property="ColumnWidth" value="10.86" type="Double" /><column name="cf12" property="NumberFormat" value="#,##0" type="String" /><column name="vat01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat01" property="Address" value="$AP$4" type="String" /><column name="vat01" property="ColumnWidth" value="10.86" type="Double" /><column name="vat01" property="NumberFormat" value="#,##0" type="String" /><column name="vat02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat02" property="Address" value="$AQ$4" type="String" /><column name="vat02" property="ColumnWidth" value="9.86" type="Double" /><column name="vat02" property="NumberFormat" value="#,##0" type="String" /><column name="vat03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat03" property="Address" value="$AR$4" type="String" /><column name="vat03" property="ColumnWidth" value="9.86" type="Double" /><column name="vat03" property="NumberFormat" value="#,##0" type="String" /><column name="vat04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat04" property="Address" value="$AS$4" type="String" /><column name="vat04" property="ColumnWidth" value="9.86" type="Double" /><column name="vat04" property="NumberFormat" value="#,##0" type="String" /><column name="vat05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat05" property="Address" value="$AT$4" type="String" /><column name="vat05" property="ColumnWidth" value="9.86" type="Double" /><column name="vat05" property="NumberFormat" value="#,##0" type="String" /><column name="vat06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat06" property="Address" value="$AU$4" type="String" /><column name="vat06" property="ColumnWidth" value="9.86" type="Double" /><column name="vat06" property="NumberFormat" value="#,##0" type="String" /><column name="vat07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat07" property="Address" value="$AV$4" type="String" /><column name="vat07" property="ColumnWidth" value="9.86" type="Double" /><column name="vat07" property="NumberFormat" value="#,##0" type="String" /><column name="vat08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat08" property="Address" value="$AW$4" type="String" /><column name="vat08" property="ColumnWidth" value="9.86" type="Double" /><column name="vat08" property="NumberFormat" value="#,##0" type="String" /><column name="vat09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat09" property="Address" value="$AX$4" type="String" /><column name="vat09" property="ColumnWidth" value="9.86" type="Double" /><column name="vat09" property="NumberFormat" value="#,##0" type="String" /><column name="vat10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat10" property="Address" value="$AY$4" type="String" /><column name="vat10" property="ColumnWidth" value="9.86" type="Double" /><column name="vat10" property="NumberFormat" value="#,##0" type="String" /><column name="vat11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat11" property="Address" value="$AZ$4" type="String" /><column name="vat11" property="ColumnWidth" value="9.86" type="Double" /><column name="vat11" property="NumberFormat" value="#,##0" type="String" /><column name="vat12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat12" property="Address" value="$BA$4" type="String" /><column name="vat12" property="ColumnWidth" value="9.86" type="Double" /><column name="vat12" property="NumberFormat" value="#,##0" type="String" /><column name="pl01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl01" property="Address" value="$BB$4" type="String" /><column name="pl01" property="ColumnWidth" value="10.86" type="Double" /><column name="pl01" property="NumberFormat" value="#,##0" type="String" /><column name="pl02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl02" property="Address" value="$BC$4" type="String" /><column name="pl02" property="ColumnWidth" value="10.86" type="Double" /><column name="pl02" property="NumberFormat" value="#,##0" type="String" /><column name="pl03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl03" property="Address" value="$BD$4" type="String" /><column name="pl03" property="ColumnWidth" value="10.86" type="Double" /><column name="pl03" property="NumberFormat" value="#,##0" type="String" /><column name="pl04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl04" property="Address" value="$BE$4" type="String" /><column name="pl04" property="ColumnWidth" value="10.86" type="Double" /><column name="pl04" property="NumberFormat" value="#,##0" type="String" /><column name="pl05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl05" property="Address" value="$BF$4" type="String" /><column name="pl05" property="ColumnWidth" value="10.86" type="Double" /><column name="pl05" property="NumberFormat" value="#,##0" type="String" /><column name="pl06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl06" property="Address" value="$BG$4" type="String" /><column name="pl06" property="ColumnWidth" value="10.86" type="Double" /><column name="pl06" property="NumberFormat" value="#,##0" type="String" /><column name="pl07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl07" property="Address" value="$BH$4" type="String" /><column name="pl07" property="ColumnWidth" value="10.86" type="Double" /><column name="pl07" property="NumberFormat" value="#,##0" type="String" /><column name="pl08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl08" property="Address" value="$BI$4" type="String" /><column name="pl08" property="ColumnWidth" value="10.86" type="Double" /><column name="pl08" property="NumberFormat" value="#,##0" type="String" /><column name="pl09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl09" property="Address" value="$BJ$4" type="String" /><column name="pl09" property="ColumnWidth" value="10.86" type="Double" /><column name="pl09" property="NumberFormat" value="#,##0" type="String" /><column name="pl10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl10" property="Address" value="$BK$4" type="String" /><column name="pl10" property="ColumnWidth" value="10.86" type="Double" /><column name="pl10" property="NumberFormat" value="#,##0" type="String" /><column name="pl11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl11" property="Address" value="$BL$4" type="String" /><column name="pl11" property="ColumnWidth" value="10.86" type="Double" /><column name="pl11" property="NumberFormat" value="#,##0" type="String" /><column name="pl12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl12" property="Address" value="$BM$4" type="String" /><column name="pl12" property="ColumnWidth" value="10.86" type="Double" /><column name="pl12" property="NumberFormat" value="#,##0" type="String" /><column name="dr01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="dr01" property="Address" value="$BN$4" type="String" /><column name="dr01" property="ColumnWidth" value="10.86" type="Double" /><column name="dr01" property="NumberFormat" value="#,##0" type="String" /><column name="dr02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="dr02" property="Address" value="$BO$4" type="String" /><column name="dr02" property="ColumnWidth" value="10.14" type="Double" /><column name="dr02" property="NumberFormat" value="#,##0" type="String" /><column name="dr03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="dr03" property="Address" value="$BP$4" type="String" /><column name="dr03" property="ColumnWidth" value="10.14" type="Double" /><column name="dr03" property="NumberFormat" value="#,##0" type="String" /><column name="dr04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="dr04" property="Address" value="$BQ$4" type="String" /><column name="dr04" property="ColumnWidth" value="10.14" type="Double" /><column name="dr04" property="NumberFormat" value="#,##0" type="String" /><column name="dr05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="dr05" property="Address" value="$BR$4" type="String" /><column name="dr05" property="ColumnWidth" value="10.14" type="Double" /><column name="dr05" property="NumberFormat" value="#,##0" type="String" /><column name="dr06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="dr06" property="Address" value="$BS$4" type="String" /><column name="dr06" property="ColumnWidth" value="10.14" type="Double" /><column name="dr06" property="NumberFormat" value="#,##0" type="String" /><column name="dr07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="dr07" property="Address" value="$BT$4" type="String" /><column name="dr07" property="ColumnWidth" value="10.14" type="Double" /><column name="dr07" property="NumberFormat" value="#,##0" type="String" /><column name="dr08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="dr08" property="Address" value="$BU$4" type="String" /><column name="dr08" property="ColumnWidth" value="10.14" type="Double" /><column name="dr08" property="NumberFormat" value="#,##0" type="String" /><column name="dr09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="dr09" property="Address" value="$BV$4" type="String" /><column name="dr09" property="ColumnWidth" value="10.14" type="Double" /><column name="dr09" property="NumberFormat" value="#,##0" type="String" /><column name="dr10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="dr10" property="Address" value="$BW$4" type="String" /><column name="dr10" property="ColumnWidth" value="10.14" type="Double" /><column name="dr10" property="NumberFormat" value="#,##0" type="String" /><column name="dr11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="dr11" property="Address" value="$BX$4" type="String" /><column name="dr11" property="ColumnWidth" value="10.14" type="Double" /><column name="dr11" property="NumberFormat" value="#,##0" type="String" /><column name="dr12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="dr12" property="Address" value="$BY$4" type="String" /><column name="dr12" property="ColumnWidth" value="10.14" type="Double" /><column name="dr12" property="NumberFormat" value="#,##0" type="String" /><column name="cr01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cr01" property="Address" value="$BZ$4" type="String" /><column name="cr01" property="ColumnWidth" value="10.14" type="Double" /><column name="cr01" property="NumberFormat" value="#,##0" type="String" /><column name="cr02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cr02" property="Address" value="$CA$4" type="String" /><column name="cr02" property="ColumnWidth" value="10.14" type="Double" /><column name="cr02" property="NumberFormat" value="#,##0" type="String" /><column name="cr03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cr03" property="Address" value="$CB$4" type="String" /><column name="cr03" property="ColumnWidth" value="10.14" type="Double" /><column name="cr03" property="NumberFormat" value="#,##0" type="String" /><column name="cr04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cr04" property="Address" value="$CC$4" type="String" /><column name="cr04" property="ColumnWidth" value="10.14" type="Double" /><column name="cr04" property="NumberFormat" value="#,##0" type="String" /><column name="cr05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cr05" property="Address" value="$CD$4" type="String" /><column name="cr05" property="ColumnWidth" value="10.14" type="Double" /><column name="cr05" property="NumberFormat" value="#,##0" type="String" /><column name="cr06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cr06" property="Address" value="$CE$4" type="String" /><column name="cr06" property="ColumnWidth" value="10.14" type="Double" /><column name="cr06" property="NumberFormat" value="#,##0" type="String" /><column name="cr07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cr07" property="Address" value="$CF$4" type="String" /><column name="cr07" property="ColumnWidth" value="10.14" type="Double" /><column name="cr07" property="NumberFormat" value="#,##0" type="String" /><column name="cr08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cr08" property="Address" value="$CG$4" type="String" /><column name="cr08" property="ColumnWidth" value="10.14" type="Double" /><column name="cr08" property="NumberFormat" value="#,##0" type="String" /><column name="cr09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cr09" property="Address" value="$CH$4" type="String" /><column name="cr09" property="ColumnWidth" value="10.14" type="Double" /><column name="cr09" property="NumberFormat" value="#,##0" type="String" /><column name="cr10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cr10" property="Address" value="$CI$4" type="String" /><column name="cr10" property="ColumnWidth" value="10.14" type="Double" /><column name="cr10" property="NumberFormat" value="#,##0" type="String" /><column name="cr11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cr11" property="Address" value="$CJ$4" type="String" /><column name="cr11" property="ColumnWidth" value="10.14" type="Double" /><column name="cr11" property="NumberFormat" value="#,##0" type="String" /><column name="cr12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cr12" property="Address" value="$CK$4" type="String" /><column name="cr12" property="ColumnWidth" value="10.14" type="Double" /><column name="cr12" property="NumberFormat" value="#,##0" type="String" /><column name="balance00" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance00" property="Address" value="$CL$4" type="String" /><column name="balance00" property="ColumnWidth" value="12.71" type="Double" /><column name="balance00" property="NumberFormat" value="#,##0" type="String" /><column name="balance01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance01" property="Address" value="$CM$4" type="String" /><column name="balance01" property="ColumnWidth" value="12.71" type="Double" /><column name="balance01" property="NumberFormat" value="#,##0" type="String" /><column name="balance02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance02" property="Address" value="$CN$4" type="String" /><column name="balance02" property="ColumnWidth" value="12.86" type="Double" /><column name="balance02" property="NumberFormat" value="#,##0" type="String" /><column name="balance03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance03" property="Address" value="$CO$4" type="String" /><column name="balance03" property="ColumnWidth" value="12.86" type="Double" /><column name="balance03" property="NumberFormat" value="#,##0" type="String" /><column name="balance04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance04" property="Address" value="$CP$4" type="String" /><column name="balance04" property="ColumnWidth" value="12.86" type="Double" /><column name="balance04" property="NumberFormat" value="#,##0" type="String" /><column name="balance05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance05" property="Address" value="$CQ$4" type="String" /><column name="balance05" property="ColumnWidth" value="12.86" type="Double" /><column name="balance05" property="NumberFormat" value="#,##0" type="String" /><column name="balance06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance06" property="Address" value="$CR$4" type="String" /><column name="balance06" property="ColumnWidth" value="12.86" type="Double" /><column name="balance06" property="NumberFormat" value="#,##0" type="String" /><column name="balance07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance07" property="Address" value="$CS$4" type="String" /><column name="balance07" property="ColumnWidth" value="12.86" type="Double" /><column name="balance07" property="NumberFormat" value="#,##0" type="String" /><column name="balance08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance08" property="Address" value="$CT$4" type="String" /><column name="balance08" property="ColumnWidth" value="12.86" type="Double" /><column name="balance08" property="NumberFormat" value="#,##0" type="String" /><column name="balance09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance09" property="Address" value="$CU$4" type="String" /><column name="balance09" property="ColumnWidth" value="12.86" type="Double" /><column name="balance09" property="NumberFormat" value="#,##0" type="String" /><column name="balance10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance10" property="Address" value="$CV$4" type="String" /><column name="balance10" property="ColumnWidth" value="12.86" type="Double" /><column name="balance10" property="NumberFormat" value="#,##0" type="String" /><column name="balance11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance11" property="Address" value="$CW$4" type="String" /><column name="balance11" property="ColumnWidth" value="12.86" type="Double" /><column name="balance11" property="NumberFormat" value="#,##0" type="String" /><column name="balance12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance12" property="Address" value="$CX$4" type="String" /><column name="balance12" property="ColumnWidth" value="12.86" type="Double" /><column name="balance12" property="NumberFormat" value="#,##0" type="String" /><column name="bd00" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bd00" property="Address" value="$CY$4" type="String" /><column name="bd00" property="ColumnWidth" value="12.86" type="Double" /><column name="bd00" property="NumberFormat" value="#,##0" type="String" /><column name="bd01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bd01" property="Address" value="$CZ$4" type="String" /><column name="bd01" property="ColumnWidth" value="12.71" type="Double" /><column name="bd01" property="NumberFormat" value="#,##0" type="String" /><column name="bd02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bd02" property="Address" value="$DA$4" type="String" /><column name="bd02" property="ColumnWidth" value="12.71" type="Double" /><column name="bd02" property="NumberFormat" value="#,##0" type="String" /><column name="bd03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bd03" property="Address" value="$DB$4" type="String" /><column name="bd03" property="ColumnWidth" value="12.71" type="Double" /><column name="bd03" property="NumberFormat" value="#,##0" type="String" /><column name="bd04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bd04" property="Address" value="$DC$4" type="String" /><column name="bd04" property="ColumnWidth" value="12.71" type="Double" /><column name="bd04" property="NumberFormat" value="#,##0" type="String" /><column name="bd05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bd05" property="Address" value="$DD$4" type="String" /><column name="bd05" property="ColumnWidth" value="12.71" type="Double" /><column name="bd05" property="NumberFormat" value="#,##0" type="String" /><column name="bd06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bd06" property="Address" value="$DE$4" type="String" /><column name="bd06" property="ColumnWidth" value="12.71" type="Double" /><column name="bd06" property="NumberFormat" value="#,##0" type="String" /><column name="bd07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bd07" property="Address" value="$DF$4" type="String" /><column name="bd07" property="ColumnWidth" value="12.71" type="Double" /><column name="bd07" property="NumberFormat" value="#,##0" type="String" /><column name="bd08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bd08" property="Address" value="$DG$4" type="String" /><column name="bd08" property="ColumnWidth" value="12.71" type="Double" /><column name="bd08" property="NumberFormat" value="#,##0" type="String" /><column name="bd09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bd09" property="Address" value="$DH$4" type="String" /><column name="bd09" property="ColumnWidth" value="12.71" type="Double" /><column name="bd09" property="NumberFormat" value="#,##0" type="String" /><column name="bd10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bd10" property="Address" value="$DI$4" type="String" /><column name="bd10" property="ColumnWidth" value="12.71" type="Double" /><column name="bd10" property="NumberFormat" value="#,##0" type="String" /><column name="bd11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bd11" property="Address" value="$DJ$4" type="String" /><column name="bd11" property="ColumnWidth" value="12.71" type="Double" /><column name="bd11" property="NumberFormat" value="#,##0" type="String" /><column name="bd12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bd12" property="Address" value="$DK$4" type="String" /><column name="bd12" property="ColumnWidth" value="12.71" type="Double" /><column name="bd12" property="NumberFormat" value="#,##0" type="String" /><column name="bc00" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bc00" property="Address" value="$DL$4" type="String" /><column name="bc00" property="ColumnWidth" value="12.71" type="Double" /><column name="bc00" property="NumberFormat" value="#,##0" type="String" /><column name="bc01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bc01" property="Address" value="$DM$4" type="String" /><column name="bc01" property="ColumnWidth" value="11.57" type="Double" /><column name="bc01" property="NumberFormat" value="#,##0" type="String" /><column name="bc02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bc02" property="Address" value="$DN$4" type="String" /><column name="bc02" property="ColumnWidth" value="11.57" type="Double" /><column name="bc02" property="NumberFormat" value="#,##0" type="String" /><column name="bc03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bc03" property="Address" value="$DO$4" type="String" /><column name="bc03" property="ColumnWidth" value="11.57" type="Double" /><column name="bc03" property="NumberFormat" value="#,##0" type="String" /><column name="bc04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bc04" property="Address" value="$DP$4" type="String" /><column name="bc04" property="ColumnWidth" value="11.57" type="Double" /><column name="bc04" property="NumberFormat" value="#,##0" type="String" /><column name="bc05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bc05" property="Address" value="$DQ$4" type="String" /><column name="bc05" property="ColumnWidth" value="11.57" type="Double" /><column name="bc05" property="NumberFormat" value="#,##0" type="String" /><column name="bc06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bc06" property="Address" value="$DR$4" type="String" /><column name="bc06" property="ColumnWidth" value="11.57" type="Double" /><column name="bc06" property="NumberFormat" value="#,##0" type="String" /><column name="bc07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bc07" property="Address" value="$DS$4" type="String" /><column name="bc07" property="ColumnWidth" value="11.57" type="Double" /><column name="bc07" property="NumberFormat" value="#,##0" type="String" /><column name="bc08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bc08" property="Address" value="$DT$4" type="String" /><column name="bc08" property="ColumnWidth" value="11.57" type="Double" /><column name="bc08" property="NumberFormat" value="#,##0" type="String" /><column name="bc09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bc09" property="Address" value="$DU$4" type="String" /><column name="bc09" property="ColumnWidth" value="11.57" type="Double" /><column name="bc09" property="NumberFormat" value="#,##0" type="String" /><column name="bc10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bc10" property="Address" value="$DV$4" type="String" /><column name="bc10" property="ColumnWidth" value="11.57" type="Double" /><column name="bc10" property="NumberFormat" value="#,##0" type="String" /><column name="bc11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bc11" property="Address" value="$DW$4" type="String" /><column name="bc11" property="ColumnWidth" value="11.57" type="Double" /><column name="bc11" property="NumberFormat" value="#,##0" type="String" /><column name="bc12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bc12" property="Address" value="$DX$4" type="String" /><column name="bc12" property="ColumnWidth" value="12.43" type="Double" /><column name="bc12" property="NumberFormat" value="#,##0" type="String" /><column name="" property="Tab.Color" value="6299648" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats><views><view name="all data"><column name="" property="ListObjectName" value="data" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="key" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="section" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="dr01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="dr02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="dr03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="dr04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="dr05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="dr06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="dr07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="dr08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="dr09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="dr10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="dr11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="dr12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cr01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cr02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cr03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cr04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cr05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cr06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cr07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cr08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cr09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cr10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cr11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cr12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance00" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bd00" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bd01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bd02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bd03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bd04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bd05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bd06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bd07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bd08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bd09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bd10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bd11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bd12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bc00" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bc01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bc02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bc03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bc04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bc05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bc06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bc07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bc08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bc09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bc10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bc11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bc12" property="EntireColumn.Hidden" value="False" type="Boolean" /></view><view name="accounts"><column name="" property="ListObjectName" value="data" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="key" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="section" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="dr01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance00" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd00" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc00" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="section" property="AutoFilter.Criteria1" value="=accounts" type="String" /></view><view name="companies"><column name="" property="ListObjectName" value="data" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="key" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="section" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="dr01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance00" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd00" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc00" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="section" property="AutoFilter.Criteria1" value="=accounts+companies" type="String" /></view><view name="ledger accounts"><column name="" property="ListObjectName" value="data" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="key" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="section" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="dr02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="dr03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="dr04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="dr05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="dr06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="dr07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="dr08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="dr09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="dr10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="dr11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="dr12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cr01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cr02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cr03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cr04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cr05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cr06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cr07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cr08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cr09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cr10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cr11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cr12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance00" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bd00" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bd01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bd02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bd03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bd04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bd05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bd06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bd07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bd08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bd09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bd10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bd11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bd12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bc00" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bc01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bc02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bc03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bc04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bc05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bc06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bc07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bc08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bc09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bc10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bc11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bc12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="section" property="AutoFilter.Criteria1" value="=ledger_accounts" type="String" /></view><view name="subsidiary accounts"><column name="" property="ListObjectName" value="data" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="key" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="section" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance00" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bd00" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc00" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="section" property="AutoFilter.Criteria1" value="=ledger+subsidiary_accounts" type="String" /></view><view name="entities"><column name="" property="ListObjectName" value="data" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="key" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="section" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="dr01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance00" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd00" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc00" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="section" property="AutoFilter.Criteria1" value="=entities" type="String" /></view><view name="products"><column name="" property="ListObjectName" value="data" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="key" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="section" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="dr01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance00" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd00" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc00" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="section" property="AutoFilter.Criteria1" value="=accounts+products" type="String" /></view><view name="regions"><column name="" property="ListObjectName" value="data" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="key" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="section" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="dr01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance00" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd00" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc00" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="section" property="AutoFilter.Criteria1" value="=accounts+regions" type="String" /></view><view name="totals"><column name="" property="ListObjectName" value="data" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="key" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="section" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="dr01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance00" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd00" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc00" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="section" property="AutoFilter.Criteria1" value="=totals_cf" type="String" /><column name="section" property="AutoFilter.Operator" value="2" type="Double" /><column name="section" property="AutoFilter.Criteria2" value="=totals_pl" type="String" /></view><view name="cash flow"><column name="" property="ListObjectName" value="data" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="key" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="section" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance00" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd00" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc00" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="section" property="AutoFilter.Criteria1" value="=accounts" type="String" /><column name="section" property="AutoFilter.Operator" value="2" type="Double" /><column name="section" property="AutoFilter.Criteria2" value="=totals_cf" type="String" /></view><view name="profit and losses"><column name="" property="ListObjectName" value="data" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="key" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="section" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="dr01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance00" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd00" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc00" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="section" property="AutoFilter.Criteria1" value="=accounts" type="String" /><column name="section" property="AutoFilter.Operator" value="2" type="Double" /><column name="section" property="AutoFilter.Criteria2" value="=totals_pl" type="String" /></view><view name="assets"><column name="" property="ListObjectName" value="data" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="key" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="section" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance00" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd00" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bd01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bd02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bd03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bd04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bd05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bd06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bd07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bd08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bd09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bd10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bd11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bd12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bc00" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="section" property="AutoFilter.Criteria1" value="=ledger_accounts" type="String" /></view><view name="balances"><column name="" property="ListObjectName" value="data" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="key" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="section" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance00" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bd00" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc00" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="section" property="AutoFilter.Criteria1" value="=ledger_accounts" type="String" /></view><view name="vat"><column name="" property="ListObjectName" value="data" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="key" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="section" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dr12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cr12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance00" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd00" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bd12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc00" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="bc12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="section" property="AutoFilter.Criteria1" value="=accounts" type="String" /></view></views></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N'xls27', N'usp_budget_journal', N'<table name="xls27.usp_budget_journal"><columnFormats><column name="" property="ListObjectName" value="budget_journal" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="date" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="date" property="Address" value="$C$4" type="String" /><column name="date" property="ColumnWidth" value="10.71" type="Double" /><column name="date" property="NumberFormat" value="m/d/yyyy" type="String" /><column name="debit_account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="debit_account_id" property="Address" value="$D$4" type="String" /><column name="debit_account_id" property="ColumnWidth" value="7.86" type="Double" /><column name="debit_account_id" property="NumberFormat" value="General" type="String" /><column name="credit_account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="credit_account_id" property="Address" value="$E$4" type="String" /><column name="credit_account_id" property="ColumnWidth" value="7.86" type="Double" /><column name="credit_account_id" property="NumberFormat" value="General" type="String" /><column name="amount" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="amount" property="Address" value="$F$4" type="String" /><column name="amount" property="ColumnWidth" value="13.57" type="Double" /><column name="amount" property="NumberFormat" value="#,##0.00" type="String" /><column name="debit_subsidiary_account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="debit_subsidiary_account_id" property="Address" value="$G$4" type="String" /><column name="debit_subsidiary_account_id" property="ColumnWidth" value="28.43" type="Double" /><column name="debit_subsidiary_account_id" property="NumberFormat" value="General" type="String" /><column name="credit_subsidiary_account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="credit_subsidiary_account_id" property="Address" value="$H$4" type="String" /><column name="credit_subsidiary_account_id" property="ColumnWidth" value="28.86" type="Double" /><column name="credit_subsidiary_account_id" property="NumberFormat" value="General" type="String" /><column name="description" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="description" property="Address" value="$I$4" type="String" /><column name="description" property="ColumnWidth" value="46.86" type="Double" /><column name="description" property="NumberFormat" value="General" type="String" /><column name="currency" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="currency" property="Address" value="$J$4" type="String" /><column name="currency" property="ColumnWidth" value="10.14" type="Double" /><column name="currency" property="NumberFormat" value="General" type="String" /><column name="rate" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="rate" property="Address" value="$K$4" type="String" /><column name="rate" property="ColumnWidth" value="6.14" type="Double" /><column name="rate" property="NumberFormat" value="General" type="String" /><column name="amount$" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="amount$" property="Address" value="$L$4" type="String" /><column name="amount$" property="ColumnWidth" value="13.57" type="Double" /><column name="amount$" property="NumberFormat" value="#,##0.00" type="String" /><column name="entity_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="entity_id" property="Address" value="$M$4" type="String" /><column name="entity_id" property="ColumnWidth" value="18.57" type="Double" /><column name="entity_id" property="NumberFormat" value="General" type="String" /><column name="account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account_id" property="Address" value="$N$4" type="String" /><column name="account_id" property="ColumnWidth" value="12.14" type="Double" /><column name="account_id" property="NumberFormat" value="General" type="String" /><column name="region_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="region_id" property="Address" value="$O$4" type="String" /><column name="region_id" property="ColumnWidth" value="11" type="Double" /><column name="region_id" property="NumberFormat" value="General" type="String" /><column name="product_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="product_id" property="Address" value="$P$4" type="String" /><column name="product_id" property="ColumnWidth" value="12.14" type="Double" /><column name="product_id" property="NumberFormat" value="General" type="String" /><column name="" property="Tab.Color" value="12611584" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats><views><view name="Form"><column name="" property="ListObjectName" value="budget_journal" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="date" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="debit_account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="credit_account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="amount" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="debit_subsidiary_account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="credit_subsidiary_account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="description" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="currency" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="rate" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="amount$" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="entity_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="region_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="product_id" property="EntireColumn.Hidden" value="False" type="Boolean" /></view><view name="All Columns"><column name="" property="ListObjectName" value="budget_journal" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="date" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="debit_account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="credit_account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="amount" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="debit_subsidiary_account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="credit_subsidiary_account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="description" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="currency" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="rate" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="amount$" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="entity_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="region_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="product_id" property="EntireColumn.Hidden" value="False" type="Boolean" /></view></views></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N'xls27', N'usp_budget_report', N'<table name="xls27.usp_budget_report"><columnFormats><column name="" property="ListObjectName" value="report_data" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="ColumnWidth" value="11.71" type="Double" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="row" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="row" property="Address" value="$C$4" type="String" /><column name="row" property="ColumnWidth" value="8.43" type="Double" /><column name="row" property="NumberFormat" value="General" type="String" /><column name="id1" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="id1" property="Address" value="$D$4" type="String" /><column name="id1" property="ColumnWidth" value="10.57" type="Double" /><column name="id1" property="NumberFormat" value="General" type="String" /><column name="id1" property="Validation.Type" value="6" type="Double" /><column name="id1" property="Validation.Operator" value="8" type="Double" /><column name="id1" property="Validation.Formula1" value="50" type="String" /><column name="id1" property="Validation.AlertStyle" value="1" type="Double" /><column name="id1" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="id1" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="id1" property="Validation.ShowInput" value="True" type="Boolean" /><column name="id1" property="Validation.ShowError" value="True" type="Boolean" /><column name="id2" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="id2" property="Address" value="$E$4" type="String" /><column name="id2" property="ColumnWidth" value="7.29" type="Double" /><column name="id2" property="NumberFormat" value="General" type="String" /><column name="id2" property="Validation.Type" value="1" type="Double" /><column name="id2" property="Validation.Operator" value="1" type="Double" /><column name="id2" property="Validation.Formula1" value="-2147483648" type="String" /><column name="id2" property="Validation.Formula2" value="2147483647" type="String" /><column name="id2" property="Validation.AlertStyle" value="1" type="Double" /><column name="id2" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="id2" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="id2" property="Validation.ShowInput" value="True" type="Boolean" /><column name="id2" property="Validation.ShowError" value="True" type="Boolean" /><column name="form" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="form" property="Address" value="$F$4" type="String" /><column name="form" property="ColumnWidth" value="6.86" type="Double" /><column name="form" property="NumberFormat" value="General" type="String" /><column name="form" property="Validation.Type" value="1" type="Double" /><column name="form" property="Validation.Operator" value="1" type="Double" /><column name="form" property="Validation.Formula1" value="-2147483648" type="String" /><column name="form" property="Validation.Formula2" value="2147483647" type="String" /><column name="form" property="Validation.AlertStyle" value="1" type="Double" /><column name="form" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="form" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="form" property="Validation.ShowInput" value="True" type="Boolean" /><column name="form" property="Validation.ShowError" value="True" type="Boolean" /><column name="row_level" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="row_level" property="Address" value="$G$4" type="String" /><column name="row_level" property="ColumnWidth" value="7" type="Double" /><column name="row_level" property="NumberFormat" value="General" type="String" /><column name="row_level" property="Validation.Type" value="1" type="Double" /><column name="row_level" property="Validation.Operator" value="1" type="Double" /><column name="row_level" property="Validation.Formula1" value="-2147483648" type="String" /><column name="row_level" property="Validation.Formula2" value="2147483647" type="String" /><column name="row_level" property="Validation.AlertStyle" value="1" type="Double" /><column name="row_level" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="row_level" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="row_level" property="Validation.ShowInput" value="True" type="Boolean" /><column name="row_level" property="Validation.ShowError" value="True" type="Boolean" /><column name="row_format" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="row_format" property="Address" value="$H$4" type="String" /><column name="row_format" property="ColumnWidth" value="8.57" type="Double" /><column name="row_format" property="NumberFormat" value="General" type="String" /><column name="row_format" property="Validation.Type" value="1" type="Double" /><column name="row_format" property="Validation.Operator" value="1" type="Double" /><column name="row_format" property="Validation.Formula1" value="-2147483648" type="String" /><column name="row_format" property="Validation.Formula2" value="2147483647" type="String" /><column name="row_format" property="Validation.AlertStyle" value="1" type="Double" /><column name="row_format" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="row_format" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="row_format" property="Validation.ShowInput" value="True" type="Boolean" /><column name="row_format" property="Validation.ShowError" value="True" type="Boolean" /><column name="hide" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="hide" property="Address" value="$I$4" type="String" /><column name="hide" property="ColumnWidth" value="8.43" type="Double" /><column name="hide" property="NumberFormat" value="General" type="String" /><column name="zero" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="zero" property="Address" value="$J$4" type="String" /><column name="zero" property="ColumnWidth" value="8.43" type="Double" /><column name="zero" property="NumberFormat" value="General" type="String" /><column name="code1" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code1" property="Address" value="$K$4" type="String" /><column name="code1" property="ColumnWidth" value="9.71" type="Double" /><column name="code1" property="NumberFormat" value="General" type="String" /><column name="code1" property="Validation.Type" value="6" type="Double" /><column name="code1" property="Validation.Operator" value="8" type="Double" /><column name="code1" property="Validation.Formula1" value="50" type="String" /><column name="code1" property="Validation.AlertStyle" value="1" type="Double" /><column name="code1" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="code1" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="code1" property="Validation.ShowInput" value="True" type="Boolean" /><column name="code1" property="Validation.ShowError" value="True" type="Boolean" /><column name="code2" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code2" property="Address" value="$L$4" type="String" /><column name="code2" property="ColumnWidth" value="7.86" type="Double" /><column name="code2" property="NumberFormat" value="General" type="String" /><column name="code2" property="Validation.Type" value="6" type="Double" /><column name="code2" property="Validation.Operator" value="8" type="Double" /><column name="code2" property="Validation.Formula1" value="50" type="String" /><column name="code2" property="Validation.AlertStyle" value="1" type="Double" /><column name="code2" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="code2" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="code2" property="Validation.ShowInput" value="True" type="Boolean" /><column name="code2" property="Validation.ShowError" value="True" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="Address" value="$M$4" type="String" /><column name="code" property="ColumnWidth" value="6.86" type="Double" /><column name="code" property="NumberFormat" value="General" type="String" /><column name="code" property="Validation.Type" value="6" type="Double" /><column name="code" property="Validation.Operator" value="8" type="Double" /><column name="code" property="Validation.Formula1" value="50" type="String" /><column name="code" property="Validation.AlertStyle" value="1" type="Double" /><column name="code" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="code" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="code" property="Validation.ShowInput" value="True" type="Boolean" /><column name="code" property="Validation.ShowError" value="True" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="Address" value="$N$4" type="String" /><column name="name" property="ColumnWidth" value="59.71" type="Double" /><column name="name" property="NumberFormat" value="General" type="String" /><column name="name" property="Validation.Type" value="6" type="Double" /><column name="name" property="Validation.Operator" value="8" type="Double" /><column name="name" property="Validation.Formula1" value="255" type="String" /><column name="name" property="Validation.AlertStyle" value="1" type="Double" /><column name="name" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="name" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="name" property="Validation.ShowInput" value="True" type="Boolean" /><column name="name" property="Validation.ShowError" value="True" type="Boolean" /><column name="data00" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data00" property="Address" value="$O$4" type="String" /><column name="data00" property="ColumnWidth" value="8.86" type="Double" /><column name="data00" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="data00" property="Validation.Type" value="2" type="Double" /><column name="data00" property="Validation.Operator" value="4" type="Double" /><column name="data00" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="data00" property="Validation.AlertStyle" value="1" type="Double" /><column name="data00" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="data00" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="data00" property="Validation.ShowInput" value="True" type="Boolean" /><column name="data00" property="Validation.ShowError" value="True" type="Boolean" /><column name="data01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data01" property="Address" value="$P$4" type="String" /><column name="data01" property="ColumnWidth" value="8.86" type="Double" /><column name="data01" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="data01" property="Validation.Type" value="2" type="Double" /><column name="data01" property="Validation.Operator" value="4" type="Double" /><column name="data01" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="data01" property="Validation.AlertStyle" value="1" type="Double" /><column name="data01" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="data01" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="data01" property="Validation.ShowInput" value="True" type="Boolean" /><column name="data01" property="Validation.ShowError" value="True" type="Boolean" /><column name="data02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data02" property="Address" value="$Q$4" type="String" /><column name="data02" property="ColumnWidth" value="8.57" type="Double" /><column name="data02" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="data02" property="Validation.Type" value="2" type="Double" /><column name="data02" property="Validation.Operator" value="4" type="Double" /><column name="data02" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="data02" property="Validation.AlertStyle" value="1" type="Double" /><column name="data02" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="data02" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="data02" property="Validation.ShowInput" value="True" type="Boolean" /><column name="data02" property="Validation.ShowError" value="True" type="Boolean" /><column name="data03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data03" property="Address" value="$R$4" type="String" /><column name="data03" property="ColumnWidth" value="8.57" type="Double" /><column name="data03" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="data03" property="Validation.Type" value="2" type="Double" /><column name="data03" property="Validation.Operator" value="4" type="Double" /><column name="data03" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="data03" property="Validation.AlertStyle" value="1" type="Double" /><column name="data03" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="data03" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="data03" property="Validation.ShowInput" value="True" type="Boolean" /><column name="data03" property="Validation.ShowError" value="True" type="Boolean" /><column name="data04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data04" property="Address" value="$S$4" type="String" /><column name="data04" property="ColumnWidth" value="8.86" type="Double" /><column name="data04" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="data04" property="Validation.Type" value="2" type="Double" /><column name="data04" property="Validation.Operator" value="4" type="Double" /><column name="data04" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="data04" property="Validation.AlertStyle" value="1" type="Double" /><column name="data04" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="data04" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="data04" property="Validation.ShowInput" value="True" type="Boolean" /><column name="data04" property="Validation.ShowError" value="True" type="Boolean" /><column name="data05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data05" property="Address" value="$T$4" type="String" /><column name="data05" property="ColumnWidth" value="8.86" type="Double" /><column name="data05" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="data05" property="Validation.Type" value="2" type="Double" /><column name="data05" property="Validation.Operator" value="4" type="Double" /><column name="data05" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="data05" property="Validation.AlertStyle" value="1" type="Double" /><column name="data05" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="data05" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="data05" property="Validation.ShowInput" value="True" type="Boolean" /><column name="data05" property="Validation.ShowError" value="True" type="Boolean" /><column name="data06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data06" property="Address" value="$U$4" type="String" /><column name="data06" property="ColumnWidth" value="8.86" type="Double" /><column name="data06" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="data06" property="Validation.Type" value="2" type="Double" /><column name="data06" property="Validation.Operator" value="4" type="Double" /><column name="data06" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="data06" property="Validation.AlertStyle" value="1" type="Double" /><column name="data06" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="data06" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="data06" property="Validation.ShowInput" value="True" type="Boolean" /><column name="data06" property="Validation.ShowError" value="True" type="Boolean" /><column name="data07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data07" property="Address" value="$V$4" type="String" /><column name="data07" property="ColumnWidth" value="8.86" type="Double" /><column name="data07" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="data07" property="Validation.Type" value="2" type="Double" /><column name="data07" property="Validation.Operator" value="4" type="Double" /><column name="data07" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="data07" property="Validation.AlertStyle" value="1" type="Double" /><column name="data07" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="data07" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="data07" property="Validation.ShowInput" value="True" type="Boolean" /><column name="data07" property="Validation.ShowError" value="True" type="Boolean" /><column name="data08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data08" property="Address" value="$W$4" type="String" /><column name="data08" property="ColumnWidth" value="8.86" type="Double" /><column name="data08" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="data08" property="Validation.Type" value="2" type="Double" /><column name="data08" property="Validation.Operator" value="4" type="Double" /><column name="data08" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="data08" property="Validation.AlertStyle" value="1" type="Double" /><column name="data08" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="data08" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="data08" property="Validation.ShowInput" value="True" type="Boolean" /><column name="data08" property="Validation.ShowError" value="True" type="Boolean" /><column name="data09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data09" property="Address" value="$X$4" type="String" /><column name="data09" property="ColumnWidth" value="8.86" type="Double" /><column name="data09" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="data09" property="Validation.Type" value="2" type="Double" /><column name="data09" property="Validation.Operator" value="4" type="Double" /><column name="data09" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="data09" property="Validation.AlertStyle" value="1" type="Double" /><column name="data09" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="data09" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="data09" property="Validation.ShowInput" value="True" type="Boolean" /><column name="data09" property="Validation.ShowError" value="True" type="Boolean" /><column name="data10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data10" property="Address" value="$Y$4" type="String" /><column name="data10" property="ColumnWidth" value="8.86" type="Double" /><column name="data10" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="data10" property="Validation.Type" value="2" type="Double" /><column name="data10" property="Validation.Operator" value="4" type="Double" /><column name="data10" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="data10" property="Validation.AlertStyle" value="1" type="Double" /><column name="data10" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="data10" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="data10" property="Validation.ShowInput" value="True" type="Boolean" /><column name="data10" property="Validation.ShowError" value="True" type="Boolean" /><column name="data11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data11" property="Address" value="$Z$4" type="String" /><column name="data11" property="ColumnWidth" value="8.86" type="Double" /><column name="data11" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="data11" property="Validation.Type" value="2" type="Double" /><column name="data11" property="Validation.Operator" value="4" type="Double" /><column name="data11" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="data11" property="Validation.AlertStyle" value="1" type="Double" /><column name="data11" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="data11" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="data11" property="Validation.ShowInput" value="True" type="Boolean" /><column name="data11" property="Validation.ShowError" value="True" type="Boolean" /><column name="data12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data12" property="Address" value="$AA$4" type="String" /><column name="data12" property="ColumnWidth" value="8.86" type="Double" /><column name="data12" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="data12" property="Validation.Type" value="2" type="Double" /><column name="data12" property="Validation.Operator" value="4" type="Double" /><column name="data12" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="data12" property="Validation.AlertStyle" value="1" type="Double" /><column name="data12" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="data12" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="data12" property="Validation.ShowInput" value="True" type="Boolean" /><column name="data12" property="Validation.ShowError" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(1).AppliesToTable" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(1).AppliesTo.Address" value="$B$4:$AA$422" type="String" /><column name="_RowNum" property="FormatConditions(1).Type" value="2" type="Double" /><column name="_RowNum" property="FormatConditions(1).Priority" value="2" type="Double" /><column name="_RowNum" property="FormatConditions(1).Formula1" value="=$H4=4" type="String" /><column name="_RowNum" property="FormatConditions(1).Font.Italic" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(2).AppliesToTable" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(2).AppliesTo.Address" value="$B$4:$AA$422" type="String" /><column name="_RowNum" property="FormatConditions(2).Type" value="2" type="Double" /><column name="_RowNum" property="FormatConditions(2).Priority" value="3" type="Double" /><column name="_RowNum" property="FormatConditions(2).Formula1" value="=$H4=9" type="String" /><column name="_RowNum" property="FormatConditions(2).Font.Bold" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(2).Font.Color" value="16777215" type="Double" /><column name="_RowNum" property="FormatConditions(2).Font.ThemeColor" value="1" type="Double" /><column name="_RowNum" property="FormatConditions(2).Font.TintAndShade" value="0" type="Double" /><column name="_RowNum" property="FormatConditions(2).Interior.Color" value="6299904" type="Double" /><column name="_RowNum" property="FormatConditions(2).Interior.Color" value="6299904" type="Double" /><column name="_RowNum" property="FormatConditions(3).AppliesToTable" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(3).AppliesTo.Address" value="$B$4:$AA$422" type="String" /><column name="_RowNum" property="FormatConditions(3).Type" value="2" type="Double" /><column name="_RowNum" property="FormatConditions(3).Priority" value="4" type="Double" /><column name="_RowNum" property="FormatConditions(3).Formula1" value="=$H4=2" type="String" /><column name="_RowNum" property="FormatConditions(3).Font.Bold" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(4).AppliesToTable" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(4).AppliesTo.Address" value="$B$4:$AA$422" type="String" /><column name="_RowNum" property="FormatConditions(4).Type" value="2" type="Double" /><column name="_RowNum" property="FormatConditions(4).Priority" value="5" type="Double" /><column name="_RowNum" property="FormatConditions(4).Formula1" value="=$H4=1" type="String" /><column name="_RowNum" property="FormatConditions(4).Font.Bold" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(4).Font.Color" value="16777215" type="Double" /><column name="_RowNum" property="FormatConditions(4).Font.ThemeColor" value="1" type="Double" /><column name="_RowNum" property="FormatConditions(4).Font.TintAndShade" value="0" type="Double" /><column name="_RowNum" property="FormatConditions(4).Interior.Color" value="6773025" type="Double" /><column name="_RowNum" property="FormatConditions(4).Interior.Color" value="6773025" type="Double" /><column name="data00" property="FormatConditions(1).ColumnsCount" value="13" type="Double" /><column name="data00" property="FormatConditions(1).AppliesTo.Address" value="$O$4:$AA$422" type="String" /><column name="data00" property="FormatConditions(1).Type" value="2" type="Double" /><column name="data00" property="FormatConditions(1).Priority" value="1" type="Double" /><column name="data00" property="FormatConditions(1).Formula1" value="=$H4=4" type="String" /><column name="data00" property="FormatConditions(1).NumberFormat" value="0%" type="String" /><column name="" property="Tab.Color" value="6299648" type="Double" /><column name="" property="Tab.Color" value="6299648" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats><views><view name="All columns"><column name="" property="ListObjectName" value="report_data" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="row" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="id1" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="id2" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="form" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="level" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="format" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="hide" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="zero" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code1" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code2" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data00" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data12" property="EntireColumn.Hidden" value="False" type="Boolean" /></view><view name="Report"><column name="" property="ListObjectName" value="report_data" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="id1" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="id2" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="form" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="level" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="format" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="hide" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="zero" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="code1" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="code2" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data00" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="hide" property="AutoFilter.Criteria1" value="=1" type="String" /></view></views></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N'xls27', N'usp_budget_reports', N'<table name="xls27.usp_budget_reports"><columnFormats><column name="" property="ListObjectName" value="budget_reports" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="row_index" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_index" property="Address" value="$C$4" type="String" /><column name="row_index" property="NumberFormat" value="General" type="String" /><column name="ref_number" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="ref_number" property="Address" value="$D$4" type="String" /><column name="ref_number" property="NumberFormat" value="General" type="String" /><column name="ref_number" property="HorizontalAlignment" value="-4131" type="Double" /><column name="account" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="account" property="Address" value="$E$4" type="String" /><column name="account" property="NumberFormat" value="General" type="String" /><column name="account" property="HorizontalAlignment" value="-4131" type="Double" /><column name="report" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="report" property="Address" value="$F$4" type="String" /><column name="report" property="NumberFormat" value="General" type="String" /><column name="page_break" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="page_break" property="Address" value="$G$4" type="String" /><column name="page_break" property="NumberFormat" value="General" type="String" /><column name="row_level" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_level" property="Address" value="$H$4" type="String" /><column name="row_level" property="NumberFormat" value="General" type="String" /><column name="row_format" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_format" property="Address" value="$I$4" type="String" /><column name="row_format" property="NumberFormat" value="General" type="String" /><column name="hide" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="hide" property="Address" value="$J$4" type="String" /><column name="hide" property="NumberFormat" value="General" type="String" /><column name="zero" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="zero" property="Address" value="$K$4" type="String" /><column name="zero" property="NumberFormat" value="General" type="String" /><column name="code1" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="code1" property="Address" value="$L$4" type="String" /><column name="code1" property="NumberFormat" value="General" type="String" /><column name="code2" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="code2" property="Address" value="$M$4" type="String" /><column name="code2" property="NumberFormat" value="General" type="String" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="Address" value="$N$4" type="String" /><column name="code" property="ColumnWidth" value="6.86" type="Double" /><column name="code" property="NumberFormat" value="General" type="String" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="Address" value="$O$4" type="String" /><column name="name" property="ColumnWidth" value="55.57" type="Double" /><column name="name" property="NumberFormat" value="General" type="String" /><column name="data00" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data00" property="Address" value="$P$4" type="String" /><column name="data00" property="ColumnWidth" value="13.29" type="Double" /><column name="data00" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="data01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data01" property="Address" value="$Q$4" type="String" /><column name="data01" property="ColumnWidth" value="12.71" type="Double" /><column name="data01" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="data02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data02" property="Address" value="$R$4" type="String" /><column name="data02" property="ColumnWidth" value="12.71" type="Double" /><column name="data02" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="data03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data03" property="Address" value="$S$4" type="String" /><column name="data03" property="ColumnWidth" value="12.71" type="Double" /><column name="data03" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="data04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data04" property="Address" value="$T$4" type="String" /><column name="data04" property="ColumnWidth" value="12.71" type="Double" /><column name="data04" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="data05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data05" property="Address" value="$U$4" type="String" /><column name="data05" property="ColumnWidth" value="12.71" type="Double" /><column name="data05" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="data06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data06" property="Address" value="$V$4" type="String" /><column name="data06" property="ColumnWidth" value="12.71" type="Double" /><column name="data06" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="data07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data07" property="Address" value="$W$4" type="String" /><column name="data07" property="ColumnWidth" value="12.71" type="Double" /><column name="data07" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="data08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data08" property="Address" value="$X$4" type="String" /><column name="data08" property="ColumnWidth" value="12.71" type="Double" /><column name="data08" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="data09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data09" property="Address" value="$Y$4" type="String" /><column name="data09" property="ColumnWidth" value="12.71" type="Double" /><column name="data09" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="data10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data10" property="Address" value="$Z$4" type="String" /><column name="data10" property="ColumnWidth" value="12.71" type="Double" /><column name="data10" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="data11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data11" property="Address" value="$AA$4" type="String" /><column name="data11" property="ColumnWidth" value="12.71" type="Double" /><column name="data11" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="data12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data12" property="Address" value="$AB$4" type="String" /><column name="data12" property="ColumnWidth" value="12.71" type="Double" /><column name="data12" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="_RowNum" property="FormatConditions(1).AppliesToTable" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(1).AppliesTo.Address" value="$B$4:$AB$171" type="String" /><column name="_RowNum" property="FormatConditions(1).Type" value="2" type="Double" /><column name="_RowNum" property="FormatConditions(1).Priority" value="5" type="Double" /><column name="_RowNum" property="FormatConditions(1).Formula1" value="=$I4=8" type="String" /><column name="_RowNum" property="FormatConditions(2).AppliesToTable" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(2).AppliesTo.Address" value="$B$4:$AB$171" type="String" /><column name="_RowNum" property="FormatConditions(2).Type" value="2" type="Double" /><column name="_RowNum" property="FormatConditions(2).Priority" value="6" type="Double" /><column name="_RowNum" property="FormatConditions(2).Formula1" value="=$I4=2" type="String" /><column name="_RowNum" property="FormatConditions(2).Font.Bold" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(3).AppliesToTable" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(3).AppliesTo.Address" value="$B$4:$AB$171" type="String" /><column name="_RowNum" property="FormatConditions(3).Type" value="2" type="Double" /><column name="_RowNum" property="FormatConditions(3).Priority" value="7" type="Double" /><column name="_RowNum" property="FormatConditions(3).Formula1" value="=$I4=1" type="String" /><column name="_RowNum" property="FormatConditions(3).Font.Bold" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(3).Font.Color" value="16777215" type="Double" /><column name="_RowNum" property="FormatConditions(3).Font.ThemeColor" value="1" type="Double" /><column name="_RowNum" property="FormatConditions(3).Font.TintAndShade" value="0" type="Double" /><column name="_RowNum" property="FormatConditions(3).Interior.Color" value="6773025" type="Double" /><column name="_RowNum" property="FormatConditions(4).AppliesToTable" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(4).AppliesTo.Address" value="$B$4:$AB$171" type="String" /><column name="_RowNum" property="FormatConditions(4).Type" value="2" type="Double" /><column name="_RowNum" property="FormatConditions(4).Priority" value="8" type="Double" /><column name="_RowNum" property="FormatConditions(4).Formula1" value="=$I4=9" type="String" /><column name="_RowNum" property="FormatConditions(4).Font.Bold" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(4).Font.Color" value="16777215" type="Double" /><column name="_RowNum" property="FormatConditions(4).Font.ThemeColor" value="1" type="Double" /><column name="_RowNum" property="FormatConditions(4).Font.TintAndShade" value="0" type="Double" /><column name="_RowNum" property="FormatConditions(4).Interior.Color" value="6299904" type="Double" /><column name="" property="Tab.Color" value="5287936" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats><views><view name="All Columns"><column name="" property="ListObjectName" value="budget_reports" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="row_index" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="ref_number" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="report" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="page_break" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="row_level" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="row_format" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="hide" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="zero" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code1" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code2" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data00" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="" property="AutoFilter.Off" value="True" type="Boolean" /></view><view name="Report with References"><column name="" property="ListObjectName" value="budget_reports" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_index" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="ref_number" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="report" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="page_break" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_level" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_format" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="hide" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="zero" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="code1" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="code2" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data00" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="" property="AutoFilter.Off" value="True" type="Boolean" /></view><view name="Report with Accounts"><column name="" property="ListObjectName" value="budget_reports" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_index" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="ref_number" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="account" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="report" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="page_break" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_level" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_format" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="hide" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="zero" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="code1" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="code2" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data00" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="" property="AutoFilter.Off" value="True" type="Boolean" /></view></views></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N'xls27', N'usp_budget_request', N'<table name="xls27.usp_budget_request"><columnFormats><column name="" property="ListObjectName" value="request" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$9" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="_RowNum" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="_RowNum" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="_RowNum" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="_RowNum" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="row" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row" property="Address" value="$C$9" type="String" /><column name="row" property="NumberFormat" value="General" type="String" /><column name="row" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="row" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="format" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="format" property="Address" value="$D$9" type="String" /><column name="format" property="NumberFormat" value="General" type="String" /><column name="format" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="format" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="format" property="Validation.Type" value="1" type="Double" /><column name="format" property="Validation.Operator" value="1" type="Double" /><column name="format" property="Validation.Formula1" value="-2147483648" type="String" /><column name="format" property="Validation.Formula2" value="2147483647" type="String" /><column name="format" property="Validation.AlertStyle" value="1" type="Double" /><column name="format" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="format" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="format" property="Validation.ShowInput" value="True" type="Boolean" /><column name="format" property="Validation.ShowError" value="True" type="Boolean" /><column name="comment" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="comment" property="Address" value="$E$9" type="String" /><column name="comment" property="ColumnWidth" value="29.29" type="Double" /><column name="comment" property="NumberFormat" value="General" type="String" /><column name="comment" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="comment" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="comment" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="comment" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="comment" property="Validation.Type" value="6" type="Double" /><column name="comment" property="Validation.Operator" value="8" type="Double" /><column name="comment" property="Validation.Formula1" value="255" type="String" /><column name="comment" property="Validation.AlertStyle" value="1" type="Double" /><column name="comment" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="comment" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="comment" property="Validation.ShowInput" value="True" type="Boolean" /><column name="comment" property="Validation.ShowError" value="True" type="Boolean" /><column name="account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account_id" property="Address" value="$F$9" type="String" /><column name="account_id" property="ColumnWidth" value="16.71" type="Double" /><column name="account_id" property="NumberFormat" value="General" type="String" /><column name="account_id" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="account_id" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="account_id" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="account_id" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="account_id" property="Validation.Type" value="3" type="Double" /><column name="account_id" property="Validation.Operator" value="1" type="Double" /><column name="account_id" property="Validation.Formula1" value="=INDIRECT(&quot;vl_xls27_xl_validation_list_account_id[name]&quot;)" type="String" /><column name="account_id" property="Validation.Formula2" value="" type="String" /><column name="account_id" property="Validation.AlertStyle" value="1" type="Double" /><column name="account_id" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="account_id" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="account_id" property="Validation.ShowInput" value="True" type="Boolean" /><column name="account_id" property="Validation.ShowError" value="True" type="Boolean" /><column name="subaccount_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="subaccount_id" property="Address" value="$G$9" type="String" /><column name="subaccount_id" property="ColumnWidth" value="5" type="Double" /><column name="subaccount_id" property="NumberFormat" value="General" type="String" /><column name="subaccount_id" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="subaccount_id" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="subaccount_id" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="subaccount_id" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="subaccount_id" property="Validation.Type" value="3" type="Double" /><column name="subaccount_id" property="Validation.Operator" value="1" type="Double" /><column name="subaccount_id" property="Validation.Formula1" value="=INDIRECT(&quot;vl_xls27_xl_validation_list_subaccount_id[name]&quot;)" type="String" /><column name="subaccount_id" property="Validation.Formula2" value="" type="String" /><column name="subaccount_id" property="Validation.AlertStyle" value="1" type="Double" /><column name="subaccount_id" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="subaccount_id" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="subaccount_id" property="Validation.ShowInput" value="True" type="Boolean" /><column name="subaccount_id" property="Validation.ShowError" value="True" type="Boolean" /><column name="product_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="product_id" property="Address" value="$H$9" type="String" /><column name="product_id" property="ColumnWidth" value="5" type="Double" /><column name="product_id" property="NumberFormat" value="General" type="String" /><column name="product_id" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="product_id" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="product_id" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="product_id" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="product_id" property="Validation.Type" value="3" type="Double" /><column name="product_id" property="Validation.Operator" value="1" type="Double" /><column name="product_id" property="Validation.Formula1" value="=INDIRECT(&quot;vl_xls27_xl_validation_list_product_id[name]&quot;)" type="String" /><column name="product_id" property="Validation.Formula2" value="" type="String" /><column name="product_id" property="Validation.AlertStyle" value="1" type="Double" /><column name="product_id" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="product_id" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="product_id" property="Validation.ShowInput" value="True" type="Boolean" /><column name="product_id" property="Validation.ShowError" value="True" type="Boolean" /><column name="vat_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat_id" property="Address" value="$I$9" type="String" /><column name="vat_id" property="ColumnWidth" value="5" type="Double" /><column name="vat_id" property="NumberFormat" value="General" type="String" /><column name="vat_id" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="vat_id" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="vat_id" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="vat_id" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="vat_id" property="Validation.Type" value="3" type="Double" /><column name="vat_id" property="Validation.Operator" value="1" type="Double" /><column name="vat_id" property="Validation.Formula1" value="=INDIRECT(&quot;vl_xls27_xl_validation_list_vat_id[name]&quot;)" type="String" /><column name="vat_id" property="Validation.Formula2" value="" type="String" /><column name="vat_id" property="Validation.AlertStyle" value="1" type="Double" /><column name="vat_id" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="vat_id" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="vat_id" property="Validation.ShowInput" value="True" type="Boolean" /><column name="vat_id" property="Validation.ShowError" value="True" type="Boolean" /><column name="unit_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="unit_id" property="Address" value="$J$9" type="String" /><column name="unit_id" property="ColumnWidth" value="5" type="Double" /><column name="unit_id" property="NumberFormat" value="General" type="String" /><column name="unit_id" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="unit_id" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="unit_id" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="unit_id" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="unit_id" property="Validation.Type" value="3" type="Double" /><column name="unit_id" property="Validation.Operator" value="1" type="Double" /><column name="unit_id" property="Validation.Formula1" value="=INDIRECT(&quot;vl_xls27_xl_validation_list_unit_id[name]&quot;)" type="String" /><column name="unit_id" property="Validation.Formula2" value="" type="String" /><column name="unit_id" property="Validation.AlertStyle" value="1" type="Double" /><column name="unit_id" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="unit_id" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="unit_id" property="Validation.ShowInput" value="True" type="Boolean" /><column name="unit_id" property="Validation.ShowError" value="True" type="Boolean" /><column name="total_payments" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="total_payments" property="Address" value="$K$9" type="String" /><column name="total_payments" property="FormulaR1C1" value="=[@payments01]+[@payments02]+[@payments03]+[@payments04]+[@payments05]+[@payments06]+[@payments07]+[@payments08]+[@payments09]+[@payments10]+[@payments11]+[@payments12]" type="String" /><column name="total_payments" property="ColumnWidth" value="14.29" type="Double" /><column name="total_payments" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="total_payments" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="total_payments" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="total_payments" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="total_payments" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="total_charges" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="total_charges" property="Address" value="$L$9" type="String" /><column name="total_charges" property="FormulaR1C1" value="=[@charges01]+[@charges02]+[@charges03]+[@charges04]+[@charges05]+[@charges06]+[@charges07]+[@charges08]+[@charges09]+[@charges10]+[@charges11]+[@charges12]" type="String" /><column name="total_charges" property="ColumnWidth" value="12.14" type="Double" /><column name="total_charges" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="total_charges" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="total_charges" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="total_charges" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="total_charges" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="balance00" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance00" property="Address" value="$M$9" type="String" /><column name="balance00" property="ColumnWidth" value="11.43" type="Double" /><column name="balance00" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="balance00" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="balance00" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="balance00" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="balance00" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="balance00" property="Validation.Type" value="2" type="Double" /><column name="balance00" property="Validation.Operator" value="4" type="Double" /><column name="balance00" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="balance00" property="Validation.AlertStyle" value="1" type="Double" /><column name="balance00" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="balance00" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="balance00" property="Validation.ShowInput" value="True" type="Boolean" /><column name="balance00" property="Validation.ShowError" value="True" type="Boolean" /><column name="payments01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments01" property="Address" value="$N$9" type="String" /><column name="payments01" property="ColumnWidth" value="13.29" type="Double" /><column name="payments01" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="payments01" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="payments01" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="payments01" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="payments01" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="payments01" property="Validation.Type" value="2" type="Double" /><column name="payments01" property="Validation.Operator" value="4" type="Double" /><column name="payments01" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="payments01" property="Validation.AlertStyle" value="1" type="Double" /><column name="payments01" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="payments01" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="payments01" property="Validation.ShowInput" value="True" type="Boolean" /><column name="payments01" property="Validation.ShowError" value="True" type="Boolean" /><column name="charges01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges01" property="Address" value="$O$9" type="String" /><column name="charges01" property="ColumnWidth" value="11.29" type="Double" /><column name="charges01" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="charges01" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="charges01" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="charges01" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="charges01" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="charges01" property="Validation.Type" value="2" type="Double" /><column name="charges01" property="Validation.Operator" value="4" type="Double" /><column name="charges01" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="charges01" property="Validation.AlertStyle" value="1" type="Double" /><column name="charges01" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="charges01" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="charges01" property="Validation.ShowInput" value="True" type="Boolean" /><column name="charges01" property="Validation.ShowError" value="True" type="Boolean" /><column name="balance01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance01" property="Address" value="$P$9" type="String" /><column name="balance01" property="FormulaR1C1" value="=[@balance00]-[@payments01]+[@charges01]" type="String" /><column name="balance01" property="ColumnWidth" value="11.43" type="Double" /><column name="balance01" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="balance01" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="balance01" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="balance01" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="balance01" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="payments02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments02" property="Address" value="$Q$9" type="String" /><column name="payments02" property="FormulaR1C1" value="=RC[-2]" type="String" /><column name="payments02" property="ColumnWidth" value="13.29" type="Double" /><column name="payments02" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="payments02" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="payments02" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="payments02" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="payments02" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="payments02" property="Validation.Type" value="2" type="Double" /><column name="payments02" property="Validation.Operator" value="4" type="Double" /><column name="payments02" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="payments02" property="Validation.AlertStyle" value="1" type="Double" /><column name="payments02" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="payments02" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="payments02" property="Validation.ShowInput" value="True" type="Boolean" /><column name="payments02" property="Validation.ShowError" value="True" type="Boolean" /><column name="charges02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges02" property="Address" value="$R$9" type="String" /><column name="charges02" property="FormulaR1C1" value="=RC[-3]" type="String" /><column name="charges02" property="ColumnWidth" value="11.29" type="Double" /><column name="charges02" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="charges02" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="charges02" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="charges02" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="charges02" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="charges02" property="Validation.Type" value="2" type="Double" /><column name="charges02" property="Validation.Operator" value="4" type="Double" /><column name="charges02" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="charges02" property="Validation.AlertStyle" value="1" type="Double" /><column name="charges02" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="charges02" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="charges02" property="Validation.ShowInput" value="True" type="Boolean" /><column name="charges02" property="Validation.ShowError" value="True" type="Boolean" /><column name="balance02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance02" property="Address" value="$S$9" type="String" /><column name="balance02" property="FormulaR1C1" value="=[@balance01]-[@payments02]+[@charges02]" type="String" /><column name="balance02" property="ColumnWidth" value="11.43" type="Double" /><column name="balance02" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="balance02" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="balance02" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="balance02" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="balance02" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="payments03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments03" property="Address" value="$T$9" type="String" /><column name="payments03" property="FormulaR1C1" value="=RC[-2]" type="String" /><column name="payments03" property="ColumnWidth" value="13.29" type="Double" /><column name="payments03" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="payments03" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="payments03" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="payments03" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="payments03" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="payments03" property="Validation.Type" value="2" type="Double" /><column name="payments03" property="Validation.Operator" value="4" type="Double" /><column name="payments03" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="payments03" property="Validation.AlertStyle" value="1" type="Double" /><column name="payments03" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="payments03" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="payments03" property="Validation.ShowInput" value="True" type="Boolean" /><column name="payments03" property="Validation.ShowError" value="True" type="Boolean" /><column name="charges03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges03" property="Address" value="$U$9" type="String" /><column name="charges03" property="FormulaR1C1" value="=RC[-3]" type="String" /><column name="charges03" property="ColumnWidth" value="11.29" type="Double" /><column name="charges03" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="charges03" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="charges03" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="charges03" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="charges03" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="charges03" property="Validation.Type" value="2" type="Double" /><column name="charges03" property="Validation.Operator" value="4" type="Double" /><column name="charges03" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="charges03" property="Validation.AlertStyle" value="1" type="Double" /><column name="charges03" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="charges03" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="charges03" property="Validation.ShowInput" value="True" type="Boolean" /><column name="charges03" property="Validation.ShowError" value="True" type="Boolean" /><column name="balance03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance03" property="Address" value="$V$9" type="String" /><column name="balance03" property="FormulaR1C1" value="=[@balance02]-[@payments03]+[@charges03]" type="String" /><column name="balance03" property="ColumnWidth" value="11.43" type="Double" /><column name="balance03" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="balance03" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="balance03" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="balance03" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="balance03" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="payments04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments04" property="Address" value="$W$9" type="String" /><column name="payments04" property="FormulaR1C1" value="=RC[-2]" type="String" /><column name="payments04" property="ColumnWidth" value="13.29" type="Double" /><column name="payments04" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="payments04" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="payments04" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="payments04" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="payments04" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="payments04" property="Validation.Type" value="2" type="Double" /><column name="payments04" property="Validation.Operator" value="4" type="Double" /><column name="payments04" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="payments04" property="Validation.AlertStyle" value="1" type="Double" /><column name="payments04" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="payments04" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="payments04" property="Validation.ShowInput" value="True" type="Boolean" /><column name="payments04" property="Validation.ShowError" value="True" type="Boolean" /><column name="charges04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges04" property="Address" value="$X$9" type="String" /><column name="charges04" property="FormulaR1C1" value="=RC[-3]" type="String" /><column name="charges04" property="ColumnWidth" value="11.29" type="Double" /><column name="charges04" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="charges04" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="charges04" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="charges04" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="charges04" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="charges04" property="Validation.Type" value="2" type="Double" /><column name="charges04" property="Validation.Operator" value="4" type="Double" /><column name="charges04" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="charges04" property="Validation.AlertStyle" value="1" type="Double" /><column name="charges04" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="charges04" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="charges04" property="Validation.ShowInput" value="True" type="Boolean" /><column name="charges04" property="Validation.ShowError" value="True" type="Boolean" /><column name="balance04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance04" property="Address" value="$Y$9" type="String" /><column name="balance04" property="FormulaR1C1" value="=[@balance03]-[@payments04]+[@charges04]" type="String" /><column name="balance04" property="ColumnWidth" value="11.43" type="Double" /><column name="balance04" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="balance04" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="balance04" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="balance04" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="balance04" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="payments05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments05" property="Address" value="$Z$9" type="String" /><column name="payments05" property="FormulaR1C1" value="=RC[-2]" type="String" /><column name="payments05" property="ColumnWidth" value="13.29" type="Double" /><column name="payments05" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="payments05" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="payments05" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="payments05" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="payments05" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="payments05" property="Validation.Type" value="2" type="Double" /><column name="payments05" property="Validation.Operator" value="4" type="Double" /><column name="payments05" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="payments05" property="Validation.AlertStyle" value="1" type="Double" /><column name="payments05" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="payments05" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="payments05" property="Validation.ShowInput" value="True" type="Boolean" /><column name="payments05" property="Validation.ShowError" value="True" type="Boolean" /><column name="charges05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges05" property="Address" value="$AA$9" type="String" /><column name="charges05" property="FormulaR1C1" value="=RC[-3]" type="String" /><column name="charges05" property="ColumnWidth" value="11.29" type="Double" /><column name="charges05" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="charges05" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="charges05" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="charges05" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="charges05" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="charges05" property="Validation.Type" value="2" type="Double" /><column name="charges05" property="Validation.Operator" value="4" type="Double" /><column name="charges05" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="charges05" property="Validation.AlertStyle" value="1" type="Double" /><column name="charges05" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="charges05" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="charges05" property="Validation.ShowInput" value="True" type="Boolean" /><column name="charges05" property="Validation.ShowError" value="True" type="Boolean" /><column name="balance05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance05" property="Address" value="$AB$9" type="String" /><column name="balance05" property="FormulaR1C1" value="=[@balance04]-[@payments05]+[@charges05]" type="String" /><column name="balance05" property="ColumnWidth" value="11.43" type="Double" /><column name="balance05" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="balance05" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="balance05" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="balance05" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="balance05" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="payments06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments06" property="Address" value="$AC$9" type="String" /><column name="payments06" property="FormulaR1C1" value="=RC[-2]" type="String" /><column name="payments06" property="ColumnWidth" value="13.29" type="Double" /><column name="payments06" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="payments06" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="payments06" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="payments06" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="payments06" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="payments06" property="Validation.Type" value="2" type="Double" /><column name="payments06" property="Validation.Operator" value="4" type="Double" /><column name="payments06" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="payments06" property="Validation.AlertStyle" value="1" type="Double" /><column name="payments06" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="payments06" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="payments06" property="Validation.ShowInput" value="True" type="Boolean" /><column name="payments06" property="Validation.ShowError" value="True" type="Boolean" /><column name="charges06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges06" property="Address" value="$AD$9" type="String" /><column name="charges06" property="FormulaR1C1" value="=RC[-3]" type="String" /><column name="charges06" property="ColumnWidth" value="11.29" type="Double" /><column name="charges06" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="charges06" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="charges06" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="charges06" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="charges06" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="charges06" property="Validation.Type" value="2" type="Double" /><column name="charges06" property="Validation.Operator" value="4" type="Double" /><column name="charges06" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="charges06" property="Validation.AlertStyle" value="1" type="Double" /><column name="charges06" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="charges06" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="charges06" property="Validation.ShowInput" value="True" type="Boolean" /><column name="charges06" property="Validation.ShowError" value="True" type="Boolean" /><column name="balance06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance06" property="Address" value="$AE$9" type="String" /><column name="balance06" property="FormulaR1C1" value="=[@balance05]-[@payments06]+[@charges06]" type="String" /><column name="balance06" property="ColumnWidth" value="11.43" type="Double" /><column name="balance06" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="balance06" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="balance06" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="balance06" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="balance06" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="payments07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments07" property="Address" value="$AF$9" type="String" /><column name="payments07" property="FormulaR1C1" value="=RC[-2]" type="String" /><column name="payments07" property="ColumnWidth" value="13.29" type="Double" /><column name="payments07" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="payments07" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="payments07" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="payments07" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="payments07" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="payments07" property="Validation.Type" value="2" type="Double" /><column name="payments07" property="Validation.Operator" value="4" type="Double" /><column name="payments07" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="payments07" property="Validation.AlertStyle" value="1" type="Double" /><column name="payments07" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="payments07" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="payments07" property="Validation.ShowInput" value="True" type="Boolean" /><column name="payments07" property="Validation.ShowError" value="True" type="Boolean" /><column name="charges07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges07" property="Address" value="$AG$9" type="String" /><column name="charges07" property="FormulaR1C1" value="=RC[-3]" type="String" /><column name="charges07" property="ColumnWidth" value="11.29" type="Double" /><column name="charges07" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="charges07" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="charges07" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="charges07" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="charges07" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="charges07" property="Validation.Type" value="2" type="Double" /><column name="charges07" property="Validation.Operator" value="4" type="Double" /><column name="charges07" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="charges07" property="Validation.AlertStyle" value="1" type="Double" /><column name="charges07" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="charges07" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="charges07" property="Validation.ShowInput" value="True" type="Boolean" /><column name="charges07" property="Validation.ShowError" value="True" type="Boolean" /><column name="balance07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance07" property="Address" value="$AH$9" type="String" /><column name="balance07" property="FormulaR1C1" value="=[@balance06]-[@payments07]+[@charges07]" type="String" /><column name="balance07" property="ColumnWidth" value="11.43" type="Double" /><column name="balance07" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="balance07" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="balance07" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="balance07" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="balance07" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="payments08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments08" property="Address" value="$AI$9" type="String" /><column name="payments08" property="FormulaR1C1" value="=RC[-2]" type="String" /><column name="payments08" property="ColumnWidth" value="13.29" type="Double" /><column name="payments08" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="payments08" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="payments08" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="payments08" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="payments08" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="payments08" property="Validation.Type" value="2" type="Double" /><column name="payments08" property="Validation.Operator" value="4" type="Double" /><column name="payments08" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="payments08" property="Validation.AlertStyle" value="1" type="Double" /><column name="payments08" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="payments08" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="payments08" property="Validation.ShowInput" value="True" type="Boolean" /><column name="payments08" property="Validation.ShowError" value="True" type="Boolean" /><column name="charges08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges08" property="Address" value="$AJ$9" type="String" /><column name="charges08" property="FormulaR1C1" value="=RC[-3]" type="String" /><column name="charges08" property="ColumnWidth" value="11.29" type="Double" /><column name="charges08" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="charges08" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="charges08" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="charges08" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="charges08" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="charges08" property="Validation.Type" value="2" type="Double" /><column name="charges08" property="Validation.Operator" value="4" type="Double" /><column name="charges08" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="charges08" property="Validation.AlertStyle" value="1" type="Double" /><column name="charges08" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="charges08" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="charges08" property="Validation.ShowInput" value="True" type="Boolean" /><column name="charges08" property="Validation.ShowError" value="True" type="Boolean" /><column name="balance08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance08" property="Address" value="$AK$9" type="String" /><column name="balance08" property="FormulaR1C1" value="=[@balance07]-[@payments08]+[@charges08]" type="String" /><column name="balance08" property="ColumnWidth" value="11.43" type="Double" /><column name="balance08" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="balance08" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="balance08" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="balance08" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="balance08" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="payments09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments09" property="Address" value="$AL$9" type="String" /><column name="payments09" property="FormulaR1C1" value="=RC[-2]" type="String" /><column name="payments09" property="ColumnWidth" value="13.29" type="Double" /><column name="payments09" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="payments09" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="payments09" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="payments09" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="payments09" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="payments09" property="Validation.Type" value="2" type="Double" /><column name="payments09" property="Validation.Operator" value="4" type="Double" /><column name="payments09" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="payments09" property="Validation.AlertStyle" value="1" type="Double" /><column name="payments09" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="payments09" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="payments09" property="Validation.ShowInput" value="True" type="Boolean" /><column name="payments09" property="Validation.ShowError" value="True" type="Boolean" /><column name="charges09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges09" property="Address" value="$AM$9" type="String" /><column name="charges09" property="FormulaR1C1" value="=RC[-3]" type="String" /><column name="charges09" property="ColumnWidth" value="11.29" type="Double" /><column name="charges09" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="charges09" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="charges09" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="charges09" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="charges09" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="charges09" property="Validation.Type" value="2" type="Double" /><column name="charges09" property="Validation.Operator" value="4" type="Double" /><column name="charges09" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="charges09" property="Validation.AlertStyle" value="1" type="Double" /><column name="charges09" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="charges09" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="charges09" property="Validation.ShowInput" value="True" type="Boolean" /><column name="charges09" property="Validation.ShowError" value="True" type="Boolean" /><column name="balance09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance09" property="Address" value="$AN$9" type="String" /><column name="balance09" property="FormulaR1C1" value="=[@balance08]-[@payments09]+[@charges09]" type="String" /><column name="balance09" property="ColumnWidth" value="11.43" type="Double" /><column name="balance09" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="balance09" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="balance09" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="balance09" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="balance09" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="payments10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments10" property="Address" value="$AO$9" type="String" /><column name="payments10" property="FormulaR1C1" value="=RC[-2]" type="String" /><column name="payments10" property="ColumnWidth" value="13.29" type="Double" /><column name="payments10" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="payments10" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="payments10" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="payments10" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="payments10" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="payments10" property="Validation.Type" value="2" type="Double" /><column name="payments10" property="Validation.Operator" value="4" type="Double" /><column name="payments10" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="payments10" property="Validation.AlertStyle" value="1" type="Double" /><column name="payments10" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="payments10" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="payments10" property="Validation.ShowInput" value="True" type="Boolean" /><column name="payments10" property="Validation.ShowError" value="True" type="Boolean" /><column name="charges10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges10" property="Address" value="$AP$9" type="String" /><column name="charges10" property="FormulaR1C1" value="=RC[-3]" type="String" /><column name="charges10" property="ColumnWidth" value="11.29" type="Double" /><column name="charges10" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="charges10" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="charges10" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="charges10" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="charges10" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="charges10" property="Validation.Type" value="2" type="Double" /><column name="charges10" property="Validation.Operator" value="4" type="Double" /><column name="charges10" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="charges10" property="Validation.AlertStyle" value="1" type="Double" /><column name="charges10" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="charges10" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="charges10" property="Validation.ShowInput" value="True" type="Boolean" /><column name="charges10" property="Validation.ShowError" value="True" type="Boolean" /><column name="balance10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance10" property="Address" value="$AQ$9" type="String" /><column name="balance10" property="FormulaR1C1" value="=[@balance09]-[@payments10]+[@charges10]" type="String" /><column name="balance10" property="ColumnWidth" value="11.43" type="Double" /><column name="balance10" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="balance10" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="balance10" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="balance10" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="balance10" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="payments11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments11" property="Address" value="$AR$9" type="String" /><column name="payments11" property="FormulaR1C1" value="=RC[-2]" type="String" /><column name="payments11" property="ColumnWidth" value="13.29" type="Double" /><column name="payments11" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="payments11" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="payments11" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="payments11" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="payments11" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="payments11" property="Validation.Type" value="2" type="Double" /><column name="payments11" property="Validation.Operator" value="4" type="Double" /><column name="payments11" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="payments11" property="Validation.AlertStyle" value="1" type="Double" /><column name="payments11" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="payments11" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="payments11" property="Validation.ShowInput" value="True" type="Boolean" /><column name="payments11" property="Validation.ShowError" value="True" type="Boolean" /><column name="charges11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges11" property="Address" value="$AS$9" type="String" /><column name="charges11" property="FormulaR1C1" value="=RC[-3]" type="String" /><column name="charges11" property="ColumnWidth" value="11.29" type="Double" /><column name="charges11" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="charges11" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="charges11" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="charges11" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="charges11" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="charges11" property="Validation.Type" value="2" type="Double" /><column name="charges11" property="Validation.Operator" value="4" type="Double" /><column name="charges11" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="charges11" property="Validation.AlertStyle" value="1" type="Double" /><column name="charges11" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="charges11" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="charges11" property="Validation.ShowInput" value="True" type="Boolean" /><column name="charges11" property="Validation.ShowError" value="True" type="Boolean" /><column name="balance11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance11" property="Address" value="$AT$9" type="String" /><column name="balance11" property="FormulaR1C1" value="=[@balance10]-[@payments11]+[@charges11]" type="String" /><column name="balance11" property="ColumnWidth" value="11.43" type="Double" /><column name="balance11" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="balance11" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="balance11" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="balance11" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="balance11" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="payments12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments12" property="Address" value="$AU$9" type="String" /><column name="payments12" property="FormulaR1C1" value="=RC[-2]" type="String" /><column name="payments12" property="ColumnWidth" value="13.29" type="Double" /><column name="payments12" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="payments12" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="payments12" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="payments12" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="payments12" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="payments12" property="Validation.Type" value="2" type="Double" /><column name="payments12" property="Validation.Operator" value="4" type="Double" /><column name="payments12" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="payments12" property="Validation.AlertStyle" value="1" type="Double" /><column name="payments12" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="payments12" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="payments12" property="Validation.ShowInput" value="True" type="Boolean" /><column name="payments12" property="Validation.ShowError" value="True" type="Boolean" /><column name="charges12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges12" property="Address" value="$AV$9" type="String" /><column name="charges12" property="FormulaR1C1" value="=RC[-3]" type="String" /><column name="charges12" property="ColumnWidth" value="11.29" type="Double" /><column name="charges12" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="charges12" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="charges12" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="charges12" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="charges12" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="charges12" property="Validation.Type" value="2" type="Double" /><column name="charges12" property="Validation.Operator" value="4" type="Double" /><column name="charges12" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="charges12" property="Validation.AlertStyle" value="1" type="Double" /><column name="charges12" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="charges12" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="charges12" property="Validation.ShowInput" value="True" type="Boolean" /><column name="charges12" property="Validation.ShowError" value="True" type="Boolean" /><column name="balance12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance12" property="Address" value="$AW$9" type="String" /><column name="balance12" property="FormulaR1C1" value="=[@balance11]-[@payments12]+[@charges12]" type="String" /><column name="balance12" property="ColumnWidth" value="11.43" type="Double" /><column name="balance12" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="balance12" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="balance12" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="balance12" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="balance12" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="row_formulas" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_formulas" property="Address" value="$AX$9" type="String" /><column name="row_formulas" property="NumberFormat" value="General" type="String" /><column name="row_formulas" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="row_formulas" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="row_formulas" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="row_formulas" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="" property="AutoFilter.Off" value="True" type="Boolean" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="-1" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="8" type="Double" /><column name="" property="PageSetup.Orientation" value="2" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats><views><view name="Форма"><column name="" property="ListObjectName" value="request" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="format" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="comment" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="subaccount_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="product_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="unit_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="total_payments" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="total_charges" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance00" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="row_formulas" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="" property="AutoFilter.Off" value="True" type="Boolean" /></view><view name="Все колонки"><column name="" property="ListObjectName" value="request" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="row" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="format" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="comment" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="subaccount_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="product_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="unit_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="total_payments" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="total_charges" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance00" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="row_formulas" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="" property="AutoFilter.Off" value="True" type="Boolean" /></view></views></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N'xls27', N'usp_budget_request1', N'<table name="xls27.usp_budget_request1"><columnFormats><column name="" property="ListObjectName" value="budget_request1" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$9" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="_RowNum" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="_RowNum" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="_RowNum" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="_RowNum" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="row_index" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_index" property="Address" value="$C$9" type="String" /><column name="row_index" property="NumberFormat" value="General" type="String" /><column name="row_index" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="row_index" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="row_index" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="row_index" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="row_format" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_format" property="Address" value="$D$9" type="String" /><column name="row_format" property="NumberFormat" value="General" type="String" /><column name="row_format" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="row_format" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="row_format" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="row_format" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="description" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="description" property="Address" value="$E$9" type="String" /><column name="description" property="ColumnWidth" value="42.14" type="Double" /><column name="description" property="NumberFormat" value="General" type="String" /><column name="description" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="description" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="description" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="description" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account_id" property="Address" value="$F$9" type="String" /><column name="account_id" property="ColumnWidth" value="6.71" type="Double" /><column name="account_id" property="NumberFormat" value="@" type="String" /><column name="account_id" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="account_id" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="account_id" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="account_id" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="account_name" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="account_name" property="Address" value="$G$9" type="String" /><column name="account_name" property="NumberFormat" value="General" type="String" /><column name="account_name" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="account_name" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="account_name" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="account_name" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="subsidiary_account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="subsidiary_account_id" property="Address" value="$H$9" type="String" /><column name="subsidiary_account_id" property="ColumnWidth" value="15" type="Double" /><column name="subsidiary_account_id" property="NumberFormat" value="General" type="String" /><column name="subsidiary_account_id" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="subsidiary_account_id" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="subsidiary_account_id" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="subsidiary_account_id" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="region_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="region_id" property="Address" value="$I$9" type="String" /><column name="region_id" property="ColumnWidth" value="8.43" type="Double" /><column name="region_id" property="NumberFormat" value="General" type="String" /><column name="region_id" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="region_id" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="region_id" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="region_id" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="product_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="product_id" property="Address" value="$J$9" type="String" /><column name="product_id" property="ColumnWidth" value="5" type="Double" /><column name="product_id" property="NumberFormat" value="General" type="String" /><column name="product_id" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="product_id" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="product_id" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="product_id" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="vat_rate_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat_rate_id" property="Address" value="$K$9" type="String" /><column name="vat_rate_id" property="ColumnWidth" value="5" type="Double" /><column name="vat_rate_id" property="NumberFormat" value="General" type="String" /><column name="vat_rate_id" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="vat_rate_id" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="vat_rate_id" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="vat_rate_id" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="unit_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="unit_id" property="Address" value="$L$9" type="String" /><column name="unit_id" property="ColumnWidth" value="5" type="Double" /><column name="unit_id" property="NumberFormat" value="General" type="String" /><column name="unit_id" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="unit_id" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="unit_id" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="unit_id" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="total_payments" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="total_payments" property="Address" value="$M$9" type="String" /><column name="total_payments" property="FormulaR1C1" value="=[@payments01]+[@payments02]+[@payments03]+[@payments04]+[@payments05]+[@payments06]+[@payments07]+[@payments08]+[@payments09]+[@payments10]+[@payments11]+[@payments12]" type="String" /><column name="total_payments" property="ColumnWidth" value="16.29" type="Double" /><column name="total_payments" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="total_payments" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="total_payments" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="total_payments" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="total_payments" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="total_charges" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="total_charges" property="Address" value="$N$9" type="String" /><column name="total_charges" property="FormulaR1C1" value="=[@charges01]+[@charges02]+[@charges03]+[@charges04]+[@charges05]+[@charges06]+[@charges07]+[@charges08]+[@charges09]+[@charges10]+[@charges11]+[@charges12]" type="String" /><column name="total_charges" property="ColumnWidth" value="14.71" type="Double" /><column name="total_charges" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="total_charges" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="total_charges" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="total_charges" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="total_charges" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="balance00" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance00" property="Address" value="$O$9" type="String" /><column name="balance00" property="ColumnWidth" value="12.86" type="Double" /><column name="balance00" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="balance00" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="balance00" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="balance00" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="balance00" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="balance00" property="Validation.Type" value="2" type="Double" /><column name="balance00" property="Validation.Operator" value="4" type="Double" /><column name="balance00" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="balance00" property="Validation.AlertStyle" value="1" type="Double" /><column name="balance00" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="balance00" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="balance00" property="Validation.ShowInput" value="True" type="Boolean" /><column name="balance00" property="Validation.ShowError" value="True" type="Boolean" /><column name="payments01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments01" property="Address" value="$P$9" type="String" /><column name="payments01" property="ColumnWidth" value="13.29" type="Double" /><column name="payments01" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="payments01" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="payments01" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="payments01" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="payments01" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="payments01" property="Validation.Type" value="2" type="Double" /><column name="payments01" property="Validation.Operator" value="4" type="Double" /><column name="payments01" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="payments01" property="Validation.AlertStyle" value="1" type="Double" /><column name="payments01" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="payments01" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="payments01" property="Validation.ShowInput" value="True" type="Boolean" /><column name="payments01" property="Validation.ShowError" value="True" type="Boolean" /><column name="charges01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges01" property="Address" value="$Q$9" type="String" /><column name="charges01" property="ColumnWidth" value="13.14" type="Double" /><column name="charges01" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="charges01" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="charges01" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="charges01" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="charges01" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="charges01" property="Validation.Type" value="2" type="Double" /><column name="charges01" property="Validation.Operator" value="4" type="Double" /><column name="charges01" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="charges01" property="Validation.AlertStyle" value="1" type="Double" /><column name="charges01" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="charges01" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="charges01" property="Validation.ShowInput" value="True" type="Boolean" /><column name="charges01" property="Validation.ShowError" value="True" type="Boolean" /><column name="balance01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance01" property="Address" value="$R$9" type="String" /><column name="balance01" property="FormulaR1C1" value="=[@balance00]-[@payments01]+[@charges01]" type="String" /><column name="balance01" property="ColumnWidth" value="12.86" type="Double" /><column name="balance01" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="balance01" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="balance01" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="balance01" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="balance01" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="payments02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments02" property="Address" value="$S$9" type="String" /><column name="payments02" property="ColumnWidth" value="13.29" type="Double" /><column name="payments02" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="payments02" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="payments02" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="payments02" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="payments02" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="payments02" property="Validation.Type" value="2" type="Double" /><column name="payments02" property="Validation.Operator" value="4" type="Double" /><column name="payments02" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="payments02" property="Validation.AlertStyle" value="1" type="Double" /><column name="payments02" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="payments02" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="payments02" property="Validation.ShowInput" value="True" type="Boolean" /><column name="payments02" property="Validation.ShowError" value="True" type="Boolean" /><column name="charges02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges02" property="Address" value="$T$9" type="String" /><column name="charges02" property="ColumnWidth" value="13.14" type="Double" /><column name="charges02" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="charges02" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="charges02" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="charges02" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="charges02" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="charges02" property="Validation.Type" value="2" type="Double" /><column name="charges02" property="Validation.Operator" value="4" type="Double" /><column name="charges02" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="charges02" property="Validation.AlertStyle" value="1" type="Double" /><column name="charges02" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="charges02" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="charges02" property="Validation.ShowInput" value="True" type="Boolean" /><column name="charges02" property="Validation.ShowError" value="True" type="Boolean" /><column name="balance02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance02" property="Address" value="$U$9" type="String" /><column name="balance02" property="FormulaR1C1" value="=[@balance01]-[@payments02]+[@charges02]" type="String" /><column name="balance02" property="ColumnWidth" value="12.86" type="Double" /><column name="balance02" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="balance02" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="balance02" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="balance02" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="balance02" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="payments03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments03" property="Address" value="$V$9" type="String" /><column name="payments03" property="ColumnWidth" value="13.29" type="Double" /><column name="payments03" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="payments03" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="payments03" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="payments03" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="payments03" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="payments03" property="Validation.Type" value="2" type="Double" /><column name="payments03" property="Validation.Operator" value="4" type="Double" /><column name="payments03" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="payments03" property="Validation.AlertStyle" value="1" type="Double" /><column name="payments03" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="payments03" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="payments03" property="Validation.ShowInput" value="True" type="Boolean" /><column name="payments03" property="Validation.ShowError" value="True" type="Boolean" /><column name="charges03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges03" property="Address" value="$W$9" type="String" /><column name="charges03" property="ColumnWidth" value="13.14" type="Double" /><column name="charges03" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="charges03" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="charges03" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="charges03" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="charges03" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="charges03" property="Validation.Type" value="2" type="Double" /><column name="charges03" property="Validation.Operator" value="4" type="Double" /><column name="charges03" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="charges03" property="Validation.AlertStyle" value="1" type="Double" /><column name="charges03" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="charges03" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="charges03" property="Validation.ShowInput" value="True" type="Boolean" /><column name="charges03" property="Validation.ShowError" value="True" type="Boolean" /><column name="balance03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance03" property="Address" value="$X$9" type="String" /><column name="balance03" property="FormulaR1C1" value="=[@balance02]-[@payments03]+[@charges03]" type="String" /><column name="balance03" property="ColumnWidth" value="12.86" type="Double" /><column name="balance03" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="balance03" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="balance03" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="balance03" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="balance03" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="payments04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments04" property="Address" value="$Y$9" type="String" /><column name="payments04" property="ColumnWidth" value="13.29" type="Double" /><column name="payments04" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="payments04" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="payments04" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="payments04" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="payments04" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="payments04" property="Validation.Type" value="2" type="Double" /><column name="payments04" property="Validation.Operator" value="4" type="Double" /><column name="payments04" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="payments04" property="Validation.AlertStyle" value="1" type="Double" /><column name="payments04" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="payments04" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="payments04" property="Validation.ShowInput" value="True" type="Boolean" /><column name="payments04" property="Validation.ShowError" value="True" type="Boolean" /><column name="charges04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges04" property="Address" value="$Z$9" type="String" /><column name="charges04" property="ColumnWidth" value="13.14" type="Double" /><column name="charges04" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="charges04" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="charges04" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="charges04" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="charges04" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="charges04" property="Validation.Type" value="2" type="Double" /><column name="charges04" property="Validation.Operator" value="4" type="Double" /><column name="charges04" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="charges04" property="Validation.AlertStyle" value="1" type="Double" /><column name="charges04" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="charges04" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="charges04" property="Validation.ShowInput" value="True" type="Boolean" /><column name="charges04" property="Validation.ShowError" value="True" type="Boolean" /><column name="balance04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance04" property="Address" value="$AA$9" type="String" /><column name="balance04" property="FormulaR1C1" value="=[@balance03]-[@payments04]+[@charges04]" type="String" /><column name="balance04" property="ColumnWidth" value="12.86" type="Double" /><column name="balance04" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="balance04" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="balance04" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="balance04" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="balance04" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="payments05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments05" property="Address" value="$AB$9" type="String" /><column name="payments05" property="ColumnWidth" value="13.29" type="Double" /><column name="payments05" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="payments05" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="payments05" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="payments05" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="payments05" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="payments05" property="Validation.Type" value="2" type="Double" /><column name="payments05" property="Validation.Operator" value="4" type="Double" /><column name="payments05" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="payments05" property="Validation.AlertStyle" value="1" type="Double" /><column name="payments05" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="payments05" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="payments05" property="Validation.ShowInput" value="True" type="Boolean" /><column name="payments05" property="Validation.ShowError" value="True" type="Boolean" /><column name="charges05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges05" property="Address" value="$AC$9" type="String" /><column name="charges05" property="ColumnWidth" value="13.14" type="Double" /><column name="charges05" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="charges05" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="charges05" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="charges05" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="charges05" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="charges05" property="Validation.Type" value="2" type="Double" /><column name="charges05" property="Validation.Operator" value="4" type="Double" /><column name="charges05" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="charges05" property="Validation.AlertStyle" value="1" type="Double" /><column name="charges05" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="charges05" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="charges05" property="Validation.ShowInput" value="True" type="Boolean" /><column name="charges05" property="Validation.ShowError" value="True" type="Boolean" /><column name="balance05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance05" property="Address" value="$AD$9" type="String" /><column name="balance05" property="FormulaR1C1" value="=[@balance04]-[@payments05]+[@charges05]" type="String" /><column name="balance05" property="ColumnWidth" value="12.86" type="Double" /><column name="balance05" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="balance05" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="balance05" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="balance05" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="balance05" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="payments06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments06" property="Address" value="$AE$9" type="String" /><column name="payments06" property="ColumnWidth" value="13.29" type="Double" /><column name="payments06" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="payments06" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="payments06" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="payments06" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="payments06" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="payments06" property="Validation.Type" value="2" type="Double" /><column name="payments06" property="Validation.Operator" value="4" type="Double" /><column name="payments06" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="payments06" property="Validation.AlertStyle" value="1" type="Double" /><column name="payments06" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="payments06" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="payments06" property="Validation.ShowInput" value="True" type="Boolean" /><column name="payments06" property="Validation.ShowError" value="True" type="Boolean" /><column name="charges06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges06" property="Address" value="$AF$9" type="String" /><column name="charges06" property="ColumnWidth" value="13.14" type="Double" /><column name="charges06" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="charges06" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="charges06" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="charges06" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="charges06" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="charges06" property="Validation.Type" value="2" type="Double" /><column name="charges06" property="Validation.Operator" value="4" type="Double" /><column name="charges06" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="charges06" property="Validation.AlertStyle" value="1" type="Double" /><column name="charges06" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="charges06" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="charges06" property="Validation.ShowInput" value="True" type="Boolean" /><column name="charges06" property="Validation.ShowError" value="True" type="Boolean" /><column name="balance06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance06" property="Address" value="$AG$9" type="String" /><column name="balance06" property="FormulaR1C1" value="=[@balance05]-[@payments06]+[@charges06]" type="String" /><column name="balance06" property="ColumnWidth" value="12.86" type="Double" /><column name="balance06" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="balance06" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="balance06" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="balance06" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="balance06" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="payments07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments07" property="Address" value="$AH$9" type="String" /><column name="payments07" property="ColumnWidth" value="13.29" type="Double" /><column name="payments07" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="payments07" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="payments07" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="payments07" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="payments07" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="payments07" property="Validation.Type" value="2" type="Double" /><column name="payments07" property="Validation.Operator" value="4" type="Double" /><column name="payments07" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="payments07" property="Validation.AlertStyle" value="1" type="Double" /><column name="payments07" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="payments07" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="payments07" property="Validation.ShowInput" value="True" type="Boolean" /><column name="payments07" property="Validation.ShowError" value="True" type="Boolean" /><column name="charges07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges07" property="Address" value="$AI$9" type="String" /><column name="charges07" property="ColumnWidth" value="13.14" type="Double" /><column name="charges07" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="charges07" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="charges07" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="charges07" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="charges07" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="charges07" property="Validation.Type" value="2" type="Double" /><column name="charges07" property="Validation.Operator" value="4" type="Double" /><column name="charges07" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="charges07" property="Validation.AlertStyle" value="1" type="Double" /><column name="charges07" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="charges07" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="charges07" property="Validation.ShowInput" value="True" type="Boolean" /><column name="charges07" property="Validation.ShowError" value="True" type="Boolean" /><column name="balance07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance07" property="Address" value="$AJ$9" type="String" /><column name="balance07" property="FormulaR1C1" value="=[@balance06]-[@payments07]+[@charges07]" type="String" /><column name="balance07" property="ColumnWidth" value="12.86" type="Double" /><column name="balance07" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="balance07" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="balance07" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="balance07" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="balance07" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="payments08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments08" property="Address" value="$AK$9" type="String" /><column name="payments08" property="ColumnWidth" value="13.29" type="Double" /><column name="payments08" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="payments08" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="payments08" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="payments08" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="payments08" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="payments08" property="Validation.Type" value="2" type="Double" /><column name="payments08" property="Validation.Operator" value="4" type="Double" /><column name="payments08" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="payments08" property="Validation.AlertStyle" value="1" type="Double" /><column name="payments08" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="payments08" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="payments08" property="Validation.ShowInput" value="True" type="Boolean" /><column name="payments08" property="Validation.ShowError" value="True" type="Boolean" /><column name="charges08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges08" property="Address" value="$AL$9" type="String" /><column name="charges08" property="ColumnWidth" value="13.14" type="Double" /><column name="charges08" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="charges08" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="charges08" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="charges08" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="charges08" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="charges08" property="Validation.Type" value="2" type="Double" /><column name="charges08" property="Validation.Operator" value="4" type="Double" /><column name="charges08" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="charges08" property="Validation.AlertStyle" value="1" type="Double" /><column name="charges08" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="charges08" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="charges08" property="Validation.ShowInput" value="True" type="Boolean" /><column name="charges08" property="Validation.ShowError" value="True" type="Boolean" /><column name="balance08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance08" property="Address" value="$AM$9" type="String" /><column name="balance08" property="FormulaR1C1" value="=[@balance07]-[@payments08]+[@charges08]" type="String" /><column name="balance08" property="ColumnWidth" value="12.86" type="Double" /><column name="balance08" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="balance08" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="balance08" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="balance08" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="balance08" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="payments09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments09" property="Address" value="$AN$9" type="String" /><column name="payments09" property="ColumnWidth" value="13.29" type="Double" /><column name="payments09" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="payments09" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="payments09" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="payments09" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="payments09" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="payments09" property="Validation.Type" value="2" type="Double" /><column name="payments09" property="Validation.Operator" value="4" type="Double" /><column name="payments09" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="payments09" property="Validation.AlertStyle" value="1" type="Double" /><column name="payments09" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="payments09" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="payments09" property="Validation.ShowInput" value="True" type="Boolean" /><column name="payments09" property="Validation.ShowError" value="True" type="Boolean" /><column name="charges09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges09" property="Address" value="$AO$9" type="String" /><column name="charges09" property="ColumnWidth" value="13.14" type="Double" /><column name="charges09" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="charges09" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="charges09" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="charges09" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="charges09" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="charges09" property="Validation.Type" value="2" type="Double" /><column name="charges09" property="Validation.Operator" value="4" type="Double" /><column name="charges09" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="charges09" property="Validation.AlertStyle" value="1" type="Double" /><column name="charges09" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="charges09" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="charges09" property="Validation.ShowInput" value="True" type="Boolean" /><column name="charges09" property="Validation.ShowError" value="True" type="Boolean" /><column name="balance09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance09" property="Address" value="$AP$9" type="String" /><column name="balance09" property="FormulaR1C1" value="=[@balance08]-[@payments09]+[@charges09]" type="String" /><column name="balance09" property="ColumnWidth" value="12.86" type="Double" /><column name="balance09" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="balance09" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="balance09" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="balance09" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="balance09" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="payments10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments10" property="Address" value="$AQ$9" type="String" /><column name="payments10" property="ColumnWidth" value="13.29" type="Double" /><column name="payments10" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="payments10" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="payments10" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="payments10" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="payments10" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="payments10" property="Validation.Type" value="2" type="Double" /><column name="payments10" property="Validation.Operator" value="4" type="Double" /><column name="payments10" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="payments10" property="Validation.AlertStyle" value="1" type="Double" /><column name="payments10" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="payments10" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="payments10" property="Validation.ShowInput" value="True" type="Boolean" /><column name="payments10" property="Validation.ShowError" value="True" type="Boolean" /><column name="charges10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges10" property="Address" value="$AR$9" type="String" /><column name="charges10" property="ColumnWidth" value="13.14" type="Double" /><column name="charges10" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="charges10" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="charges10" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="charges10" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="charges10" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="charges10" property="Validation.Type" value="2" type="Double" /><column name="charges10" property="Validation.Operator" value="4" type="Double" /><column name="charges10" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="charges10" property="Validation.AlertStyle" value="1" type="Double" /><column name="charges10" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="charges10" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="charges10" property="Validation.ShowInput" value="True" type="Boolean" /><column name="charges10" property="Validation.ShowError" value="True" type="Boolean" /><column name="balance10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance10" property="Address" value="$AS$9" type="String" /><column name="balance10" property="FormulaR1C1" value="=[@balance09]-[@payments10]+[@charges10]" type="String" /><column name="balance10" property="ColumnWidth" value="12.86" type="Double" /><column name="balance10" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="balance10" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="balance10" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="balance10" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="balance10" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="payments11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments11" property="Address" value="$AT$9" type="String" /><column name="payments11" property="ColumnWidth" value="13.29" type="Double" /><column name="payments11" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="payments11" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="payments11" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="payments11" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="payments11" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="payments11" property="Validation.Type" value="2" type="Double" /><column name="payments11" property="Validation.Operator" value="4" type="Double" /><column name="payments11" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="payments11" property="Validation.AlertStyle" value="1" type="Double" /><column name="payments11" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="payments11" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="payments11" property="Validation.ShowInput" value="True" type="Boolean" /><column name="payments11" property="Validation.ShowError" value="True" type="Boolean" /><column name="charges11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges11" property="Address" value="$AU$9" type="String" /><column name="charges11" property="ColumnWidth" value="13.14" type="Double" /><column name="charges11" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="charges11" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="charges11" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="charges11" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="charges11" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="charges11" property="Validation.Type" value="2" type="Double" /><column name="charges11" property="Validation.Operator" value="4" type="Double" /><column name="charges11" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="charges11" property="Validation.AlertStyle" value="1" type="Double" /><column name="charges11" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="charges11" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="charges11" property="Validation.ShowInput" value="True" type="Boolean" /><column name="charges11" property="Validation.ShowError" value="True" type="Boolean" /><column name="balance11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance11" property="Address" value="$AV$9" type="String" /><column name="balance11" property="FormulaR1C1" value="=[@balance10]-[@payments11]+[@charges11]" type="String" /><column name="balance11" property="ColumnWidth" value="12.86" type="Double" /><column name="balance11" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="balance11" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="balance11" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="balance11" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="balance11" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="payments12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments12" property="Address" value="$AW$9" type="String" /><column name="payments12" property="ColumnWidth" value="13.29" type="Double" /><column name="payments12" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="payments12" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="payments12" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="payments12" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="payments12" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="payments12" property="Validation.Type" value="2" type="Double" /><column name="payments12" property="Validation.Operator" value="4" type="Double" /><column name="payments12" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="payments12" property="Validation.AlertStyle" value="1" type="Double" /><column name="payments12" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="payments12" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="payments12" property="Validation.ShowInput" value="True" type="Boolean" /><column name="payments12" property="Validation.ShowError" value="True" type="Boolean" /><column name="charges12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges12" property="Address" value="$AX$9" type="String" /><column name="charges12" property="ColumnWidth" value="13.14" type="Double" /><column name="charges12" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="charges12" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="charges12" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="charges12" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="charges12" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="charges12" property="Validation.Type" value="2" type="Double" /><column name="charges12" property="Validation.Operator" value="4" type="Double" /><column name="charges12" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="charges12" property="Validation.AlertStyle" value="1" type="Double" /><column name="charges12" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="charges12" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="charges12" property="Validation.ShowInput" value="True" type="Boolean" /><column name="charges12" property="Validation.ShowError" value="True" type="Boolean" /><column name="balance12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance12" property="Address" value="$AY$9" type="String" /><column name="balance12" property="FormulaR1C1" value="=[@balance11]-[@payments12]+[@charges12]" type="String" /><column name="balance12" property="ColumnWidth" value="12.86" type="Double" /><column name="balance12" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="balance12" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="balance12" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="balance12" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="balance12" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="row_formulas" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_formulas" property="Address" value="$AZ$9" type="String" /><column name="row_formulas" property="NumberFormat" value="General" type="String" /><column name="row_formulas" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="row_formulas" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="row_formulas" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="row_formulas" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="row_comments" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_comments" property="Address" value="$BA$9" type="String" /><column name="row_comments" property="NumberFormat" value="m/d/yyyy" type="String" /><column name="row_comments" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="row_comments" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="row_comments" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="row_comments" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="modified_by" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="modified_by" property="Address" value="$BB$9" type="String" /><column name="modified_by" property="NumberFormat" value="@" type="String" /><column name="modified_by" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="modified_by" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="modified_on" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="modified_on" property="Address" value="$BC$9" type="String" /><column name="modified_on" property="NumberFormat" value="m/d/yyyy" type="String" /><column name="modified_on" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="modified_on" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="_RowNum" property="FormatConditions(1).AppliesToTable" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(1).AppliesTo.Address" value="$B$9:$BC$34" type="String" /><column name="_RowNum" property="FormatConditions(1).Type" value="2" type="Double" /><column name="_RowNum" property="FormatConditions(1).Priority" value="1" type="Double" /><column name="_RowNum" property="FormatConditions(1).Formula1" value="=$D9=1" type="String" /><column name="_RowNum" property="FormatConditions(1).Font.Bold" value="True" type="Boolean" /><column name="" property="Tab.Color" value="10498160" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="-1" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="10" type="Double" /><column name="" property="PageSetup.Orientation" value="2" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /><column name="" property="PageSetup.PaperSize" value="1" type="Double" /></columnFormats><views><view name="Form"><column name="" property="ListObjectName" value="budget_request1" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_index" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_format" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="description" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account_name" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="subsidiary_account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="region_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="product_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat_rate_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="unit_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="total_payments" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="total_charges" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance00" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="row_formulas" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_comments" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="modified_by" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="modified_on" property="EntireColumn.Hidden" value="True" type="Boolean" /></view><view name="All Columns"><column name="" property="ListObjectName" value="budget_request1" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="row_index" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="row_format" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="description" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account_name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="subsidiary_account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="region_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="product_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat_rate_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="unit_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="total_payments" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="total_charges" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance00" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="row_formulas" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="row_comments" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="modified_by" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="modified_on" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="" property="AutoFilter.Off" value="True" type="Boolean" /></view><view name="Payments"><column name="" property="ListObjectName" value="budget_request1" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_index" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_format" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="description" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account_name" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="subsidiary_account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="region_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="product_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat_rate_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="unit_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="total_payments" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="total_charges" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance00" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_formulas" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_comments" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="modified_by" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="modified_on" property="EntireColumn.Hidden" value="True" type="Boolean" /></view><view name="Charges"><column name="" property="ListObjectName" value="budget_request1" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_index" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_format" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="description" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account_name" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="subsidiary_account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="region_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="product_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat_rate_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="unit_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="total_payments" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="total_charges" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance00" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_formulas" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_comments" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="modified_by" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="modified_on" property="EntireColumn.Hidden" value="True" type="Boolean" /></view><view name="Balances"><column name="" property="ListObjectName" value="budget_request1" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_index" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_format" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="description" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account_name" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="subsidiary_account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="region_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="product_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat_rate_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="unit_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="total_payments" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="total_charges" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance00" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="row_formulas" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_comments" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="modified_by" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="modified_on" property="EntireColumn.Hidden" value="True" type="Boolean" /></view><view name="Totals"><column name="" property="ListObjectName" value="budget_request1" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_index" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_format" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="description" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account_name" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="subsidiary_account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="region_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="product_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat_rate_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="unit_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="total_payments" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="total_charges" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance00" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_formulas" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_comments" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="modified_by" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="modified_on" property="EntireColumn.Hidden" value="True" type="Boolean" /></view></views></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N'xls27', N'usp_budget_request2', N'<table name="xls27.usp_budget_request2"><columnFormats><column name="" property="ListObjectName" value="budget_request2" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$9" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="_RowNum" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="_RowNum" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="_RowNum" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="_RowNum" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="row_index" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_index" property="Address" value="$C$9" type="String" /><column name="row_index" property="NumberFormat" value="General" type="String" /><column name="row_index" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="row_index" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="row_format" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_format" property="Address" value="$D$9" type="String" /><column name="row_format" property="NumberFormat" value="General" type="String" /><column name="row_format" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="row_format" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="description" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="description" property="Address" value="$E$9" type="String" /><column name="description" property="ColumnWidth" value="42.14" type="Double" /><column name="description" property="NumberFormat" value="General" type="String" /><column name="description" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="description" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="description" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="description" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account_id" property="Address" value="$F$9" type="String" /><column name="account_id" property="ColumnWidth" value="6.71" type="Double" /><column name="account_id" property="NumberFormat" value="@" type="String" /><column name="account_id" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="account_id" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="account_id" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="account_id" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="account_name" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="account_name" property="Address" value="$G$9" type="String" /><column name="account_name" property="NumberFormat" value="General" type="String" /><column name="account_name" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="account_name" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="account_name" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="account_name" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="subsidiary_account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="subsidiary_account_id" property="Address" value="$H$9" type="String" /><column name="subsidiary_account_id" property="ColumnWidth" value="15" type="Double" /><column name="subsidiary_account_id" property="NumberFormat" value="General" type="String" /><column name="subsidiary_account_id" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="subsidiary_account_id" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="subsidiary_account_id" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="subsidiary_account_id" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="region_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="region_id" property="Address" value="$I$9" type="String" /><column name="region_id" property="ColumnWidth" value="8.43" type="Double" /><column name="region_id" property="NumberFormat" value="General" type="String" /><column name="region_id" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="region_id" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="region_id" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="region_id" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="product_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="product_id" property="Address" value="$J$9" type="String" /><column name="product_id" property="ColumnWidth" value="5" type="Double" /><column name="product_id" property="NumberFormat" value="General" type="String" /><column name="product_id" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="product_id" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="product_id" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="product_id" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="vat_rate_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat_rate_id" property="Address" value="$K$9" type="String" /><column name="vat_rate_id" property="ColumnWidth" value="5" type="Double" /><column name="vat_rate_id" property="NumberFormat" value="General" type="String" /><column name="vat_rate_id" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="vat_rate_id" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="vat_rate_id" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="vat_rate_id" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="unit_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="unit_id" property="Address" value="$L$9" type="String" /><column name="unit_id" property="ColumnWidth" value="5" type="Double" /><column name="unit_id" property="NumberFormat" value="General" type="String" /><column name="unit_id" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="unit_id" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="unit_id" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="unit_id" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="total_payments" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="total_payments" property="Address" value="$M$9" type="String" /><column name="total_payments" property="FormulaR1C1" value="=[@payments01]+[@payments02]+[@payments03]+[@payments04]+[@payments05]+[@payments06]+[@payments07]+[@payments08]+[@payments09]+[@payments10]+[@payments11]+[@payments12]" type="String" /><column name="total_payments" property="ColumnWidth" value="16.29" type="Double" /><column name="total_payments" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="total_payments" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="total_payments" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="total_payments" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="total_payments" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="total_charges" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="total_charges" property="Address" value="$N$9" type="String" /><column name="total_charges" property="FormulaR1C1" value="=[@charges01]+[@charges02]+[@charges03]+[@charges04]+[@charges05]+[@charges06]+[@charges07]+[@charges08]+[@charges09]+[@charges10]+[@charges11]+[@charges12]" type="String" /><column name="total_charges" property="ColumnWidth" value="14.71" type="Double" /><column name="total_charges" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="total_charges" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="total_charges" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="total_charges" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="total_charges" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="balance00" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance00" property="Address" value="$O$9" type="String" /><column name="balance00" property="ColumnWidth" value="12.86" type="Double" /><column name="balance00" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="balance00" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="balance00" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="balance00" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="balance00" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="charges01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges01" property="Address" value="$P$9" type="String" /><column name="charges01" property="ColumnWidth" value="13.14" type="Double" /><column name="charges01" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="charges01" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="charges01" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="charges01" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="charges01" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="charges02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges02" property="Address" value="$Q$9" type="String" /><column name="charges02" property="ColumnWidth" value="13.14" type="Double" /><column name="charges02" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="charges02" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="charges02" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="charges02" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="charges02" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="charges03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges03" property="Address" value="$R$9" type="String" /><column name="charges03" property="ColumnWidth" value="13.14" type="Double" /><column name="charges03" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="charges03" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="charges03" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="charges03" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="charges03" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="charges04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges04" property="Address" value="$S$9" type="String" /><column name="charges04" property="ColumnWidth" value="13.14" type="Double" /><column name="charges04" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="charges04" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="charges04" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="charges04" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="charges04" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="charges05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges05" property="Address" value="$T$9" type="String" /><column name="charges05" property="ColumnWidth" value="13.14" type="Double" /><column name="charges05" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="charges05" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="charges05" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="charges05" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="charges05" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="charges06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges06" property="Address" value="$U$9" type="String" /><column name="charges06" property="ColumnWidth" value="13.14" type="Double" /><column name="charges06" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="charges06" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="charges06" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="charges06" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="charges06" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="charges07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges07" property="Address" value="$V$9" type="String" /><column name="charges07" property="ColumnWidth" value="13.14" type="Double" /><column name="charges07" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="charges07" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="charges07" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="charges07" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="charges07" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="charges08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges08" property="Address" value="$W$9" type="String" /><column name="charges08" property="ColumnWidth" value="13.14" type="Double" /><column name="charges08" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="charges08" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="charges08" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="charges08" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="charges08" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="charges09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges09" property="Address" value="$X$9" type="String" /><column name="charges09" property="ColumnWidth" value="13.14" type="Double" /><column name="charges09" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="charges09" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="charges09" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="charges09" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="charges09" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="charges10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges10" property="Address" value="$Y$9" type="String" /><column name="charges10" property="ColumnWidth" value="13.14" type="Double" /><column name="charges10" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="charges10" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="charges10" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="charges10" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="charges10" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="charges11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges11" property="Address" value="$Z$9" type="String" /><column name="charges11" property="ColumnWidth" value="13.14" type="Double" /><column name="charges11" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="charges11" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="charges11" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="charges11" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="charges11" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="charges12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges12" property="Address" value="$AA$9" type="String" /><column name="charges12" property="ColumnWidth" value="13.14" type="Double" /><column name="charges12" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="charges12" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="charges12" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="charges12" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="charges12" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="payments01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments01" property="Address" value="$AB$9" type="String" /><column name="payments01" property="ColumnWidth" value="13.29" type="Double" /><column name="payments01" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="payments01" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="payments01" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="payments01" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="payments01" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="payments02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments02" property="Address" value="$AC$9" type="String" /><column name="payments02" property="ColumnWidth" value="13.29" type="Double" /><column name="payments02" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="payments02" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="payments02" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="payments02" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="payments02" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="payments03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments03" property="Address" value="$AD$9" type="String" /><column name="payments03" property="ColumnWidth" value="13.29" type="Double" /><column name="payments03" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="payments03" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="payments03" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="payments03" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="payments03" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="payments04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments04" property="Address" value="$AE$9" type="String" /><column name="payments04" property="ColumnWidth" value="13.29" type="Double" /><column name="payments04" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="payments04" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="payments04" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="payments04" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="payments04" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="payments05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments05" property="Address" value="$AF$9" type="String" /><column name="payments05" property="ColumnWidth" value="13.29" type="Double" /><column name="payments05" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="payments05" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="payments05" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="payments05" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="payments05" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="payments06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments06" property="Address" value="$AG$9" type="String" /><column name="payments06" property="ColumnWidth" value="13.29" type="Double" /><column name="payments06" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="payments06" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="payments06" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="payments06" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="payments06" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="payments07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments07" property="Address" value="$AH$9" type="String" /><column name="payments07" property="ColumnWidth" value="13.29" type="Double" /><column name="payments07" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="payments07" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="payments07" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="payments07" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="payments07" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="payments08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments08" property="Address" value="$AI$9" type="String" /><column name="payments08" property="ColumnWidth" value="13.29" type="Double" /><column name="payments08" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="payments08" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="payments08" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="payments08" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="payments08" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="payments09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments09" property="Address" value="$AJ$9" type="String" /><column name="payments09" property="ColumnWidth" value="13.29" type="Double" /><column name="payments09" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="payments09" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="payments09" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="payments09" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="payments09" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="payments10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments10" property="Address" value="$AK$9" type="String" /><column name="payments10" property="ColumnWidth" value="13.29" type="Double" /><column name="payments10" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="payments10" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="payments10" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="payments10" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="payments10" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="payments11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments11" property="Address" value="$AL$9" type="String" /><column name="payments11" property="ColumnWidth" value="13.29" type="Double" /><column name="payments11" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="payments11" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="payments11" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="payments11" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="payments11" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="payments12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments12" property="Address" value="$AM$9" type="String" /><column name="payments12" property="ColumnWidth" value="13.29" type="Double" /><column name="payments12" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="payments12" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="payments12" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="payments12" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="payments12" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="balance01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance01" property="Address" value="$AN$9" type="String" /><column name="balance01" property="FormulaR1C1" value="=[@balance00]-[@payments01]+[@charges01]" type="String" /><column name="balance01" property="ColumnWidth" value="12.86" type="Double" /><column name="balance01" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="balance01" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="balance01" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="balance01" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="balance01" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="balance02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance02" property="Address" value="$AO$9" type="String" /><column name="balance02" property="FormulaR1C1" value="=[@balance01]-[@payments02]+[@charges02]" type="String" /><column name="balance02" property="ColumnWidth" value="12.86" type="Double" /><column name="balance02" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="balance02" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="balance02" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="balance02" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="balance02" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="balance03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance03" property="Address" value="$AP$9" type="String" /><column name="balance03" property="FormulaR1C1" value="=[@balance02]-[@payments03]+[@charges03]" type="String" /><column name="balance03" property="ColumnWidth" value="12.86" type="Double" /><column name="balance03" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="balance03" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="balance03" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="balance03" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="balance03" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="balance04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance04" property="Address" value="$AQ$9" type="String" /><column name="balance04" property="FormulaR1C1" value="=[@balance03]-[@payments04]+[@charges04]" type="String" /><column name="balance04" property="ColumnWidth" value="12.86" type="Double" /><column name="balance04" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="balance04" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="balance04" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="balance04" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="balance04" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="balance05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance05" property="Address" value="$AR$9" type="String" /><column name="balance05" property="FormulaR1C1" value="=[@balance04]-[@payments05]+[@charges05]" type="String" /><column name="balance05" property="ColumnWidth" value="12.86" type="Double" /><column name="balance05" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="balance05" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="balance05" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="balance05" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="balance05" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="balance06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance06" property="Address" value="$AS$9" type="String" /><column name="balance06" property="FormulaR1C1" value="=[@balance05]-[@payments06]+[@charges06]" type="String" /><column name="balance06" property="ColumnWidth" value="12.86" type="Double" /><column name="balance06" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="balance06" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="balance06" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="balance06" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="balance06" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="balance07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance07" property="Address" value="$AT$9" type="String" /><column name="balance07" property="FormulaR1C1" value="=[@balance06]-[@payments07]+[@charges07]" type="String" /><column name="balance07" property="ColumnWidth" value="12.86" type="Double" /><column name="balance07" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="balance07" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="balance07" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="balance07" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="balance07" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="balance08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance08" property="Address" value="$AU$9" type="String" /><column name="balance08" property="FormulaR1C1" value="=[@balance07]-[@payments08]+[@charges08]" type="String" /><column name="balance08" property="ColumnWidth" value="12.86" type="Double" /><column name="balance08" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="balance08" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="balance08" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="balance08" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="balance08" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="balance09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance09" property="Address" value="$AV$9" type="String" /><column name="balance09" property="FormulaR1C1" value="=[@balance08]-[@payments09]+[@charges09]" type="String" /><column name="balance09" property="ColumnWidth" value="12.86" type="Double" /><column name="balance09" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="balance09" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="balance09" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="balance09" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="balance09" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="balance10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance10" property="Address" value="$AW$9" type="String" /><column name="balance10" property="FormulaR1C1" value="=[@balance09]-[@payments10]+[@charges10]" type="String" /><column name="balance10" property="ColumnWidth" value="12.86" type="Double" /><column name="balance10" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="balance10" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="balance10" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="balance10" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="balance10" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="balance11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance11" property="Address" value="$AX$9" type="String" /><column name="balance11" property="FormulaR1C1" value="=[@balance10]-[@payments11]+[@charges11]" type="String" /><column name="balance11" property="ColumnWidth" value="12.86" type="Double" /><column name="balance11" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="balance11" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="balance11" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="balance11" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="balance11" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="balance12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance12" property="Address" value="$AY$9" type="String" /><column name="balance12" property="FormulaR1C1" value="=[@balance11]-[@payments12]+[@charges12]" type="String" /><column name="balance12" property="ColumnWidth" value="12.86" type="Double" /><column name="balance12" property="NumberFormat" value="#,##0.00;-#,##0.00;" type="String" /><column name="balance12" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="balance12" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="balance12" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="balance12" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="row_formulas" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_formulas" property="Address" value="$AZ$9" type="String" /><column name="row_formulas" property="NumberFormat" value="General" type="String" /><column name="row_formulas" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="row_formulas" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="row_formulas" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="row_formulas" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="row_comments" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_comments" property="Address" value="$BA$9" type="String" /><column name="row_comments" property="NumberFormat" value="m/d/yyyy" type="String" /><column name="row_comments" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="row_comments" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="row_comments" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="row_comments" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="modified_by" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="modified_by" property="Address" value="$BB$9" type="String" /><column name="modified_by" property="NumberFormat" value="@" type="String" /><column name="modified_by" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="modified_by" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="modified_by" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="modified_by" property="BorderxlEdgeRight.Weight" value="2" type="Double" /><column name="modified_on" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="modified_on" property="Address" value="$BC$9" type="String" /><column name="modified_on" property="NumberFormat" value="m/d/yyyy" type="String" /><column name="modified_on" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="modified_on" property="BorderxlEdgeLeft.Weight" value="2" type="Double" /><column name="modified_on" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="modified_on" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="_RowNum" property="FormatConditions(1).AppliesToTable" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(1).AppliesTo.Address" value="$B$9:$BC$34" type="String" /><column name="_RowNum" property="FormatConditions(1).Type" value="2" type="Double" /><column name="_RowNum" property="FormatConditions(1).Priority" value="1" type="Double" /><column name="_RowNum" property="FormatConditions(1).Formula1" value="=$D9=1" type="String" /><column name="_RowNum" property="FormatConditions(1).Font.Bold" value="True" type="Boolean" /><column name="" property="Tab.Color" value="10498160" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="-1" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="10" type="Double" /><column name="" property="PageSetup.Orientation" value="2" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /><column name="" property="PageSetup.PaperSize" value="1" type="Double" /></columnFormats><views><view name="Form"><column name="" property="ListObjectName" value="budget_request2" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_index" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_format" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="description" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account_name" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="subsidiary_account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="region_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="product_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat_rate_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="unit_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="total_payments" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="total_charges" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance00" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="row_formulas" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_comments" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="modified_by" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="modified_on" property="EntireColumn.Hidden" value="True" type="Boolean" /></view><view name="All Columns"><column name="" property="ListObjectName" value="budget_request2" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="row_index" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="row_format" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="description" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account_name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="subsidiary_account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="region_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="product_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat_rate_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="unit_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="total_payments" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="total_charges" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance00" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="row_formulas" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="row_comments" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="modified_by" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="modified_on" property="EntireColumn.Hidden" value="False" type="Boolean" /></view><view name="Payments"><column name="" property="ListObjectName" value="budget_request2" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_index" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_format" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="description" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account_name" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="subsidiary_account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="region_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="product_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat_rate_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="unit_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="total_payments" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="total_charges" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance00" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_formulas" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_comments" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="modified_by" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="modified_on" property="EntireColumn.Hidden" value="True" type="Boolean" /></view><view name="Charges"><column name="" property="ListObjectName" value="budget_request2" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_index" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_format" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="description" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account_name" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="subsidiary_account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="region_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="product_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat_rate_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="unit_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="total_payments" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="total_charges" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance00" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_formulas" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_comments" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="modified_by" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="modified_on" property="EntireColumn.Hidden" value="True" type="Boolean" /></view><view name="Balances"><column name="" property="ListObjectName" value="budget_request2" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_index" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_format" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="description" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account_name" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="subsidiary_account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="region_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="product_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat_rate_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="unit_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="total_payments" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="total_charges" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance00" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="row_formulas" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_comments" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="modified_by" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="modified_on" property="EntireColumn.Hidden" value="True" type="Boolean" /></view><view name="Totals"><column name="" property="ListObjectName" value="budget_request2" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_index" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_format" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="description" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account_name" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="subsidiary_account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="region_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="product_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat_rate_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="unit_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="total_payments" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="total_charges" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="balance00" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charges12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payments12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance01" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance02" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance03" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance04" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance05" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance06" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance07" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance08" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance09" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance10" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance11" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="balance12" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_formulas" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_comments" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="modified_by" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="modified_on" property="EntireColumn.Hidden" value="True" type="Boolean" /></view></views></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N'xls27', N'usp_budget_requests', N'<table name="xls27.usp_budget_requests"><columnFormats><column name="" property="ListObjectName" value="budget_requests" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="category_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="category_id" property="Address" value="$C$4" type="String" /><column name="category_id" property="NumberFormat" value="General" type="String" /><column name="time_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="time_id" property="Address" value="$D$4" type="String" /><column name="time_id" property="NumberFormat" value="General" type="String" /><column name="entity_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="entity_id" property="Address" value="$E$4" type="String" /><column name="entity_id" property="NumberFormat" value="General" type="String" /><column name="category_name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="category_name" property="Address" value="$F$4" type="String" /><column name="category_name" property="ColumnWidth" value="26.57" type="Double" /><column name="category_name" property="NumberFormat" value="General" type="String" /><column name="period_name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="period_name" property="Address" value="$G$4" type="String" /><column name="period_name" property="ColumnWidth" value="25.29" type="Double" /><column name="period_name" property="NumberFormat" value="General" type="String" /><column name="entity_name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="entity_name" property="Address" value="$H$4" type="String" /><column name="entity_name" property="ColumnWidth" value="32.14" type="Double" /><column name="entity_name" property="NumberFormat" value="General" type="String" /><column name="rows" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="rows" property="Address" value="$I$4" type="String" /><column name="rows" property="ColumnWidth" value="17.43" type="Double" /><column name="rows" property="NumberFormat" value="General" type="String" /><column name="modified_on" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="modified_on" property="Address" value="$J$4" type="String" /><column name="modified_on" property="ColumnWidth" value="12.57" type="Double" /><column name="modified_on" property="NumberFormat" value="m/d/yyyy" type="String" /><column name="" property="Tab.Color" value="10498160" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats><views><view name="Form"><column name="" property="ListObjectName" value="budget_requests" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="category_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="time_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="entity_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="category_name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="period_name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="entity_name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="rows" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="modified_on" property="EntireColumn.Hidden" value="False" type="Boolean" /></view><view name="All Columns"><column name="" property="ListObjectName" value="budget_requests" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="category_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="time_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="entity_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="category_name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="period_name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="entity_name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="rows" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="modified_on" property="EntireColumn.Hidden" value="False" type="Boolean" /></view></views></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N'xls27', N'usp_budget_requests_totals', N'<table name="xls27.usp_budget_requests_totals"><columnFormats><column name="" property="ListObjectName" value="budget_requests_totals" type="String" /><column name="" property="ShowTotals" value="True" type="Boolean" /><column name="cf" property="TotalsCalculation" value="1" type="Double" /><column name="pl" property="TotalsCalculation" value="1" type="Double" /><column name="assets" property="TotalsCalculation" value="1" type="Double" /><column name="vat" property="TotalsCalculation" value="1" type="Double" /><column name="bs" property="TotalsCalculation" value="1" type="Double" /><column name="vat_credit_type_id" property="TotalsCalculation" value="1" type="Double" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="Address" value="$C$4" type="String" /><column name="code" property="ColumnWidth" value="6.86" type="Double" /><column name="code" property="NumberFormat" value="General" type="String" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="Address" value="$D$4" type="String" /><column name="name" property="ColumnWidth" value="55.86" type="Double" /><column name="name" property="NumberFormat" value="General" type="String" /><column name="type" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="type" property="Address" value="$E$4" type="String" /><column name="type" property="ColumnWidth" value="30.43" type="Double" /><column name="type" property="NumberFormat" value="General" type="String" /><column name="payments" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments" property="Address" value="$F$4" type="String" /><column name="payments" property="ColumnWidth" value="13" type="Double" /><column name="payments" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="charges" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges" property="Address" value="$G$4" type="String" /><column name="charges" property="ColumnWidth" value="13.43" type="Double" /><column name="charges" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="cf" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf" property="Address" value="$H$4" type="String" /><column name="cf" property="ColumnWidth" value="12.43" type="Double" /><column name="cf" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="pl" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl" property="Address" value="$I$4" type="String" /><column name="pl" property="ColumnWidth" value="12.43" type="Double" /><column name="pl" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="assets" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="assets" property="Address" value="$J$4" type="String" /><column name="assets" property="ColumnWidth" value="10.86" type="Double" /><column name="assets" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="vat" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat" property="Address" value="$K$4" type="String" /><column name="vat" property="ColumnWidth" value="11.57" type="Double" /><column name="vat" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="bs" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bs" property="Address" value="$L$4" type="String" /><column name="bs" property="ColumnWidth" value="11.57" type="Double" /><column name="bs" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="payment_debit" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payment_debit" property="Address" value="$M$4" type="String" /><column name="payment_debit" property="ColumnWidth" value="6.43" type="Double" /><column name="payment_debit" property="NumberFormat" value="General" type="String" /><column name="payment_credit" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payment_credit" property="Address" value="$N$4" type="String" /><column name="payment_credit" property="ColumnWidth" value="6.43" type="Double" /><column name="payment_credit" property="NumberFormat" value="General" type="String" /><column name="charge_debit" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charge_debit" property="Address" value="$O$4" type="String" /><column name="charge_debit" property="ColumnWidth" value="6.43" type="Double" /><column name="charge_debit" property="NumberFormat" value="General" type="String" /><column name="charge_credit" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charge_credit" property="Address" value="$P$4" type="String" /><column name="charge_credit" property="ColumnWidth" value="6.43" type="Double" /><column name="charge_credit" property="NumberFormat" value="General" type="String" /><column name="vat_debit" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat_debit" property="Address" value="$Q$4" type="String" /><column name="vat_debit" property="ColumnWidth" value="6.43" type="Double" /><column name="vat_debit" property="NumberFormat" value="General" type="String" /><column name="vat_credit" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat_credit" property="Address" value="$R$4" type="String" /><column name="vat_credit" property="ColumnWidth" value="6.43" type="Double" /><column name="vat_credit" property="NumberFormat" value="General" type="String" /><column name="payment_debit_type_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payment_debit_type_id" property="Address" value="$S$4" type="String" /><column name="payment_debit_type_id" property="NumberFormat" value="General" type="String" /><column name="payment_credit_type_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payment_credit_type_id" property="Address" value="$T$4" type="String" /><column name="payment_credit_type_id" property="NumberFormat" value="General" type="String" /><column name="charge_debit_type_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charge_debit_type_id" property="Address" value="$U$4" type="String" /><column name="charge_debit_type_id" property="NumberFormat" value="General" type="String" /><column name="charge_credit_type_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charge_credit_type_id" property="Address" value="$V$4" type="String" /><column name="charge_credit_type_id" property="NumberFormat" value="General" type="String" /><column name="vat_debit_type_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat_debit_type_id" property="Address" value="$W$4" type="String" /><column name="vat_debit_type_id" property="NumberFormat" value="General" type="String" /><column name="vat_credit_type_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat_credit_type_id" property="Address" value="$X$4" type="String" /><column name="vat_credit_type_id" property="NumberFormat" value="General" type="String" /><column name="payment_debit" property="FormatConditions(1).AppliesTo.Address" value="$M$4:$M$38" type="String" /><column name="payment_debit" property="FormatConditions(1).Type" value="2" type="Double" /><column name="payment_debit" property="FormatConditions(1).Priority" value="16" type="Double" /><column name="payment_debit" property="FormatConditions(1).StopIfTrue" value="True" type="Boolean" /><column name="payment_debit" property="FormatConditions(1).Formula1" value="=AND($S4=0,$M4&lt;&gt;&quot;&quot;)" type="String" /><column name="payment_debit" property="FormatConditions(1).Interior.Color" value="255" type="Double" /><column name="payment_debit" property="FormatConditions(2).AppliesTo.Address" value="$M$4:$M$38" type="String" /><column name="payment_debit" property="FormatConditions(2).Type" value="2" type="Double" /><column name="payment_debit" property="FormatConditions(2).Priority" value="19" type="Double" /><column name="payment_debit" property="FormatConditions(2).StopIfTrue" value="True" type="Boolean" /><column name="payment_debit" property="FormatConditions(2).Formula1" value="=$S4=2" type="String" /><column name="payment_debit" property="FormatConditions(2).Interior.Color" value="10284031" type="Double" /><column name="payment_debit" property="FormatConditions(3).AppliesTo.Address" value="$M$4:$M$38" type="String" /><column name="payment_debit" property="FormatConditions(3).Type" value="2" type="Double" /><column name="payment_debit" property="FormatConditions(3).Priority" value="20" type="Double" /><column name="payment_debit" property="FormatConditions(3).StopIfTrue" value="True" type="Boolean" /><column name="payment_debit" property="FormatConditions(3).Formula1" value="=$S4=1" type="String" /><column name="payment_debit" property="FormatConditions(3).Interior.Color" value="13561798" type="Double" /><column name="payment_credit" property="FormatConditions(1).AppliesTo.Address" value="$N$4:$N$38" type="String" /><column name="payment_credit" property="FormatConditions(1).Type" value="2" type="Double" /><column name="payment_credit" property="FormatConditions(1).Priority" value="15" type="Double" /><column name="payment_credit" property="FormatConditions(1).StopIfTrue" value="True" type="Boolean" /><column name="payment_credit" property="FormatConditions(1).Formula1" value="=AND($T4=0,$N4&lt;&gt;&quot;&quot;)" type="String" /><column name="payment_credit" property="FormatConditions(1).Interior.Color" value="255" type="Double" /><column name="payment_credit" property="FormatConditions(2).AppliesTo.Address" value="$N$4:$N$38" type="String" /><column name="payment_credit" property="FormatConditions(2).Type" value="2" type="Double" /><column name="payment_credit" property="FormatConditions(2).Priority" value="17" type="Double" /><column name="payment_credit" property="FormatConditions(2).StopIfTrue" value="True" type="Boolean" /><column name="payment_credit" property="FormatConditions(2).Formula1" value="=$S4=1" type="String" /><column name="payment_credit" property="FormatConditions(2).Interior.Color" value="10284031" type="Double" /><column name="payment_credit" property="FormatConditions(3).AppliesTo.Address" value="$N$4:$N$38" type="String" /><column name="payment_credit" property="FormatConditions(3).Type" value="2" type="Double" /><column name="payment_credit" property="FormatConditions(3).Priority" value="18" type="Double" /><column name="payment_credit" property="FormatConditions(3).StopIfTrue" value="True" type="Boolean" /><column name="payment_credit" property="FormatConditions(3).Formula1" value="=$S4=2" type="String" /><column name="payment_credit" property="FormatConditions(3).Interior.Color" value="13561798" type="Double" /><column name="charge_debit" property="FormatConditions(1).AppliesTo.Address" value="$O$4:$O$38" type="String" /><column name="charge_debit" property="FormatConditions(1).Type" value="2" type="Double" /><column name="charge_debit" property="FormatConditions(1).Priority" value="12" type="Double" /><column name="charge_debit" property="FormatConditions(1).StopIfTrue" value="True" type="Boolean" /><column name="charge_debit" property="FormatConditions(1).Formula1" value="=AND($U4=0,$O4&lt;&gt;&quot;&quot;)" type="String" /><column name="charge_debit" property="FormatConditions(1).Interior.Color" value="255" type="Double" /><column name="charge_debit" property="FormatConditions(2).AppliesTo.Address" value="$O$4:$O$38" type="String" /><column name="charge_debit" property="FormatConditions(2).Type" value="2" type="Double" /><column name="charge_debit" property="FormatConditions(2).Priority" value="13" type="Double" /><column name="charge_debit" property="FormatConditions(2).StopIfTrue" value="True" type="Boolean" /><column name="charge_debit" property="FormatConditions(2).Formula1" value="=$U4=2" type="String" /><column name="charge_debit" property="FormatConditions(2).Interior.Color" value="10284031" type="Double" /><column name="charge_debit" property="FormatConditions(3).AppliesTo.Address" value="$O$4:$O$38" type="String" /><column name="charge_debit" property="FormatConditions(3).Type" value="2" type="Double" /><column name="charge_debit" property="FormatConditions(3).Priority" value="14" type="Double" /><column name="charge_debit" property="FormatConditions(3).StopIfTrue" value="True" type="Boolean" /><column name="charge_debit" property="FormatConditions(3).Formula1" value="=$U4=3" type="String" /><column name="charge_debit" property="FormatConditions(3).Interior.Color" value="13551615" type="Double" /><column name="charge_credit" property="FormatConditions(1).AppliesTo.Address" value="$P$4:$P$38" type="String" /><column name="charge_credit" property="FormatConditions(1).Type" value="2" type="Double" /><column name="charge_credit" property="FormatConditions(1).Priority" value="9" type="Double" /><column name="charge_credit" property="FormatConditions(1).StopIfTrue" value="True" type="Boolean" /><column name="charge_credit" property="FormatConditions(1).Formula1" value="=AND($U4=0,$P4&lt;&gt;&quot;&quot;)" type="String" /><column name="charge_credit" property="FormatConditions(1).Interior.Color" value="255" type="Double" /><column name="charge_credit" property="FormatConditions(2).AppliesTo.Address" value="$P$4:$P$38" type="String" /><column name="charge_credit" property="FormatConditions(2).Type" value="2" type="Double" /><column name="charge_credit" property="FormatConditions(2).Priority" value="10" type="Double" /><column name="charge_credit" property="FormatConditions(2).StopIfTrue" value="True" type="Boolean" /><column name="charge_credit" property="FormatConditions(2).Formula1" value="=$V4=2" type="String" /><column name="charge_credit" property="FormatConditions(2).Interior.Color" value="10284031" type="Double" /><column name="charge_credit" property="FormatConditions(3).AppliesTo.Address" value="$P$4:$P$38" type="String" /><column name="charge_credit" property="FormatConditions(3).Type" value="2" type="Double" /><column name="charge_credit" property="FormatConditions(3).Priority" value="11" type="Double" /><column name="charge_credit" property="FormatConditions(3).StopIfTrue" value="True" type="Boolean" /><column name="charge_credit" property="FormatConditions(3).Formula1" value="=$V4=3" type="String" /><column name="charge_credit" property="FormatConditions(3).Interior.Color" value="13551615" type="Double" /><column name="vat_debit" property="FormatConditions(1).AppliesTo.Address" value="$Q$4:$Q$38" type="String" /><column name="vat_debit" property="FormatConditions(1).Type" value="2" type="Double" /><column name="vat_debit" property="FormatConditions(1).Priority" value="5" type="Double" /><column name="vat_debit" property="FormatConditions(1).StopIfTrue" value="True" type="Boolean" /><column name="vat_debit" property="FormatConditions(1).Formula1" value="=$W4=4" type="String" /><column name="vat_debit" property="FormatConditions(1).Interior.Color" value="15987674" type="Double" /><column name="vat_debit" property="FormatConditions(2).AppliesTo.Address" value="$Q$4:$Q$38" type="String" /><column name="vat_debit" property="FormatConditions(2).Type" value="2" type="Double" /><column name="vat_debit" property="FormatConditions(2).Priority" value="6" type="Double" /><column name="vat_debit" property="FormatConditions(2).StopIfTrue" value="True" type="Boolean" /><column name="vat_debit" property="FormatConditions(2).Formula1" value="=AND($W4=0,$Q4&lt;&gt;&quot;&quot;)" type="String" /><column name="vat_debit" property="FormatConditions(2).Interior.Color" value="255" type="Double" /><column name="vat_debit" property="FormatConditions(3).AppliesTo.Address" value="$Q$4:$Q$38" type="String" /><column name="vat_debit" property="FormatConditions(3).Type" value="2" type="Double" /><column name="vat_debit" property="FormatConditions(3).Priority" value="7" type="Double" /><column name="vat_debit" property="FormatConditions(3).StopIfTrue" value="True" type="Boolean" /><column name="vat_debit" property="FormatConditions(3).Formula1" value="=$W4=2" type="String" /><column name="vat_debit" property="FormatConditions(3).Interior.Color" value="10284031" type="Double" /><column name="vat_debit" property="FormatConditions(4).AppliesTo.Address" value="$Q$4:$Q$38" type="String" /><column name="vat_debit" property="FormatConditions(4).Type" value="2" type="Double" /><column name="vat_debit" property="FormatConditions(4).Priority" value="8" type="Double" /><column name="vat_debit" property="FormatConditions(4).StopIfTrue" value="True" type="Boolean" /><column name="vat_debit" property="FormatConditions(4).Formula1" value="=$W4=3" type="String" /><column name="vat_debit" property="FormatConditions(4).Interior.Color" value="13551615" type="Double" /><column name="vat_credit" property="FormatConditions(1).AppliesTo.Address" value="$R$4:$R$38" type="String" /><column name="vat_credit" property="FormatConditions(1).Type" value="2" type="Double" /><column name="vat_credit" property="FormatConditions(1).Priority" value="1" type="Double" /><column name="vat_credit" property="FormatConditions(1).StopIfTrue" value="True" type="Boolean" /><column name="vat_credit" property="FormatConditions(1).Formula1" value="=$X4=4" type="String" /><column name="vat_credit" property="FormatConditions(1).Interior.Color" value="15987674" type="Double" /><column name="vat_credit" property="FormatConditions(2).AppliesTo.Address" value="$R$4:$R$38" type="String" /><column name="vat_credit" property="FormatConditions(2).Type" value="2" type="Double" /><column name="vat_credit" property="FormatConditions(2).Priority" value="2" type="Double" /><column name="vat_credit" property="FormatConditions(2).StopIfTrue" value="True" type="Boolean" /><column name="vat_credit" property="FormatConditions(2).Formula1" value="=AND($X4=0,$R4&lt;&gt;&quot;&quot;)" type="String" /><column name="vat_credit" property="FormatConditions(2).Interior.Color" value="255" type="Double" /><column name="vat_credit" property="FormatConditions(3).AppliesTo.Address" value="$R$4:$R$38" type="String" /><column name="vat_credit" property="FormatConditions(3).Type" value="2" type="Double" /><column name="vat_credit" property="FormatConditions(3).Priority" value="3" type="Double" /><column name="vat_credit" property="FormatConditions(3).StopIfTrue" value="True" type="Boolean" /><column name="vat_credit" property="FormatConditions(3).Formula1" value="=$X4=2" type="String" /><column name="vat_credit" property="FormatConditions(3).Interior.Color" value="10284031" type="Double" /><column name="vat_credit" property="FormatConditions(4).AppliesTo.Address" value="$R$4:$R$38" type="String" /><column name="vat_credit" property="FormatConditions(4).Type" value="2" type="Double" /><column name="vat_credit" property="FormatConditions(4).Priority" value="4" type="Double" /><column name="vat_credit" property="FormatConditions(4).StopIfTrue" value="True" type="Boolean" /><column name="vat_credit" property="FormatConditions(4).Formula1" value="=$X4=3" type="String" /><column name="vat_credit" property="FormatConditions(4).Interior.Color" value="13551615" type="Double" /><column name="" property="Tab.Color" value="5287936" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats><views><view name="Form"><column name="" property="ListObjectName" value="budget_requests_totals" type="String" /><column name="" property="ShowTotals" value="True" type="Boolean" /><column name="cf" property="TotalsCalculation" value="1" type="Double" /><column name="pl" property="TotalsCalculation" value="1" type="Double" /><column name="assets" property="TotalsCalculation" value="1" type="Double" /><column name="vat" property="TotalsCalculation" value="1" type="Double" /><column name="bs" property="TotalsCalculation" value="1" type="Double" /><column name="vat_credit_type_id" property="TotalsCalculation" value="1" type="Double" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="type" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="assets" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bs" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payment_debit" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payment_credit" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charge_debit" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charge_credit" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat_debit" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat_credit" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payment_debit_type_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payment_credit_type_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charge_debit_type_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charge_credit_type_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat_debit_type_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat_credit_type_id" property="EntireColumn.Hidden" value="True" type="Boolean" /></view><view name="All Columns"><column name="" property="ListObjectName" value="budget_requests_totals" type="String" /><column name="" property="ShowTotals" value="True" type="Boolean" /><column name="cf" property="TotalsCalculation" value="1" type="Double" /><column name="pl" property="TotalsCalculation" value="1" type="Double" /><column name="assets" property="TotalsCalculation" value="1" type="Double" /><column name="vat" property="TotalsCalculation" value="1" type="Double" /><column name="bs" property="TotalsCalculation" value="1" type="Double" /><column name="vat_credit_type_id" property="TotalsCalculation" value="1" type="Double" /><column name="_RowNum" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="type" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payments" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charges" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="assets" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bs" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payment_debit" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payment_credit" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charge_debit" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charge_credit" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat_debit" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat_credit" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payment_debit_type_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payment_credit_type_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charge_debit_type_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charge_credit_type_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat_debit_type_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat_credit_type_id" property="EntireColumn.Hidden" value="False" type="Boolean" /></view></views></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N'xls27', N'usp_budgeting_accounts', N'<table name="xls27.usp_budgeting_accounts"><columnFormats><column name="" property="ListObjectName" value="budgeting_accounts" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="id" property="Address" value="$C$4" type="String" /><column name="id" property="NumberFormat" value="General" type="String" /><column name="id" property="Validation.Type" value="1" type="Double" /><column name="id" property="Validation.Operator" value="1" type="Double" /><column name="id" property="Validation.Formula1" value="-2147483648" type="String" /><column name="id" property="Validation.Formula2" value="2147483647" type="String" /><column name="id" property="Validation.AlertStyle" value="1" type="Double" /><column name="id" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="id" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="id" property="Validation.ShowInput" value="True" type="Boolean" /><column name="id" property="Validation.ShowError" value="True" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="Address" value="$D$4" type="String" /><column name="code" property="ColumnWidth" value="8.43" type="Double" /><column name="code" property="NumberFormat" value="@" type="String" /><column name="code" property="Validation.Type" value="6" type="Double" /><column name="code" property="Validation.Operator" value="8" type="Double" /><column name="code" property="Validation.Formula1" value="50" type="String" /><column name="code" property="Validation.AlertStyle" value="1" type="Double" /><column name="code" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="code" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="code" property="Validation.ShowInput" value="True" type="Boolean" /><column name="code" property="Validation.ShowError" value="True" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="Address" value="$E$4" type="String" /><column name="name" property="ColumnWidth" value="55.71" type="Double" /><column name="name" property="NumberFormat" value="General" type="String" /><column name="name" property="Validation.Type" value="6" type="Double" /><column name="name" property="Validation.Operator" value="8" type="Double" /><column name="name" property="Validation.Formula1" value="255" type="String" /><column name="name" property="Validation.AlertStyle" value="1" type="Double" /><column name="name" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="name" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="name" property="Validation.ShowInput" value="True" type="Boolean" /><column name="name" property="Validation.ShowError" value="True" type="Boolean" /><column name="translated_name" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="translated_name" property="Address" value="$F$4" type="String" /><column name="translated_name" property="NumberFormat" value="General" type="String" /><column name="translated_name" property="Validation.Type" value="6" type="Double" /><column name="translated_name" property="Validation.Operator" value="8" type="Double" /><column name="translated_name" property="Validation.Formula1" value="255" type="String" /><column name="translated_name" property="Validation.AlertStyle" value="1" type="Double" /><column name="translated_name" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="translated_name" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="translated_name" property="Validation.ShowInput" value="True" type="Boolean" /><column name="translated_name" property="Validation.ShowError" value="True" type="Boolean" /><column name="is_parent" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="is_parent" property="Address" value="$G$4" type="String" /><column name="is_parent" property="NumberFormat" value="General" type="String" /><column name="is_parent" property="HorizontalAlignment" value="-4108" type="Double" /><column name="is_currency" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="is_currency" property="Address" value="$H$4" type="String" /><column name="is_currency" property="NumberFormat" value="General" type="String" /><column name="is_currency" property="HorizontalAlignment" value="-4108" type="Double" /><column name="parent_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="parent_id" property="Address" value="$I$4" type="String" /><column name="parent_id" property="ColumnWidth" value="8.43" type="Double" /><column name="parent_id" property="NumberFormat" value="@" type="String" /><column name="unit_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="unit_id" property="Address" value="$J$4" type="String" /><column name="unit_id" property="ColumnWidth" value="9.57" type="Double" /><column name="unit_id" property="NumberFormat" value="General" type="String" /><column name="vat_rate_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat_rate_id" property="Address" value="$K$4" type="String" /><column name="vat_rate_id" property="ColumnWidth" value="12.57" type="Double" /><column name="vat_rate_id" property="NumberFormat" value="General" type="String" /><column name="account_type_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account_type_id" property="Address" value="$L$4" type="String" /><column name="account_type_id" property="ColumnWidth" value="27.86" type="Double" /><column name="account_type_id" property="NumberFormat" value="General" type="String" /><column name="payment_debit_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payment_debit_id" property="Address" value="$M$4" type="String" /><column name="payment_debit_id" property="ColumnWidth" value="8.57" type="Double" /><column name="payment_debit_id" property="NumberFormat" value="@" type="String" /><column name="payment_credit_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payment_credit_id" property="Address" value="$N$4" type="String" /><column name="payment_credit_id" property="ColumnWidth" value="8.57" type="Double" /><column name="payment_credit_id" property="NumberFormat" value="@" type="String" /><column name="charge_debit_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charge_debit_id" property="Address" value="$O$4" type="String" /><column name="charge_debit_id" property="ColumnWidth" value="8.57" type="Double" /><column name="charge_debit_id" property="NumberFormat" value="@" type="String" /><column name="charge_credit_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charge_credit_id" property="Address" value="$P$4" type="String" /><column name="charge_credit_id" property="ColumnWidth" value="8.57" type="Double" /><column name="charge_credit_id" property="NumberFormat" value="@" type="String" /><column name="vat_debit_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat_debit_id" property="Address" value="$Q$4" type="String" /><column name="vat_debit_id" property="ColumnWidth" value="8.57" type="Double" /><column name="vat_debit_id" property="NumberFormat" value="@" type="String" /><column name="vat_credit_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat_credit_id" property="Address" value="$R$4" type="String" /><column name="vat_credit_id" property="ColumnWidth" value="8.57" type="Double" /><column name="vat_credit_id" property="NumberFormat" value="@" type="String" /><column name="payment_debit_type_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payment_debit_type_id" property="Address" value="$S$4" type="String" /><column name="payment_debit_type_id" property="NumberFormat" value="General" type="String" /><column name="payment_credit_type_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payment_credit_type_id" property="Address" value="$T$4" type="String" /><column name="payment_credit_type_id" property="NumberFormat" value="General" type="String" /><column name="charge_debit_type_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charge_debit_type_id" property="Address" value="$U$4" type="String" /><column name="charge_debit_type_id" property="NumberFormat" value="General" type="String" /><column name="charge_credit_type_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charge_credit_type_id" property="Address" value="$V$4" type="String" /><column name="charge_credit_type_id" property="NumberFormat" value="General" type="String" /><column name="vat_debit_type_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat_debit_type_id" property="Address" value="$W$4" type="String" /><column name="vat_debit_type_id" property="NumberFormat" value="General" type="String" /><column name="vat_credit_type_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat_credit_type_id" property="Address" value="$X$4" type="String" /><column name="vat_credit_type_id" property="NumberFormat" value="General" type="String" /><column name="is_in_budget_request" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="is_in_budget_request" property="Address" value="$Y$4" type="String" /><column name="is_in_budget_request" property="NumberFormat" value="General" type="String" /><column name="is_in_budget_request" property="HorizontalAlignment" value="-4108" type="Double" /><column name="is_in_budget_request" property="Font.Size" value="10" type="Double" /><column name="is_active" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="is_active" property="Address" value="$Z$4" type="String" /><column name="is_active" property="NumberFormat" value="General" type="String" /><column name="is_active" property="HorizontalAlignment" value="-4108" type="Double" /><column name="is_active" property="Font.Size" value="10" type="Double" /><column name="_RowNum" property="FormatConditions(1).AppliesToTable" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(1).AppliesTo.Address" value="$B$4:$Z$70" type="String" /><column name="_RowNum" property="FormatConditions(1).Type" value="2" type="Double" /><column name="_RowNum" property="FormatConditions(1).Priority" value="2" type="Double" /><column name="_RowNum" property="FormatConditions(1).Formula1" value="=$G4=1" type="String" /><column name="_RowNum" property="FormatConditions(1).Font.Bold" value="True" type="Boolean" /><column name="payment_debit_id" property="FormatConditions(1).AppliesTo.Address" value="$M$4:$M$70" type="String" /><column name="payment_debit_id" property="FormatConditions(1).Type" value="2" type="Double" /><column name="payment_debit_id" property="FormatConditions(1).Priority" value="18" type="Double" /><column name="payment_debit_id" property="FormatConditions(1).StopIfTrue" value="True" type="Boolean" /><column name="payment_debit_id" property="FormatConditions(1).Formula1" value="=AND($S4=0,$M4&lt;&gt;&quot;&quot;)" type="String" /><column name="payment_debit_id" property="FormatConditions(1).Interior.Color" value="255" type="Double" /><column name="payment_debit_id" property="FormatConditions(2).AppliesTo.Address" value="$M$4:$M$70" type="String" /><column name="payment_debit_id" property="FormatConditions(2).Type" value="2" type="Double" /><column name="payment_debit_id" property="FormatConditions(2).Priority" value="21" type="Double" /><column name="payment_debit_id" property="FormatConditions(2).StopIfTrue" value="True" type="Boolean" /><column name="payment_debit_id" property="FormatConditions(2).Formula1" value="=$S4=2" type="String" /><column name="payment_debit_id" property="FormatConditions(2).Interior.Color" value="10284031" type="Double" /><column name="payment_debit_id" property="FormatConditions(3).AppliesTo.Address" value="$M$4:$M$70" type="String" /><column name="payment_debit_id" property="FormatConditions(3).Type" value="2" type="Double" /><column name="payment_debit_id" property="FormatConditions(3).Priority" value="22" type="Double" /><column name="payment_debit_id" property="FormatConditions(3).StopIfTrue" value="True" type="Boolean" /><column name="payment_debit_id" property="FormatConditions(3).Formula1" value="=$S4=1" type="String" /><column name="payment_debit_id" property="FormatConditions(3).Interior.Color" value="13561798" type="Double" /><column name="payment_credit_id" property="FormatConditions(1).AppliesTo.Address" value="$N$4:$N$70" type="String" /><column name="payment_credit_id" property="FormatConditions(1).Type" value="2" type="Double" /><column name="payment_credit_id" property="FormatConditions(1).Priority" value="17" type="Double" /><column name="payment_credit_id" property="FormatConditions(1).StopIfTrue" value="True" type="Boolean" /><column name="payment_credit_id" property="FormatConditions(1).Formula1" value="=AND($T4=0,$N4&lt;&gt;&quot;&quot;)" type="String" /><column name="payment_credit_id" property="FormatConditions(1).Interior.Color" value="255" type="Double" /><column name="payment_credit_id" property="FormatConditions(2).AppliesTo.Address" value="$N$4:$N$70" type="String" /><column name="payment_credit_id" property="FormatConditions(2).Type" value="2" type="Double" /><column name="payment_credit_id" property="FormatConditions(2).Priority" value="19" type="Double" /><column name="payment_credit_id" property="FormatConditions(2).StopIfTrue" value="True" type="Boolean" /><column name="payment_credit_id" property="FormatConditions(2).Formula1" value="=$S4=1" type="String" /><column name="payment_credit_id" property="FormatConditions(2).Interior.Color" value="10284031" type="Double" /><column name="payment_credit_id" property="FormatConditions(3).AppliesTo.Address" value="$N$4:$N$70" type="String" /><column name="payment_credit_id" property="FormatConditions(3).Type" value="2" type="Double" /><column name="payment_credit_id" property="FormatConditions(3).Priority" value="20" type="Double" /><column name="payment_credit_id" property="FormatConditions(3).StopIfTrue" value="True" type="Boolean" /><column name="payment_credit_id" property="FormatConditions(3).Formula1" value="=$S4=2" type="String" /><column name="payment_credit_id" property="FormatConditions(3).Interior.Color" value="13561798" type="Double" /><column name="charge_debit_id" property="FormatConditions(1).AppliesTo.Address" value="$O$4:$O$70" type="String" /><column name="charge_debit_id" property="FormatConditions(1).Type" value="2" type="Double" /><column name="charge_debit_id" property="FormatConditions(1).Priority" value="14" type="Double" /><column name="charge_debit_id" property="FormatConditions(1).StopIfTrue" value="True" type="Boolean" /><column name="charge_debit_id" property="FormatConditions(1).Formula1" value="=AND($U4=0,$O4&lt;&gt;&quot;&quot;)" type="String" /><column name="charge_debit_id" property="FormatConditions(1).Interior.Color" value="255" type="Double" /><column name="charge_debit_id" property="FormatConditions(2).AppliesTo.Address" value="$O$4:$O$70" type="String" /><column name="charge_debit_id" property="FormatConditions(2).Type" value="2" type="Double" /><column name="charge_debit_id" property="FormatConditions(2).Priority" value="15" type="Double" /><column name="charge_debit_id" property="FormatConditions(2).StopIfTrue" value="True" type="Boolean" /><column name="charge_debit_id" property="FormatConditions(2).Formula1" value="=$U4=2" type="String" /><column name="charge_debit_id" property="FormatConditions(2).Interior.Color" value="10284031" type="Double" /><column name="charge_debit_id" property="FormatConditions(3).AppliesTo.Address" value="$O$4:$O$70" type="String" /><column name="charge_debit_id" property="FormatConditions(3).Type" value="2" type="Double" /><column name="charge_debit_id" property="FormatConditions(3).Priority" value="16" type="Double" /><column name="charge_debit_id" property="FormatConditions(3).StopIfTrue" value="True" type="Boolean" /><column name="charge_debit_id" property="FormatConditions(3).Formula1" value="=$U4=3" type="String" /><column name="charge_debit_id" property="FormatConditions(3).Interior.Color" value="13551615" type="Double" /><column name="charge_credit_id" property="FormatConditions(1).AppliesTo.Address" value="$P$4:$P$70" type="String" /><column name="charge_credit_id" property="FormatConditions(1).Type" value="2" type="Double" /><column name="charge_credit_id" property="FormatConditions(1).Priority" value="11" type="Double" /><column name="charge_credit_id" property="FormatConditions(1).StopIfTrue" value="True" type="Boolean" /><column name="charge_credit_id" property="FormatConditions(1).Formula1" value="=AND($U4=0,$P4&lt;&gt;&quot;&quot;)" type="String" /><column name="charge_credit_id" property="FormatConditions(1).Interior.Color" value="255" type="Double" /><column name="charge_credit_id" property="FormatConditions(2).AppliesTo.Address" value="$P$4:$P$70" type="String" /><column name="charge_credit_id" property="FormatConditions(2).Type" value="2" type="Double" /><column name="charge_credit_id" property="FormatConditions(2).Priority" value="12" type="Double" /><column name="charge_credit_id" property="FormatConditions(2).StopIfTrue" value="True" type="Boolean" /><column name="charge_credit_id" property="FormatConditions(2).Formula1" value="=$V4=2" type="String" /><column name="charge_credit_id" property="FormatConditions(2).Interior.Color" value="10284031" type="Double" /><column name="charge_credit_id" property="FormatConditions(3).AppliesTo.Address" value="$P$4:$P$70" type="String" /><column name="charge_credit_id" property="FormatConditions(3).Type" value="2" type="Double" /><column name="charge_credit_id" property="FormatConditions(3).Priority" value="13" type="Double" /><column name="charge_credit_id" property="FormatConditions(3).StopIfTrue" value="True" type="Boolean" /><column name="charge_credit_id" property="FormatConditions(3).Formula1" value="=$V4=3" type="String" /><column name="charge_credit_id" property="FormatConditions(3).Interior.Color" value="13551615" type="Double" /><column name="vat_debit_id" property="FormatConditions(1).AppliesTo.Address" value="$Q$4:$Q$70" type="String" /><column name="vat_debit_id" property="FormatConditions(1).Type" value="2" type="Double" /><column name="vat_debit_id" property="FormatConditions(1).Priority" value="7" type="Double" /><column name="vat_debit_id" property="FormatConditions(1).StopIfTrue" value="True" type="Boolean" /><column name="vat_debit_id" property="FormatConditions(1).Formula1" value="=$W4=4" type="String" /><column name="vat_debit_id" property="FormatConditions(1).Interior.Color" value="15987674" type="Double" /><column name="vat_debit_id" property="FormatConditions(2).AppliesTo.Address" value="$Q$4:$Q$70" type="String" /><column name="vat_debit_id" property="FormatConditions(2).Type" value="2" type="Double" /><column name="vat_debit_id" property="FormatConditions(2).Priority" value="8" type="Double" /><column name="vat_debit_id" property="FormatConditions(2).StopIfTrue" value="True" type="Boolean" /><column name="vat_debit_id" property="FormatConditions(2).Formula1" value="=AND($W4=0,$Q4&lt;&gt;&quot;&quot;)" type="String" /><column name="vat_debit_id" property="FormatConditions(2).Interior.Color" value="255" type="Double" /><column name="vat_debit_id" property="FormatConditions(3).AppliesTo.Address" value="$Q$4:$Q$70" type="String" /><column name="vat_debit_id" property="FormatConditions(3).Type" value="2" type="Double" /><column name="vat_debit_id" property="FormatConditions(3).Priority" value="9" type="Double" /><column name="vat_debit_id" property="FormatConditions(3).StopIfTrue" value="True" type="Boolean" /><column name="vat_debit_id" property="FormatConditions(3).Formula1" value="=$W4=2" type="String" /><column name="vat_debit_id" property="FormatConditions(3).Interior.Color" value="10284031" type="Double" /><column name="vat_debit_id" property="FormatConditions(4).AppliesTo.Address" value="$Q$4:$Q$70" type="String" /><column name="vat_debit_id" property="FormatConditions(4).Type" value="2" type="Double" /><column name="vat_debit_id" property="FormatConditions(4).Priority" value="10" type="Double" /><column name="vat_debit_id" property="FormatConditions(4).StopIfTrue" value="True" type="Boolean" /><column name="vat_debit_id" property="FormatConditions(4).Formula1" value="=$W4=3" type="String" /><column name="vat_debit_id" property="FormatConditions(4).Interior.Color" value="13551615" type="Double" /><column name="vat_credit_id" property="FormatConditions(1).AppliesTo.Address" value="$R$4:$R$70" type="String" /><column name="vat_credit_id" property="FormatConditions(1).Type" value="2" type="Double" /><column name="vat_credit_id" property="FormatConditions(1).Priority" value="3" type="Double" /><column name="vat_credit_id" property="FormatConditions(1).StopIfTrue" value="True" type="Boolean" /><column name="vat_credit_id" property="FormatConditions(1).Formula1" value="=$X4=4" type="String" /><column name="vat_credit_id" property="FormatConditions(1).Interior.Color" value="15987674" type="Double" /><column name="vat_credit_id" property="FormatConditions(2).AppliesTo.Address" value="$R$4:$R$70" type="String" /><column name="vat_credit_id" property="FormatConditions(2).Type" value="2" type="Double" /><column name="vat_credit_id" property="FormatConditions(2).Priority" value="4" type="Double" /><column name="vat_credit_id" property="FormatConditions(2).StopIfTrue" value="True" type="Boolean" /><column name="vat_credit_id" property="FormatConditions(2).Formula1" value="=AND($X4=0,$R4&lt;&gt;&quot;&quot;)" type="String" /><column name="vat_credit_id" property="FormatConditions(2).Interior.Color" value="255" type="Double" /><column name="vat_credit_id" property="FormatConditions(3).AppliesTo.Address" value="$R$4:$R$70" type="String" /><column name="vat_credit_id" property="FormatConditions(3).Type" value="2" type="Double" /><column name="vat_credit_id" property="FormatConditions(3).Priority" value="5" type="Double" /><column name="vat_credit_id" property="FormatConditions(3).StopIfTrue" value="True" type="Boolean" /><column name="vat_credit_id" property="FormatConditions(3).Formula1" value="=$X4=2" type="String" /><column name="vat_credit_id" property="FormatConditions(3).Interior.Color" value="10284031" type="Double" /><column name="vat_credit_id" property="FormatConditions(4).AppliesTo.Address" value="$R$4:$R$70" type="String" /><column name="vat_credit_id" property="FormatConditions(4).Type" value="2" type="Double" /><column name="vat_credit_id" property="FormatConditions(4).Priority" value="6" type="Double" /><column name="vat_credit_id" property="FormatConditions(4).StopIfTrue" value="True" type="Boolean" /><column name="vat_credit_id" property="FormatConditions(4).Formula1" value="=$X4=3" type="String" /><column name="vat_credit_id" property="FormatConditions(4).Interior.Color" value="13551615" type="Double" /><column name="is_in_budget_request" property="FormatConditions(1).AppliesTo.Address" value="$Y$4:$Y$70" type="String" /><column name="is_in_budget_request" property="FormatConditions(1).Type" value="6" type="Double" /><column name="is_in_budget_request" property="FormatConditions(1).Priority" value="1" type="Double" /><column name="is_in_budget_request" property="FormatConditions(1).ShowIconOnly" value="True" type="Boolean" /><column name="is_in_budget_request" property="FormatConditions(1).IconSet.ID" value="8" type="Double" /><column name="is_in_budget_request" property="FormatConditions(1).IconCriteria(1).Type" value="3" type="Double" /><column name="is_in_budget_request" property="FormatConditions(1).IconCriteria(1).Operator" value="7" type="Double" /><column name="is_in_budget_request" property="FormatConditions(1).IconCriteria(2).Type" value="0" type="Double" /><column name="is_in_budget_request" property="FormatConditions(1).IconCriteria(2).Value" value="0.5" type="Double" /><column name="is_in_budget_request" property="FormatConditions(1).IconCriteria(2).Operator" value="7" type="Double" /><column name="is_in_budget_request" property="FormatConditions(1).IconCriteria(3).Type" value="0" type="Double" /><column name="is_in_budget_request" property="FormatConditions(1).IconCriteria(3).Value" value="1" type="Double" /><column name="is_in_budget_request" property="FormatConditions(1).IconCriteria(3).Operator" value="7" type="Double" /><column name="is_active" property="FormatConditions(1).AppliesTo.Address" value="$Z$4:$Z$70" type="String" /><column name="is_active" property="FormatConditions(1).Type" value="6" type="Double" /><column name="is_active" property="FormatConditions(1).Priority" value="1486" type="Double" /><column name="is_active" property="FormatConditions(1).ShowIconOnly" value="True" type="Boolean" /><column name="is_active" property="FormatConditions(1).IconSet.ID" value="8" type="Double" /><column name="is_active" property="FormatConditions(1).IconCriteria(1).Type" value="3" type="Double" /><column name="is_active" property="FormatConditions(1).IconCriteria(1).Operator" value="7" type="Double" /><column name="is_active" property="FormatConditions(1).IconCriteria(2).Type" value="0" type="Double" /><column name="is_active" property="FormatConditions(1).IconCriteria(2).Value" value="0.5" type="Double" /><column name="is_active" property="FormatConditions(1).IconCriteria(2).Operator" value="7" type="Double" /><column name="is_active" property="FormatConditions(1).IconCriteria(3).Type" value="0" type="Double" /><column name="is_active" property="FormatConditions(1).IconCriteria(3).Value" value="1" type="Double" /><column name="is_active" property="FormatConditions(1).IconCriteria(3).Operator" value="7" type="Double" /><column name="" property="Tab.Color" value="5287936" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats><views><view name="Form"><column name="" property="ListObjectName" value="budgeting_accounts" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="translated_name" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="is_parent" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="is_currency" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="parent_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="unit_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat_rate_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account_type_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payment_debit_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payment_credit_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charge_debit_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charge_credit_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat_debit_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat_credit_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payment_debit_type_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="payment_credit_type_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charge_debit_type_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="charge_credit_type_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat_debit_type_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="vat_credit_type_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="is_in_budget_request" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="is_active" property="EntireColumn.Hidden" value="True" type="Boolean" /></view><view name="All Columns"><column name="" property="ListObjectName" value="budgeting_accounts" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="translated_name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="is_parent" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="is_currency" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="parent_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="unit_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat_rate_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account_type_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payment_debit_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payment_credit_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charge_debit_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charge_credit_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat_debit_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat_credit_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payment_debit_type_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payment_credit_type_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charge_debit_type_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charge_credit_type_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat_debit_type_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat_credit_type_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl_section_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl_ref_number" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf_ref_number" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="is_in_budget_request" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="is_active" property="EntireColumn.Hidden" value="False" type="Boolean" /></view></views></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N'xls27', N'usp_companies', N'<table name="xls27.usp_companies"><columnFormats><column name="" property="ListObjectName" value="companies" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="id" property="Address" value="$C$4" type="String" /><column name="id" property="ColumnWidth" value="4.29" type="Double" /><column name="id" property="NumberFormat" value="General" type="String" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="Address" value="$D$4" type="String" /><column name="code" property="ColumnWidth" value="20.71" type="Double" /><column name="code" property="NumberFormat" value="General" type="String" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="Address" value="$E$4" type="String" /><column name="name" property="ColumnWidth" value="27.86" type="Double" /><column name="name" property="NumberFormat" value="General" type="String" /><column name="translated_name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="translated_name" property="Address" value="$F$4" type="String" /><column name="translated_name" property="ColumnWidth" value="27.86" type="Double" /><column name="translated_name" property="NumberFormat" value="General" type="String" /><column name="default_language" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="default_language" property="Address" value="$G$4" type="String" /><column name="default_language" property="ColumnWidth" value="27.86" type="Double" /><column name="default_language" property="NumberFormat" value="General" type="String" /><column name="sort_order" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="sort_order" property="Address" value="$H$4" type="String" /><column name="sort_order" property="ColumnWidth" value="27.86" type="Double" /><column name="sort_order" property="NumberFormat" value="General" type="String" /><column name="" property="Tab.Color" value="6299648" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N'xls27', N'usp_dimensions', N'<table name="xls27.usp_dimensions"><columnFormats><column name="" property="ListObjectName" value="dimensions" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="id" property="Address" value="$C$4" type="String" /><column name="id" property="ColumnWidth" value="4.29" type="Double" /><column name="id" property="NumberFormat" value="General" type="String" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="Address" value="$D$4" type="String" /><column name="code" property="ColumnWidth" value="20.71" type="Double" /><column name="code" property="NumberFormat" value="General" type="String" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="Address" value="$E$4" type="String" /><column name="name" property="ColumnWidth" value="27.86" type="Double" /><column name="name" property="NumberFormat" value="General" type="String" /><column name="" property="Tab.Color" value="0" type="Double" /><column name="" property="Tab.ThemeColor" value="2" type="Double" /><column name="" property="Tab.TintAndShade" value="0" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N'xls27', N'usp_entry_sides', N'<table name="xls27.usp_entry_sides"><columnFormats><column name="" property="ListObjectName" value="entry_sides" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="id" property="Address" value="$C$4" type="String" /><column name="id" property="ColumnWidth" value="4.43" type="Double" /><column name="id" property="NumberFormat" value="General" type="String" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="Address" value="$D$4" type="String" /><column name="code" property="ColumnWidth" value="13.57" type="Double" /><column name="code" property="NumberFormat" value="General" type="String" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="Address" value="$E$4" type="String" /><column name="name" property="ColumnWidth" value="13.57" type="Double" /><column name="name" property="NumberFormat" value="General" type="String" /><column name="" property="Tab.Color" value="0" type="Double" /><column name="" property="Tab.ThemeColor" value="2" type="Double" /><column name="" property="Tab.TintAndShade" value="0" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N'xls27', N'usp_journal', N'<table name="xls27.usp_journal"><columnFormats><column name="" property="ListObjectName" value="journal" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="id" property="Address" value="$C$4" type="String" /><column name="id" property="NumberFormat" value="General" type="String" /><column name="id" property="Validation.Type" value="1" type="Double" /><column name="id" property="Validation.Operator" value="1" type="Double" /><column name="id" property="Validation.Formula1" value="-2147483648" type="String" /><column name="id" property="Validation.Formula2" value="2147483647" type="String" /><column name="id" property="Validation.AlertStyle" value="1" type="Double" /><column name="id" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="id" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="id" property="Validation.ShowInput" value="True" type="Boolean" /><column name="id" property="Validation.ShowError" value="True" type="Boolean" /><column name="date" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="date" property="Address" value="$D$4" type="String" /><column name="date" property="ColumnWidth" value="10.71" type="Double" /><column name="date" property="NumberFormat" value="m/d/yyyy" type="String" /><column name="date" property="Validation.Type" value="4" type="Double" /><column name="date" property="Validation.Operator" value="5" type="Double" /><column name="date" property="Validation.Formula1" value="12/31/1899" type="String" /><column name="date" property="Validation.AlertStyle" value="1" type="Double" /><column name="date" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="date" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="date" property="Validation.ShowInput" value="True" type="Boolean" /><column name="date" property="Validation.ShowError" value="True" type="Boolean" /><column name="debit_account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="debit_account_id" property="Address" value="$E$4" type="String" /><column name="debit_account_id" property="ColumnWidth" value="7.86" type="Double" /><column name="debit_account_id" property="NumberFormat" value="@" type="String" /><column name="credit_account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="credit_account_id" property="Address" value="$F$4" type="String" /><column name="credit_account_id" property="ColumnWidth" value="7.86" type="Double" /><column name="credit_account_id" property="NumberFormat" value="@" type="String" /><column name="amount" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="amount" property="Address" value="$G$4" type="String" /><column name="amount" property="ColumnWidth" value="13.57" type="Double" /><column name="amount" property="NumberFormat" value="#,##0.00" type="String" /><column name="debit_subsidiary_account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="debit_subsidiary_account_id" property="Address" value="$H$4" type="String" /><column name="debit_subsidiary_account_id" property="ColumnWidth" value="28.43" type="Double" /><column name="debit_subsidiary_account_id" property="NumberFormat" value="m/d/yyyy" type="String" /><column name="debit_subsidiary_account_id" property="Validation.Type" value="3" type="Double" /><column name="debit_subsidiary_account_id" property="Validation.Operator" value="1" type="Double" /><column name="debit_subsidiary_account_id" property="Validation.Formula1" value="=vl_d4_journal" type="String" /><column name="debit_subsidiary_account_id" property="Validation.AlertStyle" value="1" type="Double" /><column name="debit_subsidiary_account_id" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="debit_subsidiary_account_id" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="debit_subsidiary_account_id" property="Validation.ShowInput" value="True" type="Boolean" /><column name="debit_subsidiary_account_id" property="Validation.ShowError" value="True" type="Boolean" /><column name="credit_subsidiary_account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="credit_subsidiary_account_id" property="Address" value="$I$4" type="String" /><column name="credit_subsidiary_account_id" property="ColumnWidth" value="28.86" type="Double" /><column name="credit_subsidiary_account_id" property="NumberFormat" value="m/d/yyyy" type="String" /><column name="description" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="description" property="Address" value="$J$4" type="String" /><column name="description" property="ColumnWidth" value="46.86" type="Double" /><column name="description" property="NumberFormat" value="@" type="String" /><column name="currency" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="currency" property="Address" value="$K$4" type="String" /><column name="currency" property="ColumnWidth" value="10.14" type="Double" /><column name="currency" property="NumberFormat" value="General" type="String" /><column name="rate" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="rate" property="Address" value="$L$4" type="String" /><column name="rate" property="ColumnWidth" value="6.14" type="Double" /><column name="rate" property="NumberFormat" value="General" type="String" /><column name="amount$" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="amount$" property="Address" value="$M$4" type="String" /><column name="amount$" property="ColumnWidth" value="13.57" type="Double" /><column name="amount$" property="NumberFormat" value="#,##0.00" type="String" /><column name="entity_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="entity_id" property="Address" value="$N$4" type="String" /><column name="entity_id" property="ColumnWidth" value="18.57" type="Double" /><column name="entity_id" property="NumberFormat" value="General" type="String" /><column name="account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account_id" property="Address" value="$O$4" type="String" /><column name="account_id" property="ColumnWidth" value="12.14" type="Double" /><column name="account_id" property="NumberFormat" value="General" type="String" /><column name="region_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="region_id" property="Address" value="$P$4" type="String" /><column name="region_id" property="ColumnWidth" value="12.86" type="Double" /><column name="region_id" property="NumberFormat" value="General" type="String" /><column name="product_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="product_id" property="Address" value="$Q$4" type="String" /><column name="product_id" property="ColumnWidth" value="13.29" type="Double" /><column name="product_id" property="NumberFormat" value="General" type="String" /><column name="is_draft" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="is_draft" property="Address" value="$R$4" type="String" /><column name="is_draft" property="ColumnWidth" value="2.86" type="Double" /><column name="is_draft" property="NumberFormat" value="General" type="String" /><column name="is_draft" property="HorizontalAlignment" value="-4108" type="Double" /><column name="is_draft" property="Font.Size" value="10" type="Double" /><column name="auto_type_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="auto_type_id" property="Address" value="$S$4" type="String" /><column name="auto_type_id" property="ColumnWidth" value="2.86" type="Double" /><column name="auto_type_id" property="NumberFormat" value="General" type="String" /><column name="modified_by" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="modified_by" property="Address" value="$T$4" type="String" /><column name="modified_by" property="ColumnWidth" value="13.86" type="Double" /><column name="modified_by" property="NumberFormat" value="General" type="String" /><column name="modified_on" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="modified_on" property="Address" value="$U$4" type="String" /><column name="modified_on" property="ColumnWidth" value="10.86" type="Double" /><column name="modified_on" property="NumberFormat" value="m/d/yyyy" type="String" /><column name="_RowNum" property="FormatConditions(1).AppliesToTable" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(1).AppliesTo.Address" value="$B$4:$U$712" type="String" /><column name="_RowNum" property="FormatConditions(1).Type" value="2" type="Double" /><column name="_RowNum" property="FormatConditions(1).Priority" value="2" type="Double" /><column name="_RowNum" property="FormatConditions(1).Formula1" value="=$S4&gt;0" type="String" /><column name="_RowNum" property="FormatConditions(1).Interior.Color" value="15921906" type="Double" /><column name="_RowNum" property="FormatConditions(1).Interior.ThemeColor" value="1" type="Double" /><column name="_RowNum" property="FormatConditions(1).Interior.TintAndShade" value="-0.0499893185216834" type="Double" /><column name="is_draft" property="FormatConditions(1).AppliesTo.Address" value="$R$4:$R$712" type="String" /><column name="is_draft" property="FormatConditions(1).Type" value="6" type="Double" /><column name="is_draft" property="FormatConditions(1).Priority" value="100" type="Double" /><column name="is_draft" property="FormatConditions(1).ReverseOrder" value="True" type="Boolean" /><column name="is_draft" property="FormatConditions(1).ShowIconOnly" value="True" type="Boolean" /><column name="is_draft" property="FormatConditions(1).IconSet.ID" value="8" type="Double" /><column name="is_draft" property="FormatConditions(1).IconCriteria(1).Type" value="3" type="Double" /><column name="is_draft" property="FormatConditions(1).IconCriteria(1).Operator" value="7" type="Double" /><column name="is_draft" property="FormatConditions(1).IconCriteria(2).Type" value="0" type="Double" /><column name="is_draft" property="FormatConditions(1).IconCriteria(2).Value" value="0.5" type="Double" /><column name="is_draft" property="FormatConditions(1).IconCriteria(2).Operator" value="7" type="Double" /><column name="is_draft" property="FormatConditions(1).IconCriteria(3).Type" value="0" type="Double" /><column name="is_draft" property="FormatConditions(1).IconCriteria(3).Value" value="1" type="Double" /><column name="is_draft" property="FormatConditions(1).IconCriteria(3).Operator" value="7" type="Double" /><column name="SortFields(1)" property="KeyfieldName" value="id" type="String" /><column name="SortFields(1)" property="SortOn" value="0" type="Double" /><column name="SortFields(1)" property="Order" value="1" type="Double" /><column name="SortFields(1)" property="DataOption" value="0" type="Double" /><column name="" property="Tab.Color" value="5287936" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats><views><view name="Form"><column name="" property="ListObjectName" value="journal" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="date" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="debit_account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="credit_account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="amount" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="debit_subsidiary_account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="credit_subsidiary_account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="description" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="currency" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="rate" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="amount$" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="entity_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="region_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="product_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="is_draft" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="auto_type_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="modified_by" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="modified_on" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="SortFields(1)" property="KeyfieldName" value="id" type="String" /><column name="SortFields(1)" property="SortOn" value="0" type="Double" /><column name="SortFields(1)" property="Order" value="1" type="Double" /><column name="SortFields(1)" property="DataOption" value="0" type="Double" /></view><view name="All Columns"><column name="" property="ListObjectName" value="journal" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="date" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="debit_account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="credit_account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="amount" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="debit_subsidiary_account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="credit_subsidiary_account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="description" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="currency" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="rate" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="amount$" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="entity_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="region_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="product_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="is_draft" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="auto_type_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="modified_by" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="modified_on" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="SortFields(1)" property="KeyfieldName" value="id" type="String" /><column name="SortFields(1)" property="SortOn" value="0" type="Double" /><column name="SortFields(1)" property="Order" value="1" type="Double" /><column name="SortFields(1)" property="DataOption" value="0" type="Double" /></view></views></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N'xls27', N'usp_ledger_account_special_types', N'<table name="xls27.usp_ledger_account_special_types"><columnFormats><column name="" property="ListObjectName" value="ledger_account_special_types" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="id" property="Address" value="$C$4" type="String" /><column name="id" property="ColumnWidth" value="4.43" type="Double" /><column name="id" property="NumberFormat" value="General" type="String" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="Address" value="$D$4" type="String" /><column name="code" property="ColumnWidth" value="27.86" type="Double" /><column name="code" property="NumberFormat" value="General" type="String" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="Address" value="$E$4" type="String" /><column name="name" property="ColumnWidth" value="28" type="Double" /><column name="name" property="NumberFormat" value="General" type="String" /><column name="" property="Tab.Color" value="0" type="Double" /><column name="" property="Tab.ThemeColor" value="2" type="Double" /><column name="" property="Tab.TintAndShade" value="0" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N'xls27', N'usp_ledger_account_types', N'<table name="xls27.usp_ledger_account_types"><columnFormats><column name="" property="ListObjectName" value="ledger_account_types" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="id" property="Address" value="$C$4" type="String" /><column name="id" property="ColumnWidth" value="4.29" type="Double" /><column name="id" property="NumberFormat" value="General" type="String" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="Address" value="$D$4" type="String" /><column name="code" property="ColumnWidth" value="35.71" type="Double" /><column name="code" property="NumberFormat" value="General" type="String" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="Address" value="$E$4" type="String" /><column name="name" property="ColumnWidth" value="36.14" type="Double" /><column name="name" property="NumberFormat" value="General" type="String" /><column name="bs_section" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bs_section" property="Address" value="$F$4" type="String" /><column name="bs_section" property="ColumnWidth" value="12" type="Double" /><column name="bs_section" property="NumberFormat" value="General" type="String" /><column name="bs_sign" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="bs_sign" property="Address" value="$G$4" type="String" /><column name="bs_sign" property="ColumnWidth" value="9.14" type="Double" /><column name="bs_sign" property="NumberFormat" value="General" type="String" /><column name="pl_section" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl_section" property="Address" value="$H$4" type="String" /><column name="pl_section" property="ColumnWidth" value="11.71" type="Double" /><column name="pl_section" property="NumberFormat" value="General" type="String" /><column name="is_pl" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="is_pl" property="Address" value="$I$4" type="String" /><column name="is_pl" property="ColumnWidth" value="6.71" type="Double" /><column name="is_pl" property="NumberFormat" value="General" type="String" /><column name="is_da" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="is_da" property="Address" value="$J$4" type="String" /><column name="is_da" property="ColumnWidth" value="7.14" type="Double" /><column name="is_da" property="NumberFormat" value="General" type="String" /><column name="cf_section" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf_section" property="Address" value="$K$4" type="String" /><column name="cf_section" property="ColumnWidth" value="11.57" type="Double" /><column name="cf_section" property="NumberFormat" value="General" type="String" /><column name="specific_type_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="specific_type_id" property="Address" value="$L$4" type="String" /><column name="specific_type_id" property="ColumnWidth" value="17.14" type="Double" /><column name="specific_type_id" property="NumberFormat" value="General" type="String" /><column name="" property="Tab.Color" value="0" type="Double" /><column name="" property="Tab.ThemeColor" value="2" type="Double" /><column name="" property="Tab.TintAndShade" value="0" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N'xls27', N'usp_ledger_accounts', N'<table name="xls27.usp_ledger_accounts"><columnFormats><column name="" property="ListObjectName" value="ledger_accounts" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="id" property="Address" value="$C$4" type="String" /><column name="id" property="NumberFormat" value="General" type="String" /><column name="id" property="Validation.Type" value="1" type="Double" /><column name="id" property="Validation.Operator" value="1" type="Double" /><column name="id" property="Validation.Formula1" value="-2147483648" type="String" /><column name="id" property="Validation.Formula2" value="2147483647" type="String" /><column name="id" property="Validation.AlertStyle" value="2" type="Double" /><column name="id" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="id" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="id" property="Validation.ShowInput" value="True" type="Boolean" /><column name="id" property="Validation.ShowError" value="True" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="Address" value="$D$4" type="String" /><column name="code" property="ColumnWidth" value="7.14" type="Double" /><column name="code" property="NumberFormat" value="@" type="String" /><column name="code" property="Validation.Type" value="6" type="Double" /><column name="code" property="Validation.Operator" value="8" type="Double" /><column name="code" property="Validation.Formula1" value="50" type="String" /><column name="code" property="Validation.AlertStyle" value="2" type="Double" /><column name="code" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="code" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="code" property="Validation.ShowInput" value="True" type="Boolean" /><column name="code" property="Validation.ShowError" value="True" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="Address" value="$E$4" type="String" /><column name="name" property="ColumnWidth" value="55.71" type="Double" /><column name="name" property="NumberFormat" value="General" type="String" /><column name="name" property="Validation.Type" value="6" type="Double" /><column name="name" property="Validation.Operator" value="8" type="Double" /><column name="name" property="Validation.Formula1" value="255" type="String" /><column name="name" property="Validation.AlertStyle" value="2" type="Double" /><column name="name" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="name" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="name" property="Validation.ShowInput" value="True" type="Boolean" /><column name="name" property="Validation.ShowError" value="True" type="Boolean" /><column name="translated_name" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="translated_name" property="Address" value="$F$4" type="String" /><column name="translated_name" property="NumberFormat" value="@" type="String" /><column name="translated_name" property="Validation.Type" value="6" type="Double" /><column name="translated_name" property="Validation.Operator" value="8" type="Double" /><column name="translated_name" property="Validation.Formula1" value="255" type="String" /><column name="translated_name" property="Validation.AlertStyle" value="2" type="Double" /><column name="translated_name" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="translated_name" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="translated_name" property="Validation.ShowInput" value="True" type="Boolean" /><column name="translated_name" property="Validation.ShowError" value="True" type="Boolean" /><column name="parent_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="parent_id" property="Address" value="$G$4" type="String" /><column name="parent_id" property="ColumnWidth" value="16.71" type="Double" /><column name="parent_id" property="NumberFormat" value="@" type="String" /><column name="account_type_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account_type_id" property="Address" value="$H$4" type="String" /><column name="account_type_id" property="ColumnWidth" value="43.14" type="Double" /><column name="account_type_id" property="NumberFormat" value="@" type="String" /><column name="subsidiary_group_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="subsidiary_group_id" property="Address" value="$I$4" type="String" /><column name="subsidiary_group_id" property="ColumnWidth" value="20.71" type="Double" /><column name="subsidiary_group_id" property="NumberFormat" value="@" type="String" /><column name="closing_child_account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="closing_child_account_id" property="Address" value="$J$4" type="String" /><column name="closing_child_account_id" property="ColumnWidth" value="25" type="Double" /><column name="closing_child_account_id" property="NumberFormat" value="@" type="String" /><column name="closing_debit_account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="closing_debit_account_id" property="Address" value="$K$4" type="String" /><column name="closing_debit_account_id" property="ColumnWidth" value="25.43" type="Double" /><column name="closing_debit_account_id" property="NumberFormat" value="@" type="String" /><column name="closing_credit_account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="closing_credit_account_id" property="Address" value="$L$4" type="String" /><column name="closing_credit_account_id" property="ColumnWidth" value="25.86" type="Double" /><column name="closing_credit_account_id" property="NumberFormat" value="@" type="String" /><column name="ref_number" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="ref_number" property="Address" value="$M$4" type="String" /><column name="ref_number" property="ColumnWidth" value="8.43" type="Double" /><column name="ref_number" property="NumberFormat" value="General" type="String" /><column name="is_parent" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="is_parent" property="Address" value="$N$4" type="String" /><column name="is_parent" property="NumberFormat" value="General" type="String" /><column name="_RowNum" property="FormatConditions(1).AppliesToTable" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(1).AppliesTo.Address" value="$B$4:$N$86" type="String" /><column name="_RowNum" property="FormatConditions(1).Type" value="2" type="Double" /><column name="_RowNum" property="FormatConditions(1).Priority" value="1" type="Double" /><column name="_RowNum" property="FormatConditions(1).Formula1" value="=$N4=1" type="String" /><column name="_RowNum" property="FormatConditions(1).Font.Bold" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(1).Interior.Color" value="16313309" type="Double" /><column name="" property="Tab.Color" value="5287936" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats><views><view name="Form"><column name="" property="ListObjectName" value="ledger_accounts" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="translated_name" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="parent_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account_type_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="subsidiary_group_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="closing_child_account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="closing_debit_account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="closing_credit_account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="ref_number" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="is_parent" property="EntireColumn.Hidden" value="True" type="Boolean" /></view><view name="All Columns"><column name="" property="ListObjectName" value="ledger_accounts" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="translated_name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="parent_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account_type_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="subsidiary_group_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="closing_child_account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="closing_debit_account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="closing_credit_account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="is_parent" property="EntireColumn.Hidden" value="False" type="Boolean" /></view><view name="Reference Numbers"><column name="" property="ListObjectName" value="ledger_accounts" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="translated_name" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="parent_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="account_type_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="subsidiary_group_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="closing_child_account_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="closing_debit_account_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="closing_credit_account_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="ref_number" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="is_parent" property="EntireColumn.Hidden" value="True" type="Boolean" /></view></views></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N'xls27', N'usp_member_permissions', N'<table name="xls27.usp_member_permissions"><columnFormats><column name="" property="ListObjectName" value="member_permissions" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="id" property="Address" value="$C$4" type="String" /><column name="id" property="NumberFormat" value="General" type="String" /><column name="dimension_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dimension_id" property="Address" value="$D$4" type="String" /><column name="dimension_id" property="NumberFormat" value="General" type="String" /><column name="sort_order" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="sort_order" property="Address" value="$E$4" type="String" /><column name="sort_order" property="NumberFormat" value="General" type="String" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="Address" value="$F$4" type="String" /><column name="code" property="ColumnWidth" value="9.29" type="Double" /><column name="code" property="NumberFormat" value="General" type="String" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="Address" value="$G$4" type="String" /><column name="name" property="ColumnWidth" value="55.86" type="Double" /><column name="name" property="NumberFormat" value="General" type="String" /><column name="is_in_budget_request" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="is_in_budget_request" property="Address" value="$H$4" type="String" /><column name="is_in_budget_request" property="NumberFormat" value="General" type="String" /><column name="is_in_budget_request" property="HorizontalAlignment" value="-4108" type="Double" /><column name="data_format" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="data_format" property="Address" value="$I$4" type="String" /><column name="data_format" property="NumberFormat" value="General" type="String" /><column name="data_format" property="HorizontalAlignment" value="-4108" type="Double" /><column name="ba_accountant_01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="ba_accountant_01" property="Address" value="$J$4" type="String" /><column name="ba_accountant_01" property="ColumnWidth" value="18.57" type="Double" /><column name="ba_accountant_01" property="NumberFormat" value="General" type="String" /><column name="ba_accountant_01" property="HorizontalAlignment" value="-4108" type="Double" /><column name="ba_user_101" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="ba_user_101" property="Address" value="$K$4" type="String" /><column name="ba_user_101" property="ColumnWidth" value="13.57" type="Double" /><column name="ba_user_101" property="NumberFormat" value="General" type="String" /><column name="ba_user_101" property="HorizontalAlignment" value="-4108" type="Double" /><column name="ba_user_201" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="ba_user_201" property="Address" value="$L$4" type="String" /><column name="ba_user_201" property="ColumnWidth" value="13.57" type="Double" /><column name="ba_user_201" property="NumberFormat" value="General" type="String" /><column name="ba_user_201" property="HorizontalAlignment" value="-4108" type="Double" /><column name="ba_user_301" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="ba_user_301" property="Address" value="$M$4" type="String" /><column name="ba_user_301" property="ColumnWidth" value="13.57" type="Double" /><column name="ba_user_301" property="NumberFormat" value="General" type="String" /><column name="ba_user_301" property="HorizontalAlignment" value="-4108" type="Double" /><column name="ba_user_401" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="ba_user_401" property="Address" value="$N$4" type="String" /><column name="ba_user_401" property="ColumnWidth" value="13.57" type="Double" /><column name="ba_user_401" property="NumberFormat" value="General" type="String" /><column name="ba_user_401" property="HorizontalAlignment" value="-4108" type="Double" /><column name="last_format_column" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="last_format_column" property="Address" value="$O$4" type="String" /><column name="last_format_column" property="NumberFormat" value="h:mm:ss" type="String" /><column name="last_format_column" property="HorizontalAlignment" value="-4108" type="Double" /><column name="_RowNum" property="FormatConditions(1).AppliesToTable" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(1).AppliesTo.Address" value="$B$4:$O$69" type="String" /><column name="_RowNum" property="FormatConditions(1).Type" value="2" type="Double" /><column name="_RowNum" property="FormatConditions(1).Priority" value="4" type="Double" /><column name="_RowNum" property="FormatConditions(1).Formula1" value="=$H4=0" type="String" /><column name="_RowNum" property="FormatConditions(1).Font.Bold" value="True" type="Boolean" /><column name="data_format" property="FormatConditions(1).ColumnsCount" value="7" type="Double" /><column name="data_format" property="FormatConditions(1).AppliesTo.Address" value="$I$4:$O$69" type="String" /><column name="data_format" property="FormatConditions(1).Type" value="1" type="Double" /><column name="data_format" property="FormatConditions(1).Priority" value="1" type="Double" /><column name="data_format" property="FormatConditions(1).StopIfTrue" value="True" type="Boolean" /><column name="data_format" property="FormatConditions(1).Formula1" value="=&quot;R&quot;" type="String" /><column name="data_format" property="FormatConditions(1).Operator" value="3" type="Double" /><column name="data_format" property="FormatConditions(1).Font.Color" value="24832" type="Double" /><column name="data_format" property="FormatConditions(1).Interior.Color" value="13561798" type="Double" /><column name="data_format" property="FormatConditions(2).ColumnsCount" value="7" type="Double" /><column name="data_format" property="FormatConditions(2).AppliesTo.Address" value="$I$4:$O$69" type="String" /><column name="data_format" property="FormatConditions(2).Type" value="1" type="Double" /><column name="data_format" property="FormatConditions(2).Priority" value="2" type="Double" /><column name="data_format" property="FormatConditions(2).StopIfTrue" value="True" type="Boolean" /><column name="data_format" property="FormatConditions(2).Formula1" value="=&quot;W&quot;" type="String" /><column name="data_format" property="FormatConditions(2).Operator" value="3" type="Double" /><column name="data_format" property="FormatConditions(2).Font.Color" value="22428" type="Double" /><column name="data_format" property="FormatConditions(2).Interior.Color" value="10284031" type="Double" /><column name="data_format" property="FormatConditions(3).ColumnsCount" value="7" type="Double" /><column name="data_format" property="FormatConditions(3).AppliesTo.Address" value="$I$4:$O$69" type="String" /><column name="data_format" property="FormatConditions(3).Type" value="1" type="Double" /><column name="data_format" property="FormatConditions(3).Priority" value="3" type="Double" /><column name="data_format" property="FormatConditions(3).StopIfTrue" value="True" type="Boolean" /><column name="data_format" property="FormatConditions(3).Formula1" value="=&quot;D&quot;" type="String" /><column name="data_format" property="FormatConditions(3).Operator" value="3" type="Double" /><column name="data_format" property="FormatConditions(3).Font.Color" value="393372" type="Double" /><column name="data_format" property="FormatConditions(3).Interior.Color" value="13551615" type="Double" /><column name="" property="Tab.Color" value="5287936" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats><views><view name="Form"><column name="" property="ListObjectName" value="member_permissions" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dimension_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="sort_order" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="is_in_budget_request" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="data_format" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="ba_accountant_01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="ba_user_101" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="ba_user_201" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="ba_user_301" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="ba_user_401" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="last_format_column" property="EntireColumn.Hidden" value="True" type="Boolean" /></view><view name="All Columns"><column name="" property="ListObjectName" value="member_permissions" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="dimension_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="sort_order" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data_format" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="budgeting_app_user_101" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="budgeting_app_user_201" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="budgeting_app_user_301" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="budgeting_app_user_401" property="EntireColumn.Hidden" value="False" type="Boolean" /></view></views></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N'xls27', N'usp_member_relations', N'<table name="xls27.usp_member_relations"><columnFormats><column name="" property="ListObjectName" value="member_relations" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="id" property="Address" value="$C$4" type="String" /><column name="id" property="NumberFormat" value="General" type="String" /><column name="sort_order" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="sort_order" property="Address" value="$D$4" type="String" /><column name="sort_order" property="NumberFormat" value="General" type="String" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="Address" value="$E$4" type="String" /><column name="code" property="ColumnWidth" value="9.29" type="Double" /><column name="code" property="NumberFormat" value="General" type="String" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="Address" value="$F$4" type="String" /><column name="name" property="ColumnWidth" value="55.71" type="Double" /><column name="name" property="NumberFormat" value="General" type="String" /><column name="data_format" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="data_format" property="Address" value="$G$4" type="String" /><column name="data_format" property="NumberFormat" value="General" type="String" /><column name="data_format" property="HorizontalAlignment" value="-4108" type="Double" /><column name="data_format" property="Font.Size" value="10" type="Double" /><column name="E101" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="E101" property="Address" value="$H$4" type="String" /><column name="E101" property="ColumnWidth" value="13.43" type="Double" /><column name="E101" property="NumberFormat" value="General" type="String" /><column name="E101" property="HorizontalAlignment" value="-4108" type="Double" /><column name="E101" property="Font.Size" value="10" type="Double" /><column name="E201" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="E201" property="Address" value="$I$4" type="String" /><column name="E201" property="ColumnWidth" value="13.43" type="Double" /><column name="E201" property="NumberFormat" value="General" type="String" /><column name="E201" property="HorizontalAlignment" value="-4108" type="Double" /><column name="E201" property="Font.Size" value="10" type="Double" /><column name="E301" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="E301" property="Address" value="$J$4" type="String" /><column name="E301" property="ColumnWidth" value="13.43" type="Double" /><column name="E301" property="NumberFormat" value="General" type="String" /><column name="E301" property="HorizontalAlignment" value="-4108" type="Double" /><column name="E301" property="Font.Size" value="10" type="Double" /><column name="E401" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="E401" property="Address" value="$K$4" type="String" /><column name="E401" property="ColumnWidth" value="13.43" type="Double" /><column name="E401" property="NumberFormat" value="General" type="String" /><column name="E401" property="HorizontalAlignment" value="-4108" type="Double" /><column name="E401" property="Font.Size" value="10" type="Double" /><column name="data_format" property="FormatConditions(1).ColumnsCount" value="5" type="Double" /><column name="data_format" property="FormatConditions(1).AppliesTo.Address" value="$G$4:$K$69" type="String" /><column name="data_format" property="FormatConditions(1).Type" value="6" type="Double" /><column name="data_format" property="FormatConditions(1).Priority" value="1552" type="Double" /><column name="data_format" property="FormatConditions(1).ShowIconOnly" value="True" type="Boolean" /><column name="data_format" property="FormatConditions(1).IconSet.ID" value="8" type="Double" /><column name="data_format" property="FormatConditions(1).IconCriteria(1).Type" value="3" type="Double" /><column name="data_format" property="FormatConditions(1).IconCriteria(1).Operator" value="7" type="Double" /><column name="data_format" property="FormatConditions(1).IconCriteria(2).Type" value="0" type="Double" /><column name="data_format" property="FormatConditions(1).IconCriteria(2).Value" value="0.5" type="Double" /><column name="data_format" property="FormatConditions(1).IconCriteria(2).Operator" value="7" type="Double" /><column name="data_format" property="FormatConditions(1).IconCriteria(3).Type" value="0" type="Double" /><column name="data_format" property="FormatConditions(1).IconCriteria(3).Value" value="1" type="Double" /><column name="data_format" property="FormatConditions(1).IconCriteria(3).Operator" value="7" type="Double" /><column name="" property="Tab.Color" value="5287936" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N'xls27', N'usp_member_types', N'<table name="xls27.usp_member_types"><columnFormats><column name="" property="ListObjectName" value="member_types" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="id" property="Address" value="$C$4" type="String" /><column name="id" property="ColumnWidth" value="4.29" type="Double" /><column name="id" property="NumberFormat" value="General" type="String" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="Address" value="$D$4" type="String" /><column name="code" property="ColumnWidth" value="19.43" type="Double" /><column name="code" property="NumberFormat" value="General" type="String" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="Address" value="$E$4" type="String" /><column name="name" property="ColumnWidth" value="15.71" type="Double" /><column name="name" property="NumberFormat" value="General" type="String" /><column name="cf_sign" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf_sign" property="Address" value="$F$4" type="String" /><column name="cf_sign" property="ColumnWidth" value="8.71" type="Double" /><column name="cf_sign" property="NumberFormat" value="General" type="String" /><column name="pl_sign" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl_sign" property="Address" value="$G$4" type="String" /><column name="pl_sign" property="ColumnWidth" value="8.86" type="Double" /><column name="pl_sign" property="NumberFormat" value="General" type="String" /><column name="asset_sign" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="asset_sign" property="Address" value="$H$4" type="String" /><column name="asset_sign" property="ColumnWidth" value="11.71" type="Double" /><column name="asset_sign" property="NumberFormat" value="General" type="String" /><column name="vat_sign" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat_sign" property="Address" value="$I$4" type="String" /><column name="vat_sign" property="ColumnWidth" value="9.86" type="Double" /><column name="vat_sign" property="NumberFormat" value="General" type="String" /><column name="payment_debit_type_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payment_debit_type_id" property="Address" value="$J$4" type="String" /><column name="payment_debit_type_id" property="ColumnWidth" value="19.29" type="Double" /><column name="payment_debit_type_id" property="NumberFormat" value="General" type="String" /><column name="payment_credit_type_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="payment_credit_type_id" property="Address" value="$K$4" type="String" /><column name="payment_credit_type_id" property="ColumnWidth" value="19.29" type="Double" /><column name="payment_credit_type_id" property="NumberFormat" value="General" type="String" /><column name="charge_debit_type_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charge_debit_type_id" property="Address" value="$L$4" type="String" /><column name="charge_debit_type_id" property="ColumnWidth" value="19.29" type="Double" /><column name="charge_debit_type_id" property="NumberFormat" value="General" type="String" /><column name="charge_credit_type_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="charge_credit_type_id" property="Address" value="$M$4" type="String" /><column name="charge_credit_type_id" property="ColumnWidth" value="19.29" type="Double" /><column name="charge_credit_type_id" property="NumberFormat" value="General" type="String" /><column name="vat_debit_type_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat_debit_type_id" property="Address" value="$N$4" type="String" /><column name="vat_debit_type_id" property="ColumnWidth" value="19.29" type="Double" /><column name="vat_debit_type_id" property="NumberFormat" value="General" type="String" /><column name="vat_credit_type_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat_credit_type_id" property="Address" value="$O$4" type="String" /><column name="vat_credit_type_id" property="ColumnWidth" value="19.29" type="Double" /><column name="vat_credit_type_id" property="NumberFormat" value="General" type="String" /><column name="" property="Tab.Color" value="0" type="Double" /><column name="" property="Tab.ThemeColor" value="2" type="Double" /><column name="" property="Tab.TintAndShade" value="0" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N'xls27', N'usp_members', N'<table name="xls27.usp_members"><columnFormats><column name="" property="ListObjectName" value="members" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="id" property="Address" value="$C$4" type="String" /><column name="id" property="NumberFormat" value="General" type="String" /><column name="id" property="Validation.Type" value="1" type="Double" /><column name="id" property="Validation.Operator" value="1" type="Double" /><column name="id" property="Validation.Formula1" value="-2147483648" type="String" /><column name="id" property="Validation.Formula2" value="2147483647" type="String" /><column name="id" property="Validation.AlertStyle" value="1" type="Double" /><column name="id" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="id" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="id" property="Validation.ShowInput" value="True" type="Boolean" /><column name="id" property="Validation.ShowError" value="True" type="Boolean" /><column name="sort_order" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="sort_order" property="Address" value="$D$4" type="String" /><column name="sort_order" property="NumberFormat" value="General" type="String" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="Address" value="$E$4" type="String" /><column name="code" property="ColumnWidth" value="10.14" type="Double" /><column name="code" property="NumberFormat" value="@" type="String" /><column name="code" property="Validation.Type" value="6" type="Double" /><column name="code" property="Validation.Operator" value="8" type="Double" /><column name="code" property="Validation.Formula1" value="50" type="String" /><column name="code" property="Validation.AlertStyle" value="1" type="Double" /><column name="code" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="code" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="code" property="Validation.ShowInput" value="True" type="Boolean" /><column name="code" property="Validation.ShowError" value="True" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="Address" value="$F$4" type="String" /><column name="name" property="ColumnWidth" value="55.71" type="Double" /><column name="name" property="NumberFormat" value="General" type="String" /><column name="name" property="Validation.Type" value="6" type="Double" /><column name="name" property="Validation.Operator" value="8" type="Double" /><column name="name" property="Validation.Formula1" value="255" type="String" /><column name="name" property="Validation.AlertStyle" value="1" type="Double" /><column name="name" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="name" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="name" property="Validation.ShowInput" value="True" type="Boolean" /><column name="name" property="Validation.ShowError" value="True" type="Boolean" /><column name="translated_name" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="translated_name" property="Address" value="$G$4" type="String" /><column name="translated_name" property="NumberFormat" value="General" type="String" /><column name="is_in_budget_request" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="is_in_budget_request" property="Address" value="$H$4" type="String" /><column name="is_in_budget_request" property="NumberFormat" value="General" type="String" /><column name="is_in_budget_request" property="HorizontalAlignment" value="-4108" type="Double" /><column name="is_in_budget_request" property="Font.Size" value="10" type="Double" /><column name="is_active" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="is_active" property="Address" value="$I$4" type="String" /><column name="is_active" property="ColumnWidth" value="10.14" type="Double" /><column name="is_active" property="NumberFormat" value="General" type="String" /><column name="is_active" property="HorizontalAlignment" value="-4108" type="Double" /><column name="is_active" property="Font.Size" value="10" type="Double" /><column name="_RowNum" property="FormatConditions(1).AppliesToTable" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(1).AppliesTo.Address" value="$B$4:$I$7" type="String" /><column name="_RowNum" property="FormatConditions(1).Type" value="2" type="Double" /><column name="_RowNum" property="FormatConditions(1).Priority" value="1" type="Double" /><column name="_RowNum" property="FormatConditions(1).Formula1" value="=AND($H4=0,$I4=1)" type="String" /><column name="_RowNum" property="FormatConditions(1).Font.Bold" value="True" type="Boolean" /><column name="is_in_budget_request" property="FormatConditions(1).AppliesTo.Address" value="$H$4:$H$7" type="String" /><column name="is_in_budget_request" property="FormatConditions(1).Type" value="6" type="Double" /><column name="is_in_budget_request" property="FormatConditions(1).Priority" value="1910" type="Double" /><column name="is_in_budget_request" property="FormatConditions(1).ShowIconOnly" value="True" type="Boolean" /><column name="is_in_budget_request" property="FormatConditions(1).IconSet.ID" value="8" type="Double" /><column name="is_in_budget_request" property="FormatConditions(1).IconCriteria(1).Type" value="3" type="Double" /><column name="is_in_budget_request" property="FormatConditions(1).IconCriteria(1).Operator" value="7" type="Double" /><column name="is_in_budget_request" property="FormatConditions(1).IconCriteria(2).Type" value="0" type="Double" /><column name="is_in_budget_request" property="FormatConditions(1).IconCriteria(2).Value" value="0.5" type="Double" /><column name="is_in_budget_request" property="FormatConditions(1).IconCriteria(2).Operator" value="7" type="Double" /><column name="is_in_budget_request" property="FormatConditions(1).IconCriteria(3).Type" value="0" type="Double" /><column name="is_in_budget_request" property="FormatConditions(1).IconCriteria(3).Value" value="1" type="Double" /><column name="is_in_budget_request" property="FormatConditions(1).IconCriteria(3).Operator" value="7" type="Double" /><column name="" property="Tab.Color" value="5287936" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats><views><view name="Form"><column name="" property="ListObjectName" value="members" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="sort_order" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="translated_name" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="is_in_budget_request" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="is_active" property="EntireColumn.Hidden" value="False" type="Boolean" /></view><view name="All Columns"><column name="" property="ListObjectName" value="members" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="sort_order" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="translated_name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="is_in_budget_request" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="is_active" property="EntireColumn.Hidden" value="False" type="Boolean" /></view></views></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N'xls27', N'usp_report_section_accounts', N'<table name="xls27.usp_report_section_accounts"><columnFormats><column name="" property="ListObjectName" value="report_section_accounts" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="id" property="Address" value="$C$4" type="String" /><column name="id" property="NumberFormat" value="General" type="String" /><column name="sort_order" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="sort_order" property="Address" value="$D$4" type="String" /><column name="sort_order" property="ColumnWidth" value="12" type="Double" /><column name="sort_order" property="NumberFormat" value="General" type="String" /><column name="account_type_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account_type_id" property="Address" value="$E$4" type="String" /><column name="account_type_id" property="ColumnWidth" value="36.14" type="Double" /><column name="account_type_id" property="NumberFormat" value="General" type="String" /><column name="is_pl" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="is_pl" property="Address" value="$F$4" type="String" /><column name="is_pl" property="ColumnWidth" value="8.43" type="Double" /><column name="is_pl" property="NumberFormat" value="General" type="String" /><column name="entry_side_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="entry_side_id" property="Address" value="$G$4" type="String" /><column name="entry_side_id" property="ColumnWidth" value="14.86" type="Double" /><column name="entry_side_id" property="NumberFormat" value="General" type="String" /><column name="report" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="report" property="Address" value="$H$4" type="String" /><column name="report" property="ColumnWidth" value="28" type="Double" /><column name="report" property="NumberFormat" value="General" type="String" /><column name="section_type_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="section_type_id" property="Address" value="$I$4" type="String" /><column name="section_type_id" property="ColumnWidth" value="28" type="Double" /><column name="section_type_id" property="NumberFormat" value="General" type="String" /><column name="value_sign" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="value_sign" property="Address" value="$J$4" type="String" /><column name="value_sign" property="ColumnWidth" value="11.86" type="Double" /><column name="value_sign" property="NumberFormat" value="General" type="String" /><column name="value_type_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="value_type_id" property="Address" value="$K$4" type="String" /><column name="value_type_id" property="ColumnWidth" value="30.71" type="Double" /><column name="value_type_id" property="NumberFormat" value="General" type="String" /><column name="pair_account_type_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pair_account_type_id" property="Address" value="$L$4" type="String" /><column name="pair_account_type_id" property="ColumnWidth" value="19.14" type="Double" /><column name="pair_account_type_id" property="NumberFormat" value="General" type="String" /><column name="SortFields(1)" property="KeyfieldName" value="sort_order" type="String" /><column name="SortFields(1)" property="SortOn" value="0" type="Double" /><column name="SortFields(1)" property="Order" value="1" type="Double" /><column name="SortFields(1)" property="DataOption" value="0" type="Double" /><column name="" property="Tab.Color" value="0" type="Double" /><column name="" property="Tab.ThemeColor" value="2" type="Double" /><column name="" property="Tab.TintAndShade" value="0" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N'xls27', N'usp_report_section_types', N'<table name="xls27.usp_report_section_types"><columnFormats><column name="" property="ListObjectName" value="report_section_types" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="id" property="Address" value="$C$4" type="String" /><column name="id" property="ColumnWidth" value="4.29" type="Double" /><column name="id" property="NumberFormat" value="General" type="String" /><column name="report_type_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="report_type_id" property="Address" value="$D$4" type="String" /><column name="report_type_id" property="ColumnWidth" value="16" type="Double" /><column name="report_type_id" property="NumberFormat" value="General" type="String" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="Address" value="$E$4" type="String" /><column name="name" property="ColumnWidth" value="30.71" type="Double" /><column name="name" property="NumberFormat" value="General" type="String" /><column name="total_type_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="total_type_id" property="Address" value="$F$4" type="String" /><column name="total_type_id" property="ColumnWidth" value="17.14" type="Double" /><column name="total_type_id" property="NumberFormat" value="General" type="String" /><column name="hide_accounts" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="hide_accounts" property="Address" value="$G$4" type="String" /><column name="hide_accounts" property="ColumnWidth" value="15.43" type="Double" /><column name="hide_accounts" property="NumberFormat" value="General" type="String" /><column name="" property="Tab.Color" value="0" type="Double" /><column name="" property="Tab.ThemeColor" value="2" type="Double" /><column name="" property="Tab.TintAndShade" value="0" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N'xls27', N'usp_report_section_value_types', N'<table name="xls27.usp_report_section_value_types"><columnFormats><column name="" property="ListObjectName" value="report_section_value_types" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="id" property="Address" value="$C$4" type="String" /><column name="id" property="ColumnWidth" value="4.43" type="Double" /><column name="id" property="NumberFormat" value="General" type="String" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="Address" value="$D$4" type="String" /><column name="code" property="ColumnWidth" value="13.43" type="Double" /><column name="code" property="NumberFormat" value="General" type="String" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="Address" value="$E$4" type="String" /><column name="name" property="ColumnWidth" value="28" type="Double" /><column name="name" property="NumberFormat" value="General" type="String" /><column name="" property="Tab.Color" value="0" type="Double" /><column name="" property="Tab.ThemeColor" value="2" type="Double" /><column name="" property="Tab.TintAndShade" value="0" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N'xls27', N'usp_report_sections', N'<table name="xls27.usp_report_sections"><columnFormats><column name="" property="ListObjectName" value="report_section_types" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="id" property="Address" value="$C$4" type="String" /><column name="id" property="NumberFormat" value="General" type="String" /><column name="sort_order" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="sort_order" property="Address" value="$D$4" type="String" /><column name="sort_order" property="ColumnWidth" value="4.29" type="Double" /><column name="sort_order" property="NumberFormat" value="General" type="String" /><column name="report_type_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="report_type_id" property="Address" value="$E$4" type="String" /><column name="report_type_id" property="ColumnWidth" value="4.86" type="Double" /><column name="report_type_id" property="NumberFormat" value="General" type="String" /><column name="section" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="section" property="Address" value="$F$4" type="String" /><column name="section" property="ColumnWidth" value="9" type="Double" /><column name="section" property="NumberFormat" value="General" type="String" /><column name="row_format" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="row_format" property="Address" value="$G$4" type="String" /><column name="row_format" property="ColumnWidth" value="10.86" type="Double" /><column name="row_format" property="NumberFormat" value="General" type="String" /><column name="ref_number" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="ref_number" property="Address" value="$H$4" type="String" /><column name="ref_number" property="ColumnWidth" value="13.14" type="Double" /><column name="ref_number" property="NumberFormat" value="General" type="String" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="Address" value="$I$4" type="String" /><column name="code" property="ColumnWidth" value="6.86" type="Double" /><column name="code" property="NumberFormat" value="General" type="String" /><column name="description" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="description" property="Address" value="$J$4" type="String" /><column name="description" property="ColumnWidth" value="38.14" type="Double" /><column name="description" property="NumberFormat" value="General" type="String" /><column name="translated_name" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="translated_name" property="Address" value="$K$4" type="String" /><column name="translated_name" property="NumberFormat" value="General" type="String" /><column name="parent_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="parent_id" property="Address" value="$L$4" type="String" /><column name="parent_id" property="ColumnWidth" value="36.57" type="Double" /><column name="parent_id" property="NumberFormat" value="General" type="String" /><column name="parent2_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="parent2_id" property="Address" value="$M$4" type="String" /><column name="parent2_id" property="ColumnWidth" value="24.43" type="Double" /><column name="parent2_id" property="NumberFormat" value="General" type="String" /><column name="section_type_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="section_type_id" property="Address" value="$N$4" type="String" /><column name="section_type_id" property="ColumnWidth" value="21.57" type="Double" /><column name="section_type_id" property="NumberFormat" value="General" type="String" /><column name="inverse_sign" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="inverse_sign" property="Address" value="$O$4" type="String" /><column name="inverse_sign" property="ColumnWidth" value="13.71" type="Double" /><column name="inverse_sign" property="NumberFormat" value="General" type="String" /><column name="hide_items" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="hide_items" property="Address" value="$P$4" type="String" /><column name="hide_items" property="ColumnWidth" value="12.57" type="Double" /><column name="hide_items" property="NumberFormat" value="General" type="String" /><column name="hide_items" property="HorizontalAlignment" value="-4108" type="Double" /><column name="hide_items" property="Font.Size" value="10" type="Double" /><column name="show_line" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="show_line" property="Address" value="$Q$4" type="String" /><column name="show_line" property="ColumnWidth" value="10.71" type="Double" /><column name="show_line" property="NumberFormat" value="General" type="String" /><column name="show_line" property="HorizontalAlignment" value="-4108" type="Double" /><column name="show_line" property="Font.Size" value="9" type="Double" /><column name="show_line_before" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="show_line_before" property="Address" value="$R$4" type="String" /><column name="show_line_before" property="ColumnWidth" value="10.71" type="Double" /><column name="show_line_before" property="NumberFormat" value="General" type="String" /><column name="show_line_before" property="HorizontalAlignment" value="-4108" type="Double" /><column name="show_line_before" property="Font.Size" value="9" type="Double" /><column name="show_line_after" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="show_line_after" property="Address" value="$S$4" type="String" /><column name="show_line_after" property="ColumnWidth" value="10.71" type="Double" /><column name="show_line_after" property="NumberFormat" value="General" type="String" /><column name="show_line_after" property="HorizontalAlignment" value="-4108" type="Double" /><column name="show_line_after" property="Font.Size" value="9" type="Double" /><column name="page_break_before" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="page_break_before" property="Address" value="$T$4" type="String" /><column name="page_break_before" property="ColumnWidth" value="10.71" type="Double" /><column name="page_break_before" property="NumberFormat" value="General" type="String" /><column name="page_break_before" property="HorizontalAlignment" value="-4108" type="Double" /><column name="page_break_before" property="Font.Size" value="9" type="Double" /><column name="row_format" property="FormatConditions(1).AppliesTo.Address" value="$G$4:$G$99" type="String" /><column name="row_format" property="FormatConditions(1).Type" value="2" type="Double" /><column name="row_format" property="FormatConditions(1).Priority" value="1" type="Double" /><column name="row_format" property="FormatConditions(1).Formula1" value="=$G4=8" type="String" /><column name="row_format" property="FormatConditions(2).AppliesTo.Address" value="$G$4:$G$99" type="String" /><column name="row_format" property="FormatConditions(2).Type" value="2" type="Double" /><column name="row_format" property="FormatConditions(2).Priority" value="2" type="Double" /><column name="row_format" property="FormatConditions(2).Formula1" value="=$G4=2" type="String" /><column name="row_format" property="FormatConditions(2).Font.Bold" value="True" type="Boolean" /><column name="row_format" property="FormatConditions(3).AppliesTo.Address" value="$G$4:$G$99" type="String" /><column name="row_format" property="FormatConditions(3).Type" value="2" type="Double" /><column name="row_format" property="FormatConditions(3).Priority" value="3" type="Double" /><column name="row_format" property="FormatConditions(3).Formula1" value="=$G4=1" type="String" /><column name="row_format" property="FormatConditions(3).Font.Bold" value="True" type="Boolean" /><column name="row_format" property="FormatConditions(3).Font.Color" value="16777215" type="Double" /><column name="row_format" property="FormatConditions(3).Font.ThemeColor" value="1" type="Double" /><column name="row_format" property="FormatConditions(3).Font.TintAndShade" value="0" type="Double" /><column name="row_format" property="FormatConditions(3).Interior.Color" value="6773025" type="Double" /><column name="row_format" property="FormatConditions(4).AppliesTo.Address" value="$G$4:$G$99" type="String" /><column name="row_format" property="FormatConditions(4).Type" value="2" type="Double" /><column name="row_format" property="FormatConditions(4).Priority" value="4" type="Double" /><column name="row_format" property="FormatConditions(4).Formula1" value="=$G4=9" type="String" /><column name="row_format" property="FormatConditions(4).Font.Bold" value="True" type="Boolean" /><column name="row_format" property="FormatConditions(4).Font.Color" value="16777215" type="Double" /><column name="row_format" property="FormatConditions(4).Font.ThemeColor" value="1" type="Double" /><column name="row_format" property="FormatConditions(4).Font.TintAndShade" value="0" type="Double" /><column name="row_format" property="FormatConditions(4).Interior.Color" value="6299904" type="Double" /><column name="hide_items" property="FormatConditions(1).AppliesTo.Address" value="$P$4:$P$99" type="String" /><column name="hide_items" property="FormatConditions(1).Type" value="6" type="Double" /><column name="hide_items" property="FormatConditions(1).Priority" value="9" type="Double" /><column name="hide_items" property="FormatConditions(1).ShowIconOnly" value="True" type="Boolean" /><column name="hide_items" property="FormatConditions(1).IconSet.ID" value="8" type="Double" /><column name="hide_items" property="FormatConditions(1).IconCriteria(1).Type" value="3" type="Double" /><column name="hide_items" property="FormatConditions(1).IconCriteria(1).Operator" value="7" type="Double" /><column name="hide_items" property="FormatConditions(1).IconCriteria(2).Type" value="0" type="Double" /><column name="hide_items" property="FormatConditions(1).IconCriteria(2).Value" value="0.5" type="Double" /><column name="hide_items" property="FormatConditions(1).IconCriteria(2).Operator" value="7" type="Double" /><column name="hide_items" property="FormatConditions(1).IconCriteria(3).Type" value="0" type="Double" /><column name="hide_items" property="FormatConditions(1).IconCriteria(3).Value" value="1" type="Double" /><column name="hide_items" property="FormatConditions(1).IconCriteria(3).Operator" value="7" type="Double" /><column name="show_line" property="FormatConditions(1).AppliesTo.Address" value="$Q$4:$Q$99" type="String" /><column name="show_line" property="FormatConditions(1).Type" value="6" type="Double" /><column name="show_line" property="FormatConditions(1).Priority" value="5" type="Double" /><column name="show_line" property="FormatConditions(1).ShowIconOnly" value="True" type="Boolean" /><column name="show_line" property="FormatConditions(1).IconSet.ID" value="8" type="Double" /><column name="show_line" property="FormatConditions(1).IconCriteria(1).Type" value="3" type="Double" /><column name="show_line" property="FormatConditions(1).IconCriteria(1).Operator" value="7" type="Double" /><column name="show_line" property="FormatConditions(1).IconCriteria(2).Type" value="0" type="Double" /><column name="show_line" property="FormatConditions(1).IconCriteria(2).Value" value="0.5" type="Double" /><column name="show_line" property="FormatConditions(1).IconCriteria(2).Operator" value="7" type="Double" /><column name="show_line" property="FormatConditions(1).IconCriteria(3).Type" value="0" type="Double" /><column name="show_line" property="FormatConditions(1).IconCriteria(3).Value" value="1" type="Double" /><column name="show_line" property="FormatConditions(1).IconCriteria(3).Operator" value="7" type="Double" /><column name="show_line_before" property="FormatConditions(1).AppliesTo.Address" value="$R$4:$R$99" type="String" /><column name="show_line_before" property="FormatConditions(1).Type" value="6" type="Double" /><column name="show_line_before" property="FormatConditions(1).Priority" value="6" type="Double" /><column name="show_line_before" property="FormatConditions(1).ShowIconOnly" value="True" type="Boolean" /><column name="show_line_before" property="FormatConditions(1).IconSet.ID" value="8" type="Double" /><column name="show_line_before" property="FormatConditions(1).IconCriteria(1).Type" value="3" type="Double" /><column name="show_line_before" property="FormatConditions(1).IconCriteria(1).Operator" value="7" type="Double" /><column name="show_line_before" property="FormatConditions(1).IconCriteria(2).Type" value="0" type="Double" /><column name="show_line_before" property="FormatConditions(1).IconCriteria(2).Value" value="0.5" type="Double" /><column name="show_line_before" property="FormatConditions(1).IconCriteria(2).Operator" value="7" type="Double" /><column name="show_line_before" property="FormatConditions(1).IconCriteria(3).Type" value="0" type="Double" /><column name="show_line_before" property="FormatConditions(1).IconCriteria(3).Value" value="1" type="Double" /><column name="show_line_before" property="FormatConditions(1).IconCriteria(3).Operator" value="7" type="Double" /><column name="show_line_after" property="FormatConditions(1).AppliesTo.Address" value="$S$4:$S$99" type="String" /><column name="show_line_after" property="FormatConditions(1).Type" value="6" type="Double" /><column name="show_line_after" property="FormatConditions(1).Priority" value="7" type="Double" /><column name="show_line_after" property="FormatConditions(1).ShowIconOnly" value="True" type="Boolean" /><column name="show_line_after" property="FormatConditions(1).IconSet.ID" value="8" type="Double" /><column name="show_line_after" property="FormatConditions(1).IconCriteria(1).Type" value="3" type="Double" /><column name="show_line_after" property="FormatConditions(1).IconCriteria(1).Operator" value="7" type="Double" /><column name="show_line_after" property="FormatConditions(1).IconCriteria(2).Type" value="0" type="Double" /><column name="show_line_after" property="FormatConditions(1).IconCriteria(2).Value" value="0.5" type="Double" /><column name="show_line_after" property="FormatConditions(1).IconCriteria(2).Operator" value="7" type="Double" /><column name="show_line_after" property="FormatConditions(1).IconCriteria(3).Type" value="0" type="Double" /><column name="show_line_after" property="FormatConditions(1).IconCriteria(3).Value" value="1" type="Double" /><column name="show_line_after" property="FormatConditions(1).IconCriteria(3).Operator" value="7" type="Double" /><column name="page_break_before" property="FormatConditions(1).AppliesTo.Address" value="$T$4:$T$99" type="String" /><column name="page_break_before" property="FormatConditions(1).Type" value="6" type="Double" /><column name="page_break_before" property="FormatConditions(1).Priority" value="8" type="Double" /><column name="page_break_before" property="FormatConditions(1).ShowIconOnly" value="True" type="Boolean" /><column name="page_break_before" property="FormatConditions(1).IconSet.ID" value="8" type="Double" /><column name="page_break_before" property="FormatConditions(1).IconCriteria(1).Type" value="3" type="Double" /><column name="page_break_before" property="FormatConditions(1).IconCriteria(1).Operator" value="7" type="Double" /><column name="page_break_before" property="FormatConditions(1).IconCriteria(2).Type" value="0" type="Double" /><column name="page_break_before" property="FormatConditions(1).IconCriteria(2).Value" value="0.5" type="Double" /><column name="page_break_before" property="FormatConditions(1).IconCriteria(2).Operator" value="7" type="Double" /><column name="page_break_before" property="FormatConditions(1).IconCriteria(3).Type" value="0" type="Double" /><column name="page_break_before" property="FormatConditions(1).IconCriteria(3).Value" value="1" type="Double" /><column name="page_break_before" property="FormatConditions(1).IconCriteria(3).Operator" value="7" type="Double" /><column name="" property="Tab.Color" value="6299648" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats><views><view name="Form"><column name="" property="ListObjectName" value="report_section_types" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="report_type_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="section" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="row_format" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="ref_number" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="description" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="translated_name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="parent_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="parent2_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="section_type_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="inverse_sign" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="hide_items" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="show_line" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="show_line_before" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="show_line_after" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="page_break_before" property="EntireColumn.Hidden" value="False" type="Boolean" /></view><view name="All Columns"><column name="" property="ListObjectName" value="report_section_types" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="sort_order" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="report_type_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="section" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="row_format" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="ref_number" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="description" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="translated_name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="parent_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="parent2_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="section_type_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="inverse_sign" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="hide_items" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="show_line" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="show_line_before" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="show_line_after" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="page_break_before" property="EntireColumn.Hidden" value="False" type="Boolean" /></view></views></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N'xls27', N'usp_report_types', N'<table name="xls27.usp_report_types"><columnFormats><column name="" property="ListObjectName" value="report_types" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="id" property="Address" value="$C$4" type="String" /><column name="id" property="ColumnWidth" value="4.29" type="Double" /><column name="id" property="NumberFormat" value="General" type="String" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="Address" value="$D$4" type="String" /><column name="code" property="ColumnWidth" value="6.86" type="Double" /><column name="code" property="NumberFormat" value="General" type="String" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="Address" value="$E$4" type="String" /><column name="name" property="ColumnWidth" value="27.86" type="Double" /><column name="name" property="NumberFormat" value="General" type="String" /><column name="" property="Tab.Color" value="0" type="Double" /><column name="" property="Tab.ThemeColor" value="2" type="Double" /><column name="" property="Tab.TintAndShade" value="0" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N'xls27', N'usp_role_members', N'<table name="xls27.usp_role_members"><columnFormats><column name="" property="ListObjectName" value="role_members" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="type" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="type" property="Address" value="$C$4" type="String" /><column name="type" property="ColumnWidth" value="13" type="Double" /><column name="type" property="NumberFormat" value="General" type="String" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="Address" value="$D$4" type="String" /><column name="name" property="ColumnWidth" value="26.71" type="Double" /><column name="name" property="NumberFormat" value="General" type="String" /><column name="format_column" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="format_column" property="Address" value="$E$4" type="String" /><column name="format_column" property="NumberFormat" value="General" type="String" /><column name="format_column" property="HorizontalAlignment" value="-4108" type="Double" /><column name="format_column" property="Font.Size" value="9" type="Double" /><column name="budgeting_app_accountants" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="budgeting_app_accountants" property="Address" value="$F$4" type="String" /><column name="budgeting_app_accountants" property="ColumnWidth" value="28" type="Double" /><column name="budgeting_app_accountants" property="NumberFormat" value="General" type="String" /><column name="budgeting_app_accountants" property="HorizontalAlignment" value="-4108" type="Double" /><column name="budgeting_app_accountants" property="Font.Size" value="9" type="Double" /><column name="budgeting_app_admins" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="budgeting_app_admins" property="Address" value="$G$4" type="String" /><column name="budgeting_app_admins" property="ColumnWidth" value="23.71" type="Double" /><column name="budgeting_app_admins" property="NumberFormat" value="General" type="String" /><column name="budgeting_app_admins" property="HorizontalAlignment" value="-4108" type="Double" /><column name="budgeting_app_admins" property="Font.Size" value="9" type="Double" /><column name="budgeting_app_users" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="budgeting_app_users" property="Address" value="$H$4" type="String" /><column name="budgeting_app_users" property="ColumnWidth" value="21.86" type="Double" /><column name="budgeting_app_users" property="NumberFormat" value="General" type="String" /><column name="budgeting_app_users" property="HorizontalAlignment" value="-4108" type="Double" /><column name="budgeting_app_users" property="Font.Size" value="9" type="Double" /><column name="xls_admins" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="xls_admins" property="Address" value="$I$4" type="String" /><column name="xls_admins" property="ColumnWidth" value="12.43" type="Double" /><column name="xls_admins" property="NumberFormat" value="General" type="String" /><column name="xls_admins" property="HorizontalAlignment" value="-4108" type="Double" /><column name="xls_admins" property="Font.Size" value="9" type="Double" /><column name="xls_developers" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="xls_developers" property="Address" value="$J$4" type="String" /><column name="xls_developers" property="ColumnWidth" value="16.14" type="Double" /><column name="xls_developers" property="NumberFormat" value="General" type="String" /><column name="xls_developers" property="HorizontalAlignment" value="-4108" type="Double" /><column name="xls_developers" property="Font.Size" value="9" type="Double" /><column name="xls_formats" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="xls_formats" property="Address" value="$K$4" type="String" /><column name="xls_formats" property="ColumnWidth" value="12.86" type="Double" /><column name="xls_formats" property="NumberFormat" value="General" type="String" /><column name="xls_formats" property="HorizontalAlignment" value="-4108" type="Double" /><column name="xls_formats" property="Font.Size" value="9" type="Double" /><column name="xls_users" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="xls_users" property="Address" value="$L$4" type="String" /><column name="xls_users" property="ColumnWidth" value="10.71" type="Double" /><column name="xls_users" property="NumberFormat" value="General" type="String" /><column name="xls_users" property="HorizontalAlignment" value="-4108" type="Double" /><column name="xls_users" property="Font.Size" value="9" type="Double" /><column name="last_format_column" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="last_format_column" property="Address" value="$M$4" type="String" /><column name="last_format_column" property="NumberFormat" value="General" type="String" /><column name="last_format_column" property="HorizontalAlignment" value="-4108" type="Double" /><column name="last_format_column" property="Font.Size" value="9" type="Double" /><column name="format_column" property="FormatConditions(1).ColumnsCount" value="3" type="Double" /><column name="format_column" property="FormatConditions(1).AppliesTo.Address" value="$E$4:$G$11" type="String" /><column name="format_column" property="FormatConditions(1).Type" value="6" type="Double" /><column name="format_column" property="FormatConditions(1).Priority" value="29" type="Double" /><column name="format_column" property="FormatConditions(1).ShowIconOnly" value="True" type="Boolean" /><column name="format_column" property="FormatConditions(1).IconSet.ID" value="8" type="Double" /><column name="format_column" property="FormatConditions(1).IconCriteria(1).Type" value="3" type="Double" /><column name="format_column" property="FormatConditions(1).IconCriteria(1).Operator" value="7" type="Double" /><column name="format_column" property="FormatConditions(1).IconCriteria(2).Type" value="0" type="Double" /><column name="format_column" property="FormatConditions(1).IconCriteria(2).Value" value="0.5" type="Double" /><column name="format_column" property="FormatConditions(1).IconCriteria(2).Operator" value="7" type="Double" /><column name="format_column" property="FormatConditions(1).IconCriteria(3).Type" value="0" type="Double" /><column name="format_column" property="FormatConditions(1).IconCriteria(3).Value" value="1" type="Double" /><column name="format_column" property="FormatConditions(1).IconCriteria(3).Operator" value="7" type="Double" /><column name="format_column" property="FormatConditions(2).ColumnsCount" value="9" type="Double" /><column name="format_column" property="FormatConditions(2).AppliesTo.Address" value="$E$4:$M$11" type="String" /><column name="format_column" property="FormatConditions(2).Type" value="6" type="Double" /><column name="format_column" property="FormatConditions(2).Priority" value="33" type="Double" /><column name="format_column" property="FormatConditions(2).ShowIconOnly" value="True" type="Boolean" /><column name="format_column" property="FormatConditions(2).IconSet.ID" value="8" type="Double" /><column name="format_column" property="FormatConditions(2).IconCriteria(1).Type" value="3" type="Double" /><column name="format_column" property="FormatConditions(2).IconCriteria(1).Operator" value="7" type="Double" /><column name="format_column" property="FormatConditions(2).IconCriteria(2).Type" value="0" type="Double" /><column name="format_column" property="FormatConditions(2).IconCriteria(2).Value" value="0.5" type="Double" /><column name="format_column" property="FormatConditions(2).IconCriteria(2).Operator" value="7" type="Double" /><column name="format_column" property="FormatConditions(2).IconCriteria(3).Type" value="0" type="Double" /><column name="format_column" property="FormatConditions(2).IconCriteria(3).Value" value="1" type="Double" /><column name="format_column" property="FormatConditions(2).IconCriteria(3).Operator" value="7" type="Double" /><column name="budgeting_app_admins" property="FormatConditions(1).ColumnsCount" value="5" type="Double" /><column name="budgeting_app_admins" property="FormatConditions(1).AppliesTo.Address" value="$G$4:$K$11" type="String" /><column name="budgeting_app_admins" property="FormatConditions(1).Type" value="6" type="Double" /><column name="budgeting_app_admins" property="FormatConditions(1).Priority" value="31" type="Double" /><column name="budgeting_app_admins" property="FormatConditions(1).ShowIconOnly" value="True" type="Boolean" /><column name="budgeting_app_admins" property="FormatConditions(1).IconSet.ID" value="8" type="Double" /><column name="budgeting_app_admins" property="FormatConditions(1).IconCriteria(1).Type" value="3" type="Double" /><column name="budgeting_app_admins" property="FormatConditions(1).IconCriteria(1).Operator" value="7" type="Double" /><column name="budgeting_app_admins" property="FormatConditions(1).IconCriteria(2).Type" value="0" type="Double" /><column name="budgeting_app_admins" property="FormatConditions(1).IconCriteria(2).Value" value="0.5" type="Double" /><column name="budgeting_app_admins" property="FormatConditions(1).IconCriteria(2).Operator" value="7" type="Double" /><column name="budgeting_app_admins" property="FormatConditions(1).IconCriteria(3).Type" value="0" type="Double" /><column name="budgeting_app_admins" property="FormatConditions(1).IconCriteria(3).Value" value="1" type="Double" /><column name="budgeting_app_admins" property="FormatConditions(1).IconCriteria(3).Operator" value="7" type="Double" /><column name="" property="Tab.Color" value="6299648" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N'xls27', N'usp_saved_report_types', N'<table name="xls27.usp_saved_report_types"><columnFormats><column name="" property="ListObjectName" value="saved_report_types" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="id" property="Address" value="$C$4" type="String" /><column name="id" property="ColumnWidth" value="4.43" type="Double" /><column name="id" property="NumberFormat" value="General" type="String" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="Address" value="$D$4" type="String" /><column name="code" property="ColumnWidth" value="14.71" type="Double" /><column name="code" property="NumberFormat" value="General" type="String" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="Address" value="$E$4" type="String" /><column name="name" property="ColumnWidth" value="21.43" type="Double" /><column name="name" property="NumberFormat" value="General" type="String" /><column name="translated_name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="translated_name" property="Address" value="$F$4" type="String" /><column name="translated_name" property="ColumnWidth" value="26" type="Double" /><column name="translated_name" property="NumberFormat" value="General" type="String" /><column name="" property="Tab.Color" value="6299648" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N'xls27', N'usp_saved_reports', N'<table name="xls27.usp_saved_reports"><columnFormats><column name="" property="ListObjectName" value="base_report" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="saved_row_index" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="saved_row_index" property="Address" value="$C$4" type="String" /><column name="saved_row_index" property="NumberFormat" value="General" type="String" /><column name="saved_row_index" property="Validation.Type" value="2" type="Double" /><column name="saved_row_index" property="Validation.Operator" value="4" type="Double" /><column name="saved_row_index" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="saved_row_index" property="Validation.AlertStyle" value="1" type="Double" /><column name="saved_row_index" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="saved_row_index" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="saved_row_index" property="Validation.ShowInput" value="True" type="Boolean" /><column name="saved_row_index" property="Validation.ShowError" value="True" type="Boolean" /><column name="id1" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="id1" property="Address" value="$D$4" type="String" /><column name="id1" property="NumberFormat" value="General" type="String" /><column name="id1" property="Validation.Type" value="6" type="Double" /><column name="id1" property="Validation.Operator" value="8" type="Double" /><column name="id1" property="Validation.Formula1" value="50" type="String" /><column name="id1" property="Validation.AlertStyle" value="1" type="Double" /><column name="id1" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="id1" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="id1" property="Validation.ShowInput" value="True" type="Boolean" /><column name="id1" property="Validation.ShowError" value="True" type="Boolean" /><column name="id2" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="id2" property="Address" value="$E$4" type="String" /><column name="id2" property="NumberFormat" value="General" type="String" /><column name="id2" property="Validation.Type" value="1" type="Double" /><column name="id2" property="Validation.Operator" value="1" type="Double" /><column name="id2" property="Validation.Formula1" value="-2147483648" type="String" /><column name="id2" property="Validation.Formula2" value="2147483647" type="String" /><column name="id2" property="Validation.AlertStyle" value="1" type="Double" /><column name="id2" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="id2" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="id2" property="Validation.ShowInput" value="True" type="Boolean" /><column name="id2" property="Validation.ShowError" value="True" type="Boolean" /><column name="ref_number" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="ref_number" property="Address" value="$F$4" type="String" /><column name="ref_number" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="ref_number" property="Validation.Type" value="2" type="Double" /><column name="ref_number" property="Validation.Operator" value="4" type="Double" /><column name="ref_number" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="ref_number" property="Validation.AlertStyle" value="1" type="Double" /><column name="ref_number" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="ref_number" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="ref_number" property="Validation.ShowInput" value="True" type="Boolean" /><column name="ref_number" property="Validation.ShowError" value="True" type="Boolean" /><column name="account" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="account" property="Address" value="$G$4" type="String" /><column name="account" property="NumberFormat" value="General" type="String" /><column name="report" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="report" property="Address" value="$H$4" type="String" /><column name="report" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="report" property="Validation.Type" value="2" type="Double" /><column name="report" property="Validation.Operator" value="4" type="Double" /><column name="report" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="report" property="Validation.AlertStyle" value="1" type="Double" /><column name="report" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="report" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="report" property="Validation.ShowInput" value="True" type="Boolean" /><column name="report" property="Validation.ShowError" value="True" type="Boolean" /><column name="page_break" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="page_break" property="Address" value="$I$4" type="String" /><column name="page_break" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="page_break" property="Validation.Type" value="2" type="Double" /><column name="page_break" property="Validation.Operator" value="4" type="Double" /><column name="page_break" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="page_break" property="Validation.AlertStyle" value="1" type="Double" /><column name="page_break" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="page_break" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="page_break" property="Validation.ShowInput" value="True" type="Boolean" /><column name="page_break" property="Validation.ShowError" value="True" type="Boolean" /><column name="row_level" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_level" property="Address" value="$J$4" type="String" /><column name="row_level" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="row_level" property="Validation.Type" value="2" type="Double" /><column name="row_level" property="Validation.Operator" value="4" type="Double" /><column name="row_level" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="row_level" property="Validation.AlertStyle" value="1" type="Double" /><column name="row_level" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="row_level" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="row_level" property="Validation.ShowInput" value="True" type="Boolean" /><column name="row_level" property="Validation.ShowError" value="True" type="Boolean" /><column name="row_format" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_format" property="Address" value="$K$4" type="String" /><column name="row_format" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="row_format" property="Validation.Type" value="2" type="Double" /><column name="row_format" property="Validation.Operator" value="4" type="Double" /><column name="row_format" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="row_format" property="Validation.AlertStyle" value="1" type="Double" /><column name="row_format" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="row_format" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="row_format" property="Validation.ShowInput" value="True" type="Boolean" /><column name="row_format" property="Validation.ShowError" value="True" type="Boolean" /><column name="hide" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="hide" property="Address" value="$L$4" type="String" /><column name="hide" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="hide" property="Validation.Type" value="2" type="Double" /><column name="hide" property="Validation.Operator" value="4" type="Double" /><column name="hide" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="hide" property="Validation.AlertStyle" value="1" type="Double" /><column name="hide" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="hide" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="hide" property="Validation.ShowInput" value="True" type="Boolean" /><column name="hide" property="Validation.ShowError" value="True" type="Boolean" /><column name="zero" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="zero" property="Address" value="$M$4" type="String" /><column name="zero" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="zero" property="Validation.Type" value="2" type="Double" /><column name="zero" property="Validation.Operator" value="4" type="Double" /><column name="zero" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="zero" property="Validation.AlertStyle" value="1" type="Double" /><column name="zero" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="zero" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="zero" property="Validation.ShowInput" value="True" type="Boolean" /><column name="zero" property="Validation.ShowError" value="True" type="Boolean" /><column name="code1" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="code1" property="Address" value="$N$4" type="String" /><column name="code1" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="code1" property="Validation.Type" value="2" type="Double" /><column name="code1" property="Validation.Operator" value="4" type="Double" /><column name="code1" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="code1" property="Validation.AlertStyle" value="1" type="Double" /><column name="code1" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="code1" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="code1" property="Validation.ShowInput" value="True" type="Boolean" /><column name="code1" property="Validation.ShowError" value="True" type="Boolean" /><column name="code2" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="code2" property="Address" value="$O$4" type="String" /><column name="code2" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="code2" property="Validation.Type" value="2" type="Double" /><column name="code2" property="Validation.Operator" value="4" type="Double" /><column name="code2" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="code2" property="Validation.AlertStyle" value="1" type="Double" /><column name="code2" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="code2" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="code2" property="Validation.ShowInput" value="True" type="Boolean" /><column name="code2" property="Validation.ShowError" value="True" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="Address" value="$P$4" type="String" /><column name="code" property="ColumnWidth" value="6.43" type="Double" /><column name="code" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="code" property="Validation.Type" value="2" type="Double" /><column name="code" property="Validation.Operator" value="4" type="Double" /><column name="code" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="code" property="Validation.AlertStyle" value="1" type="Double" /><column name="code" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="code" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="code" property="Validation.ShowInput" value="True" type="Boolean" /><column name="code" property="Validation.ShowError" value="True" type="Boolean" /><column name="description" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="description" property="Address" value="$Q$4" type="String" /><column name="description" property="ColumnWidth" value="42.14" type="Double" /><column name="description" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="description" property="Validation.Type" value="2" type="Double" /><column name="description" property="Validation.Operator" value="4" type="Double" /><column name="description" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="description" property="Validation.AlertStyle" value="1" type="Double" /><column name="description" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="description" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="description" property="Validation.ShowInput" value="True" type="Boolean" /><column name="description" property="Validation.ShowError" value="True" type="Boolean" /><column name="data00" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data00" property="Address" value="$R$4" type="String" /><column name="data00" property="ColumnWidth" value="12.71" type="Double" /><column name="data00" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="data00" property="Validation.Type" value="2" type="Double" /><column name="data00" property="Validation.Operator" value="4" type="Double" /><column name="data00" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="data00" property="Validation.AlertStyle" value="1" type="Double" /><column name="data00" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="data00" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="data00" property="Validation.ShowInput" value="True" type="Boolean" /><column name="data00" property="Validation.ShowError" value="True" type="Boolean" /><column name="data01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data01" property="Address" value="$S$4" type="String" /><column name="data01" property="ColumnWidth" value="12.71" type="Double" /><column name="data01" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="data01" property="Validation.Type" value="2" type="Double" /><column name="data01" property="Validation.Operator" value="4" type="Double" /><column name="data01" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="data01" property="Validation.AlertStyle" value="1" type="Double" /><column name="data01" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="data01" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="data01" property="Validation.ShowInput" value="True" type="Boolean" /><column name="data01" property="Validation.ShowError" value="True" type="Boolean" /><column name="data02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data02" property="Address" value="$T$4" type="String" /><column name="data02" property="ColumnWidth" value="12.71" type="Double" /><column name="data02" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="data02" property="Validation.Type" value="2" type="Double" /><column name="data02" property="Validation.Operator" value="4" type="Double" /><column name="data02" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="data02" property="Validation.AlertStyle" value="1" type="Double" /><column name="data02" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="data02" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="data02" property="Validation.ShowInput" value="True" type="Boolean" /><column name="data02" property="Validation.ShowError" value="True" type="Boolean" /><column name="data03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data03" property="Address" value="$U$4" type="String" /><column name="data03" property="ColumnWidth" value="12.71" type="Double" /><column name="data03" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="data03" property="Validation.Type" value="2" type="Double" /><column name="data03" property="Validation.Operator" value="4" type="Double" /><column name="data03" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="data03" property="Validation.AlertStyle" value="1" type="Double" /><column name="data03" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="data03" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="data03" property="Validation.ShowInput" value="True" type="Boolean" /><column name="data03" property="Validation.ShowError" value="True" type="Boolean" /><column name="data04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data04" property="Address" value="$V$4" type="String" /><column name="data04" property="ColumnWidth" value="12.71" type="Double" /><column name="data04" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="data04" property="Validation.Type" value="2" type="Double" /><column name="data04" property="Validation.Operator" value="4" type="Double" /><column name="data04" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="data04" property="Validation.AlertStyle" value="1" type="Double" /><column name="data04" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="data04" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="data04" property="Validation.ShowInput" value="True" type="Boolean" /><column name="data04" property="Validation.ShowError" value="True" type="Boolean" /><column name="data05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data05" property="Address" value="$W$4" type="String" /><column name="data05" property="ColumnWidth" value="12.71" type="Double" /><column name="data05" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="data05" property="Validation.Type" value="2" type="Double" /><column name="data05" property="Validation.Operator" value="4" type="Double" /><column name="data05" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="data05" property="Validation.AlertStyle" value="1" type="Double" /><column name="data05" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="data05" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="data05" property="Validation.ShowInput" value="True" type="Boolean" /><column name="data05" property="Validation.ShowError" value="True" type="Boolean" /><column name="data06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data06" property="Address" value="$X$4" type="String" /><column name="data06" property="ColumnWidth" value="12.71" type="Double" /><column name="data06" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="data06" property="Validation.Type" value="2" type="Double" /><column name="data06" property="Validation.Operator" value="4" type="Double" /><column name="data06" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="data06" property="Validation.AlertStyle" value="1" type="Double" /><column name="data06" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="data06" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="data06" property="Validation.ShowInput" value="True" type="Boolean" /><column name="data06" property="Validation.ShowError" value="True" type="Boolean" /><column name="data07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data07" property="Address" value="$Y$4" type="String" /><column name="data07" property="ColumnWidth" value="12.71" type="Double" /><column name="data07" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="data07" property="Validation.Type" value="2" type="Double" /><column name="data07" property="Validation.Operator" value="4" type="Double" /><column name="data07" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="data07" property="Validation.AlertStyle" value="1" type="Double" /><column name="data07" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="data07" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="data07" property="Validation.ShowInput" value="True" type="Boolean" /><column name="data07" property="Validation.ShowError" value="True" type="Boolean" /><column name="data08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data08" property="Address" value="$Z$4" type="String" /><column name="data08" property="ColumnWidth" value="12.71" type="Double" /><column name="data08" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="data08" property="Validation.Type" value="2" type="Double" /><column name="data08" property="Validation.Operator" value="4" type="Double" /><column name="data08" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="data08" property="Validation.AlertStyle" value="1" type="Double" /><column name="data08" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="data08" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="data08" property="Validation.ShowInput" value="True" type="Boolean" /><column name="data08" property="Validation.ShowError" value="True" type="Boolean" /><column name="data09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data09" property="Address" value="$AA$4" type="String" /><column name="data09" property="ColumnWidth" value="12.71" type="Double" /><column name="data09" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="data09" property="Validation.Type" value="2" type="Double" /><column name="data09" property="Validation.Operator" value="4" type="Double" /><column name="data09" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="data09" property="Validation.AlertStyle" value="1" type="Double" /><column name="data09" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="data09" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="data09" property="Validation.ShowInput" value="True" type="Boolean" /><column name="data09" property="Validation.ShowError" value="True" type="Boolean" /><column name="data10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data10" property="Address" value="$AB$4" type="String" /><column name="data10" property="ColumnWidth" value="12.71" type="Double" /><column name="data10" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="data10" property="Validation.Type" value="2" type="Double" /><column name="data10" property="Validation.Operator" value="4" type="Double" /><column name="data10" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="data10" property="Validation.AlertStyle" value="1" type="Double" /><column name="data10" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="data10" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="data10" property="Validation.ShowInput" value="True" type="Boolean" /><column name="data10" property="Validation.ShowError" value="True" type="Boolean" /><column name="data11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data11" property="Address" value="$AC$4" type="String" /><column name="data11" property="ColumnWidth" value="12.71" type="Double" /><column name="data11" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="data11" property="Validation.Type" value="2" type="Double" /><column name="data11" property="Validation.Operator" value="4" type="Double" /><column name="data11" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="data11" property="Validation.AlertStyle" value="1" type="Double" /><column name="data11" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="data11" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="data11" property="Validation.ShowInput" value="True" type="Boolean" /><column name="data11" property="Validation.ShowError" value="True" type="Boolean" /><column name="data12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data12" property="Address" value="$AD$4" type="String" /><column name="data12" property="ColumnWidth" value="12.71" type="Double" /><column name="data12" property="NumberFormat" value="#,##0;-#,##0;" type="String" /><column name="data12" property="Validation.Type" value="2" type="Double" /><column name="data12" property="Validation.Operator" value="4" type="Double" /><column name="data12" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="data12" property="Validation.AlertStyle" value="1" type="Double" /><column name="data12" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="data12" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="data12" property="Validation.ShowInput" value="True" type="Boolean" /><column name="data12" property="Validation.ShowError" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(1).AppliesToTable" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(1).AppliesTo.Address" value="$B$4:$AD$306" type="String" /><column name="_RowNum" property="FormatConditions(1).Type" value="2" type="Double" /><column name="_RowNum" property="FormatConditions(1).Priority" value="214" type="Double" /><column name="_RowNum" property="FormatConditions(1).StopIfTrue" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(1).Formula1" value="=$K4=9" type="String" /><column name="_RowNum" property="FormatConditions(1).Font.Bold" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(1).Font.Color" value="16777215" type="Double" /><column name="_RowNum" property="FormatConditions(1).Font.ThemeColor" value="1" type="Double" /><column name="_RowNum" property="FormatConditions(1).Font.TintAndShade" value="0" type="Double" /><column name="_RowNum" property="FormatConditions(1).Interior.Color" value="6299904" type="Double" /><column name="_RowNum" property="FormatConditions(2).AppliesToTable" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(2).AppliesTo.Address" value="$B$4:$AD$306" type="String" /><column name="_RowNum" property="FormatConditions(2).Type" value="2" type="Double" /><column name="_RowNum" property="FormatConditions(2).Priority" value="215" type="Double" /><column name="_RowNum" property="FormatConditions(2).StopIfTrue" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(2).Formula1" value="=$K4=2" type="String" /><column name="_RowNum" property="FormatConditions(2).Font.Bold" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(3).AppliesToTable" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(3).AppliesTo.Address" value="$B$4:$AD$306" type="String" /><column name="_RowNum" property="FormatConditions(3).Type" value="2" type="Double" /><column name="_RowNum" property="FormatConditions(3).Priority" value="216" type="Double" /><column name="_RowNum" property="FormatConditions(3).StopIfTrue" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(3).Formula1" value="=$K4=1" type="String" /><column name="_RowNum" property="FormatConditions(3).Font.Bold" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(3).Font.Color" value="16777215" type="Double" /><column name="_RowNum" property="FormatConditions(3).Font.ThemeColor" value="1" type="Double" /><column name="_RowNum" property="FormatConditions(3).Font.TintAndShade" value="0" type="Double" /><column name="_RowNum" property="FormatConditions(3).Interior.Color" value="6773025" type="Double" /><column name="_RowNum" property="FormatConditions(4).AppliesToTable" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(4).AppliesTo.Address" value="$B$4:$AD$306" type="String" /><column name="_RowNum" property="FormatConditions(4).Type" value="2" type="Double" /><column name="_RowNum" property="FormatConditions(4).Priority" value="217" type="Double" /><column name="_RowNum" property="FormatConditions(4).StopIfTrue" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(4).Formula1" value="=$K4=4" type="String" /><column name="_RowNum" property="FormatConditions(4).Font.Italic" value="True" type="Boolean" /><column name="hide" property="AutoFilter.Criteria1" value="=1" type="String" /><column name="hide" property="AutoFilter.Operator" value="2" type="Double" /><column name="hide" property="AutoFilter.Criteria2" value="=" type="String" /><column name="" property="Tab.Color" value="6299648" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats><views><view name="All Columns"><column name="" property="ListObjectName" value="base_report" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="saved_row_index" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="id1" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="id2" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="ref_number" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="report" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="page_break" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="row_level" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="row_format" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="hide" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="zero" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code1" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code2" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="description" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data00" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data12" property="EntireColumn.Hidden" value="False" type="Boolean" /></view><view name="Report Columns"><column name="" property="ListObjectName" value="base_report" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="saved_row_index" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="id1" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="id2" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="ref_number" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="account" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="report" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="page_break" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_level" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_format" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="hide" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="zero" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="code1" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="code2" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="description" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data00" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="data12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="hide" property="AutoFilter.Criteria1" value="=1" type="String" /><column name="hide" property="AutoFilter.Operator" value="2" type="Double" /><column name="hide" property="AutoFilter.Criteria2" value="=" type="String" /></view></views></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N'xls27', N'usp_subsidiary_accounts', N'<table name="xls27.usp_subsidiary_accounts"><columnFormats><column name="" property="ListObjectName" value="subsidiary_accounts" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="id" property="Address" value="$C$4" type="String" /><column name="id" property="NumberFormat" value="General" type="String" /><column name="id" property="Validation.Type" value="1" type="Double" /><column name="id" property="Validation.Operator" value="1" type="Double" /><column name="id" property="Validation.Formula1" value="-2147483648" type="String" /><column name="id" property="Validation.Formula2" value="2147483647" type="String" /><column name="id" property="Validation.AlertStyle" value="2" type="Double" /><column name="id" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="id" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="id" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="id" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String" /><column name="id" property="Validation.ShowInput" value="True" type="Boolean" /><column name="id" property="Validation.ShowError" value="True" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="Address" value="$D$4" type="String" /><column name="code" property="ColumnWidth" value="13.57" type="Double" /><column name="code" property="NumberFormat" value="General" type="String" /><column name="code" property="Validation.Type" value="6" type="Double" /><column name="code" property="Validation.Operator" value="8" type="Double" /><column name="code" property="Validation.Formula1" value="50" type="String" /><column name="code" property="Validation.AlertStyle" value="2" type="Double" /><column name="code" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="code" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="code" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="code" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(50) datatype." type="String" /><column name="code" property="Validation.ShowInput" value="True" type="Boolean" /><column name="code" property="Validation.ShowError" value="True" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="Address" value="$E$4" type="String" /><column name="name" property="ColumnWidth" value="27.86" type="Double" /><column name="name" property="NumberFormat" value="General" type="String" /><column name="name" property="Validation.Type" value="6" type="Double" /><column name="name" property="Validation.Operator" value="8" type="Double" /><column name="name" property="Validation.Formula1" value="100" type="String" /><column name="name" property="Validation.AlertStyle" value="2" type="Double" /><column name="name" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="name" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="name" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="name" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(100) datatype." type="String" /><column name="name" property="Validation.ShowInput" value="True" type="Boolean" /><column name="name" property="Validation.ShowError" value="True" type="Boolean" /><column name="currency_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="currency_id" property="Address" value="$F$4" type="String" /><column name="currency_id" property="ColumnWidth" value="13.57" type="Double" /><column name="currency_id" property="NumberFormat" value="General" type="String" /><column name="group1" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="group1" property="Address" value="$G$4" type="String" /><column name="group1" property="ColumnWidth" value="20.71" type="Double" /><column name="group1" property="NumberFormat" value="General" type="String" /><column name="group2" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="group2" property="Address" value="$H$4" type="String" /><column name="group2" property="ColumnWidth" value="20.71" type="Double" /><column name="group2" property="NumberFormat" value="General" type="String" /><column name="group3" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="group3" property="Address" value="$I$4" type="String" /><column name="group3" property="ColumnWidth" value="20.71" type="Double" /><column name="group3" property="NumberFormat" value="General" type="String" /><column name="" property="Tab.Color" value="5287936" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N'xls27', N'usp_subsidiary_groups', N'<table name="xls27.usp_subsidiary_groups"><columnFormats><column name="" property="ListObjectName" value="subsidiary_groups" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="id" property="Address" value="$C$4" type="String" /><column name="id" property="ColumnWidth" value="4.29" type="Double" /><column name="id" property="NumberFormat" value="General" type="String" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="Address" value="$D$4" type="String" /><column name="code" property="ColumnWidth" value="14.57" type="Double" /><column name="code" property="NumberFormat" value="General" type="String" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="Address" value="$E$4" type="String" /><column name="name" property="ColumnWidth" value="27.86" type="Double" /><column name="name" property="NumberFormat" value="General" type="String" /><column name="translated_name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="translated_name" property="Address" value="$F$4" type="String" /><column name="translated_name" property="ColumnWidth" value="27.86" type="Double" /><column name="translated_name" property="NumberFormat" value="General" type="String" /><column name="SortFields(1)" property="KeyfieldName" value="id" type="String" /><column name="SortFields(1)" property="SortOn" value="0" type="Double" /><column name="SortFields(1)" property="Order" value="1" type="Double" /><column name="SortFields(1)" property="DataOption" value="0" type="Double" /><column name="" property="Tab.Color" value="6299648" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N'xls27', N'usp_translations', N'<table name="xls27.usp_translations"><columnFormats><column name="" property="ListObjectName" value="translations" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="table_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="table_id" property="Address" value="$C$4" type="String" /><column name="table_id" property="NumberFormat" value="General" type="String" /><column name="member_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="member_id" property="Address" value="$D$4" type="String" /><column name="member_id" property="NumberFormat" value="General" type="String" /><column name="table_name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="table_name" property="Address" value="$E$4" type="String" /><column name="table_name" property="ColumnWidth" value="18.14" type="Double" /><column name="table_name" property="NumberFormat" value="General" type="String" /><column name="is_translatable" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="is_translatable" property="Address" value="$F$4" type="String" /><column name="is_translatable" property="ColumnWidth" value="2.86" type="Double" /><column name="is_translatable" property="NumberFormat" value="General" type="String" /><column name="is_translatable" property="HorizontalAlignment" value="-4108" type="Double" /><column name="is_translatable" property="Font.Size" value="10" type="Double" /><column name="is_complete" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="is_complete" property="Address" value="$G$4" type="String" /><column name="is_complete" property="ColumnWidth" value="2.86" type="Double" /><column name="is_complete" property="NumberFormat" value="General" type="String" /><column name="is_complete" property="HorizontalAlignment" value="-4108" type="Double" /><column name="is_complete" property="Font.Size" value="10" type="Double" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="Address" value="$H$4" type="String" /><column name="name" property="ColumnWidth" value="50.57" type="Double" /><column name="name" property="NumberFormat" value="General" type="String" /><column name="fr" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="fr" property="Address" value="$I$4" type="String" /><column name="fr" property="ColumnWidth" value="50.57" type="Double" /><column name="fr" property="NumberFormat" value="General" type="String" /><column name="it" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="it" property="Address" value="$J$4" type="String" /><column name="it" property="ColumnWidth" value="50.57" type="Double" /><column name="it" property="NumberFormat" value="General" type="String" /><column name="es" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="es" property="Address" value="$K$4" type="String" /><column name="es" property="ColumnWidth" value="50.57" type="Double" /><column name="es" property="NumberFormat" value="General" type="String" /><column name="de" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="de" property="Address" value="$L$4" type="String" /><column name="de" property="ColumnWidth" value="50.57" type="Double" /><column name="de" property="NumberFormat" value="General" type="String" /><column name="ru" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="ru" property="Address" value="$M$4" type="String" /><column name="ru" property="ColumnWidth" value="63.71" type="Double" /><column name="ru" property="NumberFormat" value="General" type="String" /><column name="is_translatable" property="FormatConditions(1).AppliesTo.Address" value="$F$4:$F$280" type="String" /><column name="is_translatable" property="FormatConditions(1).Type" value="6" type="Double" /><column name="is_translatable" property="FormatConditions(1).Priority" value="1553" type="Double" /><column name="is_translatable" property="FormatConditions(1).ShowIconOnly" value="True" type="Boolean" /><column name="is_translatable" property="FormatConditions(1).IconSet.ID" value="8" type="Double" /><column name="is_translatable" property="FormatConditions(1).IconCriteria(1).Type" value="3" type="Double" /><column name="is_translatable" property="FormatConditions(1).IconCriteria(1).Operator" value="7" type="Double" /><column name="is_translatable" property="FormatConditions(1).IconCriteria(2).Type" value="0" type="Double" /><column name="is_translatable" property="FormatConditions(1).IconCriteria(2).Value" value="0.5" type="Double" /><column name="is_translatable" property="FormatConditions(1).IconCriteria(2).Operator" value="7" type="Double" /><column name="is_translatable" property="FormatConditions(1).IconCriteria(3).Type" value="0" type="Double" /><column name="is_translatable" property="FormatConditions(1).IconCriteria(3).Value" value="1" type="Double" /><column name="is_translatable" property="FormatConditions(1).IconCriteria(3).Operator" value="7" type="Double" /><column name="is_complete" property="FormatConditions(1).AppliesTo.Address" value="$G$4:$G$280" type="String" /><column name="is_complete" property="FormatConditions(1).Type" value="6" type="Double" /><column name="is_complete" property="FormatConditions(1).Priority" value="1554" type="Double" /><column name="is_complete" property="FormatConditions(1).ShowIconOnly" value="True" type="Boolean" /><column name="is_complete" property="FormatConditions(1).IconSet.ID" value="8" type="Double" /><column name="is_complete" property="FormatConditions(1).IconCriteria(1).Type" value="3" type="Double" /><column name="is_complete" property="FormatConditions(1).IconCriteria(1).Operator" value="7" type="Double" /><column name="is_complete" property="FormatConditions(1).IconCriteria(2).Type" value="0" type="Double" /><column name="is_complete" property="FormatConditions(1).IconCriteria(2).Value" value="0.5" type="Double" /><column name="is_complete" property="FormatConditions(1).IconCriteria(2).Operator" value="7" type="Double" /><column name="is_complete" property="FormatConditions(1).IconCriteria(3).Type" value="0" type="Double" /><column name="is_complete" property="FormatConditions(1).IconCriteria(3).Value" value="1" type="Double" /><column name="is_complete" property="FormatConditions(1).IconCriteria(3).Operator" value="7" type="Double" /><column name="" property="Tab.Color" value="5296274" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N'xls27', N'usp_translations_common', N'<table name="xls27.usp_translations_common"><columnFormats><column name="" property="ListObjectName" value="translation_common" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="TABLE_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="TABLE_SCHEMA" property="Address" value="$C$4" type="String" /><column name="TABLE_SCHEMA" property="ColumnWidth" value="16.57" type="Double" /><column name="TABLE_SCHEMA" property="NumberFormat" value="General" type="String" /><column name="TABLE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="TABLE_NAME" property="Address" value="$D$4" type="String" /><column name="TABLE_NAME" property="ColumnWidth" value="35" type="Double" /><column name="TABLE_NAME" property="NumberFormat" value="General" type="String" /><column name="is_complete" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="is_complete" property="Address" value="$E$4" type="String" /><column name="is_complete" property="ColumnWidth" value="2.86" type="Double" /><column name="is_complete" property="NumberFormat" value="General" type="String" /><column name="is_complete" property="HorizontalAlignment" value="-4108" type="Double" /><column name="is_complete" property="Font.Size" value="10" type="Double" /><column name="COLUMN" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="COLUMN" property="Address" value="$F$4" type="String" /><column name="COLUMN" property="ColumnWidth" value="36.14" type="Double" /><column name="COLUMN" property="NumberFormat" value="General" type="String" /><column name="en" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="en" property="Address" value="$G$4" type="String" /><column name="en" property="ColumnWidth" value="32" type="Double" /><column name="en" property="NumberFormat" value="General" type="String" /><column name="fr" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="fr" property="Address" value="$H$4" type="String" /><column name="fr" property="ColumnWidth" value="38.14" type="Double" /><column name="fr" property="NumberFormat" value="General" type="String" /><column name="it" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="it" property="Address" value="$I$4" type="String" /><column name="it" property="ColumnWidth" value="39" type="Double" /><column name="it" property="NumberFormat" value="General" type="String" /><column name="es" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="es" property="Address" value="$J$4" type="String" /><column name="es" property="ColumnWidth" value="28.14" type="Double" /><column name="es" property="NumberFormat" value="General" type="String" /><column name="de" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="de" property="Address" value="$K$4" type="String" /><column name="de" property="ColumnWidth" value="43.57" type="Double" /><column name="de" property="NumberFormat" value="General" type="String" /><column name="ru" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="ru" property="Address" value="$L$4" type="String" /><column name="ru" property="ColumnWidth" value="51.86" type="Double" /><column name="ru" property="NumberFormat" value="General" type="String" /><column name="is_complete" property="FormatConditions(1).AppliesTo.Address" value="$E$4:$E$377" type="String" /><column name="is_complete" property="FormatConditions(1).Type" value="6" type="Double" /><column name="is_complete" property="FormatConditions(1).Priority" value="68" type="Double" /><column name="is_complete" property="FormatConditions(1).ShowIconOnly" value="True" type="Boolean" /><column name="is_complete" property="FormatConditions(1).IconSet.ID" value="8" type="Double" /><column name="is_complete" property="FormatConditions(1).IconCriteria(1).Type" value="3" type="Double" /><column name="is_complete" property="FormatConditions(1).IconCriteria(1).Operator" value="7" type="Double" /><column name="is_complete" property="FormatConditions(1).IconCriteria(2).Type" value="0" type="Double" /><column name="is_complete" property="FormatConditions(1).IconCriteria(2).Value" value="0.5" type="Double" /><column name="is_complete" property="FormatConditions(1).IconCriteria(2).Operator" value="7" type="Double" /><column name="is_complete" property="FormatConditions(1).IconCriteria(3).Type" value="0" type="Double" /><column name="is_complete" property="FormatConditions(1).IconCriteria(3).Value" value="1" type="Double" /><column name="is_complete" property="FormatConditions(1).IconCriteria(3).Operator" value="7" type="Double" /><column name="" property="Tab.Color" value="6299648" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N'xls27', N'usp_translations_xls', N'<table name="xls27.usp_translations_xls"><columnFormats><column name="" property="ListObjectName" value="translation_xls" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="TABLE_SCHEMA" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="TABLE_SCHEMA" property="Address" value="$C$4" type="String" /><column name="TABLE_SCHEMA" property="NumberFormat" value="General" type="String" /><column name="TABLE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="TABLE_NAME" property="Address" value="$D$4" type="String" /><column name="TABLE_NAME" property="ColumnWidth" value="32.43" type="Double" /><column name="TABLE_NAME" property="NumberFormat" value="General" type="String" /><column name="is_complete" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="is_complete" property="Address" value="$E$4" type="String" /><column name="is_complete" property="ColumnWidth" value="2.86" type="Double" /><column name="is_complete" property="NumberFormat" value="General" type="String" /><column name="is_complete" property="HorizontalAlignment" value="-4108" type="Double" /><column name="is_complete" property="Font.Size" value="10" type="Double" /><column name="COLUMN" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="COLUMN" property="Address" value="$F$4" type="String" /><column name="COLUMN" property="ColumnWidth" value="35" type="Double" /><column name="COLUMN" property="NumberFormat" value="General" type="String" /><column name="en" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="en" property="Address" value="$G$4" type="String" /><column name="en" property="ColumnWidth" value="35" type="Double" /><column name="en" property="NumberFormat" value="General" type="String" /><column name="fr" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="fr" property="Address" value="$H$4" type="String" /><column name="fr" property="ColumnWidth" value="35" type="Double" /><column name="fr" property="NumberFormat" value="General" type="String" /><column name="fr" property="VerticalAlignment" value="-4108" type="Double" /><column name="it" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="it" property="Address" value="$I$4" type="String" /><column name="it" property="ColumnWidth" value="35" type="Double" /><column name="it" property="NumberFormat" value="General" type="String" /><column name="es" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="es" property="Address" value="$J$4" type="String" /><column name="es" property="ColumnWidth" value="35" type="Double" /><column name="es" property="NumberFormat" value="General" type="String" /><column name="de" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="de" property="Address" value="$K$4" type="String" /><column name="de" property="ColumnWidth" value="35" type="Double" /><column name="de" property="NumberFormat" value="General" type="String" /><column name="ru" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="ru" property="Address" value="$L$4" type="String" /><column name="ru" property="ColumnWidth" value="35" type="Double" /><column name="ru" property="NumberFormat" value="General" type="String" /><column name="is_complete" property="FormatConditions(1).AppliesTo.Address" value="$E$4:$E$478" type="String" /><column name="is_complete" property="FormatConditions(1).Type" value="6" type="Double" /><column name="is_complete" property="FormatConditions(1).Priority" value="74" type="Double" /><column name="is_complete" property="FormatConditions(1).ShowIconOnly" value="True" type="Boolean" /><column name="is_complete" property="FormatConditions(1).IconSet.ID" value="8" type="Double" /><column name="is_complete" property="FormatConditions(1).IconCriteria(1).Type" value="3" type="Double" /><column name="is_complete" property="FormatConditions(1).IconCriteria(1).Operator" value="7" type="Double" /><column name="is_complete" property="FormatConditions(1).IconCriteria(2).Type" value="0" type="Double" /><column name="is_complete" property="FormatConditions(1).IconCriteria(2).Value" value="0.5" type="Double" /><column name="is_complete" property="FormatConditions(1).IconCriteria(2).Operator" value="7" type="Double" /><column name="is_complete" property="FormatConditions(1).IconCriteria(3).Type" value="0" type="Double" /><column name="is_complete" property="FormatConditions(1).IconCriteria(3).Value" value="1" type="Double" /><column name="is_complete" property="FormatConditions(1).IconCriteria(3).Operator" value="7" type="Double" /><column name="" property="Tab.Color" value="6299648" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N'xls27', N'usp_units', N'<table name="xls27.usp_units"><columnFormats><column name="" property="ListObjectName" value="units" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="id" property="Address" value="$C$4" type="String" /><column name="id" property="ColumnWidth" value="4.29" type="Double" /><column name="id" property="NumberFormat" value="General" type="String" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="Address" value="$D$4" type="String" /><column name="code" property="ColumnWidth" value="6.86" type="Double" /><column name="code" property="NumberFormat" value="General" type="String" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="Address" value="$E$4" type="String" /><column name="name" property="ColumnWidth" value="16.57" type="Double" /><column name="name" property="NumberFormat" value="General" type="String" /><column name="translated_name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="translated_name" property="Address" value="$F$4" type="String" /><column name="translated_name" property="ColumnWidth" value="17.71" type="Double" /><column name="translated_name" property="NumberFormat" value="General" type="String" /><column name="translated_name" property="HorizontalAlignment" value="-4108" type="Double" /><column name="translated_name" property="Font.Size" value="10" type="Double" /><column name="sort_order" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="sort_order" property="Address" value="$G$4" type="String" /><column name="sort_order" property="ColumnWidth" value="11.86" type="Double" /><column name="sort_order" property="NumberFormat" value="General" type="String" /><column name="factor" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="factor" property="Address" value="$H$4" type="String" /><column name="factor" property="ColumnWidth" value="7.71" type="Double" /><column name="factor" property="NumberFormat" value="General" type="String" /><column name="is_currency" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="is_currency" property="Address" value="$I$4" type="String" /><column name="is_currency" property="ColumnWidth" value="12.57" type="Double" /><column name="is_currency" property="NumberFormat" value="General" type="String" /><column name="is_currency" property="HorizontalAlignment" value="-4108" type="Double" /><column name="is_currency" property="Font.Size" value="10" type="Double" /><column name="is_functional_currency" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="is_functional_currency" property="Address" value="$J$4" type="String" /><column name="is_functional_currency" property="ColumnWidth" value="22" type="Double" /><column name="is_functional_currency" property="NumberFormat" value="General" type="String" /><column name="is_functional_currency" property="HorizontalAlignment" value="-4108" type="Double" /><column name="is_functional_currency" property="Font.Size" value="10" type="Double" /><column name="is_base_currency" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="is_base_currency" property="Address" value="$K$4" type="String" /><column name="is_base_currency" property="ColumnWidth" value="17.86" type="Double" /><column name="is_base_currency" property="NumberFormat" value="General" type="String" /><column name="is_base_currency" property="HorizontalAlignment" value="-4108" type="Double" /><column name="is_base_currency" property="Font.Size" value="10" type="Double" /><column name="is_active" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="is_active" property="Address" value="$L$4" type="String" /><column name="is_active" property="ColumnWidth" value="10.29" type="Double" /><column name="is_active" property="NumberFormat" value="General" type="String" /><column name="is_active" property="HorizontalAlignment" value="-4108" type="Double" /><column name="is_active" property="Font.Size" value="10" type="Double" /><column name="is_currency" property="FormatConditions(1).ColumnsCount" value="5" type="Double" /><column name="is_currency" property="FormatConditions(1).AppliesTo.Address" value="$I$4:$M$5" type="String" /><column name="is_currency" property="FormatConditions(1).Type" value="6" type="Double" /><column name="is_currency" property="FormatConditions(1).Priority" value="1" type="Double" /><column name="is_currency" property="FormatConditions(1).ShowIconOnly" value="True" type="Boolean" /><column name="is_currency" property="FormatConditions(1).IconSet.ID" value="8" type="Double" /><column name="is_currency" property="FormatConditions(1).IconCriteria(1).Type" value="3" type="Double" /><column name="is_currency" property="FormatConditions(1).IconCriteria(1).Operator" value="7" type="Double" /><column name="is_currency" property="FormatConditions(1).IconCriteria(2).Type" value="0" type="Double" /><column name="is_currency" property="FormatConditions(1).IconCriteria(2).Value" value="0.5" type="Double" /><column name="is_currency" property="FormatConditions(1).IconCriteria(2).Operator" value="7" type="Double" /><column name="is_currency" property="FormatConditions(1).IconCriteria(3).Type" value="0" type="Double" /><column name="is_currency" property="FormatConditions(1).IconCriteria(3).Value" value="1" type="Double" /><column name="is_currency" property="FormatConditions(1).IconCriteria(3).Operator" value="7" type="Double" /><column name="" property="Tab.Color" value="6299648" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N'xls27', N'usp_users', N'<table name="xls27.usp_users"><columnFormats><column name="" property="ListObjectName" value="users" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="username" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="username" property="Address" value="$C$4" type="String" /><column name="username" property="ColumnWidth" value="27.86" type="Double" /><column name="username" property="NumberFormat" value="General" type="String" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="Address" value="$D$4" type="String" /><column name="name" property="ColumnWidth" value="27.86" type="Double" /><column name="name" property="NumberFormat" value="General" type="String" /><column name="is_admin" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="is_admin" property="Address" value="$E$4" type="String" /><column name="is_admin" property="ColumnWidth" value="13.57" type="Double" /><column name="is_admin" property="NumberFormat" value="General" type="String" /><column name="is_admin" property="HorizontalAlignment" value="-4108" type="Double" /><column name="is_admin" property="Font.Size" value="10" type="Double" /><column name="is_active" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="is_active" property="Address" value="$F$4" type="String" /><column name="is_active" property="ColumnWidth" value="13.57" type="Double" /><column name="is_active" property="NumberFormat" value="General" type="String" /><column name="is_active" property="HorizontalAlignment" value="-4108" type="Double" /><column name="is_active" property="Font.Size" value="10" type="Double" /><column name="is_default" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="is_default" property="Address" value="$G$4" type="String" /><column name="is_default" property="ColumnWidth" value="13.57" type="Double" /><column name="is_default" property="NumberFormat" value="General" type="String" /><column name="is_default" property="HorizontalAlignment" value="-4108" type="Double" /><column name="is_default" property="Font.Size" value="10" type="Double" /><column name="is_admin" property="FormatConditions(1).AppliesTo.Address" value="$E$4:$E$12" type="String" /><column name="is_admin" property="FormatConditions(1).Type" value="6" type="Double" /><column name="is_admin" property="FormatConditions(1).Priority" value="15" type="Double" /><column name="is_admin" property="FormatConditions(1).ShowIconOnly" value="True" type="Boolean" /><column name="is_admin" property="FormatConditions(1).IconSet.ID" value="8" type="Double" /><column name="is_admin" property="FormatConditions(1).IconCriteria(1).Type" value="3" type="Double" /><column name="is_admin" property="FormatConditions(1).IconCriteria(1).Operator" value="7" type="Double" /><column name="is_admin" property="FormatConditions(1).IconCriteria(2).Type" value="0" type="Double" /><column name="is_admin" property="FormatConditions(1).IconCriteria(2).Value" value="0.5" type="Double" /><column name="is_admin" property="FormatConditions(1).IconCriteria(2).Operator" value="7" type="Double" /><column name="is_admin" property="FormatConditions(1).IconCriteria(3).Type" value="0" type="Double" /><column name="is_admin" property="FormatConditions(1).IconCriteria(3).Value" value="1" type="Double" /><column name="is_admin" property="FormatConditions(1).IconCriteria(3).Operator" value="7" type="Double" /><column name="is_active" property="FormatConditions(1).AppliesTo.Address" value="$F$4:$F$12" type="String" /><column name="is_active" property="FormatConditions(1).Type" value="6" type="Double" /><column name="is_active" property="FormatConditions(1).Priority" value="17" type="Double" /><column name="is_active" property="FormatConditions(1).ShowIconOnly" value="True" type="Boolean" /><column name="is_active" property="FormatConditions(1).IconSet.ID" value="8" type="Double" /><column name="is_active" property="FormatConditions(1).IconCriteria(1).Type" value="3" type="Double" /><column name="is_active" property="FormatConditions(1).IconCriteria(1).Operator" value="7" type="Double" /><column name="is_active" property="FormatConditions(1).IconCriteria(2).Type" value="0" type="Double" /><column name="is_active" property="FormatConditions(1).IconCriteria(2).Value" value="0.5" type="Double" /><column name="is_active" property="FormatConditions(1).IconCriteria(2).Operator" value="7" type="Double" /><column name="is_active" property="FormatConditions(1).IconCriteria(3).Type" value="0" type="Double" /><column name="is_active" property="FormatConditions(1).IconCriteria(3).Value" value="1" type="Double" /><column name="is_active" property="FormatConditions(1).IconCriteria(3).Operator" value="7" type="Double" /><column name="is_default" property="FormatConditions(1).AppliesTo.Address" value="$G$4:$G$12" type="String" /><column name="is_default" property="FormatConditions(1).Type" value="6" type="Double" /><column name="is_default" property="FormatConditions(1).Priority" value="19" type="Double" /><column name="is_default" property="FormatConditions(1).ShowIconOnly" value="True" type="Boolean" /><column name="is_default" property="FormatConditions(1).IconSet.ID" value="8" type="Double" /><column name="is_default" property="FormatConditions(1).IconCriteria(1).Type" value="3" type="Double" /><column name="is_default" property="FormatConditions(1).IconCriteria(1).Operator" value="7" type="Double" /><column name="is_default" property="FormatConditions(1).IconCriteria(2).Type" value="0" type="Double" /><column name="is_default" property="FormatConditions(1).IconCriteria(2).Value" value="0.5" type="Double" /><column name="is_default" property="FormatConditions(1).IconCriteria(2).Operator" value="7" type="Double" /><column name="is_default" property="FormatConditions(1).IconCriteria(3).Type" value="0" type="Double" /><column name="is_default" property="FormatConditions(1).IconCriteria(3).Value" value="1" type="Double" /><column name="is_default" property="FormatConditions(1).IconCriteria(3).Operator" value="7" type="Double" /><column name="" property="Tab.Color" value="6299648" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N'xls27', N'usp_vat_rates', N'<table name="xls27.usp_vat_rates"><columnFormats><column name="" property="ListObjectName" value="vat_rates" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="id" property="Address" value="$C$4" type="String" /><column name="id" property="ColumnWidth" value="4.29" type="Double" /><column name="id" property="NumberFormat" value="General" type="String" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="Address" value="$D$4" type="String" /><column name="code" property="ColumnWidth" value="6.86" type="Double" /><column name="code" property="NumberFormat" value="General" type="String" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="Address" value="$E$4" type="String" /><column name="name" property="ColumnWidth" value="12.57" type="Double" /><column name="name" property="NumberFormat" value="General" type="String" /><column name="translated_name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="translated_name" property="Address" value="$F$4" type="String" /><column name="translated_name" property="ColumnWidth" value="17.71" type="Double" /><column name="translated_name" property="NumberFormat" value="General" type="String" /><column name="translated_name" property="HorizontalAlignment" value="-4108" type="Double" /><column name="translated_name" property="Font.Size" value="10" type="Double" /><column name="sort_order" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="sort_order" property="Address" value="$G$4" type="String" /><column name="sort_order" property="ColumnWidth" value="11.86" type="Double" /><column name="sort_order" property="NumberFormat" value="General" type="String" /><column name="factor" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="factor" property="Address" value="$H$4" type="String" /><column name="factor" property="ColumnWidth" value="11.29" type="Double" /><column name="factor" property="NumberFormat" value="General" type="String" /><column name="is_active" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="is_active" property="Address" value="$I$4" type="String" /><column name="is_active" property="ColumnWidth" value="10.29" type="Double" /><column name="is_active" property="NumberFormat" value="General" type="String" /><column name="is_active" property="HorizontalAlignment" value="-4108" type="Double" /><column name="is_active" property="Font.Size" value="10" type="Double" /><column name="is_active" property="FormatConditions(1).ColumnsCount" value="2" type="Double" /><column name="is_active" property="FormatConditions(1).AppliesTo.Address" value="$I$4:$J$6" type="String" /><column name="is_active" property="FormatConditions(1).Type" value="6" type="Double" /><column name="is_active" property="FormatConditions(1).Priority" value="1" type="Double" /><column name="is_active" property="FormatConditions(1).ShowIconOnly" value="True" type="Boolean" /><column name="is_active" property="FormatConditions(1).IconSet.ID" value="8" type="Double" /><column name="is_active" property="FormatConditions(1).IconCriteria(1).Type" value="3" type="Double" /><column name="is_active" property="FormatConditions(1).IconCriteria(1).Operator" value="7" type="Double" /><column name="is_active" property="FormatConditions(1).IconCriteria(2).Type" value="0" type="Double" /><column name="is_active" property="FormatConditions(1).IconCriteria(2).Value" value="0.5" type="Double" /><column name="is_active" property="FormatConditions(1).IconCriteria(2).Operator" value="7" type="Double" /><column name="is_active" property="FormatConditions(1).IconCriteria(3).Type" value="0" type="Double" /><column name="is_active" property="FormatConditions(1).IconCriteria(3).Value" value="1" type="Double" /><column name="is_active" property="FormatConditions(1).IconCriteria(3).Operator" value="7" type="Double" /><column name="" property="Tab.Color" value="6299648" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N'xls27', N'view_accounts', N'<table name="xls27.view_accounts"><columnFormats><column name="" property="ListObjectName" value="accounts" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="id" property="Address" value="$C$4" type="String" /><column name="id" property="NumberFormat" value="General" type="String" /><column name="id" property="Validation.Type" value="1" type="Double" /><column name="id" property="Validation.Operator" value="1" type="Double" /><column name="id" property="Validation.Formula1" value="-2147483648" type="String" /><column name="id" property="Validation.Formula2" value="2147483647" type="String" /><column name="id" property="Validation.AlertStyle" value="1" type="Double" /><column name="id" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="id" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="id" property="Validation.ShowInput" value="True" type="Boolean" /><column name="id" property="Validation.ShowError" value="True" type="Boolean" /><column name="dimension_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dimension_id" property="Address" value="$D$4" type="String" /><column name="dimension_id" property="NumberFormat" value="General" type="String" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="Address" value="$E$4" type="String" /><column name="code" property="ColumnWidth" value="6.57" type="Double" /><column name="code" property="NumberFormat" value="@" type="String" /><column name="code" property="Validation.Type" value="6" type="Double" /><column name="code" property="Validation.Operator" value="8" type="Double" /><column name="code" property="Validation.Formula1" value="50" type="String" /><column name="code" property="Validation.AlertStyle" value="1" type="Double" /><column name="code" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="code" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="code" property="Validation.ShowInput" value="True" type="Boolean" /><column name="code" property="Validation.ShowError" value="True" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="Address" value="$F$4" type="String" /><column name="name" property="ColumnWidth" value="55.86" type="Double" /><column name="name" property="NumberFormat" value="General" type="String" /><column name="name" property="Validation.Type" value="6" type="Double" /><column name="name" property="Validation.Operator" value="8" type="Double" /><column name="name" property="Validation.Formula1" value="255" type="String" /><column name="name" property="Validation.AlertStyle" value="1" type="Double" /><column name="name" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="name" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="name" property="Validation.ShowInput" value="True" type="Boolean" /><column name="name" property="Validation.ShowError" value="True" type="Boolean" /><column name="parent_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="parent_id" property="Address" value="$G$4" type="String" /><column name="parent_id" property="ColumnWidth" value="7.86" type="Double" /><column name="parent_id" property="NumberFormat" value="@" type="String" /><column name="is_parent" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="is_parent" property="Address" value="$H$4" type="String" /><column name="is_parent" property="NumberFormat" value="General" type="String" /><column name="is_parent" property="HorizontalAlignment" value="-4108" type="Double" /><column name="cf_sign" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf_sign" property="Address" value="$I$4" type="String" /><column name="cf_sign" property="ColumnWidth" value="11.14" type="Double" /><column name="cf_sign" property="NumberFormat" value="General" type="String" /><column name="cf_sign" property="Validation.Type" value="1" type="Double" /><column name="cf_sign" property="Validation.Operator" value="1" type="Double" /><column name="cf_sign" property="Validation.Formula1" value="-2147483648" type="String" /><column name="cf_sign" property="Validation.Formula2" value="2147483647" type="String" /><column name="cf_sign" property="Validation.AlertStyle" value="1" type="Double" /><column name="cf_sign" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="cf_sign" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="cf_sign" property="Validation.ShowInput" value="True" type="Boolean" /><column name="cf_sign" property="Validation.ShowError" value="True" type="Boolean" /><column name="pl_sign" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl_sign" property="Address" value="$J$4" type="String" /><column name="pl_sign" property="ColumnWidth" value="9.71" type="Double" /><column name="pl_sign" property="NumberFormat" value="General" type="String" /><column name="pl_sign" property="Validation.Type" value="1" type="Double" /><column name="pl_sign" property="Validation.Operator" value="1" type="Double" /><column name="pl_sign" property="Validation.Formula1" value="-2147483648" type="String" /><column name="pl_sign" property="Validation.Formula2" value="2147483647" type="String" /><column name="pl_sign" property="Validation.AlertStyle" value="1" type="Double" /><column name="pl_sign" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="pl_sign" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="pl_sign" property="Validation.ShowInput" value="True" type="Boolean" /><column name="pl_sign" property="Validation.ShowError" value="True" type="Boolean" /><column name="settlement_account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="settlement_account_id" property="Address" value="$K$4" type="String" /><column name="settlement_account_id" property="ColumnWidth" value="10.71" type="Double" /><column name="settlement_account_id" property="NumberFormat" value="General" type="String" /><column name="asset_account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="asset_account_id" property="Address" value="$L$4" type="String" /><column name="asset_account_id" property="ColumnWidth" value="9.71" type="Double" /><column name="asset_account_id" property="NumberFormat" value="@" type="String" /><column name="vat_account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat_account_id" property="Address" value="$M$4" type="String" /><column name="vat_account_id" property="ColumnWidth" value="11" type="Double" /><column name="vat_account_id" property="NumberFormat" value="General" type="String" /><column name="type_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="type_id" property="Address" value="$N$4" type="String" /><column name="type_id" property="ColumnWidth" value="31" type="Double" /><column name="type_id" property="NumberFormat" value="General" type="String" /><column name="pl_section_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl_section_id" property="Address" value="$O$4" type="String" /><column name="pl_section_id" property="ColumnWidth" value="29.29" type="Double" /><column name="pl_section_id" property="NumberFormat" value="General" type="String" /><column name="vat_rate_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat_rate_id" property="Address" value="$P$4" type="String" /><column name="vat_rate_id" property="ColumnWidth" value="8.43" type="Double" /><column name="vat_rate_id" property="NumberFormat" value="General" type="String" /><column name="unit_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="unit_id" property="Address" value="$Q$4" type="String" /><column name="unit_id" property="NumberFormat" value="General" type="String" /><column name="pl_ref_number" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl_ref_number" property="Address" value="$R$4" type="String" /><column name="pl_ref_number" property="ColumnWidth" value="9.29" type="Double" /><column name="pl_ref_number" property="NumberFormat" value="@" type="String" /><column name="cf_ref_number" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf_ref_number" property="Address" value="$S$4" type="String" /><column name="cf_ref_number" property="ColumnWidth" value="10.71" type="Double" /><column name="cf_ref_number" property="NumberFormat" value="@" type="String" /><column name="is_in_budget_request" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="is_in_budget_request" property="Address" value="$T$4" type="String" /><column name="is_in_budget_request" property="ColumnWidth" value="8.86" type="Double" /><column name="is_in_budget_request" property="NumberFormat" value="General" type="String" /><column name="is_in_budget_request" property="HorizontalAlignment" value="-4108" type="Double" /><column name="is_in_budget_request" property="Font.Size" value="10" type="Double" /><column name="is_active" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="is_active" property="Address" value="$U$4" type="String" /><column name="is_active" property="ColumnWidth" value="10" type="Double" /><column name="is_active" property="NumberFormat" value="General" type="String" /><column name="is_active" property="HorizontalAlignment" value="-4108" type="Double" /><column name="is_active" property="Font.Size" value="10" type="Double" /><column name="cf_sign" property="FormatConditions(1).ColumnsCount" value="5" type="Double" /><column name="cf_sign" property="FormatConditions(1).AppliesTo.Address" value="$I$4:$M$80" type="String" /><column name="cf_sign" property="FormatConditions(1).Type" value="2" type="Double" /><column name="cf_sign" property="FormatConditions(1).Priority" value="274" type="Double" /><column name="cf_sign" property="FormatConditions(1).StopIfTrue" value="True" type="Boolean" /><column name="cf_sign" property="FormatConditions(1).Formula1" value="=AND($H4=1,I4&lt;&gt;&quot;&quot;)" type="String" /><column name="cf_sign" property="FormatConditions(1).Interior.Color" value="255" type="Double" /><column name="cf_sign" property="FormatConditions(2).ColumnsCount" value="2" type="Double" /><column name="cf_sign" property="FormatConditions(2).AppliesTo.Address" value="$I$4:$J$80" type="String" /><column name="cf_sign" property="FormatConditions(2).Type" value="2" type="Double" /><column name="cf_sign" property="FormatConditions(2).Priority" value="275" type="Double" /><column name="cf_sign" property="FormatConditions(2).StopIfTrue" value="True" type="Boolean" /><column name="cf_sign" property="FormatConditions(2).Formula1" value="=$H4=1" type="String" /><column name="cf_sign" property="FormatConditions(2).Interior.Color" value="14277081" type="Double" /><column name="cf_sign" property="FormatConditions(2).Interior.ThemeColor" value="1" type="Double" /><column name="cf_sign" property="FormatConditions(2).Interior.TintAndShade" value="-0.14996795556505" type="Double" /><column name="cf_sign" property="FormatConditions(3).ColumnsCount" value="2" type="Double" /><column name="cf_sign" property="FormatConditions(3).AppliesTo.Address" value="$I$4:$J$80" type="String" /><column name="cf_sign" property="FormatConditions(3).Type" value="1" type="Double" /><column name="cf_sign" property="FormatConditions(3).Priority" value="277" type="Double" /><column name="cf_sign" property="FormatConditions(3).Formula1" value="=0" type="String" /><column name="cf_sign" property="FormatConditions(3).Operator" value="3" type="Double" /><column name="cf_sign" property="FormatConditions(3).Font.Color" value="26012" type="Double" /><column name="cf_sign" property="FormatConditions(3).Interior.Color" value="10284031" type="Double" /><column name="cf_sign" property="FormatConditions(4).ColumnsCount" value="2" type="Double" /><column name="cf_sign" property="FormatConditions(4).AppliesTo.Address" value="$I$4:$J$80" type="String" /><column name="cf_sign" property="FormatConditions(4).Type" value="1" type="Double" /><column name="cf_sign" property="FormatConditions(4).Priority" value="278" type="Double" /><column name="cf_sign" property="FormatConditions(4).Formula1" value="=-1" type="String" /><column name="cf_sign" property="FormatConditions(4).Operator" value="3" type="Double" /><column name="cf_sign" property="FormatConditions(4).Font.Color" value="393372" type="Double" /><column name="cf_sign" property="FormatConditions(4).Interior.Color" value="13551615" type="Double" /><column name="cf_sign" property="FormatConditions(5).ColumnsCount" value="2" type="Double" /><column name="cf_sign" property="FormatConditions(5).AppliesTo.Address" value="$I$4:$J$80" type="String" /><column name="cf_sign" property="FormatConditions(5).Type" value="1" type="Double" /><column name="cf_sign" property="FormatConditions(5).Priority" value="279" type="Double" /><column name="cf_sign" property="FormatConditions(5).Formula1" value="=1" type="String" /><column name="cf_sign" property="FormatConditions(5).Operator" value="3" type="Double" /><column name="cf_sign" property="FormatConditions(5).Font.Color" value="24832" type="Double" /><column name="cf_sign" property="FormatConditions(5).Interior.Color" value="13561798" type="Double" /><column name="asset_account_id" property="FormatConditions(1).AppliesTo.Address" value="$L$4:$L$80" type="String" /><column name="asset_account_id" property="FormatConditions(1).Type" value="2" type="Double" /><column name="asset_account_id" property="FormatConditions(1).Priority" value="1" type="Double" /><column name="asset_account_id" property="FormatConditions(1).Formula1" value="=AND($I4=0,$J4=-1,L4=&quot;&quot;)" type="String" /><column name="asset_account_id" property="FormatConditions(1).Interior.Color" value="65535" type="Double" /><column name="is_in_budget_request" property="FormatConditions(1).AppliesTo.Address" value="$T$4:$T$80" type="String" /><column name="is_in_budget_request" property="FormatConditions(1).Type" value="6" type="Double" /><column name="is_in_budget_request" property="FormatConditions(1).Priority" value="324" type="Double" /><column name="is_in_budget_request" property="FormatConditions(1).ShowIconOnly" value="True" type="Boolean" /><column name="is_in_budget_request" property="FormatConditions(1).IconSet.ID" value="8" type="Double" /><column name="is_in_budget_request" property="FormatConditions(1).IconCriteria(1).Type" value="3" type="Double" /><column name="is_in_budget_request" property="FormatConditions(1).IconCriteria(1).Operator" value="7" type="Double" /><column name="is_in_budget_request" property="FormatConditions(1).IconCriteria(2).Type" value="0" type="Double" /><column name="is_in_budget_request" property="FormatConditions(1).IconCriteria(2).Value" value="0.5" type="Double" /><column name="is_in_budget_request" property="FormatConditions(1).IconCriteria(2).Operator" value="7" type="Double" /><column name="is_in_budget_request" property="FormatConditions(1).IconCriteria(3).Type" value="0" type="Double" /><column name="is_in_budget_request" property="FormatConditions(1).IconCriteria(3).Value" value="1" type="Double" /><column name="is_in_budget_request" property="FormatConditions(1).IconCriteria(3).Operator" value="7" type="Double" /><column name="is_active" property="FormatConditions(1).ColumnsCount" value="2" type="Double" /><column name="is_active" property="FormatConditions(1).AppliesTo.Address" value="$U$4:$V$80" type="String" /><column name="is_active" property="FormatConditions(1).Type" value="6" type="Double" /><column name="is_active" property="FormatConditions(1).Priority" value="2" type="Double" /><column name="is_active" property="FormatConditions(1).ShowIconOnly" value="True" type="Boolean" /><column name="is_active" property="FormatConditions(1).IconSet.ID" value="8" type="Double" /><column name="is_active" property="FormatConditions(1).IconCriteria(1).Type" value="3" type="Double" /><column name="is_active" property="FormatConditions(1).IconCriteria(1).Operator" value="7" type="Double" /><column name="is_active" property="FormatConditions(1).IconCriteria(2).Type" value="0" type="Double" /><column name="is_active" property="FormatConditions(1).IconCriteria(2).Value" value="0.5" type="Double" /><column name="is_active" property="FormatConditions(1).IconCriteria(2).Operator" value="7" type="Double" /><column name="is_active" property="FormatConditions(1).IconCriteria(3).Type" value="0" type="Double" /><column name="is_active" property="FormatConditions(1).IconCriteria(3).Value" value="1" type="Double" /><column name="is_active" property="FormatConditions(1).IconCriteria(3).Operator" value="7" type="Double" /><column name="" property="Tab.Color" value="5287936" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats><views><view name="Form"><column name="" property="ListObjectName" value="accounts" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="dimension_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="parent_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="is_parent" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="cf_sign" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl_sign" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="settlement_account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="asset_account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat_account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="type_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl_section_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="vat_rate_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="unit_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="pl_ref_number" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf_ref_number" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="is_in_budget_request" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="is_active" property="EntireColumn.Hidden" value="False" type="Boolean" /></view><view name="All columns"><column name="" property="ListObjectName" value="accounts" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="dimension_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="cf_sign" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="pl_sign" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="settle_account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="asset_account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="tax_rate_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="unit_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="is_in_budget_request" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="is_active" property="EntireColumn.Hidden" value="False" type="Boolean" /></view></views></table>');
GO

INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_balance_sheet_trial', NULL, N'Actions', N'xls27', N'xl_actions_auto_calc_all', N'PROCEDURE', NULL, N'_reload', NULL, 0);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_request1', NULL, N'Actions', N'xls27', N'xl_actions_select_members', N'PROCEDURE', NULL, NULL, 11, 0);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_request2', NULL, N'Actions', N'xls27', N'xl_actions_select_members', N'PROCEDURE', NULL, NULL, 11, 0);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_journal', NULL, N'Actions', N'xls27', N'xl_actions_auto_calc_all', N'PROCEDURE', NULL, N'_reload', NULL, 0);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_role_members', NULL, N'Actions', N'xls27', N'SaveToDB Framework Online Help', N'HTTP', N'https://www.savetodb.com/help/savetodb-framework-procedures.htm#xls.usp_role_members', NULL, 11, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_role_members', NULL, N'Actions', N'xls27', N'MenuSeparator20', N'MENUSEPARATOR', NULL, NULL, 20, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_role_members', NULL, N'Actions', N'xls27', N'Transact-SQL Reference - Permissions', N'HTTP', N'https://msdn.microsoft.com/en-us/library/ms191291.aspx', NULL, 21, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_role_members', NULL, N'Actions', N'xls27', N'Transact-SQL Reference - CREATE ROLE', N'HTTP', N'https://msdn.microsoft.com/en-us/library/ms187936.aspx', NULL, 22, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_role_members', NULL, N'Actions', N'xls27', N'Transact-SQL Reference - ALTER ROLE', N'HTTP', N'https://msdn.microsoft.com/en-us/library/ms189775.aspx', NULL, 23, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_role_members', NULL, N'Actions', N'xls27', N'Transact-SQL Reference - DROP ROLE', N'HTTP', N'https://msdn.microsoft.com/en-us/library/ms174988.aspx', NULL, 24, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_role_members', NULL, N'Actions', N'xls27', N'Transact-SQL Reference - sp_addrolemember', N'HTTP', N'https://msdn.microsoft.com/en-us/library/ms187750.aspx', NULL, 25, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_role_members', NULL, N'Actions', N'xls27', N'Transact-SQL Reference - sp_droprolemember', N'HTTP', N'https://msdn.microsoft.com/en-us/library/ms188369.aspx', NULL, 26, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_translations', NULL, N'Actions', N'xls27', N'xl_actions_add_language', N'PROCEDURE', NULL, N'_reload', 11, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_actual_closed_periods', N'is_closed', N'BitColumn', NULL, NULL, N'ATTRIBUTE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_actual_currency_rates', N'is_checked', N'BitColumn', NULL, NULL, N'ATTRIBUTE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budgeting_accounts', N'is_active', N'BitColumn', NULL, NULL, N'ATTRIBUTE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_journal', N'is_draft', N'BitColumn', NULL, NULL, N'ATTRIBUTE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_ledger_account_types', N'is_da', N'BitColumn', NULL, NULL, N'ATTRIBUTE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_ledger_account_types', N'is_pl', N'BitColumn', NULL, NULL, N'ATTRIBUTE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_members', N'is_active', N'BitColumn', NULL, NULL, N'ATTRIBUTE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_report_section_accounts', N'is_pl', N'BitColumn', NULL, NULL, N'ATTRIBUTE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_report_section_types', N'hide_accounts', N'BitColumn', NULL, NULL, N'ATTRIBUTE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_report_sections', N'hide_items', N'BitColumn', NULL, NULL, N'ATTRIBUTE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_report_sections', N'inverse_sign', N'BitColumn', NULL, NULL, N'ATTRIBUTE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_report_sections', N'page_break_before', N'BitColumn', NULL, NULL, N'ATTRIBUTE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_report_sections', N'show_line', N'BitColumn', NULL, NULL, N'ATTRIBUTE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_report_sections', N'show_line_after', N'BitColumn', NULL, NULL, N'ATTRIBUTE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_report_sections', N'show_line_before', N'BitColumn', NULL, NULL, N'ATTRIBUTE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_units', N'is_active', N'BitColumn', NULL, NULL, N'ATTRIBUTE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_units', N'is_base_currency', N'BitColumn', NULL, NULL, N'ATTRIBUTE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_units', N'is_currency', N'BitColumn', NULL, NULL, N'ATTRIBUTE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_units', N'is_functional_currency', N'BitColumn', NULL, NULL, N'ATTRIBUTE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_users', N'is_active', N'BitColumn', NULL, NULL, N'ATTRIBUTE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_users', N'is_admin', N'BitColumn', NULL, NULL, N'ATTRIBUTE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_users', N'is_default', N'BitColumn', NULL, NULL, N'ATTRIBUTE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_vat_rates', N'is_active', N'BitColumn', NULL, NULL, N'ATTRIBUTE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_translations_common', NULL, N'Change', N'xls27', N'usp_translations_xls_change', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_actual_reports', NULL, N'ContextMenu', N'xls27', N'xl_actions_actual_report_cell_data', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_reports', NULL, N'ContextMenu', N'xls27', N'xl_actions_budget_report_cell_data', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_request1', N'rows', N'DefaultValue', NULL, NULL, N'ATTRIBUTE', N'26', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_request2', N'rows', N'DefaultValue', NULL, NULL, N'ATTRIBUTE', N'26', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'dbo27', N'report_section_types', NULL, N'DoNotAddValidation', NULL, NULL, N'ATTRIBUTE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_balances', NULL, N'DoNotAddValidation', NULL, NULL, N'ATTRIBUTE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_currency_rates', NULL, N'DoNotAddValidation', NULL, NULL, N'ATTRIBUTE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_requests_totals', NULL, N'DoNotAddValidation', NULL, NULL, N'ATTRIBUTE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_actual_balances', NULL, N'DoNotSort', NULL, NULL, N'ATTRIBUTE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_actual_closed_periods', NULL, N'DoNotSort', NULL, NULL, N'ATTRIBUTE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_actual_currency_rates', NULL, N'DoNotSort', NULL, NULL, N'ATTRIBUTE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_actual_reports', NULL, N'DoNotSort', NULL, NULL, N'ATTRIBUTE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_balance_sheet_trial', NULL, N'DoNotSort', NULL, NULL, N'ATTRIBUTE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_balances', NULL, N'DoNotSort', NULL, NULL, N'ATTRIBUTE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_closed_periods', NULL, N'DoNotSort', NULL, NULL, N'ATTRIBUTE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_currency_rates', NULL, N'DoNotSort', NULL, NULL, N'ATTRIBUTE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_reports', NULL, N'DoNotSort', NULL, NULL, N'ATTRIBUTE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_reports_raw', NULL, N'DoNotSort', NULL, NULL, N'ATTRIBUTE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_request1', NULL, N'DoNotSort', NULL, NULL, N'ATTRIBUTE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_request2', NULL, N'DoNotSort', NULL, NULL, N'ATTRIBUTE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_requests_totals', NULL, N'DoNotSort', NULL, NULL, N'ATTRIBUTE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budgeting_accounts', NULL, N'DoNotSort', NULL, NULL, N'ATTRIBUTE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_ledger_accounts', NULL, N'DoNotSort', NULL, NULL, N'ATTRIBUTE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_saved_reports', NULL, N'DoNotSort', NULL, NULL, N'ATTRIBUTE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_data', NULL, N'DoNotTranslate', NULL, NULL, N'ATTRIBUTE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_saved_reports', NULL, N'DoNotTranslate', NULL, NULL, N'ATTRIBUTE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_actual_balances', NULL, N'Format', NULL, NULL, N'ATTRIBUTE', N'[{"format":"font-family: Calibri; font-size: 11pt"},
{"formula":"is_parent=1","format":"background-color: rgb(221,235,247);font-weight: bold;"},
{"formula":"is_credit_editable=1","format":"background-color: rgb(237,237,237);","columns":"Credit"},
{"formula":"is_debit_editable=1","format":"background-color: rgb(237,237,237);","columns":"Debit"}]', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_actual_reports', NULL, N'Format', NULL, NULL, N'ATTRIBUTE', N'[{"format":"font-family: Calibri; font-size: 11pt; border-style:none"},
{"formula":"row_format=8"},
{"formula":"row_format=2","format":"font-weight: bold;"},
{"formula":"row_format=1","format":"background-color: rgb(33,89,103);color: rgb(255,255,255);font-weight: bold;"},
{"formula":"row_format=9","format":"background-color: rgb(0,33,96);color: rgb(255,255,255);font-weight: bold;"}]', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_balance_sheet_trial', NULL, N'Format', NULL, NULL, N'ATTRIBUTE', N'[{"format":"font-family: Calibri; font-size: 11pt"},
{"formula":"row_format=1","format":"background-color: rgb(220,230,241);font-weight: bold;"}]', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_balances', NULL, N'Format', NULL, NULL, N'ATTRIBUTE', N'[{"format":"font-family: Calibri; font-size: 11pt"},
{"formula":"is_credit_editable=1","format":"background-color: rgb(237,237,237);","columns":"Credit"},
{"formula":"is_debit_editable=1","format":"background-color: rgb(237,237,237);","columns":"Debit"},
{"formula":"is_parent=1","format":"background-color: rgb(220,230,240);font-weight: bold;"}]', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_reports', NULL, N'Format', NULL, NULL, N'ATTRIBUTE', N'[{"format":"font-family: Calibri; font-size: 11pt; border-style:none"},
{"formula":"row_format=8"},
{"formula":"row_format=2","format":"font-weight: bold;"},
{"formula":"row_format=1","format":"background-color: rgb(33,89,103);color: rgb(255,255,255) !important;font-weight: bold;","stopIfTrue":true},
{"formula":"row_format=9","format":"background-color: rgb(0,33,96);color: rgb(255,255,255) !important;font-weight: bold;"}]', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_request1', NULL, N'Format', NULL, NULL, N'ATTRIBUTE', N'[{"format":"font-size: 14px;"},{"formula":"row_format=1","format":"font-weight: bold;"}]', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_request2', NULL, N'Format', NULL, NULL, N'ATTRIBUTE', N'[{"format":"font-size: 14px;"},{"formula":"row_format=1","format":"font-weight: bold;"}]', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_requests_totals', NULL, N'Format', NULL, NULL, N'ATTRIBUTE', N'[{"format":"font-size: 14px;"},{"formula":"vat_credit_type_id=4","format":"background-color: rgb(218,243,243) !important;","columns":"VAT Credit","stopIfTrue": true},
{"formula":"[vat_credit_type_id=0][vat_credit<>\"\"]","format":"background-color: rgb(255,0,0) !important;","columns":"VAT Credit","stopIfTrue": true},
{"formula":"vat_credit_type_id=2","format":"background-color: rgb(255,235,156) !important;","columns":"VAT Credit","stopIfTrue": true},
{"formula":"vat_credit_type_id=3","format":"background-color: rgb(255,199,206) !important;","columns":"VAT Credit","stopIfTrue": true},
{"formula":"vat_debit_type_id=4","format":"background-color: rgb(218,243,243) !important;","columns":"VAT Debit","stopIfTrue": true},
{"formula":"[vat_debit_type_id=0][vat_debit<>\"\"]","format":"background-color: rgb(255,0,0) !important;","columns":"VAT Debit","stopIfTrue": true},
{"formula":"vat_debit_type_id=2","format":"background-color: rgb(255,235,156) !important;","columns":"VAT Debit","stopIfTrue": true},
{"formula":"vat_debit_type_id=3","format":"background-color: rgb(255,199,206) !important;","columns":"VAT Debit","stopIfTrue": true},
{"formula":"[charge_debit_type_id=0][charge_credit<>\"\"]","format":"background-color: rgb(255,0,0) !important;","columns":"Charge Credit","stopIfTrue": true},
{"formula":"charge_credit_type_id=2","format":"background-color: rgb(255,235,156) !important;","columns":"Charge Credit","stopIfTrue": true},
{"formula":"charge_credit_type_id=3","format":"background-color: rgb(255,199,206) !important;","columns":"Charge Credit","stopIfTrue": true},
{"formula":"[charge_debit_type_id=0][charge_debit<>\"\"]","format":"background-color: rgb(255,0,0) !important;","columns":"Charge Debit","stopIfTrue": true},
{"formula":"charge_debit_type_id=2","format":"background-color: rgb(255,235,156) !important;","columns":"Charge Debit","stopIfTrue": true},
{"formula":"charge_debit_type_id=3","format":"background-color: rgb(255,199,206) !important;","columns":"Charge Debit","stopIfTrue": true},
{"formula":"[payment_credit_type_id=0][payment_credit<>\"\"]","format":"background-color: rgb(255,0,0) !important;","columns":"Payment Credit","stopIfTrue": true},
{"formula":"[payment_debit_type_id=0][payment_debit<>\"\"]","format":"background-color: rgb(255,0,0) !important;","columns":"Payment Debit","stopIfTrue": true},
{"formula":"payment_debit_type_id=1","format":"background-color: rgb(255,235,156) !important;","columns":"Payment Credit","stopIfTrue": true},
{"formula":"payment_debit_type_id=2","format":"background-color: rgb(198,239,206) !important;","columns":"Payment Credit","stopIfTrue": true},
{"formula":"payment_debit_type_id=2","format":"background-color: rgb(255,235,156) !important;","columns":"Payment Debit","stopIfTrue": true},
{"formula":"payment_debit_type_id=1","format":"background-color: rgb(198,239,206) !important;","columns":"Payment Debit","stopIfTrue": true}]', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budgeting_accounts', NULL, N'Format', NULL, NULL, N'ATTRIBUTE', N'[{"format":"font-family: Calibri; font-size: 11pt"},
{"formula":"is_parent=1","format":"font-weight: bold;"},
{"formula":"vat_credit_type_id=4","format":"background-color: rgb(218,243,243) !important;","columns":"VAT Credit","stopIfTrue": true},
{"formula":"[vat_credit_type_id=0][vat_credit_id<>\"\"]","format":"background-color: rgb(255,0,0) !important;","columns":"VAT Credit","stopIfTrue": true},
{"formula":"vat_credit_type_id=2","format":"background-color: rgb(255,235,156) !important;","columns":"VAT Credit","stopIfTrue": true},
{"formula":"vat_credit_type_id=3","format":"background-color: rgb(255,199,206) !important;","columns":"VAT Credit","stopIfTrue": true},
{"formula":"vat_debit_type_id=4","format":"background-color: rgb(218,243,243) !important;","columns":"VAT Debit","stopIfTrue": true},
{"formula":"[vat_debit_type_id=0][vat_debit_id<>\"\"]","format":"background-color: rgb(255,0,0) !important;","columns":"VAT Debit","stopIfTrue": true},
{"formula":"vat_debit_type_id=2","format":"background-color: rgb(255,235,156) !important;","columns":"VAT Debit","stopIfTrue": true},
{"formula":"vat_debit_type_id=3","format":"background-color: rgb(255,199,206) !important;","columns":"VAT Debit","stopIfTrue": true},
{"formula":"[charge_debit_type_id=0][charge_credit_id<>\"\"]","format":"background-color: rgb(255,0,0) !important;","columns":"Charge Credit","stopIfTrue": true},
{"formula":"charge_credit_type_id=2","format":"background-color: rgb(255,235,156) !important;","columns":"Charge Credit","stopIfTrue": true},
{"formula":"charge_credit_type_id=3","format":"background-color: rgb(255,199,206) !important;","columns":"Charge Credit","stopIfTrue": true},
{"formula":"[charge_debit_type_id=0][charge_debit_id<>\"\"]","format":"background-color: rgb(255,0,0) !important;","columns":"Charge Debit","stopIfTrue": true},
{"formula":"charge_debit_type_id=2","format":"background-color: rgb(255,235,156) !important;","columns":"Charge Debit","stopIfTrue": true},
{"formula":"charge_debit_type_id=3","format":"background-color: rgb(255,199,206) !important;","columns":"Charge Debit","stopIfTrue": true},
{"formula":"[payment_credit_type_id=0][payment_credit_id<>\"\"]","format":"background-color: rgb(255,0,0) !important;","columns":"Payment Credit","stopIfTrue": true},
{"formula":"[payment_debit_type_id=0][payment_debit_id<>\"\"]","format":"background-color: rgb(255,0,0) !important;","columns":"Payment Debit","stopIfTrue": true},
{"formula":"payment_debit_type_id=1","format":"background-color: rgb(255,235,156) !important;","columns":"Payment Credit","stopIfTrue": true},
{"formula":"payment_debit_type_id=2","format":"background-color: rgb(198,239,206) !important;","columns":"Payment Credit","stopIfTrue": true},
{"formula":"payment_debit_type_id=2","format":"background-color: rgb(255,235,156) !important;","columns":"Payment Debit","stopIfTrue": true},
{"formula":"payment_debit_type_id=1","format":"background-color: rgb(198,239,206) !important;","columns":"Payment Debit","stopIfTrue": true}]', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_ledger_accounts', NULL, N'Format', NULL, NULL, N'ATTRIBUTE', N'[{"format":"font-family: Calibri; font-size: 11pt; border-style:none"},
{"formula":"is_parent=1","format":"background-color: rgb(221,235,248);font-weight: bold;"}]', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_member_permissions', NULL, N'Format', NULL, NULL, N'ATTRIBUTE', N'[{"formula":"=\"R\"","format":"background-color: rgb(198,239,206) !important;color: rgb(0,97,0) !important;","columns":"Data Format, ba_accountant_01, ba_user_101, ba_user_201, ba_user_301, ba_user_401, Last Format Column","stopIfTrue": true},
{"formula":"=\"W\"","format":"background-color: rgb(255,235,156) !important;color: rgb(156,87,0) !important;","columns":"Data Format, ba_accountant_01, ba_user_101, ba_user_201, ba_user_301, ba_user_401, Last Format Column","stopIfTrue": true},
{"formula":"=\"D\"","format":"background-color: rgb(255,199,206) !important;color: rgb(156,0,6) !important;","columns":"Data Format, ba_accountant_01, ba_user_101, ba_user_201, ba_user_301, ba_user_401, Last Format Column","stopIfTrue": true},
{"formula":"is_in_budget_request=0","format":"font-weight: bold;"}]', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_members', NULL, N'Format', NULL, NULL, N'ATTRIBUTE', N'[{"format":"font-family: Calibri; font-size: 11pt"},
{"formula":"[is_in_budget_request=0][is_active=1]","format":"font-weight: bold;"}]', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_report_sections', NULL, N'Format', NULL, NULL, N'ATTRIBUTE', N'[{"format":"font-family: Calibri; font-size: 11pt"},
{"formula":"row_format=8","columns":"Row Format"},
{"formula":"row_format=2","format":"font-weight: bold;","columns":"Row Format"},
{"formula":"row_format=1","format":"background-color: rgb(33,89,103);color: rgb(255,255,255);font-weight: bold;","columns":"Row Format"},
{"formula":"row_format=9","format":"background-color: rgb(0,33,96);color: rgb(255,255,255);font-weight: bold;","columns":"Row Format"}]', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_saved_reports', NULL, N'Format', NULL, NULL, N'ATTRIBUTE', N'[{"format":"font-family: Calibri; font-size: 11pt; border-style:none"},
{"formula":"row_format=9","format":"background-color: rgb(0,33,96) !important;color: rgb(255,255,255) !important;font-weight: bold;","stopIfTrue": true},
{"formula":"row_format=2","format":"font-weight: bold;","stopIfTrue": true},
{"formula":"row_format=1","format":"background-color: rgb(33,89,103) !important;color: rgb(255,255,255) !important;font-weight: bold;","stopIfTrue": true},
{"formula":"row_format=4","stopIfTrue": true}]', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'application', N'version', N'Information', NULL, NULL, N'ATTRIBUTE', N'3.2', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_request1', N'row_comments', N'KeepComments', NULL, NULL, N'ATTRIBUTE', N'rownum', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_request2', N'row_comments', N'KeepComments', NULL, NULL, N'ATTRIBUTE', N'rownum', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'dbo27', N'budget_currency_rates', N'row_formulas', N'KeepFormulas', NULL, NULL, N'ATTRIBUTE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_currency_rates', N'row_formulas', N'KeepFormulas', NULL, NULL, N'ATTRIBUTE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_request1', N'row_formulas', N'KeepFormulas', NULL, NULL, N'ATTRIBUTE', N'rownum', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_request2', N'row_formulas', N'KeepFormulas', NULL, NULL, N'ATTRIBUTE', N'rownum', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_actual_balances', N'company_id', N'ParameterValues', N'xls27', N'xl_parameter_values_company_id', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_actual_closed_periods', N'company_id', N'ParameterValues', N'xls27', N'xl_parameter_values_company_id', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_actual_currency_rates', N'company_id', N'ParameterValues', N'xls27', N'xl_parameter_values_company_id', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_actual_currency_rates', N'currency_id', N'ParameterValues', N'xls27', N'xl_parameter_values_currency_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_actual_reports', N'company_id', N'ParameterValues', N'xls27', N'xl_parameter_values_company_id', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_actual_reports', N'entity_id', N'ParameterValues', N'xls27', N'xl_parameter_values_entity_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_actual_reports', N'report_id', N'ParameterValues', N'xls27', N'xl_parameter_values_report_type_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_actual_reports', N'unit', N'ParameterValues', NULL, NULL, N'VALUES', N'1,1000,1000000', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_actual_reports', N'year', N'ParameterValues', N'xls27', N'xl_parameter_values_year', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_balance_sheet_trial', N'company_id', N'ParameterValues', N'xls27', N'xl_parameter_values_company_id', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_balance_sheet_trial', N'end_day', N'ParameterValues', N'xls27', N'xl_parameter_values_day', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_balance_sheet_trial', N'end_month', N'ParameterValues', N'xls27', N'xl_parameter_values_month', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_balance_sheet_trial', N'end_year', N'ParameterValues', N'xls27', N'xl_parameter_values_year', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_balance_sheet_trial', N'start_day', N'ParameterValues', N'xls27', N'xl_parameter_values_day', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_balance_sheet_trial', N'start_month', N'ParameterValues', N'xls27', N'xl_parameter_values_month', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_balance_sheet_trial', N'start_year', N'ParameterValues', N'xls27', N'xl_parameter_values_year', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_balances', N'category_id', N'ParameterValues', N'xls27', N'xl_parameter_values_category_id_not_null', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_balances', N'company_id', N'ParameterValues', N'xls27', N'xl_parameter_values_company_id', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_balances', N'time_id', N'ParameterValues', N'xls27', N'xl_parameter_values_time_id_not_null', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_closed_periods', N'company_id', N'ParameterValues', N'xls27', N'xl_parameter_values_company_id', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_currency_rates', N'category_id', N'ParameterValues', N'xls27', N'xl_parameter_values_category_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_currency_rates', N'company_id', N'ParameterValues', N'xls27', N'xl_parameter_values_company_id', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_currency_rates', N'time_id', N'ParameterValues', N'xls27', N'xl_parameter_values_time_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_data', N'category_id', N'ParameterValues', N'xls27', N'xl_parameter_values_category_id_not_null', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_data', N'company_id', N'ParameterValues', N'xls27', N'xl_parameter_values_company_id', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_data', N'entity_id', N'ParameterValues', N'xls27', N'xl_parameter_values_entity_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_data', N'time_id', N'ParameterValues', N'xls27', N'xl_parameter_values_time_id_not_null', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_journal', N'category_id', N'ParameterValues', N'xls27', N'xl_parameter_values_category_id_not_null', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_journal', N'company_id', N'ParameterValues', N'xls27', N'xl_parameter_values_company_id', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_journal', N'entity_id', N'ParameterValues', N'xls27', N'xl_parameter_values_entity_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_journal', N'first_month', N'ParameterValues', N'xls27', N'xl_parameter_values_month', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_journal', N'last_month', N'ParameterValues', N'xls27', N'xl_parameter_values_month', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_journal', N'product_id', N'ParameterValues', N'xls27', N'xl_validation_list_product_id_code', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_journal', N'region_id', N'ParameterValues', N'xls27', N'xl_validation_list_region_id_code', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_journal', N'subsidiary_account_id', N'ParameterValues', N'xls27', N'xl_parameter_values_subsidiary_account_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_journal', N'time_id', N'ParameterValues', N'xls27', N'xl_parameter_values_time_id_not_null', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_journal', N'unit', N'ParameterValues', NULL, NULL, N'VALUES', N'1,1000,1000000', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_reports', N'category_id', N'ParameterValues', N'xls27', N'xl_parameter_values_category_id_not_null', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_reports', N'company_id', N'ParameterValues', N'xls27', N'xl_parameter_values_company_id', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_reports', N'entity_id', N'ParameterValues', N'xls27', N'xl_parameter_values_entity_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_reports', N'report_id', N'ParameterValues', N'xls27', N'xl_parameter_values_report_type_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_reports', N'time_id', N'ParameterValues', N'xls27', N'xl_parameter_values_time_id_not_null', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_reports', N'unit', N'ParameterValues', NULL, NULL, N'VALUES', N'1,1000,1000000', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_reports_raw', N'category_id', N'ParameterValues', N'xls27', N'xl_parameter_values_category_id_not_null', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_reports_raw', N'company_id', N'ParameterValues', N'xls27', N'xl_parameter_values_company_id', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_reports_raw', N'entity_id', N'ParameterValues', N'xls27', N'xl_parameter_values_entity_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_reports_raw', N'product_id', N'ParameterValues', N'xls27', N'xl_validation_list_product_id_code', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_reports_raw', N'region_id', N'ParameterValues', N'xls27', N'xl_validation_list_region_id_code', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_reports_raw', N'subsidiary_account_id', N'ParameterValues', N'xls27', N'xl_parameter_values_subsidiary_account_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_reports_raw', N'time_id', N'ParameterValues', N'xls27', N'xl_parameter_values_time_id_not_null', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_reports_raw', N'unit', N'ParameterValues', NULL, NULL, N'VALUES', N'1,1000,1000000', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_request1', N'category_id', N'ParameterValues', N'xls27', N'xl_parameter_values_category_id_not_null', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_request1', N'company_id', N'ParameterValues', N'xls27', N'xl_parameter_values_company_id', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_request1', N'entity_id', N'ParameterValues', N'xls27', N'xl_parameter_values_entity_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_request1', N'time_id', N'ParameterValues', N'xls27', N'xl_parameter_values_time_id_not_null', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_request2', N'category_id', N'ParameterValues', N'xls27', N'xl_parameter_values_category_id_not_null', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_request2', N'company_id', N'ParameterValues', N'xls27', N'xl_parameter_values_company_id', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_request2', N'entity_id', N'ParameterValues', N'xls27', N'xl_parameter_values_entity_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_request2', N'time_id', N'ParameterValues', N'xls27', N'xl_parameter_values_time_id_not_null', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_requests', N'category_id', N'ParameterValues', N'xls27', N'xl_parameter_values_category_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_requests', N'company_id', N'ParameterValues', N'xls27', N'xl_parameter_values_company_id', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_requests', N'entity_id', N'ParameterValues', N'xls27', N'xl_parameter_values_entity_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_requests', N'time_id', N'ParameterValues', N'xls27', N'xl_parameter_values_time_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_requests_totals', N'category_id', N'ParameterValues', N'xls27', N'xl_parameter_values_category_id_not_null', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_requests_totals', N'company_id', N'ParameterValues', N'xls27', N'xl_parameter_values_company_id', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_requests_totals', N'entity_id', N'ParameterValues', N'xls27', N'xl_parameter_values_entity_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_requests_totals', N'first_month', N'ParameterValues', N'xls27', N'xl_parameter_values_month', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_requests_totals', N'last_month', N'ParameterValues', N'xls27', N'xl_parameter_values_month', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_requests_totals', N'product_id', N'ParameterValues', N'xls27', N'xl_validation_list_product_id_code', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_requests_totals', N'region_id', N'ParameterValues', N'xls27', N'xl_validation_list_region_id_code', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_requests_totals', N'subaccount_id', N'ParameterValues', N'xls27', N'xl_validation_list_subsidiary_account_id_code', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_requests_totals', N'subsidiary_account_id', N'ParameterValues', N'xls27', N'xl_parameter_values_subsidiary_account_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_requests_totals', N'time_id', N'ParameterValues', N'xls27', N'xl_parameter_values_time_id_not_null', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_requests_totals', N'unit', N'ParameterValues', NULL, NULL, N'VALUES', N'1,1000,1000000', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budgeting_accounts', N'account_type_id', N'ParameterValues', N'xls27', N'xl_parameter_values_member_type_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budgeting_accounts', N'company_id', N'ParameterValues', N'xls27', N'xl_parameter_values_company_id', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_journal', N'account_id', N'ParameterValues', N'xls27', N'xl_parameter_values_ledger_account_id_code', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_journal', N'company_id', N'ParameterValues', N'xls27', N'xl_parameter_values_company_id', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_journal', N'end_day', N'ParameterValues', N'xls27', N'xl_parameter_values_day', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_journal', N'end_month', N'ParameterValues', N'xls27', N'xl_parameter_values_month', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_journal', N'end_year', N'ParameterValues', N'xls27', N'xl_parameter_values_year', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_journal', N'entity_id', N'ParameterValues', N'xls27', N'xl_parameter_values_entity_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_journal', N'product_id', N'ParameterValues', N'xls27', N'xl_validation_list_product_id_code', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_journal', N'region_id', N'ParameterValues', N'xls27', N'xl_validation_list_region_id_code', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_journal', N'start_day', N'ParameterValues', N'xls27', N'xl_parameter_values_day', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_journal', N'start_month', N'ParameterValues', N'xls27', N'xl_parameter_values_month', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_journal', N'start_year', N'ParameterValues', N'xls27', N'xl_parameter_values_year', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_journal', N'subsidiary_account_id', N'ParameterValues', N'xls27', N'xl_parameter_values_subsidiary_account_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_ledger_accounts', N'company_id', N'ParameterValues', N'xls27', N'xl_parameter_values_company_id', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_member_permissions', N'company_id', N'ParameterValues', N'xls27', N'xl_parameter_values_company_id', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_member_permissions', N'dimension_id', N'ParameterValues', N'xls27', N'xl_parameter_values_dimension_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_member_permissions', N'username', N'ParameterValues', N'xls27', N'xl_parameter_values_username', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_member_relations', N'company_id', N'ParameterValues', N'xls27', N'xl_parameter_values_company_id', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_member_relations', N'member_dimension_id', N'ParameterValues', N'xls27', N'xl_parameter_values_dimension_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_member_relations', N'partner_dimension_id', N'ParameterValues', N'xls27', N'xl_parameter_values_dimension_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_members', N'company_id', N'ParameterValues', N'xls27', N'xl_parameter_values_company_id', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_members', N'dimension_id', N'ParameterValues', N'xls27', N'xl_parameter_values_dimension_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_report_section_accounts', N'entry_side_id', N'ParameterValues', N'xls27', N'xl_parameter_values_entry_side_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_report_section_accounts', N'report_type_id', N'ParameterValues', N'xls27', N'xl_parameter_values_report_type_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_report_sections', N'company_id', N'ParameterValues', N'xls27', N'xl_parameter_values_company_id', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_report_sections', N'report_type_id', N'ParameterValues', N'xls27', N'xl_parameter_values_report_type_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_saved_report_types', N'company_id', N'ParameterValues', N'xls27', N'xl_parameter_values_company_id', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_saved_reports', N'category_id', N'ParameterValues', N'xls27', N'xl_parameter_values_category_id_not_null', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_saved_reports', N'company_id', N'ParameterValues', N'xls27', N'xl_parameter_values_company_id', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_saved_reports', N'time_id', N'ParameterValues', N'xls27', N'xl_parameter_values_time_id_not_null', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_saved_reports', N'type_id', N'ParameterValues', N'xls27', N'xl_parameter_values_saved_report_type_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_subsidiary_accounts', N'company_id', N'ParameterValues', N'xls27', N'xl_parameter_values_company_id', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_subsidiary_accounts', N'subsidiary_group_id', N'ParameterValues', N'xls27', N'xl_parameter_values_subsidiary_group_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_subsidiary_groups', N'company_id', N'ParameterValues', N'xls27', N'xl_parameter_values_company_id', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_translations', N'company_id', N'ParameterValues', N'xls27', N'xl_parameter_values_company_id', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_translations_xls', N'field', N'ParameterValues', NULL, NULL, N'VALUES', N'TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_translations_xls', N'schema', N'ParameterValues', N'xls', N'translations', N'TABLE', N'TABLE_SCHEMA', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_units', N'company_id', N'ParameterValues', N'xls27', N'xl_parameter_values_company_id', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_users', N'company_id', N'ParameterValues', N'xls27', N'xl_parameter_values_company_id', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_vat_rates', N'company_id', N'ParameterValues', N'xls27', N'xl_parameter_values_company_id', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'xl_actions_add_language', N'company_id', N'ParameterValues', N'xls27', N'xl_parameter_values_company_id', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'xl_actions_auto_calc_all', N'company_id', N'ParameterValues', N'xls27', N'xl_parameter_values_company_id', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'xl_actions_auto_close_accounts', N'company_id', N'ParameterValues', N'xls27', N'xl_parameter_values_company_id', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'xl_actions_auto_currency_transactions', N'company_id', N'ParameterValues', N'xls27', N'xl_parameter_values_company_id', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'xl_actions_auto_currency_translation', N'company_id', N'ParameterValues', N'xls27', N'xl_parameter_values_company_id', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'xl_actions_select_members', N'company_id', N'ParameterValues', N'xls27', N'xl_parameter_values_company_id', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_actual_closed_periods', NULL, N'ProtectRows', NULL, NULL, N'ATTRIBUTE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_member_permissions', NULL, N'ProtectRows', NULL, NULL, N'ATTRIBUTE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_member_relations', NULL, N'ProtectRows', NULL, NULL, N'ATTRIBUTE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_translations', NULL, N'ProtectRows', NULL, NULL, N'ATTRIBUTE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_journal', N'account_id', N'SelectionList', N'xls27', N'xl_validation_list_budgeting_account_id_code', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_journal', N'credit_account_id', N'SelectionList', N'xls27', N'xl_validation_list_credit_account_id_code', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_journal', N'credit_subsidiary_account_id', N'SelectionList', N'xls27', N'xl_validation_list_credit_subsidiary_account_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_journal', N'debit_account_id', N'SelectionList', N'xls27', N'xl_validation_list_debit_account_id_code', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_journal', N'debit_subsidiary_account_id', N'SelectionList', N'xls27', N'xl_validation_list_debit_subsidiary_account_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_journal', N'entity_id', N'SelectionList', N'xls27', N'xl_validation_list_entity_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_journal', N'product_id', N'SelectionList', N'xls27', N'xl_validation_list_product_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_journal', N'region_id', N'SelectionList', N'xls27', N'xl_validation_list_region_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'dbo27', N'budget_currency_rates', N'category_id', N'ValidationList', N'xls27', N'xl_parameter_values_category_id_not_null', N'PROCEDURE', NULL, N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'dbo27', N'budget_currency_rates', N'time_id', N'ValidationList', N'xls27', N'xl_parameter_values_time_id_not_null', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'dbo27', N'budget_currency_rates', N'unit_id', N'ValidationList', N'xls27', N'xl_validation_list_unit_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'dbo27', N'ledger_accounts', N'account_type_id', N'ValidationList', N'xls27', N'xl_validation_list_ledger_account_type_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'dbo27', N'members', N'asset_account_id', N'ValidationList', N'xls27', N'xl_validation_list_ledger_account_id_code', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'dbo27', N'members', N'dimension_id', N'ValidationList', N'xls27', N'xl_validation_list_dimension_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'dbo27', N'members', N'settlement_account_id', N'ValidationList', N'xls27', N'xl_validation_list_ledger_account_id_code', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'dbo27', N'members', N'unit_id', N'ValidationList', N'xls27', N'xl_validation_list_unit_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'dbo27', N'members', N'vat_account_id', N'ValidationList', N'xls27', N'xl_validation_list_ledger_account_id_code', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'dbo27', N'members', N'vat_rate_id', N'ValidationList', N'xls27', N'xl_validation_list_vat_rate_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'dbo27', N'report_section_accounts', N'account_type_id', N'ValidationList', N'xls27', N'xl_validation_list_ledger_account_type_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'dbo27', N'report_section_accounts', N'section_type_id', N'ValidationList', N'xls27', N'xl_validation_list_report_section_type_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'dbo27', N'report_sections', N'parent_id', N'ValidationList', N'xls27', N'xl_validation_list_report_section_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'dbo27', N'report_sections', N'parent2_id', N'ValidationList', N'xls27', N'xl_validation_list_report_section_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'dbo27', N'report_sections', N'section_type_id', N'ValidationList', N'xls27', N'xl_validation_list_report_section_type_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_request1', N'account_id', N'ValidationList', N'xls27', N'xl_validation_list_budgeting_account_id_code', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_request1', N'product_id', N'ValidationList', N'xls27', N'xl_validation_list_product_id_code', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_request1', N'region_id', N'ValidationList', N'xls27', N'xl_validation_list_region_id_code', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_request1', N'subsidiary_account_id', N'ValidationList', N'xls27', N'xl_validation_list_subsidiary_account_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_request1', N'unit_id', N'ValidationList', N'xls27', N'xl_validation_list_unit_id_code', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_request1', N'vat_rate_id', N'ValidationList', N'xls27', N'xl_validation_list_vat_rate_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_request2', N'account_id', N'ValidationList', N'xls27', N'xl_validation_list_budgeting_account_id_code', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_request2', N'product_id', N'ValidationList', N'xls27', N'xl_validation_list_product_id_code', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_request2', N'region_id', N'ValidationList', N'xls27', N'xl_validation_list_region_id_code', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_request2', N'subsidiary_account_id', N'ValidationList', N'xls27', N'xl_validation_list_subsidiary_account_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_request2', N'unit_id', N'ValidationList', N'xls27', N'xl_validation_list_unit_id_code', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budget_request2', N'vat_rate_id', N'ValidationList', N'xls27', N'xl_validation_list_vat_rate_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budgeting_accounts', N'account_type_id', N'ValidationList', N'xls27', N'xl_validation_list_budgeting_account_type_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budgeting_accounts', N'charge_credit_id', N'ValidationList', N'xls27', N'xl_validation_list_ledger_account_id_code', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budgeting_accounts', N'charge_debit_id', N'ValidationList', N'xls27', N'xl_validation_list_ledger_account_id_code', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budgeting_accounts', N'parent_id', N'ValidationList', N'xls27', N'xl_validation_list_budgeting_parent_id_code', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budgeting_accounts', N'payment_credit_id', N'ValidationList', N'xls27', N'xl_validation_list_ledger_account_id_code', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budgeting_accounts', N'payment_debit_id', N'ValidationList', N'xls27', N'xl_validation_list_ledger_account_id_code', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budgeting_accounts', N'pl_account_id', N'ValidationList', N'xls27', N'xl_validation_list_ledger_account_id_code', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budgeting_accounts', N'unit_id', N'ValidationList', N'xls27', N'xl_validation_list_unit_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budgeting_accounts', N'vat_credit_id', N'ValidationList', N'xls27', N'xl_validation_list_ledger_account_id_code', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budgeting_accounts', N'vat_debit_id', N'ValidationList', N'xls27', N'xl_validation_list_ledger_account_id_code', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_budgeting_accounts', N'vat_rate_id', N'ValidationList', N'xls27', N'xl_validation_list_vat_rate_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_journal', N'account_id', N'ValidationList', N'xls27', N'xl_validation_list_budgeting_account_id_code', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_journal', N'credit_account_id', N'ValidationList', N'xls27', N'xl_validation_list_credit_account_id_code', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_journal', N'credit_subsidiary_account_id', N'ValidationList', N'xls27', N'xl_validation_list_credit_subsidiary_account_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_journal', N'debit_account_id', N'ValidationList', N'xls27', N'xl_validation_list_debit_account_id_code', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_journal', N'debit_subsidiary_account_id', N'ValidationList', N'xls27', N'xl_validation_list_debit_subsidiary_account_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_journal', N'entity_id', N'ValidationList', N'xls27', N'xl_validation_list_entity_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_journal', N'product_id', N'ValidationList', N'xls27', N'xl_validation_list_product_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_journal', N'region_id', N'ValidationList', N'xls27', N'xl_validation_list_region_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_ledger_account_types', N'specific_type_id', N'ValidationList', N'xls27', N'xl_validation_list_ledger_account_special_type_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_ledger_accounts', N'account_type_id', N'ValidationList', N'xls27', N'xl_validation_list_ledger_account_type_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_ledger_accounts', N'closing_child_account_id', N'ValidationList', N'xls27', N'xl_validation_list_ledger_account_id_code', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_ledger_accounts', N'closing_credit_account_id', N'ValidationList', N'xls27', N'xl_validation_list_ledger_account_id_code', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_ledger_accounts', N'closing_debit_account_id', N'ValidationList', N'xls27', N'xl_validation_list_ledger_account_id_code', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_ledger_accounts', N'parent_id', N'ValidationList', N'xls27', N'xl_validation_list_ledger_account_id_code', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_ledger_accounts', N'subsidiary_group_id', N'ValidationList', N'xls27', N'xl_validation_list_subsidiary_group_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_report_section_accounts', N'account_type_id', N'ValidationList', N'xls27', N'xl_validation_list_ledger_account_type_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_report_section_accounts', N'entry_side_id', N'ValidationList', N'xls27', N'xl_validation_list_entry_side_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_report_section_accounts', N'pair_account_type_id', N'ValidationList', N'xls27', N'xl_validation_list_ledger_account_type_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_report_section_accounts', N'report_type_id', N'ValidationList', N'xls27', N'xl_validation_list_report_type_id_code', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_report_section_accounts', N'section_type_id', N'ValidationList', N'xls27', N'xl_validation_list_report_section_type_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_report_section_accounts', N'value_type_id', N'ValidationList', N'xls27', N'xl_validation_list_report_section_value_type_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_report_section_types', N'report_type_id', N'ValidationList', N'xls27', N'xl_validation_list_report_type_id_code', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_report_section_types', N'total_type_id', N'ValidationList', N'xls27', N'xl_validation_list_report_section_total_type_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_report_sections', N'parent_id', N'ValidationList', N'xls27', N'xl_validation_list_report_section_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_report_sections', N'parent2_id', N'ValidationList', N'xls27', N'xl_validation_list_report_section_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_report_sections', N'report_type_id', N'ValidationList', N'xls27', N'xl_validation_list_report_type_id_code', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_report_sections', N'section_type_id', N'ValidationList', N'xls27', N'xl_validation_list_report_section_type_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_subsidiary_accounts', N'currency_id', N'ValidationList', N'xls27', N'xl_validation_list_currency_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_subsidiary_accounts', N'group1', N'ValidationList', N'xls27', N'xl_validation_list_subsidiary_group_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_subsidiary_accounts', N'group2', N'ValidationList', N'xls27', N'xl_validation_list_subsidiary_group_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N'xls27', N'usp_subsidiary_accounts', N'group3', N'ValidationList', N'xls27', N'xl_validation_list_subsidiary_group_id', N'PROCEDURE', NULL, NULL, NULL, NULL);
GO

INSERT INTO xls.objects (TABLE_SCHEMA, TABLE_NAME, TABLE_TYPE, TABLE_CODE, INSERT_OBJECT, UPDATE_OBJECT, DELETE_OBJECT) VALUES (N'xls27', N'usp_dimensions', N'PROCEDURE', NULL, N'dbo27.dimensions', N'dbo27.dimensions', N'dbo27.dimensions');
INSERT INTO xls.objects (TABLE_SCHEMA, TABLE_NAME, TABLE_TYPE, TABLE_CODE, INSERT_OBJECT, UPDATE_OBJECT, DELETE_OBJECT) VALUES (N'xls27', N'usp_ledger_account_types', N'PROCEDURE', NULL, N'dbo27.ledger_account_types', N'dbo27.ledger_account_types', N'dbo27.ledger_account_types');
INSERT INTO xls.objects (TABLE_SCHEMA, TABLE_NAME, TABLE_TYPE, TABLE_CODE, INSERT_OBJECT, UPDATE_OBJECT, DELETE_OBJECT) VALUES (N'xls27', N'usp_member_types', N'PROCEDURE', NULL, N'dbo27.member_types', N'dbo27.member_types', N'dbo27.member_types');
INSERT INTO xls.objects (TABLE_SCHEMA, TABLE_NAME, TABLE_TYPE, TABLE_CODE, INSERT_OBJECT, UPDATE_OBJECT, DELETE_OBJECT) VALUES (N'xls27', N'usp_report_section_accounts', N'PROCEDURE', NULL, N'dbo27.report_section_accounts', N'dbo27.report_section_accounts', N'dbo27.report_section_accounts');
INSERT INTO xls.objects (TABLE_SCHEMA, TABLE_NAME, TABLE_TYPE, TABLE_CODE, INSERT_OBJECT, UPDATE_OBJECT, DELETE_OBJECT) VALUES (N'xls27', N'usp_report_section_total_types', N'PROCEDURE', NULL, N'dbo27.report_section_total_types', N'dbo27.report_section_total_types', N'dbo27.report_section_total_types');
INSERT INTO xls.objects (TABLE_SCHEMA, TABLE_NAME, TABLE_TYPE, TABLE_CODE, INSERT_OBJECT, UPDATE_OBJECT, DELETE_OBJECT) VALUES (N'xls27', N'usp_report_section_types', N'PROCEDURE', NULL, N'dbo27.report_section_types', N'dbo27.report_section_types', N'dbo27.report_section_types');
INSERT INTO xls.objects (TABLE_SCHEMA, TABLE_NAME, TABLE_TYPE, TABLE_CODE, INSERT_OBJECT, UPDATE_OBJECT, DELETE_OBJECT) VALUES (N'xls27', N'usp_report_section_value_types', N'PROCEDURE', NULL, N'dbo27.report_section_value_types', N'dbo27.report_section_value_types', N'dbo27.report_section_value_types');
INSERT INTO xls.objects (TABLE_SCHEMA, TABLE_NAME, TABLE_TYPE, TABLE_CODE, INSERT_OBJECT, UPDATE_OBJECT, DELETE_OBJECT) VALUES (N'xls27', N'usp_report_types', N'PROCEDURE', NULL, N'dbo27.report_types', N'dbo27.report_types', N'dbo27.report_types');
GO

INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'dimensions_name', N'Accounts', N'de', N'Konten', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'dimensions_name', N'Categories', N'de', N'Kategorien', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'dimensions_name', N'Entities', N'de', N'Entitäten', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'dimensions_name', N'Products', N'de', N'Produkte', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'dimensions_name', N'Regions', N'de', N'Regionen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'dimensions_name', N'Sub.Accounts', N'de', N'Unterkonten', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'dimensions_name', N'Times', N'de', N'Perioden', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'entry_sides_name', N'Credit', N'de', N'Kredit', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'entry_sides_name', N'Debit', N'de', N'Debit', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'Calculation', N'de', N'Berechnung', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'Cash', N'de', N'Bargeld', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'Currency Exchange Gains', N'de', N'Wechselkursgewinne', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'Currency Exchange Losses', N'de', N'Wechselkursverluste', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'Currency Translation Gains', N'de', N'Währungsumrechnungsgewinne', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'Currency Translation Losses', N'de', N'Währungsumrechnungsverluste', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'Net Income (BS)', N'de', N'Nettoeinkommen (BS)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'Net Income (PL)', N'de', N'Nettoeinkommen (PL)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'VAT Payable', N'de', N'Einkommensteuer', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'VAT Receivable', N'de', N'Mehrwertsteuer in Aufwendungen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Administrative Expenses', N'de', N'Verwaltungsaufwendungen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Administrative Expenses - Amortization', N'de', N'Verwaltungskosten - Amortisation', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Administrative Expenses - Depreciation', N'de', N'Verwaltungskosten - Abschreibungen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Calculation', N'de', N'Berechnung', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Cost of Revenue', N'de', N'Umsatzkosten', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Cost of Revenue - Amortization', N'de', N'Umsatzkosten - Amortisation', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Cost of Revenue - Depreciation', N'de', N'Umsatzkosten - Abschreibungen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Currency Exchange Gains', N'de', N'Wechselkursgewinne', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Currency Exchange Losses', N'de', N'Wechselkursverluste', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Currency Translation Gains', N'de', N'Währungsumrechnungsgewinne', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Currency Translation Losses', N'de', N'Währungsumrechnungsverluste', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Assets', N'de', N'Umlaufvermögen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Assets - Cash', N'de', N'Umlaufvermögen - Bargeld', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Assets - Cash Equivalents', N'de', N'Umlaufvermögen - Zahlungsmitteläquivalente', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Assets - Receivable', N'de', N'Umlaufvermögen - Forderung', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Assets - VAT Receivable', N'de', N'Umlaufvermögen - Mehrwertsteuerforderung', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Assets/Liabilities', N'de', N'Umlaufvermögen oder Verbindlichkeiten', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Financial Assets', N'de', N'Umlaufvermögen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Financial Assets Net', N'de', N'Umlaufvermögen netto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Financial Liabilities', N'de', N'Kurzfristige finanzielle Verbindlichkeiten', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Financial Liabilities Net', N'de', N'Kurzfristige finanzielle Verbindlichkeiten netto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Investing Assets', N'de', N'Umlaufvermögen - Investition', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Investing Liabilities', N'de', N'Kurzfristige Verbindlichkeiten - Investition', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Liabilities', N'de', N'Kurzfristige Verbindlichkeiten', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Liabilities - Payable', N'de', N'Kurzfristige Verbindlichkeiten - zahlbar', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Liabilities - VAT Payable', N'de', N'Kurzfristige Verbindlichkeiten - Mehrwertsteuer', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Equity', N'de', N'Eigenkapital', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Equity - Net Income', N'de', N'Eigenkapital - Nettoeinkommen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Equity - Retained Earnings', N'de', N'Eigenkapital - Gewinnrücklagen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'General Expenses', N'de', N'Allgemeine Kosten', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'General Expenses - Amortization', N'de', N'Allgemeine Aufwendungen - Abschreibungen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'General Expenses - Depreciation', N'de', N'Allgemeine Aufwendungen - Abschreibungen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Income Tax Expense', N'de', N'Gewinnsteuer Aufwendungen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Interest Expenses', N'de', N'Einkommensteuerzahlungen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Net Income', N'de', N'Nettoeinkommen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Non-current Assets', N'de', N'Anlagevermögen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Non-current Assets - Amortization', N'de', N'Langfristige Vermögenswerte - Abschreibungen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Non-current Assets - Depreciation', N'de', N'Langfristige Vermögenswerte - Abschreibungen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Non-current Financial Assets', N'de', N'Langfristige finanzielle Vermögenswerte', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Non-current Financial Assets Net', N'de', N'Langfristiges finanzielles Vermögen netto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Non-current Financial Liabilities', N'de', N'Langfristige finanzielle Verbindlichkeiten', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Non-current Financial Liabilities Net', N'de', N'Langfristige finanzielle Verbindlichkeiten netto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Non-current Liabilities', N'de', N'Langfristige Verbindlichkeiten', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Operating Income', N'de', N'Betriebsergebnis', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Other Expenses', N'de', N'Andere Ausgaben', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Other Financial Expenses', N'de', N'Sonstige finanzielle Aufwendungen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Other Financial Income', N'de', N'Sonstige finanzielle Erträge', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Other Income', N'de', N'Anderes Einkommen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Other Income/Expenses Net', N'de', N'Sonstige Erträge / Aufwendungen netto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Other Investing Expenses', N'de', N'Sonstige Investitionskosten', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Other Investing Income', N'de', N'Sonstige Kapitalerträge', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'R&D Expenses', N'de', N'F & E-Ausgaben', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'R&D Expenses - Amortization', N'de', N'F & E-Aufwendungen - Amortisation', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'R&D Expenses - Depreciation', N'de', N'F & E-Aufwendungen - Abschreibungen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Revenue', N'de', N'Einnahmen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Selling Expenses', N'de', N'Verkaufskosten', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Selling Expenses - Amortization', N'de', N'Verkaufskosten - Amortisation', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Selling Expenses - Depreciation', N'de', N'Verkaufskosten - Abschreibungen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Amortization', N'de', N'Amortisation', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Calculated', N'de', N'Berechnet', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Cash Transfer', N'de', N'Überweisung', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Cost', N'de', N'Kostenaufwand', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Depreciation', N'de', N'Abschreibung', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Expense', N'de', N'Kosten', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Expense, no VAT', N'de', N'Kosten, keine Mehrwertsteuer', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Income', N'de', N'Einkommen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Income, no VAT', N'de', N'Einkommen, keine Mehrwertsteuer', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Inflow', N'de', N'Zufluss', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'None', N'de', N'Kein Wert', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Outflow', N'de', N'Abfluss', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Purchase', N'de', N'Kauf', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Purchase, no VAT', N'de', N'Kauf, keine Mehrwertsteuer', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Setoff', N'de', N'Losfahren', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Withholding', N'de', N'Zurückhalten', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_total_types_name', N'Closing Balance', N'de', N'Schlussbilanz', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_total_types_name', N'Opening Balance', N'de', N'Anfangsbestand', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_total_types_name', N'Total', N'de', N'Gesamt', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Administrative Expenses', N'de', N'Verwaltungsaufwendungen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Cash at the Beginning (CF)', N'de', N'Bargeld am Anfang (CF)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Cash at the Beginning (DCF)', N'de', N'Bargeld am Anfang (DCF)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Cash at the End (CF)', N'de', N'Bargeld am Ende (CF)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Cash at the End (DCF)', N'de', N'Bargeld am Ende (DCF)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Cost of Revenue', N'de', N'Umsatzkosten', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Current Assets', N'de', N'Umlaufvermögen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Current Liabilities', N'de', N'Kurzfristige Verbindlichkeiten', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Depreciation (CF)', N'de', N'Abschreibung (CF)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Disabled', N'de', N'Behindert', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Expense VAT', N'de', N'Mehrwertsteuer', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Financing Cash Flows (CF)', N'de', N'Cashflow aus Finanzierung', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Financing Cash Inflows', N'de', N'Zuflüsse aus Finanzierung (CF)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Financing Cash Inflows (CF)', N'de', N'Zuflüsse aus Finanzierung (CF)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Financing Cash Outflows (CF)', N'de', N'Abflüsse aus Finanzierung (CF)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Financing Inflows', N'de', N'Zuflüsse aus Finanzierung', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Financing Outflows', N'de', N'Abflüsse aus Finanzierung', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'General Expenses', N'de', N'Allgemeine Kosten', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Income Tax Expense', N'de', N'Gewinnsteuer Aufwendungen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Income VAT', N'de', N'Mehrwertsteuer auf Einkommen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Interest Expenses', N'de', N'Einkommensteuerzahlungen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Investing Cash Flows (CF)', N'de', N'Cashflow aus Investitionen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Investing Inflows', N'de', N'Zuflüsse von Investitionen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Investing Outflows', N'de', N'Abflüsse von Investitionen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Net Income (CF)', N'de', N'Nettoeinkommen (CF)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Non-Current Assets', N'de', N'Anlagevermögen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Non-Current Liabilities', N'de', N'Langfristige Verbindlichkeiten', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Operating Cash Flows (CF)', N'de', N'Cashflow des Betriebs', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Operating Inflows', N'de', N'Zuflüsse des Betriebs', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Operating Outflows', N'de', N'Abflüsse des Betriebs', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Other Expenses', N'de', N'Andere Ausgaben', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Other Income', N'de', N'Anderes Einkommen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'R&D Expenses', N'de', N'F & E-Ausgaben', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Revenue', N'de', N'Einnahmen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Selling Expenses', N'de', N'Verkaufskosten', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Stockholders'' Equity', N'de', N'Eigenkapital', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Stockholders'' Equity - Net Income', N'de', N'Eigenkapital - Jahresüberschuss', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'VAT Paid', N'de', N'Mehrwertsteuer bezahlt', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'VAT Set-Offs', N'de', N'Mehrwertsteueraufrechnungen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_value_types_name', N'Balance', N'de', N'Balance', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_value_types_name', N'Credit Balance', N'de', N'Kredit Balance', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_value_types_name', N'Debit Balance', N'de', N'Debit Balance', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_value_types_name', N'Flow', N'de', N'Fließen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_code', N'BS', N'de', N'BS', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_code', N'CF', N'de', N'CF', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_code', N'DCF', N'de', N'DCF', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_code', N'PL', N'de', N'PL', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_code', N'VAT', N'de', N'VAT', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_name', N'Balance Sheet', N'de', N'Bilanz', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_name', N'Cash Flow', N'de', N'Geldflussrechnung', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_name', N'Direct Cash Flow', N'de', N'Geldflussrechnung direkt', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_name', N'Income Statement', N'de', N'Gewinn- und Verlustrechnung', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_name', N'VAT', N'de', N'Mehrwertsteuer', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Access denied', N'de', N'Zugriff abgelehnt', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Cannot find member id %i', N'de', N'Artikel-ID %i kann nicht gefunden werden', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Cannot find member id %s', N'de', N'Artikel-ID %s kann nicht gefunden werden', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Cannot find member_id %i', N'de', N'Element %i kann nicht gefunden werden', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Cannot find member_id %s', N'de', N'Element %s kann nicht gefunden werden', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Cannot find the principal ''%s'', because it does not exist or you do not have permission.', N'de', N'Benutzer %s kann nicht gefunden werden', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Invalid column name: %s', N'de', N'Ungültiger Spaltenname: %s', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Member %s cannot be editable as it has children', N'de', N'Element%s kann nicht bearbeitet werden, da es untergeordnete Elemente enthält', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Role ''%s'' does not exist', N'de', N'Die Rolle ''%s'' existiert nicht', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Set 1 to add and 0 to remove a user from the role', N'de', N'Setzen Sie 1 zum Hinzufügen und 0 zum Entfernen eines Benutzers aus der Rolle', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'The code ''%s'' contains prohibited symbols (space, '', ", [ or ])', N'de', N'Der Code ''%s'' enthält verbotene Symbole (Leerzeichen, '', ", [, ]).', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'The column ''%s'' is not updatable', N'de', N'Die Spalte ''%s'' kann nicht aktualisiert werden', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'The journal has operations on %s', N'de', N'Das Journal hat Operationen auf %s', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'The period is closed for changes', N'de', N'Die Frist ist wegen Änderungen geschlossen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Unknown option: %i (Use 0 or 1)', N'de', N'Unbekannte Option: %i (Verwenden Sie 0 oder 1)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Unknown option: %s (Use R, W, D)', N'de', N'Unbekannte Option: %s (Verwenden Sie R, W, D)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Use TRANSLATED_NAME, TRANSLATED_DESC, or TRANSLATED_COMMENT', N'de', N'Verwenden Sie TRANSLATED_NAME, TRANSLATED_DESC oder TRANSLATED_COMMENT', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'User ''%s'' does not exist', N'de', N'Benutzer ''%s'' existiert nicht', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'account', N'de', N'Konto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'account_id', N'de', N'Konto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'account_type_id', N'de', N'Konto Typ', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'amount', N'de', N'Betrag', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'amount$', N'de', N'Betrag$', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'asset_sign', N'de', N'Asset-Zeichen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'assets', N'de', N'Asset', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'auto_type_id', N'de', N'Automatischer Typ', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance', N'de', N'Balance', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance$', N'de', N'Balance$', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance00', N'de', N'Balance00', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance01', N'de', N'Balance01', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance02', N'de', N'Balance02', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance03', N'de', N'Balance03', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance04', N'de', N'Balance04', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance05', N'de', N'Balance05', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance06', N'de', N'Balance06', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance07', N'de', N'Balance07', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance08', N'de', N'Balance08', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance09', N'de', N'Balance09', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance10', N'de', N'Balance10', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance11', N'de', N'Balance11', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance12', N'de', N'Balance12', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'bs', N'de', N'BS', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'bs_section', N'de', N'BS-Sektion', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'bs_sign', N'de', N'BS Sign', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'category_id', N'de', N'Kategorie', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'category_name', N'de', N'Kategoriename', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'cf', N'de', N'CF', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'cf_ref_number', N'de', N'CF-Referenznummer', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'cf_section', N'de', N'CF-Sektion', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'cf_sign', N'de', N'CF-Zeichen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charge_credit', N'de', N'Kreditkonto für Gebühren', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charge_credit_id', N'de', N'Kreditkonto für Gebühren', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charge_credit_type_id', N'de', N'Art des Kreditkontos für Gebühren', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charge_debit', N'de', N'Debitkonto für Gebühren', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charge_debit_id', N'de', N'Debitkonto für Gebühren', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charge_debit_type_id', N'de', N'Art des Debitkontos für Gebühren', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges', N'de', N'Gebühren', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges01', N'de', N'Gebühren01', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges02', N'de', N'Gebühren02', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges03', N'de', N'Gebühren03', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges04', N'de', N'Gebühren04', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges05', N'de', N'Gebühren05', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges06', N'de', N'Gebühren06', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges07', N'de', N'Gebühren07', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges08', N'de', N'Gebühren08', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges09', N'de', N'Gebühren09', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges10', N'de', N'Gebühren10', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges11', N'de', N'Gebühren11', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges12', N'de', N'Gebühren12', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'closing_balance', N'de', N'Schlusssaldo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'closing_child_account_id', N'de', N'Untergeordnetes Konto zu schließen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'closing_credit', N'de', N'Kreditschlusssaldo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'closing_credit_account_id', N'de', N'Kreditkonto schließen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'closing_debit', N'de', N'Debitschlusssaldo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'closing_debit_account_id', N'de', N'Debitkonto schließen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'code', N'de', N'Code', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'code1', N'de', N'Code 1', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'code2', N'de', N'Code 2', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'column_name', N'de', N'Spaltenname', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'company_id', N'de', N'Unternehmen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'created_by', N'de', N'Erstellt von', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'created_on', N'de', N'Erstellt', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'credit', N'de', N'Kredit', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'credit$', N'de', N'Kredit$', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'credit_account_id', N'de', N'Kreditkonto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'credit_subsidiary_account_id', N'de', N'Kreditnebenkonto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'credit_turnover', N'de', N'Kreditsummen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'currency', N'de', N'Währung', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'currency_id', N'de', N'Währung', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data_format', N'de', N'Datei Format', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data00', N'de', N'Summen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data01', N'de', N'Jan.', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data02', N'de', N'Feb.', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data03', N'de', N'Apr.', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data04', N'de', N'März', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data05', N'de', N'Mai', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data06', N'de', N'Juni', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data07', N'de', N'Juli', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data08', N'de', N'Aug.', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data09', N'de', N'Sept.', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data10', N'de', N'Okt.', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data11', N'de', N'Nov.', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data12', N'de', N'Dez.', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'date', N'de', N'Datum', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'debit', N'de', N'Debit', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'debit$', N'de', N'Debit$', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'debit_account_id', N'de', N'Debitkonto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'debit_subsidiary_account_id', N'de', N'Debitnebenkonto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'debit_turnover', N'de', N'Debitssummen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'default_language', N'de', N'Standardsprache', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'description', N'de', N'Beschreibung', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'dimension_id', N'de', N'Abmessungen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'end_day', N'de', N'Endtag', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'end_month', N'de', N'Ende des Monats', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'end_year', N'de', N'Ende des Jahres', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'entity_id', N'de', N'Entität', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'entity_name', N'de', N'Entitätsname', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'entry_side_id', N'de', N'Seite des Journaleintrags', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'factor', N'de', N'Faktor', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'field', N'de', N'Feld', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'first_month', N'de', N'Erster Monat', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'format_column', N'de', N'Formatspalte', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'group_id', N'de', N'Gruppe', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'group1', N'de', N'Gruppe 1', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'group2', N'de', N'Gruppe 2', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'group3', N'de', N'Gruppe 3', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'hide', N'de', N'Ausblenden', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'hide_accounts', N'de', N'Konten ausblenden', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'hide_items', N'de', N'Gegenstände ausblenden', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'id', N'de', N'ID', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'id1', N'de', N'ID1', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'id2', N'de', N'ID2', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'inverse_sign', N'de', N'Inverses Vorzeichen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_active', N'de', N'Aktiv', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_admin', N'de', N'Administrator', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_base_currency', N'de', N'Ist Basiswährung', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_calc_date', N'de', N'Berechnungsdatum', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_charge_net', N'de', N'Charge Net', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_checked', N'de', N'Überprüft', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_closed', N'de', N'Geschlossen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_complete', N'de', N'Komplett', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_credit_editable', N'de', N'Kreditkonto bearbeitbar', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_currency', N'de', N'Währung', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_da', N'de', N'D/A', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_debit_editable', N'de', N'Debitkonto bearbeitbar', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_default', N'de', N'Standard', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_draft', N'de', N'Entwurf', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_empty', N'de', N'Leer', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_functional_currency', N'de', N'Funktionale Währung', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_in_budget', N'de', N'Im Budget', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_in_budget_request', N'de', N'In Budgetanfrage', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_inherited', N'de', N'Vererbt', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_parent', N'de', N'Elternteil', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_pl', N'de', N'PL', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_translatable', N'de', N'Übersetzbar', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'language', N'de', N'Sprache', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'last_format_column', N'de', N'Letzte Formatspalte', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'last_month', N'de', N'Im vergangenen Monat', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'level', N'de', N'Niveau', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'line', N'de', N'Linie', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'line_factor', N'de', N'Linienfaktor', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'member_dimension_id', N'de', N'Mitgliedsdimension', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'member_id', N'de', N'Mitglied', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'modified_by', N'de', N'Geändert von', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'modified_on', N'de', N'Geändert', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'month', N'de', N'Monat', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'name', N'de', N'Name', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'opening_balance', N'de', N'Eröffnungssaldo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'opening_credit', N'de', N'Krediteröffnungssaldo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'opening_debit', N'de', N'Debiteröffnungssaldo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'page_break', N'de', N'Seitenumbruch', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'page_break_before', N'de', N'Seitenumbruch vor', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'pair', N'de', N'Währungspaar', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'pair_account_type_id', N'de', N'Paar Kontotyp', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'parent_id', N'de', N'Elternmitglied', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'parent2_id', N'de', N'Elternteil2', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'partner_dimension_id', N'de', N'Partnerdimension', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'partner_id', N'de', N'Partnermitglied', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payment_credit', N'de', N'Kreditkonto für Zahlungen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payment_credit_id', N'de', N'Kreditkonto für Zahlungen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payment_credit_type_id', N'de', N'Art des Kreditkontos für Zahlungen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payment_debit', N'de', N'Debitkonto für Zahlungen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payment_debit_id', N'de', N'Debitkonto für Zahlungen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payment_debit_type_id', N'de', N'Art des Debitkontos für Zahlungen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments', N'de', N'Zahlungen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments01', N'de', N'Zahlungen01', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments02', N'de', N'Zahlungen02', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments03', N'de', N'Zahlungen03', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments04', N'de', N'Zahlungen04', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments05', N'de', N'Zahlungen05', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments06', N'de', N'Zahlungen06', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments07', N'de', N'Zahlungen07', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments08', N'de', N'Zahlungen08', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments09', N'de', N'Zahlungen09', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments10', N'de', N'Zahlungen10', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments11', N'de', N'Zahlungen11', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments12', N'de', N'Zahlungen12', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period_name', N'de', N'Periodenname', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period01', N'de', N'Zeitraum01', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period02', N'de', N'Zeitraum02', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period03', N'de', N'Zeitraum03', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period04', N'de', N'Zeitraum04', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period05', N'de', N'Zeitraum05', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period06', N'de', N'Zeitraum06', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period07', N'de', N'Zeitraum07', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period08', N'de', N'Zeitraum08', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period09', N'de', N'Zeitraum09', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period10', N'de', N'Zeitraum10', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period11', N'de', N'Zeitraum11', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period12', N'de', N'Zeitraum12', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'permission', N'de', N'Genehmigung', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'pl', N'de', N'PL', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'pl_ref_number', N'de', N'PL Ref Nummer', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'pl_section', N'de', N'PL Abschnitt', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'pl_section_id', N'de', N'PL Abschnitt', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'pl_sign', N'de', N'PL-Zeichen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'product_id', N'de', N'Produkt', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'rate', N'de', N'Wechselkurs', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'ref_number', N'de', N'Referenznummer', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'ref_record_id', N'de', N'Referenzdatensatz', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'region_id', N'de', N'Region', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'report', N'de', N'Bericht', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'report_id', N'de', N'Bericht', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'report_section_type_id', N'de', N'Typ des Berichtsabschnitts', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'report_type_id', N'de', N'Berichtstyp', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'row_comments', N'de', N'Zeilenkommentare', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'row_format', N'de', N'Zeilenformat', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'row_formulas', N'de', N'Zeilenformeln', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'row_index', N'de', N'Zeilenindex', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'row_level', N'de', N'Zeilenebene', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'rows', N'de', N'Reihenanzahl', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'schema', N'de', N'Schema', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'section', N'de', N'Sektion', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'section_type_id', N'de', N'Abschnittsart', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'select_permission', N'de', N'Erlaubnis zu SELECT', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'show_line', N'de', N'Linie anzeigen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'show_line_after', N'de', N'Zeile nach anzeigen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'show_line_before', N'de', N'Zeile vorher anzeigen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'sort_order', N'de', N'Sortierung', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'specific_type_id', N'de', N'Spezifischer Typ', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'start_day', N'de', N'Tag beginnen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'start_month', N'de', N'Monat beginnen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'start_year', N'de', N'Startjahr', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'subsidiary_account_id', N'de', N'Nebenkonto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'subsidiary_group_id', N'de', N'Gruppe von Nebenkonten', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'subsidiary_name', N'de', N'Name des Nebenkontos', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'table_id', N'de', N'Tabellen-ID', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'time_id', N'de', N'Perioden-ID', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'total_charges', N'de', N'Gesamte Gebühren', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'total_payments', N'de', N'Gesamte Zahlungen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'total_type_id', N'de', N'Gesamttyp', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'transaction_start_time', N'de', N'Transaktionsstartzeit', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'translated_name', N'de', N'Übersetzter Name', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'type', N'de', N'Art', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'type_id', N'de', N'Art', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'unit', N'de', N'Einheit', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'unit_id', N'de', N'Einheit', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'update_permission', N'de', N'Erlaubnis zum UPDATE', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'username', N'de', N'Nutzername', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'value_sign', N'de', N'Wertzeichen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'value_type_id', N'de', N'Werttyp', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'vat', N'de', N'Mehrwertsteuer', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'vat_credit', N'de', N'Kreditkonto für Mehrwertsteuer', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'vat_credit_id', N'de', N'Kreditkonto für Mehrwertsteuer', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'vat_credit_type_id', N'de', N'Art des Kreditkontos für Mehrwertsteuer', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'vat_debit', N'de', N'Debitkonto für Mehrwertsteuer', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'vat_debit_id', N'de', N'Debitkonto für Mehrwertsteuer', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'vat_debit_type_id', N'de', N'Art des Debitkontos für Mehrwertsteuer', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'vat_rate_id', N'de', N'Mehrwertsteuersatz', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'vat_sign', N'de', N'Mehrwertsteuerzeichen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'year', N'de', N'Jahr', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'zero', N'de', N'Null', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_actual_balances', NULL, N'de', N'Tatsächliche Salden', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_actual_balances', N'account_id', N'de', N'Konto-ID', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_actual_balances', N'subsidiary_account_id', N'de', N'ID des Nebenkontos', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_actual_closed_periods', NULL, N'de', N'Tatsächliche geschlossene Perioden', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_actual_currency_rates', NULL, N'de', N'Tatsächliche Wechselkurse', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_actual_reports', NULL, N'de', N'Aktuelle Berichte', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_balance_sheet_trial', NULL, N'de', N'Umsatzbilanz', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_balances', NULL, N'de', N'Haushaltssalden', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_closed_periods', NULL, N'de', N'Budget geschlossene Perioden', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_currency_rates', NULL, N'de', N'Budget Währungskurse', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_data', NULL, N'de', N'Budgetdaten', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_journal', NULL, N'de', N'Budget Journal', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_reports', NULL, N'de', N'Budgetberichte', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_reports_raw', NULL, N'de', N'Budget-Rohberichte', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', NULL, N'de', N'Budgetanfrage 1', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', N'account', N'de', N'Konto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', N'account_id', N'de', N'Konto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', N'account_name', N'de', N'Name des Kontos', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', N'product', N'de', N'Produkt', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', N'product_id', N'de', N'Produkt', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', N'region', N'de', N'Region', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', N'region_id', N'de', N'Region', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', N'subsidiary_account', N'de', N'Nebenkonto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', N'subsidiary_account_id', N'de', N'Nebenkonto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', NULL, N'de', N'Budgetanfrage 2', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', N'account', N'de', N'Konto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', N'account_id', N'de', N'Konto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', N'account_name', N'de', N'Name des Kontos', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', N'product', N'de', N'Produkt', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', N'product_id', N'de', N'Produkt', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', N'region', N'de', N'Region', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', N'region_id', N'de', N'Region', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', N'subsidiary_account', N'de', N'Nebenkonto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', N'subsidiary_account_id', N'de', N'Nebenkonto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_requests', NULL, N'de', N'Budgetanfragen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_requests_totals', NULL, N'de', N'Budgetanfragen Gesamt', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budgeting_accounts', NULL, N'de', N'Budgetierung von Konten', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_companies', NULL, N'de', N'Unternehmen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_dimensions', NULL, N'de', N'Messungen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_entry_sides', NULL, N'de', N'Seiten des Eintragsjournals', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_journal', NULL, N'de', N'Journal', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_ledger_account_special_types', NULL, N'de', N'Arten von speziellen Sachkonten', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_ledger_account_types', NULL, N'de', N'Arten von Konten', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_ledger_accounts', NULL, N'de', N'Hauptbuchkonten', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_member_permissions', NULL, N'de', N'Mitgliederberechtigungen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_member_relations', NULL, N'de', N'Mitgliederbeziehungen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_member_types', NULL, N'de', N'Arten von Objekten', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_members', NULL, N'de', N'Mitglieder', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_report_section_accounts', NULL, N'de', N'Berichtsabschnittskonten', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_report_section_total_types', NULL, N'de', N'Arten von Berichtsabschnittssummen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_report_section_types', NULL, N'de', N'Abschnittsarten von Berichten', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_report_section_value_types', NULL, N'de', N'Arten von Berichtsabschnittswerten', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_report_sections', NULL, N'de', N'Abschnitte melden', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_report_types', NULL, N'de', N'Arten von Berichten', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_role_members', NULL, N'de', N'Mitglieder von Rollen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_saved_report_types', NULL, N'de', N'Gespeicherte Berichtstypen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_saved_reports', NULL, N'de', N'Gespeicherte Berichte', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_subsidiary_accounts', NULL, N'de', N'Nebenkonten', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_subsidiary_groups', NULL, N'de', N'Nebengruppen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_translations', NULL, N'de', N'Übersetzungen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_translations_common', NULL, N'de', N'Übersetzungen (allgemein)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_translations_xls', NULL, N'de', N'Übersetzungen (xls)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_units', NULL, N'de', N'Einheiten', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_users', NULL, N'de', N'Benutzer', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_vat_rates', NULL, N'de', N'Mehrwertsteuersätze', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_actions_actual_report_cell_data', NULL, N'de', N'Zellendetails anzeigen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_actions_add_language', NULL, N'de', N'Sprache hinzufügen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_actions_auto_calc_all', NULL, N'de', N'Alle berechnen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_actions_auto_close_accounts', NULL, N'de', N'Abschlusskonten berechnen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_actions_auto_currency_transactions', NULL, N'de', N'Währungstransaktionen berechnen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_actions_auto_currency_translation', NULL, N'de', N'Währungsumrechnung berechnen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_actions_budget_report_cell_data', NULL, N'de', N'Zellendetails anzeigen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_actions_select_members', NULL, N'de', N'Mitglieder anzeigen', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_automatic_handlers', NULL, N'de', N'Automatische Handler', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_online_help_handlers', NULL, N'de', N'Online-Hilfe-Handler', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'April', N'de', N'April', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'August', N'de', N'August', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'December', N'de', N'Dezember', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'February', N'de', N'Februar', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'January', N'de', N'Januar', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'July', N'de', N'Juli', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'June', N'de', N'Juni', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'March', N'de', N'März', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'May', N'de', N'Kann', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'November', N'de', N'November', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'October', N'de', N'Oktober', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'September', N'de', N'September', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_query_list_admin', NULL, N'de', N'Liste der Admin-Objekte', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_query_list_setup', NULL, N'de', N'Liste der Setup-Objekte', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'dimensions_name', N'Accounts', N'en', N'Accounts', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'dimensions_name', N'Categories', N'en', N'Categories', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'dimensions_name', N'Entities', N'en', N'Entities', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'dimensions_name', N'Products', N'en', N'Products', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'dimensions_name', N'Regions', N'en', N'Regions', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'dimensions_name', N'Sub.Accounts', N'en', N'Sub.Accounts', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'dimensions_name', N'Times', N'en', N'Times', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'entry_sides_name', N'Credit', N'en', N'Credit', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'entry_sides_name', N'Debit', N'en', N'Debit', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'Calculation', N'en', N'Calculation', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'Cash', N'en', N'Cash', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'Currency Exchange Gains', N'en', N'Currency Exchange Gains', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'Currency Exchange Losses', N'en', N'Currency Exchange Losses', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'Currency Translation Gains', N'en', N'Currency Translation Gains', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'Currency Translation Losses', N'en', N'Currency Translation Losses', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'Net Income (BS)', N'en', N'Net Income (BS)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'Net Income (PL)', N'en', N'Net Income (PL)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'VAT Payable', N'en', N'VAT Payable', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'VAT Receivable', N'en', N'VAT Receivable', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Administrative Expenses', N'en', N'Administrative Expenses', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Administrative Expenses - Amortization', N'en', N'Administrative Expenses - Amortization', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Administrative Expenses - Depreciation', N'en', N'Administrative Expenses - Depreciation', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Calculation', N'en', N'Calculation', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Cost of Revenue', N'en', N'Cost of Revenue', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Cost of Revenue - Amortization', N'en', N'Cost of Revenue - Amortization', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Cost of Revenue - Depreciation', N'en', N'Cost of Revenue - Depreciation', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Currency Exchange Gains', N'en', N'Currency Exchange Gains', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Currency Exchange Losses', N'en', N'Currency Exchange Losses', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Currency Translation Gains', N'en', N'Currency Translation Gains', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Currency Translation Losses', N'en', N'Currency Translation Losses', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Assets', N'en', N'Current Assets', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Assets - Cash', N'en', N'Current Assets - Cash', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Assets - Cash Equivalents', N'en', N'Current Assets - Cash Equivalents', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Assets - Receivable', N'en', N'Current Assets - Receivable', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Assets - VAT Receivable', N'en', N'Current Assets - VAT Receivable', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Assets/Liabilities', N'en', N'Current Assets/Liabilities', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Financial Assets', N'en', N'Current Financial Assets', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Financial Assets Net', N'en', N'Current Financial Assets Net', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Financial Liabilities', N'en', N'Current Financial Liabilities', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Financial Liabilities Net', N'en', N'Current Financial Liabilities Net', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Investing Assets', N'en', N'Current Investing Assets', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Investing Liabilities', N'en', N'Current Investing Liabilities', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Liabilities', N'en', N'Current Liabilities', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Liabilities - Payable', N'en', N'Current Liabilities - Payable', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Liabilities - VAT Payable', N'en', N'Current Liabilities - VAT Payable', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Equity', N'en', N'Equity', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Equity - Net Income', N'en', N'Equity - Net Income', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Equity - Retained Earnings', N'en', N'Equity - Retained Earnings', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'General Expenses', N'en', N'General Expenses', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'General Expenses - Amortization', N'en', N'General Expenses - Amortization', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'General Expenses - Depreciation', N'en', N'General Expenses - Depreciation', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Income Tax Expense', N'en', N'Income Tax Expense', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Interest Expenses', N'en', N'Interest Expenses', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Net Income', N'en', N'Net Income', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Non-current Assets', N'en', N'Non-current Assets', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Non-current Assets - Amortization', N'en', N'Non-current Assets - Amortization', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Non-current Assets - Depreciation', N'en', N'Non-current Assets - Depreciation', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Non-current Financial Assets', N'en', N'Non-current Financial Assets', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Non-current Financial Assets Net', N'en', N'Non-current Financial Assets Net', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Non-current Financial Liabilities', N'en', N'Non-current Financial Liabilities', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Non-current Financial Liabilities Net', N'en', N'Non-current Financial Liabilities Net', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Non-current Liabilities', N'en', N'Non-current Liabilities', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Operating Income', N'en', N'Operating Income', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Other Expenses', N'en', N'Other Expenses', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Other Financial Expenses', N'en', N'Other Financial Expenses', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Other Financial Income', N'en', N'Other Financial Income', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Other Income', N'en', N'Other Income', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Other Income/Expenses Net', N'en', N'Other Income/Expenses Net', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Other Investing Expenses', N'en', N'Other Investing Expenses', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Other Investing Income', N'en', N'Other Investing Income', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'R&D Expenses', N'en', N'R&D Expenses', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'R&D Expenses - Amortization', N'en', N'R&D Expenses - Amortization', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'R&D Expenses - Depreciation', N'en', N'R&D Expenses - Depreciation', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Revenue', N'en', N'Revenue', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Selling Expenses', N'en', N'Selling Expenses', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Selling Expenses - Amortization', N'en', N'Selling Expenses - Amortization', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Selling Expenses - Depreciation', N'en', N'Selling Expenses - Depreciation', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Amortization', N'en', N'Amortization', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Calculated', N'en', N'Calculated', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Cash Transfer', N'en', N'Cash Transfer', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Cost', N'en', N'Cost', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Depreciation', N'en', N'Depreciation', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Expense', N'en', N'Expense', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Expense, no VAT', N'en', N'Expense, no VAT', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Income', N'en', N'Income', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Income, no VAT', N'en', N'Income, no VAT', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Inflow', N'en', N'Inflow', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'None', N'en', N'None', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Outflow', N'en', N'Outflow', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Purchase', N'en', N'Purchase', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Purchase, no VAT', N'en', N'Purchase, no VAT', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Setoff', N'en', N'Setoff', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Withholding', N'en', N'Withholding', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_total_types_name', N'Closing Balance', N'en', N'Closing Balance', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_total_types_name', N'Opening Balance', N'en', N'Opening Balance', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_total_types_name', N'Total', N'en', N'Total', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Administrative Expenses', N'en', N'Administrative Expenses', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Cash at the Beginning (CF)', N'en', N'Cash at the Beginning (CF)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Cash at the Beginning (DCF)', N'en', N'Cash at the Beginning (DCF)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Cash at the End (CF)', N'en', N'Cash at the End (CF)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Cash at the End (DCF)', N'en', N'Cash at the End (DCF)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Cost of Revenue', N'en', N'Cost of Revenue', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Current Assets', N'en', N'Current Assets', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Current Liabilities', N'en', N'Current Liabilities', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Depreciation (CF)', N'en', N'Depreciation (CF)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Disabled', N'en', N'Disabled', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Expense VAT', N'en', N'Expense VAT', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Financing Cash Flows (CF)', N'en', N'Financing Cash Flows', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Financing Cash Inflows', N'en', N'Financing Cash Inflows (CF)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Financing Cash Inflows (CF)', N'en', N'Financing Inflows (CF)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Financing Cash Outflows (CF)', N'en', N'Financing Outflows (CF)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Financing Inflows', N'en', N'Financing Inflows', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Financing Outflows', N'en', N'Financing Outflows', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'General Expenses', N'en', N'General Expenses', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Income Tax Expense', N'en', N'Income Tax Expense', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Income VAT', N'en', N'Income VAT', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Interest Expenses', N'en', N'Interest Expenses', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Investing Cash Flows (CF)', N'en', N'Investing Cash Flows', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Investing Inflows', N'en', N'Investing Inflows', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Investing Outflows', N'en', N'Investing Outflows', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Net Income (CF)', N'en', N'Net Income (CF)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Non-Current Assets', N'en', N'Non-Current Assets', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Non-Current Liabilities', N'en', N'Non-Current Liabilities', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Operating Cash Flows (CF)', N'en', N'Operating Cash Flows', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Operating Inflows', N'en', N'Operating Inflows', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Operating Outflows', N'en', N'Operating Outflows', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Other Expenses', N'en', N'Other Expenses', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Other Income', N'en', N'Other Income', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'R&D Expenses', N'en', N'R&D Expenses', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Revenue', N'en', N'Revenue', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Selling Expenses', N'en', N'Selling Expenses', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Stockholders'' Equity', N'en', N'Stockholders'' Equity', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Stockholders'' Equity - Net Income', N'en', N'Stockholders'' Equity - Net Income', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'VAT Paid', N'en', N'VAT Paid', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'VAT Set-Offs', N'en', N'VAT Set-Offs', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_value_types_name', N'Balance', N'en', N'Balance', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_value_types_name', N'Credit Balance', N'en', N'Credit Balance', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_value_types_name', N'Debit Balance', N'en', N'Debit Balance', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_value_types_name', N'Flow', N'en', N'Flow', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_code', N'BS', N'en', N'BS', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_code', N'CF', N'en', N'CF', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_code', N'DCF', N'en', N'DCF', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_code', N'PL', N'en', N'PL', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_code', N'VAT', N'en', N'VAT', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_name', N'Balance Sheet', N'en', N'Balance Sheet', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_name', N'Cash Flow', N'en', N'Cash Flow', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_name', N'Direct Cash Flow', N'en', N'Direct Cash Flow', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_name', N'Income Statement', N'en', N'Income Statement', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_name', N'VAT', N'en', N'VAT', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Access denied', N'en', N'Access denied', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Cannot find member id %i', N'en', N'Cannot find member id %i', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Cannot find member id %s', N'en', N'Cannot find member id %s', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Cannot find member_id %i', N'en', N'Cannot find member_id %i', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Cannot find member_id %s', N'en', N'Cannot find member_id %s', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Cannot find the principal ''%s'', because it does not exist or you do not have permission.', N'en', N'Cannot find the principal ''%s'', because it does not exist or you do not have permission.', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Invalid column name: %s', N'en', N'Invalid column name: %s', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Member %s cannot be editable as it has children', N'en', N'Member %s cannot be editable as it has children', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Role ''%s'' does not exist', N'en', N'Role ''%s'' does not exist', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Set 1 to add and 0 to remove a user from the role', N'en', N'Set 1 to add and 0 to remove a user from the role', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'The code ''%s'' contains prohibited symbols (space, '', ", [ or ])', N'en', N'The code ''%s'' contains prohibited symbols (space, '', ", [ or ])', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'The column ''%s'' is not updatable', N'en', N'The column ''%s'' is not updatable', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'The journal has operations on %s', N'en', N'The journal has operations on %s', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'The period is closed for changes', N'en', N'The period is closed for changes', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Unknown option: %i (Use 0 or 1)', N'en', N'Unknown option: %i (Use 0 or 1)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Unknown option: %s (Use R, W, D)', N'en', N'Unknown option: %s (Use R, W, D)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Use TRANSLATED_NAME, TRANSLATED_DESC, or TRANSLATED_COMMENT', N'en', N'Use TRANSLATED_NAME, TRANSLATED_DESC, or TRANSLATED_COMMENT', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'User ''%s'' does not exist', N'en', N'User ''%s'' does not exist', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'account', N'en', N'Account', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'account_id', N'en', N'Account', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'account_type_id', N'en', N'Account Type', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'amount', N'en', N'Amount', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'amount$', N'en', N'Amount$', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'asset_sign', N'en', N'Asset Sign', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'assets', N'en', N'Assets', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'auto_type_id', N'en', N'Auto Type', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance', N'en', N'Balance', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance$', N'en', N'Balance$', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance00', N'en', N'Balance00', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance01', N'en', N'Balance01', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance02', N'en', N'Balance02', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance03', N'en', N'Balance03', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance04', N'en', N'Balance04', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance05', N'en', N'Balance05', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance06', N'en', N'Balance06', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance07', N'en', N'Balance07', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance08', N'en', N'Balance08', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance09', N'en', N'Balance09', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance10', N'en', N'Balance10', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance11', N'en', N'Balance11', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance12', N'en', N'Balance12', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'bs', N'en', N'BS', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'bs_section', N'en', N'BS Section', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'bs_sign', N'en', N'BS Sign', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'category_id', N'en', N'Category', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'category_name', N'en', N'Category Name', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'cf', N'en', N'CF', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'cf_ref_number', N'en', N'CF Ref Number', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'cf_section', N'en', N'CF Section', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'cf_sign', N'en', N'CF Sign', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charge_credit', N'en', N'Charge Credit', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charge_credit_id', N'en', N'Charge Credit', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charge_credit_type_id', N'en', N'Charge Credit Type', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charge_debit', N'en', N'Charge Debit', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charge_debit_id', N'en', N'Charge Debit', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charge_debit_type_id', N'en', N'Charge Debit Type', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges', N'en', N'Charges', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges01', N'en', N'Charges01', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges02', N'en', N'Charges02', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges03', N'en', N'Charges03', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges04', N'en', N'Charges04', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges05', N'en', N'Charges05', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges06', N'en', N'Charges06', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges07', N'en', N'Charges07', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges08', N'en', N'Charges08', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges09', N'en', N'Charges09', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges10', N'en', N'Charges10', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges11', N'en', N'Charges11', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges12', N'en', N'Charges12', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'closing_balance', N'en', N'Closing Balance', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'closing_child_account_id', N'en', N'Closing Child Account', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'closing_credit', N'en', N'Closing Credit Balance', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'closing_credit_account_id', N'en', N'Closing Credit Account', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'closing_debit', N'en', N'Closing Debit Balance', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'closing_debit_account_id', N'en', N'Closing Debit Account', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'code', N'en', N'Code', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'code1', N'en', N'Code 1', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'code2', N'en', N'Code 2', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'column_name', N'en', N'Column Name', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'company_id', N'en', N'Company', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'created_by', N'en', N'Created by', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'created_on', N'en', N'Created', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'credit', N'en', N'Credit', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'credit$', N'en', N'Credit$', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'credit_account_id', N'en', N'Credit Account', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'credit_subsidiary_account_id', N'en', N'Credit Subsidiary Account', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'credit_turnover', N'en', N'Credit Turnover', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'currency', N'en', N'Currency', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'currency_id', N'en', N'Currency', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data_format', N'en', N'Data Format', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data00', N'en', N'Total', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data01', N'en', N'Jan', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data02', N'en', N'Feb', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data03', N'en', N'Apr', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data04', N'en', N'Mar', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data05', N'en', N'May', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data06', N'en', N'Jun', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data07', N'en', N'Jul', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data08', N'en', N'Aug', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data09', N'en', N'Sep', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data10', N'en', N'Oct', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data11', N'en', N'Nov', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data12', N'en', N'Dec', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'date', N'en', N'Date', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'debit', N'en', N'Debit', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'debit$', N'en', N'Debit$', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'debit_account_id', N'en', N'Debit Account', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'debit_subsidiary_account_id', N'en', N'Debit Subsidiary Account', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'debit_turnover', N'en', N'Debit Turnover', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'default_language', N'en', N'Default Language', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'description', N'en', N'Description', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'dimension_id', N'en', N'Dimension', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'end_day', N'en', N'End Day', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'end_month', N'en', N'End Month', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'end_year', N'en', N'End Year', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'entity_id', N'en', N'Entity', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'entity_name', N'en', N'Entity Name', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'entry_side_id', N'en', N'Entry Side', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'factor', N'en', N'Factor', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'field', N'en', N'Field', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'first_month', N'en', N'First Month', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'format_column', N'en', N'Format Column', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'group_id', N'en', N'Group', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'group1', N'en', N'Group 1', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'group2', N'en', N'Group 2', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'group3', N'en', N'Group 3', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'hide', N'en', N'Hide', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'hide_accounts', N'en', N'Hide Accounts', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'hide_items', N'en', N'Hide Items', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'id', N'en', N'ID', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'id1', N'en', N'ID1', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'id2', N'en', N'ID2', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'inverse_sign', N'en', N'Inverse Sign', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_active', N'en', N'Active', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_admin', N'en', N'Admin', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_base_currency', N'en', N'Is Base Currency', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_calc_date', N'en', N'Calc Date', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_charge_net', N'en', N'Charge Net', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_checked', N'en', N'Checked', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_closed', N'en', N'Closed', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_complete', N'en', N'Complete', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_credit_editable', N'en', N'Credit Editable', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_currency', N'en', N'Currency', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_da', N'en', N'D/A', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_debit_editable', N'en', N'Debit Editable', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_default', N'en', N'Default', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_draft', N'en', N'Draft', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_empty', N'en', N'Empty', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_functional_currency', N'en', N'Functional Currency', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_in_budget', N'en', N'In Budget', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_in_budget_request', N'en', N'In Budget Request', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_inherited', N'en', N'Inherited', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_parent', N'en', N'Parent', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_pl', N'en', N'PL', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_translatable', N'en', N'Translatable', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'language', N'en', N'Language', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'last_format_column', N'en', N'Last Format Column', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'last_month', N'en', N'Last Month', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'level', N'en', N'Level', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'line', N'en', N'Line', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'line_factor', N'en', N'Line Factor', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'member_dimension_id', N'en', N'Member Dimension', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'member_id', N'en', N'Member', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'modified_by', N'en', N'Modified by', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'modified_on', N'en', N'Modified', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'month', N'en', N'Month', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'name', N'en', N'Name', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'opening_balance', N'en', N'Opening Balance', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'opening_credit', N'en', N'Opening Credit Balance', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'opening_debit', N'en', N'Opening Debit Balance', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'page_break', N'en', N'Page Break', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'page_break_before', N'en', N'Page Break Before', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'pair', N'en', N'Pair', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'pair_account_type_id', N'en', N'Pair Account Type', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'parent_id', N'en', N'Parent Member', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'parent2_id', N'en', N'Parent2', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'partner_dimension_id', N'en', N'Partner Dimension', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'partner_id', N'en', N'Partner Member', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payment_credit', N'en', N'Payment Credit', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payment_credit_id', N'en', N'Payment Credit', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payment_credit_type_id', N'en', N'Payment Credit Type', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payment_debit', N'en', N'Payment Debit', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payment_debit_id', N'en', N'Payment Debit', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payment_debit_type_id', N'en', N'Payment Debit Type', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments', N'en', N'Payments', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments01', N'en', N'Payments01', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments02', N'en', N'Payments02', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments03', N'en', N'Payments03', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments04', N'en', N'Payments04', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments05', N'en', N'Payments05', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments06', N'en', N'Payments06', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments07', N'en', N'Payments07', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments08', N'en', N'Payments08', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments09', N'en', N'Payments09', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments10', N'en', N'Payments10', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments11', N'en', N'Payments11', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments12', N'en', N'Payments12', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period_name', N'en', N'Period Name', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period01', N'en', N'Period01', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period02', N'en', N'Period02', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period03', N'en', N'Period03', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period04', N'en', N'Period04', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period05', N'en', N'Period05', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period06', N'en', N'Period06', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period07', N'en', N'Period07', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period08', N'en', N'Period08', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period09', N'en', N'Period09', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period10', N'en', N'Period10', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period11', N'en', N'Period11', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period12', N'en', N'Period12', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'permission', N'en', N'Permission', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'pl', N'en', N'PL', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'pl_ref_number', N'en', N'PL Ref Number', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'pl_section', N'en', N'PL Section', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'pl_section_id', N'en', N'PL Section', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'pl_sign', N'en', N'PL Sign', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'product_id', N'en', N'Product', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'rate', N'en', N'Currency Rate', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'ref_number', N'en', N'Ref.', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'ref_record_id', N'en', N'Ref.', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'region_id', N'en', N'Region', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'report', N'en', N'Report', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'report_id', N'en', N'Report', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'report_section_type_id', N'en', N'Report Section Type', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'report_type_id', N'en', N'Report Type', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'row_comments', N'en', N'Row Comments', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'row_format', N'en', N'Row Format', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'row_formulas', N'en', N'Row Formulas', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'row_index', N'en', N'Row Index', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'row_level', N'en', N'Row Level', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'rows', N'en', N'Number of Rows', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'schema', N'en', N'Schema', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'section', N'en', N'Section', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'section_type_id', N'en', N'Section Type', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'select_permission', N'en', N'SELECT Permission', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'show_line', N'en', N'Show Line', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'show_line_after', N'en', N'Show Line After', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'show_line_before', N'en', N'Show Line Before', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'sort_order', N'en', N'Sort Order', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'specific_type_id', N'en', N'Specific Type', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'start_day', N'en', N'Start Day', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'start_month', N'en', N'Start Month', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'start_year', N'en', N'Start Year', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'subsidiary_account_id', N'en', N'Sub.Account', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'subsidiary_group_id', N'en', N'Subsidiary Group', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'subsidiary_name', N'en', N'Subsidiary Account Name', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'table_id', N'en', N'Table ID', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'time_id', N'en', N'Period', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'total_charges', N'en', N'Total Charges', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'total_payments', N'en', N'Total Payments', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'total_type_id', N'en', N'Total Type', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'transaction_start_time', N'en', N'Transaction Start Time', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'translated_name', N'en', N'Translated Name', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'type', N'en', N'Type', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'type_id', N'en', N'Type', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'unit', N'en', N'Unit', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'unit_id', N'en', N'Unit', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'update_permission', N'en', N'UPDATE Permission', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'username', N'en', N'Username', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'value_sign', N'en', N'Value Sign', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'value_type_id', N'en', N'Value Type', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'vat', N'en', N'VAT', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'vat_credit', N'en', N'VAT Credit', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'vat_credit_id', N'en', N'VAT Credit', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'vat_credit_type_id', N'en', N'VAT Credit Type', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'vat_debit', N'en', N'VAT Debit', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'vat_debit_id', N'en', N'VAT Debit', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'vat_debit_type_id', N'en', N'VAT Debit Type', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'vat_rate_id', N'en', N'VAT Rate', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'vat_sign', N'en', N'VAT Sign', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'year', N'en', N'Year', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'zero', N'en', N'Zero', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_actual_balances', NULL, N'en', N'Actual Balances', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_actual_balances', N'account_id', N'en', N'Account ID', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_actual_balances', N'subsidiary_account_id', N'en', N'Subsidiary Account ID', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_actual_closed_periods', NULL, N'en', N'Actual Closed Periods', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_actual_currency_rates', NULL, N'en', N'Actual Currency Rates', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_actual_reports', NULL, N'en', N'Actual Reports', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_balance_sheet_trial', NULL, N'en', N'Balance Sheet Trial', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_balances', NULL, N'en', N'Budget Balances', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_closed_periods', NULL, N'en', N'Budget Closed Periods', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_currency_rates', NULL, N'en', N'Budget Currency Rates', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_data', NULL, N'en', N'Budget Data', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_journal', NULL, N'en', N'Budget Journal', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_reports', NULL, N'en', N'Budget Reports', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_reports_raw', NULL, N'en', N'Budget Reports Raw', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', NULL, N'en', N'Budget Request 1', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', N'account', N'en', N'Account', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', N'account_id', N'en', N'Account', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', N'account_name', N'en', N'Account Name', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', N'product', N'en', N'Product', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', N'product_id', N'en', N'Product', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', N'region', N'en', N'Region', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', N'region_id', N'en', N'Region', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', N'subsidiary_account', N'en', N'Subsidiary Account', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', N'subsidiary_account_id', N'en', N'Subsidiary Account', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', NULL, N'en', N'Budget Request 2', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', N'account', N'en', N'Account', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', N'account_id', N'en', N'Account', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', N'account_name', N'en', N'Account Name', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', N'product', N'en', N'Product', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', N'product_id', N'en', N'Product', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', N'region', N'en', N'Region', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', N'region_id', N'en', N'Region', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', N'subsidiary_account', N'en', N'Subsidiary Account', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', N'subsidiary_account_id', N'en', N'Subsidiary Account', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_requests', NULL, N'en', N'Budget Requests', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_requests_totals', NULL, N'en', N'Budget Requests Totals', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budgeting_accounts', NULL, N'en', N'Budgeting Accounts', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_companies', NULL, N'en', N'Companies', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_dimensions', NULL, N'en', N'Dimensions', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_entry_sides', NULL, N'en', N'Entry Sides', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_journal', NULL, N'en', N'Journal', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_ledger_account_special_types', NULL, N'en', N'Ledger Account Special Types', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_ledger_account_types', NULL, N'en', N'Ledger Account Types', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_ledger_accounts', NULL, N'en', N'Ledger Accounts', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_member_permissions', NULL, N'en', N'Member Permissions', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_member_relations', NULL, N'en', N'Member Relations', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_member_types', NULL, N'en', N'Member Types', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_members', NULL, N'en', N'Members', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_report_section_accounts', NULL, N'en', N'Report Section Accounts', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_report_section_total_types', NULL, N'en', N'Report Section Total Types', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_report_section_types', NULL, N'en', N'Report Section Types', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_report_section_value_types', NULL, N'en', N'Report Section Value Types', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_report_sections', NULL, N'en', N'Report Sections', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_report_types', NULL, N'en', N'Report Types', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_role_members', NULL, N'en', N'Role Members', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_saved_report_types', NULL, N'en', N'Saved Report Types', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_saved_reports', NULL, N'en', N'Saved Reports', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_subsidiary_accounts', NULL, N'en', N'Subsidiary Accounts', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_subsidiary_groups', NULL, N'en', N'Subsidiary Groups', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_translations', NULL, N'en', N'Translations', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_translations_common', NULL, N'en', N'Translations (Common)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_translations_xls', NULL, N'en', N'Translations (xls)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_units', NULL, N'en', N'Units', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_users', NULL, N'en', N'Users', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_vat_rates', NULL, N'en', N'VAT Rates', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_actions_actual_report_cell_data', NULL, N'en', N'Show Cell Details', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_actions_add_language', NULL, N'en', N'Add Language', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_actions_auto_calc_all', NULL, N'en', N'Calculate All', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_actions_auto_close_accounts', NULL, N'en', N'Calculate Closing Accounts', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_actions_auto_currency_transactions', NULL, N'en', N'Calculate Currency Transactions', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_actions_auto_currency_translation', NULL, N'en', N'Calculate Currency Translation', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_actions_budget_report_cell_data', NULL, N'en', N'Show Cell Details', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_actions_select_members', NULL, N'en', N'Show Members', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_automatic_handlers', NULL, N'en', N'Automatic Handlers', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_online_help_handlers', NULL, N'en', N'Online Help Handlers', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'April', N'en', N'April', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'August', N'en', N'August', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'December', N'en', N'December', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'February', N'en', N'February', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'January', N'en', N'January', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'July', N'en', N'July', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'June', N'en', N'June', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'March', N'en', N'March', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'May', N'en', N'May', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'November', N'en', N'November', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'October', N'en', N'October', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'September', N'en', N'September', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_query_list_admin', NULL, N'en', N'List of Admin Objects', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_query_list_setup', NULL, N'en', N'List of Setup Objects', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'dimensions_name', N'Accounts', N'es', N'Cuentas', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'dimensions_name', N'Categories', N'es', N'Categorías', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'dimensions_name', N'Entities', N'es', N'Entidades', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'dimensions_name', N'Products', N'es', N'Productos', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'dimensions_name', N'Regions', N'es', N'Regiones', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'dimensions_name', N'Sub.Accounts', N'es', N'Subcuentas', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'dimensions_name', N'Times', N'es', N'Períodos', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'entry_sides_name', N'Credit', N'es', N'Crédito', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'entry_sides_name', N'Debit', N'es', N'Débito', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'Calculation', N'es', N'Cálculo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'Cash', N'es', N'Efectivo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'Currency Exchange Gains', N'es', N'Ganancias de cambio de divisas', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'Currency Exchange Losses', N'es', N'Pérdidas de cambio de moneda', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'Currency Translation Gains', N'es', N'Ganancias de conversión de divisas', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'Currency Translation Losses', N'es', N'Pérdidas de conversión de divisas', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'Net Income (BS)', N'es', N'Ingresos netos (BS)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'Net Income (PL)', N'es', N'Ingresos netos (PL)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'VAT Payable', N'es', N'IVA a pagar', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'VAT Receivable', N'es', N'IVA por cobrar', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Administrative Expenses', N'es', N'Gastos administrativos', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Administrative Expenses - Amortization', N'es', N'Gastos administrativos - Amortización', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Administrative Expenses - Depreciation', N'es', N'Gastos administrativos - Depreciación', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Calculation', N'es', N'Cálculo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Cost of Revenue', N'es', N'Costo de los ingresos', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Cost of Revenue - Amortization', N'es', N'Costo de ingresos - Amortización', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Cost of Revenue - Depreciation', N'es', N'Costo de ingresos - Depreciación', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Currency Exchange Gains', N'es', N'Ganancias de cambio de divisas', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Currency Exchange Losses', N'es', N'Pérdidas de cambio de moneda', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Currency Translation Gains', N'es', N'Ganancias de conversión de divisas', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Currency Translation Losses', N'es', N'Pérdidas de conversión de divisas', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Assets', N'es', N'Activos circulantes', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Assets - Cash', N'es', N'Activos corrientes - Efectivo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Assets - Cash Equivalents', N'es', N'Activos corrientes - Equivalentes de efectivo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Assets - Receivable', N'es', N'Activos corrientes - Cuentas por cobrar', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Assets - VAT Receivable', N'es', N'Activos corrientes - IVA por cobrar', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Assets/Liabilities', N'es', N'Activos o pasivos corrientes', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Financial Assets', N'es', N'Activos financieros corrientes', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Financial Assets Net', N'es', N'Activos financieros corrientes netos', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Financial Liabilities', N'es', N'Pasivos financieros corrientes', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Financial Liabilities Net', N'es', N'Pasivos financieros corrientes netos', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Investing Assets', N'es', N'Activos corrientes - Inversión', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Investing Liabilities', N'es', N'Pasivos corrientes - Inversión', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Liabilities', N'es', N'Pasivos corrientes', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Liabilities - Payable', N'es', N'Pasivos corrientes - Por pagar', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Liabilities - VAT Payable', N'es', N'Pasivos corrientes - IVA por pagar', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Equity', N'es', N'Capital', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Equity - Net Income', N'es', N'Patrimonio - Utilidad neta', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Equity - Retained Earnings', N'es', N'Patrimonio - Ganancias retenidas', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'General Expenses', N'es', N'Gastos generales', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'General Expenses - Amortization', N'es', N'Gastos generales - Amortización', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'General Expenses - Depreciation', N'es', N'Gastos generales - Depreciación', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Income Tax Expense', N'es', N'Impuesto sobre la renta', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Interest Expenses', N'es', N'Gastos por intereses', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Net Income', N'es', N'Ingresos netos', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Non-current Assets', N'es', N'Activos no corrientes', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Non-current Assets - Amortization', N'es', N'Activos no corrientes - Amortización', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Non-current Assets - Depreciation', N'es', N'Activos no corrientes - Depreciación', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Non-current Financial Assets', N'es', N'Activos financieros no corrientes', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Non-current Financial Assets Net', N'es', N'Activos financieros no corrientes netos', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Non-current Financial Liabilities', N'es', N'Pasivos financieros no corrientes', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Non-current Financial Liabilities Net', N'es', N'Pasivos financieros no corrientes netos', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Non-current Liabilities', N'es', N'Pasivos no corrientes', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Operating Income', N'es', N'Ingresos de explotación', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Other Expenses', N'es', N'Otros gastos', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Other Financial Expenses', N'es', N'Otros gastos financieros', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Other Financial Income', N'es', N'Otros ingresos financieros', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Other Income', N'es', N'Otros ingresos', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Other Income/Expenses Net', N'es', N'Otros ingresos/gastos netos', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Other Investing Expenses', N'es', N'Otros gastos de inversión', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Other Investing Income', N'es', N'Otros ingresos por inversiones', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'R&D Expenses', N'es', N'Gastos de I + D', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'R&D Expenses - Amortization', N'es', N'Gastos de I + D - Amortización', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'R&D Expenses - Depreciation', N'es', N'Gastos de I + D - Depreciación', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Revenue', N'es', N'Ingresos', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Selling Expenses', N'es', N'Gastos de venta', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Selling Expenses - Amortization', N'es', N'Gastos de venta - Amortización', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Selling Expenses - Depreciation', N'es', N'Gastos de venta - Depreciación', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Amortization', N'es', N'Amortización', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Calculated', N'es', N'Calculado', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Cash Transfer', N'es', N'Transferencia de efectivo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Cost', N'es', N'Costo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Depreciation', N'es', N'Depreciación', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Expense', N'es', N'Gastos', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Expense, no VAT', N'es', N'Gastos, sin IVA', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Income', N'es', N'Ingresos', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Income, no VAT', N'es', N'Ingresos, sin IVA', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Inflow', N'es', N'Afluencia', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'None', N'es', N'Ninguno', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Outflow', N'es', N'Salida', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Purchase', N'es', N'Compra', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Purchase, no VAT', N'es', N'Compra, sin IVA', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Setoff', N'es', N'Partir', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Withholding', N'es', N'Retenciones', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_total_types_name', N'Closing Balance', N'es', N'Balance de cierre', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_total_types_name', N'Opening Balance', N'es', N'Balance de apertura', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_total_types_name', N'Total', N'es', N'Total', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Administrative Expenses', N'es', N'Gastos administrativos', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Cash at the Beginning (CF)', N'es', N'Efectivo al comienzo (CF)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Cash at the Beginning (DCF)', N'es', N'Efectivo al comienzo (DCF)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Cash at the End (CF)', N'es', N'Efectivo al final (CF)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Cash at the End (DCF)', N'es', N'Efectivo al final (DCF)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Cost of Revenue', N'es', N'Costo de los ingresos', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Current Assets', N'es', N'Activos circulantes', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Current Liabilities', N'es', N'Pasivo circulante', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Depreciation (CF)', N'es', N'Depreciación (CF)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Disabled', N'es', N'Discapacitado', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Expense VAT', N'es', N'IVA de gastos', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Financing Cash Flows (CF)', N'es', N'Flujos de efectivo de financiamiento', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Financing Cash Inflows', N'es', N'Entradas de financiamiento (CF)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Financing Cash Inflows (CF)', N'es', N'Entradas de financiamiento (CF)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Financing Cash Outflows (CF)', N'es', N'Salidas de financiamiento (CF)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Financing Inflows', N'es', N'Entradas de financiamiento', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Financing Outflows', N'es', N'Salidas de financiamiento', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'General Expenses', N'es', N'Gastos generales', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Income Tax Expense', N'es', N'Impuesto sobre la renta', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Income VAT', N'es', N'IVA de ingresos', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Interest Expenses', N'es', N'Gastos por intereses', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Investing Cash Flows (CF)', N'es', N'Flujos de efectivo de inversión', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Investing Inflows', N'es', N'Entradas de inversión', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Investing Outflows', N'es', N'Salidas de inversión', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Net Income (CF)', N'es', N'Ingresos netos (CF)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Non-Current Assets', N'es', N'Activos no corrientes', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Non-Current Liabilities', N'es', N'Pasivos no corrientes', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Operating Cash Flows (CF)', N'es', N'Flujos de efectivo de operación', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Operating Inflows', N'es', N'Entradas de operación', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Operating Outflows', N'es', N'Salidas de operación', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Other Expenses', N'es', N'Otros gastos', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Other Income', N'es', N'Otros ingresos', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'R&D Expenses', N'es', N'Gastos de I + D', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Revenue', N'es', N'Ingresos', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Selling Expenses', N'es', N'Gastos de venta', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Stockholders'' Equity', N'es', N'Capital contable', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Stockholders'' Equity - Net Income', N'es', N'Capital contable - Utilidad neta', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'VAT Paid', N'es', N'IVA pagado', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'VAT Set-Offs', N'es', N'Compensación de IVA', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_value_types_name', N'Balance', N'es', N'Balance', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_value_types_name', N'Credit Balance', N'es', N'Balance de crédito', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_value_types_name', N'Debit Balance', N'es', N'Balance de débito', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_value_types_name', N'Flow', N'es', N'Fluir', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_code', N'BS', N'es', N'BS', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_code', N'CF', N'es', N'CF', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_code', N'DCF', N'es', N'DCF', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_code', N'PL', N'es', N'PL', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_code', N'VAT', N'es', N'VAT', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_name', N'Balance Sheet', N'es', N'Hoja de balance', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_name', N'Cash Flow', N'es', N'Flujo de efectivo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_name', N'Direct Cash Flow', N'es', N'Flujo de efectivo directo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_name', N'Income Statement', N'es', N'Estado de resultados', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_name', N'VAT', N'es', N'IVA', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Access denied', N'es', N'Acceso denegado', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Cannot find member id %i', N'es', N'No se puede encontrar el ID de miembro %i', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Cannot find member id %s', N'es', N'No se puede encontrar el ID de miembro %s', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Cannot find member_id %i', N'es', N'No se puede encontrar member_id %i', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Cannot find member_id %s', N'es', N'No se puede encontrar member_id %s', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Cannot find the principal ''%s'', because it does not exist or you do not have permission.', N'es', N'No se puede encontrar el principal ''%s'' porque no existe o no tiene permiso.', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Invalid column name: %s', N'es', N'Nombre de columna no válido: %s', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Member %s cannot be editable as it has children', N'es', N'El miembro %s no puede ser editable ya que tiene hijos', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Role ''%s'' does not exist', N'es', N'El rol ''%s'' no existe', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Set 1 to add and 0 to remove a user from the role', N'es', N'Establezca 1 para agregar y 0 para eliminar a un usuario del rol', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'The code ''%s'' contains prohibited symbols (space, '', ", [ or ])', N'es', N'El código ''%s'' contiene símbolos prohibidos (espacio, '', ", [, ])', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'The column ''%s'' is not updatable', N'es', N'La columna ''%s'' no es actualizable', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'The journal has operations on %s', N'es', N'El diario tiene operaciones en %s', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'The period is closed for changes', N'es', N'El período está cerrado por cambios.', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Unknown option: %i (Use 0 or 1)', N'es', N'Opción desconocida: %i (Use 0 o 1)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Unknown option: %s (Use R, W, D)', N'es', N'Opción desconocida: %s (use R, W, D)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Use TRANSLATED_NAME, TRANSLATED_DESC, or TRANSLATED_COMMENT', N'es', N'Use TRANSLATED_NAME, TRANSLATED_DESC o TRANSLATED_COMMENT', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'User ''%s'' does not exist', N'es', N'El usuario ''%s'' no existe', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'account', N'es', N'Cuenta', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'account_id', N'es', N'Cuenta', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'account_type_id', N'es', N'Tipo de cuenta', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'amount', N'es', N'Monto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'amount$', N'es', N'Monto$', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'asset_sign', N'es', N'Signo de activo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'assets', N'es', N'Activo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'auto_type_id', N'es', N'Tipo automático', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance', N'es', N'Balance', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance$', N'es', N'Balance$', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance00', N'es', N'Balance00', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance01', N'es', N'Balance01', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance02', N'es', N'Balance02', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance03', N'es', N'Balance03', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance04', N'es', N'Balance04', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance05', N'es', N'Balance05', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance06', N'es', N'Balance06', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance07', N'es', N'Balance07', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance08', N'es', N'Balance08', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance09', N'es', N'Balance09', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance10', N'es', N'Balance10', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance11', N'es', N'Balance11', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance12', N'es', N'Balance12', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'bs', N'es', N'BS', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'bs_section', N'es', N'Sección BS', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'bs_sign', N'es', N'BS Sign', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'category_id', N'es', N'Categoría', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'category_name', N'es', N'Nombre de la categoría', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'cf', N'es', N'CF', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'cf_ref_number', N'es', N'Número de referencia de CF', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'cf_section', N'es', N'Sección CF', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'cf_sign', N'es', N'Signo CF', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charge_credit', N'es', N'Crédito de cargo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charge_credit_id', N'es', N'Crédito de cargo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charge_credit_type_id', N'es', N'Tipo de crédito de cargo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charge_debit', N'es', N'Débito de cargo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charge_debit_id', N'es', N'Débito de cargo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charge_debit_type_id', N'es', N'Tipo de débito de cargo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges', N'es', N'Cargos', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges01', N'es', N'Cargos01', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges02', N'es', N'Cargos02', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges03', N'es', N'Cargos03', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges04', N'es', N'Cargos04', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges05', N'es', N'Cargos05', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges06', N'es', N'Cargos06', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges07', N'es', N'Cargos07', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges08', N'es', N'Cargos08', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges09', N'es', N'Cargos09', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges10', N'es', N'Cargos10', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges11', N'es', N'Cargos11', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges12', N'es', N'Cargos12', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'closing_balance', N'es', N'Balance de cierre', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'closing_child_account_id', N'es', N'Cuenta infantil de cierre', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'closing_credit', N'es', N'Balance de cierre de crédito', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'closing_credit_account_id', N'es', N'Cuenta de crédito de cierre', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'closing_debit', N'es', N'Balance de cierre de débito', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'closing_debit_account_id', N'es', N'Cuenta de débito de cierre', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'code', N'es', N'Código', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'code1', N'es', N'Código 1', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'code2', N'es', N'Código 2', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'column_name', N'es', N'Nombre de columna', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'company_id', N'es', N'Empresa', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'created_by', N'es', N'Creado por', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'created_on', N'es', N'Creado', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'credit', N'es', N'Crédito', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'credit$', N'es', N'Crédito$', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'credit_account_id', N'es', N'Cuenta de crédito', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'credit_subsidiary_account_id', N'es', N'Cuenta subsidiaria de crédito', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'credit_turnover', N'es', N'Totales de crédito', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'currency', N'es', N'Moneda', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'currency_id', N'es', N'Moneda', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data_format', N'es', N'Formato de datos', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data00', N'es', N'Totales', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data01', N'es', N'Enero', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data02', N'es', N'Feb.', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data03', N'es', N'Abr.', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data04', N'es', N'Marzo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data05', N'es', N'Mayo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data06', N'es', N'Jun.', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data07', N'es', N'Jul.', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data08', N'es', N'Agosto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data09', N'es', N'Sept.', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data10', N'es', N'Oct.', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data11', N'es', N'Nov.', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data12', N'es', N'Dic.', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'date', N'es', N'Fecha', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'debit', N'es', N'Débito', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'debit$', N'es', N'Débito$', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'debit_account_id', N'es', N'Cuenta de debito', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'debit_subsidiary_account_id', N'es', N'Cuenta subsidiaria de débito', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'debit_turnover', N'es', N'Totales de débito', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'default_language', N'es', N'Idioma predeterminado', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'description', N'es', N'Descripción', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'dimension_id', N'es', N'Dimensión', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'end_day', N'es', N'Día final', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'end_month', N'es', N'Mes final', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'end_year', N'es', N'Año final', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'entity_id', N'es', N'Entidad', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'entity_name', N'es', N'Nombre de la entidad', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'entry_side_id', N'es', N'Lado de la entrada del diario', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'factor', N'es', N'Factor', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'field', N'es', N'Campo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'first_month', N'es', N'Primer mes', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'format_column', N'es', N'Columna de formato', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'group_id', N'es', N'Grupo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'group1', N'es', N'Grupo 1', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'group2', N'es', N'Grupo 2', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'group3', N'es', N'Grupo 3', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'hide', N'es', N'Esconder', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'hide_accounts', N'es', N'Ocultar cuentas', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'hide_items', N'es', N'Ocultar elementos', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'id', N'es', N'ID', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'id1', N'es', N'ID1', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'id2', N'es', N'ID2', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'inverse_sign', N'es', N'Signo inverso', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_active', N'es', N'Activo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_admin', N'es', N'Administrador', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_base_currency', N'es', N'Es la moneda base', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_calc_date', N'es', N'Fecha de cálculo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_charge_net', N'es', N'Carga neta', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_checked', N'es', N'Comprobado', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_closed', N'es', N'Cerrado', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_complete', N'es', N'Completo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_credit_editable', N'es', N'Crédito Editable', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_currency', N'es', N'Moneda', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_da', N'es', N'D/A', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_debit_editable', N'es', N'Débito Editable', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_default', N'es', N'Predeterminado', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_draft', N'es', N'Sequía', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_empty', N'es', N'Vacío', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_functional_currency', N'es', N'Moneda funcional', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_in_budget', N'es', N'En presupuesto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_in_budget_request', N'es', N'En solicitud de presupuesto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_inherited', N'es', N'Heredado', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_parent', N'es', N'Cuenta Principal', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_pl', N'es', N'PL', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_translatable', N'es', N'Traducible', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'language', N'es', N'Idioma', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'last_format_column', N'es', N'Última columna de formato', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'last_month', N'es', N'Mes pasado', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'level', N'es', N'Nivel', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'line', N'es', N'Línea', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'line_factor', N'es', N'Factor de linea', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'member_dimension_id', N'es', N'Dimensión de miembro', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'member_id', N'es', N'Miembro', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'modified_by', N'es', N'Modificado por', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'modified_on', N'es', N'Modificado', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'month', N'es', N'Mes', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'name', N'es', N'Nombre', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'opening_balance', N'es', N'Saldo de apertura', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'opening_credit', N'es', N'Saldo de apertura de crédito', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'opening_debit', N'es', N'Saldo de apertura de débito', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'page_break', N'es', N'Salto de página', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'page_break_before', N'es', N'Salto de página antes', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'pair', N'es', N'Par de divisas', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'pair_account_type_id', N'es', N'Emparejar tipo de cuenta', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'parent_id', N'es', N'Miembro padre', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'parent2_id', N'es', N'Cuenta Principal 2', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'partner_dimension_id', N'es', N'Dimensión del socio', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'partner_id', N'es', N'Miembro asociado', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payment_credit', N'es', N'Crédito de pago', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payment_credit_id', N'es', N'Crédito de pago', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payment_credit_type_id', N'es', N'Tipo de crédito de pago', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payment_debit', N'es', N'Débito de pago', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payment_debit_id', N'es', N'Débito de pago', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payment_debit_type_id', N'es', N'Tipo de débito de pago', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments', N'es', N'Pagos', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments01', N'es', N'Pagos01', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments02', N'es', N'Pagos02', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments03', N'es', N'Pagos03', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments04', N'es', N'Pagos04', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments05', N'es', N'Pagos05', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments06', N'es', N'Pagos06', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments07', N'es', N'Pagos07', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments08', N'es', N'Pagos08', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments09', N'es', N'Pagos09', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments10', N'es', N'Pagos10', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments11', N'es', N'Pagos11', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments12', N'es', N'Pagos12', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period_name', N'es', N'Nombre del periodo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period01', N'es', N'Periodo01', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period02', N'es', N'Periodo02', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period03', N'es', N'Periodo03', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period04', N'es', N'Periodo04', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period05', N'es', N'Periodo05', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period06', N'es', N'Periodo06', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period07', N'es', N'Periodo07', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period08', N'es', N'Período08', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period09', N'es', N'Periodo09', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period10', N'es', N'Periodo10', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period11', N'es', N'Periodo11', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period12', N'es', N'Periodo12', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'permission', N'es', N'Permiso', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'pl', N'es', N'PL', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'pl_ref_number', N'es', N'Número de referencia de PL', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'pl_section', N'es', N'Sección PL', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'pl_section_id', N'es', N'Sección PL', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'pl_sign', N'es', N'Signo PL', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'product_id', N'es', N'Producto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'rate', N'es', N'Taza de cambio', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'ref_number', N'es', N'Número de referencia', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'ref_record_id', N'es', N'Registro de referencia', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'region_id', N'es', N'Región', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'report', N'es', N'Reporte', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'report_id', N'es', N'Reporte', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'report_section_type_id', N'es', N'Tipo de sección de reporte', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'report_type_id', N'es', N'Tipo de reporte', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'row_comments', N'es', N'Comentarios de fila', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'row_format', N'es', N'Formato de fila', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'row_formulas', N'es', N'Fórmulas de fila', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'row_index', N'es', N'Índice de fila', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'row_level', N'es', N'Nivel de fila', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'rows', N'es', N'Número de filas', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'schema', N'es', N'Esquema', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'section', N'es', N'Sección', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'section_type_id', N'es', N'Tipo de sección', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'select_permission', N'es', N'Permiso de SELECT', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'show_line', N'es', N'Mostrar línea', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'show_line_after', N'es', N'Mostrar línea después', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'show_line_before', N'es', N'Mostrar línea antes', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'sort_order', N'es', N'Orden de clasificación', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'specific_type_id', N'es', N'Tipo específico', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'start_day', N'es', N'Día de inicio', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'start_month', N'es', N'Mes de inicio', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'start_year', N'es', N'Año de inicio', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'subsidiary_account_id', N'es', N'Cuenta subsidiaria', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'subsidiary_group_id', N'es', N'Grupo subsidiario', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'subsidiary_name', N'es', N'Nombre de cuenta subsidiaria', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'table_id', N'es', N'ID de tabla', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'time_id', N'es', N'ID del período', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'total_charges', N'es', N'Cargos totales', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'total_payments', N'es', N'Pagos totales', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'total_type_id', N'es', N'Tipo total', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'transaction_start_time', N'es', N'Hora de inicio de transacción', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'translated_name', N'es', N'Nombre traducido', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'type', N'es', N'Tipo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'type_id', N'es', N'Tipo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'unit', N'es', N'Unidad', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'unit_id', N'es', N'Unidad', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'update_permission', N'es', N'Permiso de UPDATE', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'username', N'es', N'Nombre de usuario', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'value_sign', N'es', N'Signo de valor', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'value_type_id', N'es', N'Tipo de valor', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'vat', N'es', N'IVA', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'vat_credit', N'es', N'Crédito de IVA', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'vat_credit_id', N'es', N'Crédito de IVA', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'vat_credit_type_id', N'es', N'Tipo de crédito de IVA', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'vat_debit', N'es', N'Débito de IVA', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'vat_debit_id', N'es', N'Débito de IVA', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'vat_debit_type_id', N'es', N'Tipo de débito de IVA', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'vat_rate_id', N'es', N'Tipo de IVA', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'vat_sign', N'es', N'Signo de IVA', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'year', N'es', N'Año', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'zero', N'es', N'Cero', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_actual_balances', NULL, N'es', N'Saldos reales', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_actual_balances', N'account_id', N'es', N'ID de la cuenta', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_actual_balances', N'subsidiary_account_id', N'es', N'ID de cuenta subsidiaria', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_actual_closed_periods', NULL, N'es', N'Períodos cerrados reales', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_actual_currency_rates', NULL, N'es', N'Tasas de divisas reales', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_actual_reports', NULL, N'es', N'Reportes reales', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_balance_sheet_trial', NULL, N'es', N'Balance de facturación', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_balances', NULL, N'es', N'Saldos presupuestarios', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_closed_periods', NULL, N'es', N'Períodos cerrados de presupuesto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_currency_rates', NULL, N'es', N'Presupuesto de tasas de cambio', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_data', NULL, N'es', N'Datos presupuestarios', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_journal', NULL, N'es', N'Diario de presupuesto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_reports', NULL, N'es', N'Reportes de presupuesto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_reports_raw', NULL, N'es', N'Informes presupuestarios sin procesar', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', NULL, N'es', N'Solicitud de presupuesto 1', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', N'account', N'es', N'Cuenta', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', N'account_id', N'es', N'Cuenta', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', N'account_name', N'es', N'Nombre del cuenta', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', N'product', N'es', N'Producto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', N'product_id', N'es', N'Producto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', N'region', N'es', N'Región', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', N'region_id', N'es', N'Región', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', N'subsidiary_account', N'es', N'Cuenta subsidiaria', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', N'subsidiary_account_id', N'es', N'Cuenta subsidiaria', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', NULL, N'es', N'Solicitud de presupuesto 2', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', N'account', N'es', N'Cuenta', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', N'account_id', N'es', N'Cuenta', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', N'account_name', N'es', N'Nombre del cuenta', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', N'product', N'es', N'Producto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', N'product_id', N'es', N'Producto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', N'region', N'es', N'Región', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', N'region_id', N'es', N'Región', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', N'subsidiary_account', N'es', N'Cuenta subsidiaria', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', N'subsidiary_account_id', N'es', N'Cuenta subsidiaria', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_requests', NULL, N'es', N'Solicitudes de presupuesto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_requests_totals', NULL, N'es', N'Totales de solicitudes de presupuesto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budgeting_accounts', NULL, N'es', N'Cuentas presupuestarias', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_companies', NULL, N'es', N'Compañías', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_dimensions', NULL, N'es', N'Mediciones', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_entry_sides', NULL, N'es', N'Lados del diario de entrada', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_journal', NULL, N'es', N'Diario', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_ledger_account_special_types', NULL, N'es', N'Tipos de cuentas especiales', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_ledger_account_types', NULL, N'es', N'Tipos de cuentas', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_ledger_accounts', NULL, N'es', N'Cuentas contables', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_member_permissions', NULL, N'es', N'Permisos de miembros', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_member_relations', NULL, N'es', N'Relaciones con miembros', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_member_types', NULL, N'es', N'Tipos de artículos', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_members', NULL, N'es', N'Miembros', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_report_section_accounts', NULL, N'es', N'Cuentas de la sección de informes', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_report_section_total_types', NULL, N'es', N'Tipos de totales de secciones de informes', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_report_section_types', NULL, N'es', N'Tipos de secciones de informes', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_report_section_value_types', NULL, N'es', N'Tipos de valores de secciones de informes', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_report_sections', NULL, N'es', N'Secciones de informes', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_report_types', NULL, N'es', N'Tipos de informes', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_role_members', NULL, N'es', N'Miembros de roles', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_saved_report_types', NULL, N'es', N'Tipos de informes guardados', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_saved_reports', NULL, N'es', N'Reportes guardados', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_subsidiary_accounts', NULL, N'es', N'Cuentas Subsidiarias', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_subsidiary_groups', NULL, N'es', N'Grupos subsidiarios', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_translations', NULL, N'es', N'Traducciones', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_translations_common', NULL, N'es', N'Traducciones (comunes)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_translations_xls', NULL, N'es', N'Traducciones (xls)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_units', NULL, N'es', N'Unidades', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_users', NULL, N'es', N'Usuarios', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_vat_rates', NULL, N'es', N'Tasas de IVA', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_actions_actual_report_cell_data', NULL, N'es', N'Mostrar detalles de celda', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_actions_add_language', NULL, N'es', N'Agregar idioma', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_actions_auto_calc_all', NULL, N'es', N'Calcular todo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_actions_auto_close_accounts', NULL, N'es', N'Calcular cuentas de cierre', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_actions_auto_currency_transactions', NULL, N'es', N'Calcular transacciones de divisas', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_actions_auto_currency_translation', NULL, N'es', N'Calcular conversión de moneda', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_actions_budget_report_cell_data', NULL, N'es', N'Mostrar detalles de celda', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_actions_select_members', NULL, N'es', N'Mostrar miembros', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_automatic_handlers', NULL, N'es', N'Manejadores automáticos', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_online_help_handlers', NULL, N'es', N'Manejadores de ayuda en línea', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'April', N'es', N'Abril', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'August', N'es', N'Agosto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'December', N'es', N'Diciembre', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'February', N'es', N'Febrero', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'January', N'es', N'Enero', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'July', N'es', N'Julio', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'June', N'es', N'Junio', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'March', N'es', N'Marzo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'May', N'es', N'Mayo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'November', N'es', N'Noviembre', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'October', N'es', N'Octubre', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'September', N'es', N'Septiembre', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_query_list_admin', NULL, N'es', N'Lista de objetos de administrador', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_query_list_setup', NULL, N'es', N'Lista de objetos de configuración', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'dimensions_name', N'Accounts', N'fr', N'Comptes', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'dimensions_name', N'Categories', N'fr', N'Catégories', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'dimensions_name', N'Entities', N'fr', N'Entités', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'dimensions_name', N'Products', N'fr', N'Produits', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'dimensions_name', N'Regions', N'fr', N'Régions', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'dimensions_name', N'Sub.Accounts', N'fr', N'Sous-comptes', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'dimensions_name', N'Times', N'fr', N'Périodes', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'entry_sides_name', N'Credit', N'fr', N'Crédit', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'entry_sides_name', N'Debit', N'fr', N'Débit', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'Calculation', N'fr', N'Calcul', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'Cash', N'fr', N'En espèces', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'Currency Exchange Gains', N'fr', N'Gains de change', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'Currency Exchange Losses', N'fr', N'Pertes de change', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'Currency Translation Gains', N'fr', N'Gains de conversion de devises', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'Currency Translation Losses', N'fr', N'Pertes de conversion de devises', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'Net Income (BS)', N'fr', N'Revenu net (BS)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'Net Income (PL)', N'fr', N'Revenu net (PL)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'VAT Payable', N'fr', N'TVA à payer', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'VAT Receivable', N'fr', N'TVA à recevoir', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Administrative Expenses', N'fr', N'Dépenses administratives', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Administrative Expenses - Amortization', N'fr', N'Dépenses administratives - Amortissement', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Administrative Expenses - Depreciation', N'fr', N'Dépenses administratives - Dépréciation', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Calculation', N'fr', N'Calcul', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Cost of Revenue', N'fr', N'Coût des revenus', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Cost of Revenue - Amortization', N'fr', N'Coût des revenus - Amortissement', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Cost of Revenue - Depreciation', N'fr', N'Coût des revenus - Dépréciation', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Currency Exchange Gains', N'fr', N'Gains de change', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Currency Exchange Losses', N'fr', N'Pertes de change', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Currency Translation Gains', N'fr', N'Gains de conversion de devises', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Currency Translation Losses', N'fr', N'Pertes de conversion de devises', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Assets', N'fr', N'Actifs courants', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Assets - Cash', N'fr', N'Actifs courants - Trésorerie', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Assets - Cash Equivalents', N'fr', N'Actifs courants - Équivalents de trésorerie', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Assets - Receivable', N'fr', N'Actifs courants - À recevoir', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Assets - VAT Receivable', N'fr', N'Actifs courants - TVA à recevoir', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Assets/Liabilities', N'fr', N'Actifs ou passifs courants', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Financial Assets', N'fr', N'Actifs financiers courants', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Financial Assets Net', N'fr', N'Actifs financiers courants nets', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Financial Liabilities', N'fr', N'Passifs financiers courants', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Financial Liabilities Net', N'fr', N'Passifs financiers courants nets', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Investing Assets', N'fr', N'Actifs courants - Investissement', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Investing Liabilities', N'fr', N'Passifs courants - Investissement', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Liabilities', N'fr', N'Passifs courants', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Liabilities - Payable', N'fr', N'Passifs courants - À payer', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Liabilities - VAT Payable', N'fr', N'Passifs courants - TVA à payer', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Equity', N'fr', N'Équité', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Equity - Net Income', N'fr', N'Capitaux propres - Revenu net', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Equity - Retained Earnings', N'fr', N'Capitaux propres - Bénéfices non répartis', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'General Expenses', N'fr', N'Frais généraux', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'General Expenses - Amortization', N'fr', N'Frais généraux - Amortissement', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'General Expenses - Depreciation', N'fr', N'Frais généraux - Dépréciation', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Income Tax Expense', N'fr', N'La charge d''impôt sur les sociétés', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Interest Expenses', N'fr', N'Frais d''intérêt', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Net Income', N'fr', N'Revenu net', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Non-current Assets', N'fr', N'Actifs non courants', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Non-current Assets - Amortization', N'fr', N'Actifs non courants - Amortissement', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Non-current Assets - Depreciation', N'fr', N'Actifs non courants - Dépréciation', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Non-current Financial Assets', N'fr', N'Actifs financiers non courants', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Non-current Financial Assets Net', N'fr', N'Actifs financiers non courants nets', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Non-current Financial Liabilities', N'fr', N'Passifs financiers non courants', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Non-current Financial Liabilities Net', N'fr', N'Passifs financiers non courants nets', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Non-current Liabilities', N'fr', N'Passifs non courants', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Operating Income', N'fr', N'Résultat d''exploitation', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Other Expenses', N'fr', N'Autres dépenses', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Other Financial Expenses', N'fr', N'Autres dépenses financières', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Other Financial Income', N'fr', N'Autres revenus financiers', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Other Income', N'fr', N'Autre revenu', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Other Income/Expenses Net', N'fr', N'Autres revenus/dépenses nets', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Other Investing Expenses', N'fr', N'Autres dépenses d''investissement', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Other Investing Income', N'fr', N'Autres revenus de placements', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'R&D Expenses', N'fr', N'Dépenses de R&D', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'R&D Expenses - Amortization', N'fr', N'Dépenses de R&D - Amortissement', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'R&D Expenses - Depreciation', N'fr', N'Dépenses de R&D - Dépréciation', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Revenue', N'fr', N'Revenu', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Selling Expenses', N'fr', N'Frais de vente', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Selling Expenses - Amortization', N'fr', N'Frais de vente - Amortissement', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Selling Expenses - Depreciation', N'fr', N'Frais de vente - Dépréciation', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Amortization', N'fr', N'Amortissement', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Calculated', N'fr', N'Calculé', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Cash Transfer', N'fr', N'Transfert d''argent', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Cost', N'fr', N'Coût', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Depreciation', N'fr', N'Dépréciation', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Expense', N'fr', N'Frais', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Expense, no VAT', N'fr', N'Frais, pas de TVA', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Income', N'fr', N'Revenu', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Income, no VAT', N'fr', N'Revenu, pas de TVA', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Inflow', N'fr', N'Afflux', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'None', N'fr', N'Aucun', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Outflow', N'fr', N'Sortie', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Purchase', N'fr', N'Achat', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Purchase, no VAT', N'fr', N'Achat, sans TVA', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Setoff', N'fr', N'Déclencher', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Withholding', N'fr', N'Retenue', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_total_types_name', N'Closing Balance', N'fr', N'Solde de clôture', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_total_types_name', N'Opening Balance', N'fr', N'Solde d''ouverture', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_total_types_name', N'Total', N'fr', N'Total', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Administrative Expenses', N'fr', N'Dépenses administratives', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Cash at the Beginning (CF)', N'fr', N'Trésorerie au début (CF)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Cash at the Beginning (DCF)', N'fr', N'Trésorerie au début (DCF)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Cash at the End (CF)', N'fr', N'Trésorerie à la fin (CF)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Cash at the End (DCF)', N'fr', N'Trésorerie à la fin (DCF)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Cost of Revenue', N'fr', N'Coût des revenus', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Current Assets', N'fr', N'Actifs courants', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Current Liabilities', N'fr', N'Passifs courants', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Depreciation (CF)', N'fr', N'Dépréciation (CF)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Disabled', N'fr', N'Désactivé', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Expense VAT', N'fr', N'TVA', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Financing Cash Flows (CF)', N'fr', N'Flux de trésorerie de financement', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Financing Cash Inflows', N'fr', N'Entrées de financement (CF)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Financing Cash Inflows (CF)', N'fr', N'Entrées de financement (CF)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Financing Cash Outflows (CF)', N'fr', N'Sorties de financement (CF)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Financing Inflows', N'fr', N'Entrées de financement', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Financing Outflows', N'fr', N'Sorties de financement', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'General Expenses', N'fr', N'Frais généraux', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Income Tax Expense', N'fr', N'La charge d''impôt sur les sociétés', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Income VAT', N'fr', N'TVA sur le revenu', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Interest Expenses', N'fr', N'Frais d''intérêt', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Investing Cash Flows (CF)', N'fr', N'Flux de trésorerie d''investissement', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Investing Inflows', N'fr', N'Entrées de d''investissements', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Investing Outflows', N'fr', N'Sorties d''investissement', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Net Income (CF)', N'fr', N'Revenu net (CF)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Non-Current Assets', N'fr', N'Actifs non courants', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Non-Current Liabilities', N'fr', N'Passifs non courants', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Operating Cash Flows (CF)', N'fr', N'Flux de trésorerie d''exploitation', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Operating Inflows', N'fr', N'Entrées d''exploitation', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Operating Outflows', N'fr', N'Sorties d''exploitation', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Other Expenses', N'fr', N'Autres dépenses', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Other Income', N'fr', N'Autre revenu', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'R&D Expenses', N'fr', N'Dépenses de R&D', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Revenue', N'fr', N'Revenu', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Selling Expenses', N'fr', N'Frais de vente', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Stockholders'' Equity', N'fr', N'Capitaux propres', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Stockholders'' Equity - Net Income', N'fr', N'Capitaux propres - Bénéfice net', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'VAT Paid', N'fr', N'TVA payée', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'VAT Set-Offs', N'fr', N'Compensation de TVA', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_value_types_name', N'Balance', N'fr', N'Balance', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_value_types_name', N'Credit Balance', N'fr', N'Solde créditeur', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_value_types_name', N'Debit Balance', N'fr', N'Solde débiteur', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_value_types_name', N'Flow', N'fr', N'Couler', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_code', N'BS', N'fr', N'BS', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_code', N'CF', N'fr', N'CF', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_code', N'DCF', N'fr', N'DCF', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_code', N'PL', N'fr', N'PL', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_code', N'VAT', N'fr', N'VAT', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_name', N'Balance Sheet', N'fr', N'Bilan', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_name', N'Cash Flow', N'fr', N'Flux de trésorerie', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_name', N'Direct Cash Flow', N'fr', N'Flux de trésorerie direct', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_name', N'Income Statement', N'fr', N'Releve de revenue', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_name', N'VAT', N'fr', N'TVA', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Access denied', N'fr', N'Accès refusé', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Cannot find member id %i', N'fr', N'Impossible de trouver l''ID de membre %i', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Cannot find member id %s', N'fr', N'Impossible de trouver l''ID de membre %s', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Cannot find member_id %i', N'fr', N'Impossible de trouver member_id %i', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Cannot find member_id %s', N'fr', N'Impossible de trouver member_id %s', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Cannot find the principal ''%s'', because it does not exist or you do not have permission.', N'fr', N'Impossible de trouver le principal ''%s'', car il n''existe pas ou vous n''avez pas l''autorisation.', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Invalid column name: %s', N'fr', N'Nom de colonne non valide: %s', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Member %s cannot be editable as it has children', N'fr', N'Le membre %s ne peut pas être modifié car il a des enfants', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Role ''%s'' does not exist', N'fr', N'Le rôle ''%s'' n''existe pas', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Set 1 to add and 0 to remove a user from the role', N'fr', N'Définissez 1 pour ajouter et 0 pour supprimer un utilisateur du rôle', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'The code ''%s'' contains prohibited symbols (space, '', ", [ or ])', N'fr', N'Le code ''%s'' contient des symboles interdits (espace, '', ", [,  ])', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'The column ''%s'' is not updatable', N'fr', N'La colonne ''%s'' ne peut pas être mise à jour', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'The journal has operations on %s', N'fr', N'Le journal a des opérations sur %s', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'The period is closed for changes', N'fr', N'La période est fermée pour modifications', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Unknown option: %i (Use 0 or 1)', N'fr', N'Option inconnue: %i (utilisez 0 ou 1)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Unknown option: %s (Use R, W, D)', N'fr', N'Option inconnue: %s (utilisez R, W, D)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Use TRANSLATED_NAME, TRANSLATED_DESC, or TRANSLATED_COMMENT', N'fr', N'Utilisez TRANSLATED_NAME, TRANSLATED_DESC ou TRANSLATED_COMMENT', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'User ''%s'' does not exist', N'fr', N'L''utilisateur ''%s'' n''existe pas', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'account', N'fr', N'Compte', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'account_id', N'fr', N'Compte', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'account_type_id', N'fr', N'Type de compte', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'amount', N'fr', N'Montant', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'amount$', N'fr', N'Montant$', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'asset_sign', N'fr', N'Signe de l''actif', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'assets', N'fr', N'Actif', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'auto_type_id', N'fr', N'Type automatique', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance', N'fr', N'Balance', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance$', N'fr', N'Balance$', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance00', N'fr', N'Balance00', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance01', N'fr', N'Balance01', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance02', N'fr', N'Balance02', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance03', N'fr', N'Balance03', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance04', N'fr', N'Balance04', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance05', N'fr', N'Balance05', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance06', N'fr', N'Balance06', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance07', N'fr', N'Balance07', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance08', N'fr', N'Balance08', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance09', N'fr', N'Balance09', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance10', N'fr', N'Balance10', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance11', N'fr', N'Balance11', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance12', N'fr', N'Balance12', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'bs', N'fr', N'BS', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'bs_section', N'fr', N'Section BS', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'bs_sign', N'fr', N'Signe BS', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'category_id', N'fr', N'Catégorie', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'category_name', N'fr', N'Nom de catégorie', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'cf', N'fr', N'CF', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'cf_ref_number', N'fr', N'Numéro de référence CF', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'cf_section', N'fr', N'Section des FC', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'cf_sign', N'fr', N'Signe des FC', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charge_credit', N'fr', N'Crédit de charge', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charge_credit_id', N'fr', N'Crédit de charge', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charge_credit_type_id', N'fr', N'Type de crédit de charge', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charge_debit', N'fr', N'Débit de charge', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charge_debit_id', N'fr', N'Débit de charge', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charge_debit_type_id', N'fr', N'Type de débit de charge', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges', N'fr', N'Frais', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges01', N'fr', N'Frais01', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges02', N'fr', N'Frais02', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges03', N'fr', N'Frais03', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges04', N'fr', N'Frais04', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges05', N'fr', N'Frais05', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges06', N'fr', N'Frais06', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges07', N'fr', N'Frais07', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges08', N'fr', N'Frais08', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges09', N'fr', N'Frais09', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges10', N'fr', N'Frais10', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges11', N'fr', N'Frais11', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges12', N'fr', N'Frais12', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'closing_balance', N'fr', N'Solde de clôture', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'closing_child_account_id', N'fr', N'Fermeture du compte enfant', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'closing_credit', N'fr', N'Solde de clôture du crédit', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'closing_credit_account_id', N'fr', N'Clôture du compte de crédit', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'closing_debit', N'fr', N'Solde de clôture du débit', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'closing_debit_account_id', N'fr', N'Clôture du compte de débit', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'code', N'fr', N'Code', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'code1', N'fr', N'Code 1', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'code2', N'fr', N'Code 2', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'column_name', N'fr', N'Nom de colonne', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'company_id', N'fr', N'Compagnie', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'created_by', N'fr', N'Créé par', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'created_on', N'fr', N'Créé', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'credit', N'fr', N'Crédit', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'credit$', N'fr', N'Crédit$', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'credit_account_id', N'fr', N'Compte de crédit', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'credit_subsidiary_account_id', N'fr', N'Compte subsidiaire de crédit', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'credit_turnover', N'fr', N'Totaux de crédit', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'currency', N'fr', N'Devise', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'currency_id', N'fr', N'Devise', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data_format', N'fr', N'Format des données', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data00', N'fr', N'Totaux', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data01', N'fr', N'Janv.', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data02', N'fr', N'Févr.', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data03', N'fr', N'Avril', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data04', N'fr', N'Mars', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data05', N'fr', N'Mai', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data06', N'fr', N'Juin', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data07', N'fr', N'Juil.', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data08', N'fr', N'Août', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data09', N'fr', N'Sept.', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data10', N'fr', N'Oct.', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data11', N'fr', N'Nov.', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data12', N'fr', N'Déc.', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'date', N'fr', N'Date', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'debit', N'fr', N'Débit', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'debit$', N'fr', N'Débit$', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'debit_account_id', N'fr', N'Compte de débit', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'debit_subsidiary_account_id', N'fr', N'Compte subsidiaire de débit', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'debit_turnover', N'fr', N'Totaux de débit', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'default_language', N'fr', N'Langage par défaut', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'description', N'fr', N'Вescription', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'dimension_id', N'fr', N'Dimension', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'end_day', N'fr', N'Jour de fin', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'end_month', N'fr', N'Mois de fin', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'end_year', N'fr', N'Fin d''année', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'entity_id', N'fr', N'Entité', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'entity_name', N'fr', N'Nom de l''entité', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'entry_side_id', N'fr', N'Côté de l''entrée de journal', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'factor', N'fr', N'Facteur', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'field', N'fr', N'Champ', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'first_month', N'fr', N'Premier mois', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'format_column', N'fr', N'Formater la colonne', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'group_id', N'fr', N'Groupe', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'group1', N'fr', N'Groupe 1', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'group2', N'fr', N'Groupe 2', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'group3', N'fr', N'Groupe 3', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'hide', N'fr', N'Masquer', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'hide_accounts', N'fr', N'Masquer les comptes', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'hide_items', N'fr', N'Masquer les éléments', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'id', N'fr', N'ID', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'id1', N'fr', N'ID1', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'id2', N'fr', N'ID2', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'inverse_sign', N'fr', N'Signe inversé', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_active', N'fr', N'Actif', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_admin', N'fr', N'Administrateur', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_base_currency', N'fr', N'Est la devise de base', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_calc_date', N'fr', N'Date de calcul', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_charge_net', N'fr', N'Charge Net', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_checked', N'fr', N'Vérifié', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_closed', N'fr', N'Fermé', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_complete', N'fr', N'Сomplet', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_credit_editable', N'fr', N'Crédit modifiable', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_currency', N'fr', N'Monnaie', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_da', N'fr', N'D/A', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_debit_editable', N'fr', N'Débit modifiable', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_default', N'fr', N'Défaut', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_draft', N'fr', N'Brouillon', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_empty', N'fr', N'Vide', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_functional_currency', N'fr', N'Monnaie fonctionnelle', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_in_budget', N'fr', N'Dans le budget', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_in_budget_request', N'fr', N'Dans la demande de budget', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_inherited', N'fr', N'Hérité', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_parent', N'fr', N'Parent', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_pl', N'fr', N'PL', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_translatable', N'fr', N'Traduisible', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'language', N'fr', N'Langue', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'last_format_column', N'fr', N'Colonne du dernier format', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'last_month', N'fr', N'Mois dernier', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'level', N'fr', N'Niveau', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'line', N'fr', N'Ligne', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'line_factor', N'fr', N'Facteur de ligne', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'member_dimension_id', N'fr', N'Dimension des membres', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'member_id', N'fr', N'Membre', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'modified_by', N'fr', N'Modifié par', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'modified_on', N'fr', N'Modifié', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'month', N'fr', N'Mois', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'name', N'fr', N'Nom', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'opening_balance', N'fr', N'Solde d''ouverture', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'opening_credit', N'fr', N'Solde d''ouverture du crédit', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'opening_debit', N'fr', N'Solde d''ouverture du débit', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'page_break', N'fr', N'Saut de page', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'page_break_before', N'fr', N'Saut de page avant', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'pair', N'fr', N'Paire de devises', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'pair_account_type_id', N'fr', N'Type de compte paire', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'parent_id', N'fr', N'Membre parent', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'parent2_id', N'fr', N'Parent2', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'partner_dimension_id', N'fr', N'Dimension partenaire', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'partner_id', N'fr', N'Membre partenaire', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payment_credit', N'fr', N'Crédit de paiement', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payment_credit_id', N'fr', N'Crédit de paiement', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payment_credit_type_id', N'fr', N'Type de crédit de paiement', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payment_debit', N'fr', N'Débit de paiement', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payment_debit_id', N'fr', N'Débit de paiement', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payment_debit_type_id', N'fr', N'Type de débit de paiement', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments', N'fr', N'Paiements', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments01', N'fr', N'Paiements01', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments02', N'fr', N'Paiements02', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments03', N'fr', N'Paiements03', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments04', N'fr', N'Paiements04', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments05', N'fr', N'Paiements05', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments06', N'fr', N'Paiements06', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments07', N'fr', N'Paiements07', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments08', N'fr', N'Paiements08', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments09', N'fr', N'Paiements09', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments10', N'fr', N'Paiements10', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments11', N'fr', N'Paiements11', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments12', N'fr', N'Paiements12', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period_name', N'fr', N'Nom de période', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period01', N'fr', N'Période01', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period02', N'fr', N'Période02', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period03', N'fr', N'Période03', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period04', N'fr', N'Période04', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period05', N'fr', N'Période05', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period06', N'fr', N'Période06', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period07', N'fr', N'Période07', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period08', N'fr', N'Période08', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period09', N'fr', N'Période09', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period10', N'fr', N'Période10', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period11', N'fr', N'Période11', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period12', N'fr', N'Période12', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'permission', N'fr', N'Autorisation', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'pl', N'fr', N'PL', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'pl_ref_number', N'fr', N'Numéro de référence PL', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'pl_section', N'fr', N'Section PL', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'pl_section_id', N'fr', N'Section PL', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'pl_sign', N'fr', N'Signe PL', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'product_id', N'fr', N'Produit', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'rate', N'fr', N'Cours des devises', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'ref_number', N'fr', N'Numéro de référence', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'ref_record_id', N'fr', N'Enregistrement de référence', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'region_id', N'fr', N'Région', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'report', N'fr', N'Rapport', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'report_id', N'fr', N'Rapport', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'report_section_type_id', N'fr', N'Type de section de rapport', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'report_type_id', N'fr', N'Type de rapport', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'row_comments', N'fr', N'Commentaires de ligne', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'row_format', N'fr', N'Format de ligne', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'row_formulas', N'fr', N'Formules de ligne', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'row_index', N'fr', N'Index de ligne', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'row_level', N'fr', N'Niveau de ligne', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'rows', N'fr', N'Nombre de rangées', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'schema', N'fr', N'Schéma', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'section', N'fr', N'Section', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'section_type_id', N'fr', N'Type de section', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'select_permission', N'fr', N'SELECT Permission', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'show_line', N'fr', N'Afficher la ligne', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'show_line_after', N'fr', N'Afficher la ligne après', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'show_line_before', N'fr', N'Afficher la ligne avant', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'sort_order', N'fr', N'Ordre de tri', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'specific_type_id', N'fr', N'Type spécifique', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'start_day', N'fr', N'Jour de début', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'start_month', N'fr', N'Mois de début', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'start_year', N'fr', N'Année de début', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'subsidiary_account_id', N'fr', N'Compte subsidiaire', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'subsidiary_group_id', N'fr', N'Groupe subsidiaire', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'subsidiary_name', N'fr', N'Nom du compte subsidiaire', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'table_id', N'fr', N'ID de table', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'time_id', N'fr', N'ID période', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'total_charges', N'fr', N'Charges totales', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'total_payments', N'fr', N'Paiements totaux', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'total_type_id', N'fr', N'Type total', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'transaction_start_time', N'fr', N'Heure de début de la transaction', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'translated_name', N'fr', N'Nom traduit', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'type', N'fr', N'Type', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'type_id', N'fr', N'Type', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'unit', N'fr', N'Unité', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'unit_id', N'fr', N'Unité', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'update_permission', N'fr', N'UPDATE Permission', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'username', N'fr', N'Nom d''utilisateur', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'value_sign', N'fr', N'Signe de valeur', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'value_type_id', N'fr', N'Type de valeur', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'vat', N'fr', N'TVA', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'vat_credit', N'fr', N'Crédit de TVA', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'vat_credit_id', N'fr', N'Crédit de TVA', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'vat_credit_type_id', N'fr', N'Type de crédit de TVA', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'vat_debit', N'fr', N'Débit de TVA', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'vat_debit_id', N'fr', N'Débit de TVA', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'vat_debit_type_id', N'fr', N'Type de débit de TVA', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'vat_rate_id', N'fr', N'Taux de TVA', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'vat_sign', N'fr', N'Signe TVA', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'year', N'fr', N'An', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'zero', N'fr', N'Zéro', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_actual_balances', NULL, N'fr', N'Soldes réels', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_actual_balances', N'account_id', N'fr', N'ID de compte', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_actual_balances', N'subsidiary_account_id', N'fr', N'ID de compte subsidiaire', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_actual_closed_periods', NULL, N'fr', N'Périodes de fermeture réelles', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_actual_currency_rates', NULL, N'fr', N'Taux de change réels', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_actual_reports', NULL, N'fr', N'Rapports réels', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_balance_sheet_trial', NULL, N'fr', N'Bilan du chiffre d''affaires', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_balances', NULL, N'fr', N'Soldes budgétaires', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_closed_periods', NULL, N'fr', N'Périodes de budget clôturées', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_currency_rates', NULL, N'fr', N'Taux de change du budget', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_data', NULL, N'fr', N'Données budgétaires', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_journal', NULL, N'fr', N'Journal of Budget', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_reports', NULL, N'fr', N'Rapports budgétaires', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_reports_raw', NULL, N'fr', N'Rapports budgétaires bruts', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', NULL, N'fr', N'Demande de budget 1', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', N'account', N'fr', N'Compte', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', N'account_id', N'fr', N'Compte', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', N'account_name', N'fr', N'Nom de compte', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', N'product', N'fr', N'Produit', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', N'product_id', N'fr', N'Produit', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', N'region', N'fr', N'Région', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', N'region_id', N'fr', N'Région', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', N'subsidiary_account', N'fr', N'Compte subsidiaire', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', N'subsidiary_account_id', N'fr', N'Compte subsidiaire', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', NULL, N'fr', N'Demande de budget 2', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', N'account', N'fr', N'Compte', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', N'account_id', N'fr', N'Compte', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', N'account_name', N'fr', N'Nom de compte', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', N'product', N'fr', N'Produit', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', N'product_id', N'fr', N'Produit', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', N'region', N'fr', N'Région', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', N'region_id', N'fr', N'Région', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', N'subsidiary_account', N'fr', N'Compte subsidiaire', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', N'subsidiary_account_id', N'fr', N'Compte subsidiaire', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_requests', NULL, N'fr', N'Demandes de budget', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_requests_totals', NULL, N'fr', N'Totaux des demandes budgétaires', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budgeting_accounts', NULL, N'fr', N'Comptes budgétaires', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_companies', NULL, N'fr', N'Entreprises', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_dimensions', NULL, N'fr', N'Mesures', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_entry_sides', NULL, N'fr', N'Côtés de l''entrée', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_journal', NULL, N'fr', N'Journal', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_ledger_account_special_types', NULL, N'fr', N'Types de comptes spéciaux', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_ledger_account_types', NULL, N'fr', N'Types de comptes', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_ledger_accounts', NULL, N'fr', N'Comptes de grand livre', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_member_permissions', NULL, N'fr', N'Autorisations des membres', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_member_relations', NULL, N'fr', N'Relations avec les membres', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_member_types', NULL, N'fr', N'Types d''articles', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_members', NULL, N'fr', N'Membres', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_report_section_accounts', NULL, N'fr', N'Comptes des sections du rapport', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_report_section_total_types', NULL, N'fr', N'Types de totaux des sections de rapport', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_report_section_types', NULL, N'fr', N'Types de sections de rapport', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_report_section_value_types', NULL, N'fr', N'Types de valeurs de section de rapport', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_report_sections', NULL, N'fr', N'Sections de rapport', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_report_types', NULL, N'fr', N'Types de rapports', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_role_members', NULL, N'fr', N'Membres des rôles', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_saved_report_types', NULL, N'fr', N'Types de rapports enregistrés', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_saved_reports', NULL, N'fr', N'Rapports enregistrés', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_subsidiary_accounts', NULL, N'fr', N'Comptes subsidiaires', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_subsidiary_groups', NULL, N'fr', N'Groupes subsidiaires', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_translations', NULL, N'fr', N'Traductions', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_translations_common', NULL, N'fr', N'Traductions (communes)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_translations_xls', NULL, N'fr', N'Traductions (xls)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_units', NULL, N'fr', N'Unités', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_users', NULL, N'fr', N'Utilisateurs', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_vat_rates', NULL, N'fr', N'Taux de TVA', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_actions_actual_report_cell_data', NULL, N'fr', N'Afficher les détails de la cellule', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_actions_add_language', NULL, N'fr', N'Ajouter une langue', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_actions_auto_calc_all', NULL, N'fr', N'Tout calculer', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_actions_auto_close_accounts', NULL, N'fr', N'Calculer les comptes de clôture', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_actions_auto_currency_transactions', NULL, N'fr', N'Calculer les transactions en devises', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_actions_auto_currency_translation', NULL, N'fr', N'Calculer la conversion des devises', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_actions_budget_report_cell_data', NULL, N'fr', N'Afficher les détails de la cellule', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_actions_select_members', NULL, N'fr', N'Afficher les membres', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_automatic_handlers', NULL, N'fr', N'Gestionnaires automatiques', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_online_help_handlers', NULL, N'fr', N'Gestionnaires d''aide en ligne', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'April', N'fr', N'Avril', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'August', N'fr', N'Août', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'December', N'fr', N'Décembre', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'February', N'fr', N'Février', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'January', N'fr', N'Janvier', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'July', N'fr', N'Juillet', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'June', N'fr', N'Juin', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'March', N'fr', N'Mars', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'May', N'fr', N'Mai', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'November', N'fr', N'Novembre', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'October', N'fr', N'Octobre', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'September', N'fr', N'Septembre', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_query_list_admin', NULL, N'fr', N'Liste des objets d''administration', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_query_list_setup', NULL, N'fr', N'Liste des objets de configuration', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'dimensions_name', N'Accounts', N'it', N'Conti', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'dimensions_name', N'Categories', N'it', N'Categorie', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'dimensions_name', N'Entities', N'it', N'Entità', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'dimensions_name', N'Products', N'it', N'Prodotti', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'dimensions_name', N'Regions', N'it', N'Regioni', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'dimensions_name', N'Sub.Accounts', N'it', N'Sottoconti', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'dimensions_name', N'Times', N'it', N'Periodi', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'entry_sides_name', N'Credit', N'it', N'Credito', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'entry_sides_name', N'Debit', N'it', N'Debito', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'Calculation', N'it', N'Calcolo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'Cash', N'it', N'Denaro contante', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'Currency Exchange Gains', N'it', N'Utili di cambio', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'Currency Exchange Losses', N'it', N'Perdite di cambio', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'Currency Translation Gains', N'it', N'Guadagni di conversione di valuta', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'Currency Translation Losses', N'it', N'Perdite di conversione di valuta', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'Net Income (BS)', N'it', N'Reddito netto (BS)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'Net Income (PL)', N'it', N'Reddito netto (PL)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'VAT Payable', N'it', N'IVA da pagare', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'VAT Receivable', N'it', N'IVA in ingresso', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Administrative Expenses', N'it', N'Spese amministrative', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Administrative Expenses - Amortization', N'it', N'Spese amministrative - Ammortamento', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Administrative Expenses - Depreciation', N'it', N'Spese amministrative - Deprezzamento', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Calculation', N'it', N'Calcolo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Cost of Revenue', N'it', N'Costo del ricavo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Cost of Revenue - Amortization', N'it', N'Costo delle entrate - Ammortamento', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Cost of Revenue - Depreciation', N'it', N'Costo delle entrate - Deprezzamento', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Currency Exchange Gains', N'it', N'Utili di cambio', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Currency Exchange Losses', N'it', N'Perdite di cambio', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Currency Translation Gains', N'it', N'Guadagni di traduzione di valuta', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Currency Translation Losses', N'it', N'Perdite di conversione di valuta', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Assets', N'it', N'Attività correnti', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Assets - Cash', N'it', N'Attività correnti - Contanti', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Assets - Cash Equivalents', N'it', N'Attività correnti - Disponibilità liquide', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Assets - Receivable', N'it', N'Attività correnti - Ricevibili', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Assets - VAT Receivable', N'it', N'Attività correnti - IVA', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Assets/Liabilities', N'it', N'Attività o passività correnti', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Financial Assets', N'it', N'Attività finanziarie correnti', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Financial Assets Net', N'it', N'Attività finanziarie correnti nette', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Financial Liabilities', N'it', N'Passività finanziarie correnti', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Financial Liabilities Net', N'it', N'Passività finanziarie correnti nette', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Investing Assets', N'it', N'Attività correnti - Investimenti', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Investing Liabilities', N'it', N'Passività correnti - Investimenti', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Liabilities', N'it', N'Passività correnti', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Liabilities - Payable', N'it', N'Passività correnti - Pagabili', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Liabilities - VAT Payable', N'it', N'Passività correnti - IVA dovuta', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Equity', N'it', N'Equità', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Equity - Net Income', N'it', N'Patrimonio netto - Utile netto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Equity - Retained Earnings', N'it', N'Patrimonio netto - Utili non distribuiti', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'General Expenses', N'it', N'Spese generali', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'General Expenses - Amortization', N'it', N'Spese generali - Ammortamento', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'General Expenses - Depreciation', N'it', N'Spese generali - Deprezzamento', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Income Tax Expense', N'it', N'Imposte sul reddito', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Interest Expenses', N'it', N'Spese di interessi', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Net Income', N'it', N'Reddito netto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Non-current Assets', N'it', N'Attività non correnti', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Non-current Assets - Amortization', N'it', N'Attività non correnti - Ammortamento', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Non-current Assets - Depreciation', N'it', N'Attività non correnti - Deprezzamento', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Non-current Financial Assets', N'it', N'Attività finanziarie non correnti', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Non-current Financial Assets Net', N'it', N'Attività finanziarie non correnti nette', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Non-current Financial Liabilities', N'it', N'Passività finanziarie non correnti', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Non-current Financial Liabilities Net', N'it', N'Passivo finanziario non corrente netto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Non-current Liabilities', N'it', N'Passività non correnti', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Operating Income', N'it', N'Reddito operativo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Other Expenses', N'it', N'Altre spese', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Other Financial Expenses', N'it', N'Altre spese finanziarie', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Other Financial Income', N'it', N'Altre entrate finanziarie', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Other Income', N'it', N'Altri proventi', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Other Income/Expenses Net', N'it', N'Altre entrate/uscite nette', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Other Investing Expenses', N'it', N'Altre spese di investimenti', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Other Investing Income', N'it', N'Altri proventi da investimenti', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'R&D Expenses', N'it', N'Spese di ricerca e sviluppo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'R&D Expenses - Amortization', N'it', N'Spese di ricerca e sviluppo - Ammortamento', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'R&D Expenses - Depreciation', N'it', N'Spese di ricerca e sviluppo - Deprezzamento', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Revenue', N'it', N'Reddito', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Selling Expenses', N'it', N'Spese di vendita', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Selling Expenses - Amortization', N'it', N'Spese di vendita - Ammortamento', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Selling Expenses - Depreciation', N'it', N'Spese di vendita - Deprezzamento', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Amortization', N'it', N'Ammortamento', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Calculated', N'it', N'Calcolato', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Cash Transfer', N'it', N'Trasferimento in contanti', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Cost', N'it', N'Costo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Depreciation', N'it', N'Deprezzamento', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Expense', N'it', N'Spese', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Expense, no VAT', N'it', N'Spese, IVA esclusa', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Income', N'it', N'Reddito', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Income, no VAT', N'it', N'Reddito, IVA esclusa', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Inflow', N'it', N'Afflusso', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'None', N'it', N'Nessuno', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Outflow', N'it', N'Deflusso', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Purchase', N'it', N'Acquista', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Purchase, no VAT', N'it', N'Acquisto, IVA esclusa', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Setoff', N'it', N'Partire', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Withholding', N'it', N'Ritenuta', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_total_types_name', N'Closing Balance', N'it', N'Saldo di chiusura', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_total_types_name', N'Opening Balance', N'it', N'Saldo di apertura', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_total_types_name', N'Total', N'it', N'Totale', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Administrative Expenses', N'it', N'Spese amministrative', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Cash at the Beginning (CF)', N'it', N'Contanti all''inizio (CF)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Cash at the Beginning (DCF)', N'it', N'Contanti all''inizio (DCF)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Cash at the End (CF)', N'it', N'Contanti alla fine (CF)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Cash at the End (DCF)', N'it', N'Contanti alla fine (DCF)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Cost of Revenue', N'it', N'Costo del ricavo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Current Assets', N'it', N'Attività correnti', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Current Liabilities', N'it', N'Passività correnti', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Depreciation (CF)', N'it', N'Deprezzamento (CF)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Disabled', N'it', N'Disabilitato', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Expense VAT', N'it', N'Spesa IVA', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Financing Cash Flows (CF)', N'it', N'Flussi di cassa del finanziamento', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Financing Cash Inflows', N'it', N'Afflussi di finanziamento (CF)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Financing Cash Inflows (CF)', N'it', N'Afflussi di finanziamento (CF)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Financing Cash Outflows (CF)', N'it', N'Deflussi di finanziamento (CF)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Financing Inflows', N'it', N'Afflussi di finanziamento', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Financing Outflows', N'it', N'Deflussi di finanziamento', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'General Expenses', N'it', N'Spese generali', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Income Tax Expense', N'it', N'Imposte sul reddito', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Income VAT', N'it', N'IVA sul reddito', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Interest Expenses', N'it', N'Spese di interessi', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Investing Cash Flows (CF)', N'it', N'Flussi di cassa di investimenti', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Investing Inflows', N'it', N'Afflussi di investimenti', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Investing Outflows', N'it', N'Deflussi di investimenti', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Net Income (CF)', N'it', N'Reddito netto (CF)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Non-Current Assets', N'it', N'Attività non correnti', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Non-Current Liabilities', N'it', N'Passività non correnti', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Operating Cash Flows (CF)', N'it', N'Flussi di cassa di operazioni', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Operating Inflows', N'it', N'Afflussi di operazioni', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Operating Outflows', N'it', N'Deflussi di operazioni', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Other Expenses', N'it', N'Altre spese', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Other Income', N'it', N'Altri proventi', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'R&D Expenses', N'it', N'Spese di ricerca e sviluppo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Revenue', N'it', N'Reddito', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Selling Expenses', N'it', N'Spese di vendita', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Stockholders'' Equity', N'it', N'Patrimonio netto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Stockholders'' Equity - Net Income', N'it', N'Patrimonio netto - Utile netto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'VAT Paid', N'it', N'IVA pagata', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'VAT Set-Offs', N'it', N'Compensazioni IVA', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_value_types_name', N'Balance', N'it', N'Saldo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_value_types_name', N'Credit Balance', N'it', N'Saldo del credito', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_value_types_name', N'Debit Balance', N'it', N'Saldo del debito', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_value_types_name', N'Flow', N'it', N'Flusso', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_code', N'BS', N'it', N'BS', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_code', N'CF', N'it', N'CF', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_code', N'DCF', N'it', N'DCF', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_code', N'PL', N'it', N'PL', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_code', N'VAT', N'it', N'VAT', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_name', N'Balance Sheet', N'it', N'Stato patrimoniale', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_name', N'Cash Flow', N'it', N'Flusso monetario', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_name', N'Direct Cash Flow', N'it', N'Flusso di cassa diretto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_name', N'Income Statement', N'it', N'Conto Economico', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_name', N'VAT', N'it', N'IVA', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Access denied', N'it', N'Accesso negato', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Cannot find member id %i', N'it', N'Impossibile trovare l''ID membro %i', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Cannot find member id %s', N'it', N'Impossibile trovare l''ID membro %s', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Cannot find member_id %i', N'it', N'Impossibile trovare member_id %i', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Cannot find member_id %s', N'it', N'Impossibile trovare member_id %s', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Cannot find the principal ''%s'', because it does not exist or you do not have permission.', N'it', N'Impossibile trovare il principale ''%s'', perché non esiste o non si dispone dell''autorizzazione.', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Invalid column name: %s', N'it', N'Nome colonna non valido: %s', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Member %s cannot be editable as it has children', N'it', N'Il membro %s non può essere modificabile poiché ha figli', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Role ''%s'' does not exist', N'it', N'Il ruolo ''%s'' non esiste', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Set 1 to add and 0 to remove a user from the role', N'it', N'Impostare 1 per aggiungere e 0 per rimuovere un utente dal ruolo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'The code ''%s'' contains prohibited symbols (space, '', ", [ or ])', N'it', N'Il codice ''%s'' contiene simboli proibiti (spazio, '', ", [, ])', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'The column ''%s'' is not updatable', N'it', N'La colonna ''%s'' non è aggiornabile', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'The journal has operations on %s', N'it', N'Il journal ha operazioni su %s', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'The period is closed for changes', N'it', N'Il periodo è chiuso per modifiche', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Unknown option: %i (Use 0 or 1)', N'it', N'Opzione sconosciuta: %i (usa 0 o 1)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Unknown option: %s (Use R, W, D)', N'it', N'Opzione sconosciuta: %s (usa R, W, D)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Use TRANSLATED_NAME, TRANSLATED_DESC, or TRANSLATED_COMMENT', N'it', N'Utilizza TRANSLATED_NAME, TRANSLATED_DESC o TRANSLATED_COMMENT', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'User ''%s'' does not exist', N'it', N'L''utente ''%s'' non esiste', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'account', N'it', N'Conto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'account_id', N'it', N'Conto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'account_type_id', N'it', N'Tipo di conto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'amount', N'it', N'Importo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'amount$', N'it', N'Importo$', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'asset_sign', N'it', N'Segno di attività', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'assets', N'it', N'Attività', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'auto_type_id', N'it', N'Tipo automatico', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance', N'it', N'Saldo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance$', N'it', N'Saldo $', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance00', N'it', N'Saldo00', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance01', N'it', N'Saldo01', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance02', N'it', N'Saldo02', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance03', N'it', N'Saldo03', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance04', N'it', N'Saldo04', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance05', N'it', N'Saldo05', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance06', N'it', N'Saldo06', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance07', N'it', N'Saldo07', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance08', N'it', N'Saldo08', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance09', N'it', N'Saldo09', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance10', N'it', N'Saldo10', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance11', N'it', N'Saldo11', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance12', N'it', N'Saldo12', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'bs', N'it', N'BS', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'bs_section', N'it', N'Sezione BS', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'bs_sign', N'it', N'Segno BS', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'category_id', N'it', N'Categoria', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'category_name', N'it', N'Nome della categoria', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'cf', N'it', N'CF', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'cf_ref_number', N'it', N'Numero di riferimento CF', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'cf_section', N'it', N'Sezione CF', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'cf_sign', N'it', N'Segno CF', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charge_credit', N'it', N'Credito di fattura', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charge_credit_id', N'it', N'Credito di fattura', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charge_credit_type_id', N'it', N'Tipo di credito di fattura', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charge_debit', N'it', N'Debito di fattura', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charge_debit_id', N'it', N'Debito di fattura', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charge_debit_type_id', N'it', N'Tipo di debito di fattura', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges', N'it', N'Fatture', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges01', N'it', N'Fatture01', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges02', N'it', N'Fatture02', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges03', N'it', N'Fatture03', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges04', N'it', N'Fatture04', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges05', N'it', N'Fatture05', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges06', N'it', N'Fatture06', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges07', N'it', N'Fatture07', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges08', N'it', N'Fatture08', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges09', N'it', N'Fatture09', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges10', N'it', N'Fatture10', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges11', N'it', N'Fatture11', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges12', N'it', N'Fatture12', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'closing_balance', N'it', N'Saldo di chiusura', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'closing_child_account_id', N'it', N'Conto figlio in chiusura', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'closing_credit', N'it', N'Saldo di chiusura del credito', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'closing_credit_account_id', N'it', N'Conto di credito in chiusura', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'closing_debit', N'it', N'Saldo di chiusura del debito', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'closing_debit_account_id', N'it', N'Conto di debito in chiusura', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'code', N'it', N'Codice', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'code1', N'it', N'Codice 1', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'code2', N'it', N'Codice 2', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'column_name', N'it', N'Nome colonna', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'company_id', N'it', N'Azienda', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'created_by', N'it', N'Creato da', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'created_on', N'it', N'Creato', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'credit', N'it', N'Credito', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'credit$', N'it', N'Credito$', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'credit_account_id', N'it', N'Conto di credito', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'credit_subsidiary_account_id', N'it', N'Conto di credito sussidiario', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'credit_turnover', N'it', N'Totale di credito', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'currency', N'it', N'Moneta', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'currency_id', N'it', N'Moneta', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data_format', N'it', N'Formato dei dati', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data00', N'it', N'Totali', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data01', N'it', N'Genn.', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data02', N'it', N'Febbr.', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data03', N'it', N'Apr.', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data04', N'it', N'Mar.', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data05', N'it', N'Magg.', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data06', N'it', N'Giugno', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data07', N'it', N'Luglio', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data08', N'it', N'Ag.', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data09', N'it', N'Sett.', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data10', N'it', N'Ott.', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data11', N'it', N'Nov.', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data12', N'it', N'Dic.', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'date', N'it', N'Data', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'debit', N'it', N'Debito', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'debit$', N'it', N'Debito$', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'debit_account_id', N'it', N'Conto di debito', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'debit_subsidiary_account_id', N'it', N'Conto di debito sussidiario', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'debit_turnover', N'it', N'Totale di debito', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'default_language', N'it', N'Lingua di default', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'description', N'it', N'Descrizione', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'dimension_id', N'it', N'Dimensione', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'end_day', N'it', N'Fine giornata', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'end_month', N'it', N'Fine mese', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'end_year', N'it', N'Fine anno', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'entity_id', N'it', N'Entità', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'entity_name', N'it', N'Nome dell''entità', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'entry_side_id', N'it', N'Lato della registrazione prima nota', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'factor', N'it', N'Fattore', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'field', N'it', N'Campo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'first_month', N'it', N'Primo mese', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'format_column', N'it', N'Colonna formato', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'group_id', N'it', N'Gruppo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'group1', N'it', N'Gruppo 1', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'group2', N'it', N'Gruppo 2', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'group3', N'it', N'Gruppo 3', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'hide', N'it', N'Nascondi', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'hide_accounts', N'it', N'Nascondi account', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'hide_items', N'it', N'Nascondi elementi', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'id', N'it', N'ID', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'id1', N'it', N'ID1', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'id2', N'it', N'ID2', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'inverse_sign', N'it', N'Segno inverso', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_active', N'it', N'Attivo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_admin', N'it', N'Amministratore', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_base_currency', N'it', N'È la valuta di base', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_calc_date', N'it', N'Data di calcolo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_charge_net', N'it', N'Charge Net', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_checked', N'it', N'Verificato', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_closed', N'it', N'Chiuso', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_complete', N'it', N'Completo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_credit_editable', N'it', N'Credito modificabile', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_currency', N'it', N'Valuta', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_da', N'it', N'D/A', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_debit_editable', N'it', N'Debito modificabile', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_default', N'it', N'Default', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_draft', N'it', N'Bozza', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_empty', N'it', N'Vuoto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_functional_currency', N'it', N'Valuta funzionale', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_in_budget', N'it', N'Nel bilancio', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_in_budget_request', N'it', N'Nella richiesta di budget', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_inherited', N'it', N'Ereditato', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_parent', N'it', N'Genitore', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_pl', N'it', N'PL', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_translatable', N'it', N'Traducibile', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'language', N'it', N'linguaggio', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'last_format_column', N'it', N'Colonna dell''ultimo formato', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'last_month', N'it', N'Scorso mese', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'level', N'it', N'Livello', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'line', N'it', N'Linea', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'line_factor', N'it', N'Fattore di linea', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'member_dimension_id', N'it', N'Dimensione membro', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'member_id', N'it', N'Membro', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'modified_by', N'it', N'Modificato da', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'modified_on', N'it', N'Modificato', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'month', N'it', N'Mese', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'name', N'it', N'Nome', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'opening_balance', N'it', N'Saldo di apertura', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'opening_credit', N'it', N'Saldo di apertura del credito', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'opening_debit', N'it', N'Saldo di apertura del debito', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'page_break', N'it', N'Interruzione di pagina', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'page_break_before', N'it', N'Interruzione di pagina prima', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'pair', N'it', N'Coppia di valute', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'pair_account_type_id', N'it', N'Associa il tipo di account', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'parent_id', N'it', N'Membro principale', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'parent2_id', N'it', N'Genitore2', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'partner_dimension_id', N'it', N'Dimensione del partner', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'partner_id', N'it', N'Membro partner', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payment_credit', N'it', N'Credito di pagamento', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payment_credit_id', N'it', N'Credito di pagamento', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payment_credit_type_id', N'it', N'Tipo di credito di pagamento', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payment_debit', N'it', N'Debito di pagamento', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payment_debit_id', N'it', N'Debito di pagamento', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payment_debit_type_id', N'it', N'Tipo di debito di pagamento', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments', N'it', N'Pagamenti', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments01', N'it', N'Pagamenti01', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments02', N'it', N'Pagamenti02', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments03', N'it', N'Pagamenti03', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments04', N'it', N'Pagamenti04', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments05', N'it', N'Pagamenti05', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments06', N'it', N'Pagamenti06', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments07', N'it', N'Pagamenti07', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments08', N'it', N'Pagamenti08', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments09', N'it', N'Pagamenti09', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments10', N'it', N'Pagamenti10', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments11', N'it', N'Pagamenti11', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments12', N'it', N'Pagamenti12', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period_name', N'it', N'Nome del periodo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period01', N'it', N'Periodo01', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period02', N'it', N'Periodo02', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period03', N'it', N'Periodo03', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period04', N'it', N'Periodo04', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period05', N'it', N'Periodo05', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period06', N'it', N'Periodo06', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period07', N'it', N'Periodo07', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period08', N'it', N'Periodo08', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period09', N'it', N'Periodo09', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period10', N'it', N'Periodo10', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period11', N'it', N'Periodo11', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period12', N'it', N'Periodo12', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'permission', N'it', N'Autorizzazione', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'pl', N'it', N'PL', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'pl_ref_number', N'it', N'Numero di riferimento PL', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'pl_section', N'it', N'Sezione PL', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'pl_section_id', N'it', N'Sezione PL', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'pl_sign', N'it', N'Segno PL', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'product_id', N'it', N'Prodotto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'rate', N'it', N'Tasso di cambio', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'ref_number', N'it', N'Numero di riferimento', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'ref_record_id', N'it', N'Record di riferimento', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'region_id', N'it', N'Regione', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'report', N'it', N'Rapporto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'report_id', N'it', N'Rapporto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'report_section_type_id', N'it', N'Tipo di sezione del rapporto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'report_type_id', N'it', N'Tipo di rapporto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'row_comments', N'it', N'Commenti di riga', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'row_format', N'it', N'Formato riga', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'row_formulas', N'it', N'Formule di fila', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'row_index', N'it', N'Indice di riga', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'row_level', N'it', N'Livello di riga', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'rows', N'it', N'Numero di righe', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'schema', N'it', N'Schema', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'section', N'it', N'Sezione', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'section_type_id', N'it', N'Tipo di sezione', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'select_permission', N'it', N'Autorizzazione di SELECT', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'show_line', N'it', N'Mostra linea', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'show_line_after', N'it', N'Mostra riga dopo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'show_line_before', N'it', N'Mostra riga prima', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'sort_order', N'it', N'Ordinamento', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'specific_type_id', N'it', N'Tipo specifico', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'start_day', N'it', N'Inizia la giornata', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'start_month', N'it', N'Inizia il mese', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'start_year', N'it', N'Inizia l''anno', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'subsidiary_account_id', N'it', N'Conto sussidiario', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'subsidiary_group_id', N'it', N'Gruppo sussidiario', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'subsidiary_name', N'it', N'Nome account sussidiario', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'table_id', N'it', N'ID tabella', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'time_id', N'it', N'ID periodo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'total_charges', N'it', N'Spese totali', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'total_payments', N'it', N'Pagamenti totali', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'total_type_id', N'it', N'Tipo totale', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'transaction_start_time', N'it', N'Ora di inizio della transazione', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'translated_name', N'it', N'Nome tradotto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'type', N'it', N'Typo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'type_id', N'it', N'Typo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'unit', N'it', N'Unità', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'unit_id', N'it', N'Unità', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'update_permission', N'it', N'Autorizzazione di UPDATE', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'username', N'it', N'Nome utente', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'value_sign', N'it', N'Segno di valore', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'value_type_id', N'it', N'Tipo di valore', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'vat', N'it', N'IVA', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'vat_credit', N'it', N'Credito IVA', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'vat_credit_id', N'it', N'Credito IVA', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'vat_credit_type_id', N'it', N'Tipo di credito IVA', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'vat_debit', N'it', N'Debito IVA', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'vat_debit_id', N'it', N'Debito IVA', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'vat_debit_type_id', N'it', N'Tipo di debito IVA', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'vat_rate_id', N'it', N'Aliquota IVA', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'vat_sign', N'it', N'Segno IVA', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'year', N'it', N'Anno', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'zero', N'it', N'Zero', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_actual_balances', NULL, N'it', N'Saldi effettivi', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_actual_balances', N'account_id', N'it', N'Account ID', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_actual_balances', N'subsidiary_account_id', N'it', N'ID account sussidiario', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_actual_closed_periods', NULL, N'it', N'Periodi chiusi effettivi', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_actual_currency_rates', NULL, N'it', N'Tassi di cambio effettivi', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_actual_reports', NULL, N'it', N'Rapporti reali', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_balance_sheet_trial', NULL, N'it', N'Bilancio del fatturato', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_balances', NULL, N'it', N'Saldi di bilancio', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_closed_periods', NULL, N'it', N'Periodi di bilancio chiusi', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_currency_rates', NULL, N'it', N'Tassi di cambio di bilancio', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_data', NULL, N'it', N'Dati di bilancio', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_journal', NULL, N'it', N'Rivista  di bilancio', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_reports', NULL, N'it', N'Rapporti sul bilancio', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_reports_raw', NULL, N'it', N'Budget Report Raw', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', NULL, N'it', N'Richiesta di budget 1', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', N'account', N'it', N'Conto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', N'account_id', N'it', N'Conto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', N'account_name', N'it', N'Nome del conto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', N'product', N'it', N'Prodotto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', N'product_id', N'it', N'Prodotto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', N'region', N'it', N'Regione', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', N'region_id', N'it', N'Regione', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', N'subsidiary_account', N'it', N'Account sussidiario', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', N'subsidiary_account_id', N'it', N'Account sussidiario', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', NULL, N'it', N'Richiesta di budget 2', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', N'account', N'it', N'Conto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', N'account_id', N'it', N'Conto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', N'account_name', N'it', N'Nome del conto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', N'product', N'it', N'Prodotto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', N'product_id', N'it', N'Prodotto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', N'region', N'it', N'Regione', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', N'region_id', N'it', N'Regione', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', N'subsidiary_account', N'it', N'Account sussidiario', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', N'subsidiary_account_id', N'it', N'Account sussidiario', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_requests', NULL, N'it', N'Richieste di budget', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_requests_totals', NULL, N'it', N'Totali richieste di budget', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budgeting_accounts', NULL, N'it', N'Conti di bilancio', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_companies', NULL, N'it', N'Aziende', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_dimensions', NULL, N'it', N'Misure', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_entry_sides', NULL, N'it', N'Lati del diario di entrata', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_journal', NULL, N'it', N'Rivista', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_ledger_account_special_types', NULL, N'it', N'Tipi di conti contabili speciali', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_ledger_account_types', NULL, N'it', N'Tipi di account', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_ledger_accounts', NULL, N'it', N'Conti contabili', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_member_permissions', NULL, N'it', N'Autorizzazioni per i membri', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_member_relations', NULL, N'it', N'Rapporti con i membri', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_member_types', NULL, N'it', N'Tipi di oggetti', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_members', NULL, N'it', N'Membri', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_report_section_accounts', NULL, N'it', N'Conti delle sezioni del rapporto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_report_section_total_types', NULL, N'it', N'Tipi di totali della sezione del report', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_report_section_types', NULL, N'it', N'Tipi di sezione di rapporti', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_report_section_value_types', NULL, N'it', N'Tipi di valori della sezione del report', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_report_sections', NULL, N'it', N'Segnala sezioni', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_report_types', NULL, N'it', N'Tipi di rapporti', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_role_members', NULL, N'it', N'Membri dei ruoli', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_saved_report_types', NULL, N'it', N'Tipi di rapporti salvati', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_saved_reports', NULL, N'it', N'Rapporti salvati', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_subsidiary_accounts', NULL, N'it', N'Conti sussidiari', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_subsidiary_groups', NULL, N'it', N'Gruppi sussidiari', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_translations', NULL, N'it', N'Traduzioni', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_translations_common', NULL, N'it', N'Traduzioni (comuni)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_translations_xls', NULL, N'it', N'Traduzioni (xls)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_units', NULL, N'it', N'Unità', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_users', NULL, N'it', N'Utenti', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_vat_rates', NULL, N'it', N'Aliquote IVA', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_actions_actual_report_cell_data', NULL, N'it', N'Mostra dettagli cella', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_actions_add_language', NULL, N'it', N'Aggiungi lingua', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_actions_auto_calc_all', NULL, N'it', N'Calcola tutto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_actions_auto_close_accounts', NULL, N'it', N'Calcola la chiusura dei conti', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_actions_auto_currency_transactions', NULL, N'it', N'Calcola le transazioni valutarie', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_actions_auto_currency_translation', NULL, N'it', N'Calcola la traduzione di valuta', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_actions_budget_report_cell_data', NULL, N'it', N'Mostra dettagli cella', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_actions_select_members', NULL, N'it', N'Mostra membri', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_automatic_handlers', NULL, N'it', N'Gestori automatici', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_online_help_handlers', NULL, N'it', N'Gestori della guida in linea', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'April', N'it', N'Aprile', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'August', N'it', N'Agosto', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'December', N'it', N'Dicembre', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'February', N'it', N'Febbraio', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'January', N'it', N'Gennaio', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'July', N'it', N'Luglio', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'June', N'it', N'Giugno', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'March', N'it', N'Marzo', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'May', N'it', N'Maggio', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'November', N'it', N'Novembre', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'October', N'it', N'Ottobre', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'September', N'it', N'Settembre', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_query_list_admin', NULL, N'it', N'Elenco di oggetti Admin', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_query_list_setup', NULL, N'it', N'Elenco di oggetti di installazione', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'dimensions_name', N'Accounts', N'ru', N'Показатели', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'dimensions_name', N'Categories', N'ru', N'Категории', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'dimensions_name', N'Entities', N'ru', N'Подразделения', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'dimensions_name', N'Products', N'ru', N'Продукты', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'dimensions_name', N'Regions', N'ru', N'Регионы', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'dimensions_name', N'Sub.Accounts', N'ru', N'Субсчета', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'dimensions_name', N'Times', N'ru', N'Периоды', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'entry_sides_name', N'Credit', N'ru', N'Кредит', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'entry_sides_name', N'Debit', N'ru', N'Дебет', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'Calculation', N'ru', N'Калькуляция', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'Cash', N'ru', N'Денежные средства', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'Currency Exchange Gains', N'ru', N'Прибыли от конвертации валют', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'Currency Exchange Losses', N'ru', N'Убытки от конвертации валют', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'Currency Translation Gains', N'ru', N'Положительные курсовые разницы', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'Currency Translation Losses', N'ru', N'Отрицательные курсовые разницы', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'Net Income (BS)', N'ru', N'Чистая прибыль (BS)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'Net Income (PL)', N'ru', N'Чистая прибыль (PL)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'VAT Payable', N'ru', N'НДС к оплате', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_special_types_name', N'VAT Receivable', N'ru', N'НДС к зачету', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Administrative Expenses', N'ru', N'Административные расходы', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Administrative Expenses - Amortization', N'ru', N'Административные расходы - Амортизация НМА', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Administrative Expenses - Depreciation', N'ru', N'Административные расходы - Амортизация ОС', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Calculation', N'ru', N'Калькуляция', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Cost of Revenue', N'ru', N'Себестоимость продаж', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Cost of Revenue - Amortization', N'ru', N'Себестоимость продаж - Амортизация НМА', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Cost of Revenue - Depreciation', N'ru', N'Себестоимость продаж - Амортизация ОС', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Currency Exchange Gains', N'ru', N'Прибыль от валютных операций', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Currency Exchange Losses', N'ru', N'Убыток от валютных операций', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Currency Translation Gains', N'ru', N'Положительные курсовые разницы', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Currency Translation Losses', N'ru', N'Отрицательные курсовые разницы', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Assets', N'ru', N'Оборотные активы', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Assets - Cash', N'ru', N'Оборотные активы - Денежные средства', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Assets - Cash Equivalents', N'ru', N'Оборотные активы - Эквиваленты денежных средств', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Assets - Receivable', N'ru', N'Оборотные активы - Дебиторская задолженность', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Assets - VAT Receivable', N'ru', N'Оборотные активы - НДС к зачету', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Assets/Liabilities', N'ru', N'Оборотные активы / Текущие обязательства', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Financial Assets', N'ru', N'Оборотные активы - Финансовые вложения', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Financial Assets Net', N'ru', N'Оборотные активы - Финансовые вложения - нетто', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Financial Liabilities', N'ru', N'Текущие обязательства - Кредиты и займы', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Financial Liabilities Net', N'ru', N'Текущие обязательства - Кредиты и займы - нетто', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Investing Assets', N'ru', N'Оборотные активы - Инвестиционные', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Investing Liabilities', N'ru', N'Текущие обязательства - Инвестиционные', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Liabilities', N'ru', N'Текущие обязательства', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Liabilities - Payable', N'ru', N'Текущие обязательства - Кредиторская задолженность', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Current Liabilities - VAT Payable', N'ru', N'Текущие обязательства - НДС', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Equity', N'ru', N'Собственный капитал', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Equity - Net Income', N'ru', N'Собственный капитал - Чистая прибыль', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Equity - Retained Earnings', N'ru', N'Собственный капитал - Нераспределенная прибыль', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'General Expenses', N'ru', N'Общие расходы', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'General Expenses - Amortization', N'ru', N'Общие расходы - Амортизация НМА', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'General Expenses - Depreciation', N'ru', N'Общие расходы - Амортизация ОС', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Income Tax Expense', N'ru', N'Расходы по налогу на прибыль', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Interest Expenses', N'ru', N'Расходы на проценты', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Net Income', N'ru', N'Чистая прибыль', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Non-current Assets', N'ru', N'Внеоборотные активы', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Non-current Assets - Amortization', N'ru', N'Внеоборотные активы - Амортизация НМА', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Non-current Assets - Depreciation', N'ru', N'Внеоборотные активы - Амортизация ОС', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Non-current Financial Assets', N'ru', N'Внеоборотные активы - Финансовые', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Non-current Financial Assets Net', N'ru', N'Внеоборотные активы - Финансовые - нетто', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Non-current Financial Liabilities', N'ru', N'Долгосрочные обязательства - Кредиты и займы', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Non-current Financial Liabilities Net', N'ru', N'Долгосрочные обязательства - Кредиты и займы - нетто', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Non-current Liabilities', N'ru', N'Долгосрочные обязательства', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Operating Income', N'ru', N'Прибыль от основной деятельности', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Other Expenses', N'ru', N'Расходы прочие', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Other Financial Expenses', N'ru', N'Расходы прочие - Финансовые', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Other Financial Income', N'ru', N'Доходы прочие - Финансовые', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Other Income', N'ru', N'Доходы прочие', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Other Income/Expenses Net', N'ru', N'Прибыль от прочих операций', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Other Investing Expenses', N'ru', N'Расходы прочие - Инвестиционные', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Other Investing Income', N'ru', N'Доходы прочие - Инвестиционные', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'R&D Expenses', N'ru', N'Расходы R&D', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'R&D Expenses - Amortization', N'ru', N'Расходы R&D - Амортизация НМА', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'R&D Expenses - Depreciation', N'ru', N'Расходы R&D - Амортизация ОС', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Revenue', N'ru', N'Выручка', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Selling Expenses', N'ru', N'Коммерческие расходы', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Selling Expenses - Amortization', N'ru', N'Коммерческие расходы - Амортизация НМА', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'ledger_account_types_name', N'Selling Expenses - Depreciation', N'ru', N'Коммерческие расходы - Амортизация ОС', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Amortization', N'ru', N'Амортизация НМА', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Calculated', N'ru', N'Расчетная', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Cash Transfer', N'ru', N'Перевод денежных средств', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Cost', N'ru', N'Себестоимость', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Depreciation', N'ru', N'Амортизация ОС', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Expense', N'ru', N'Расходы', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Expense, no VAT', N'ru', N'Расходы, без НДС', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Income', N'ru', N'Доход', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Income, no VAT', N'ru', N'Доход, без НДС', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Inflow', N'ru', N'Поступление денежных средств', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'None', N'ru', N'Нет', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Outflow', N'ru', N'Выбытие денежных средств', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Purchase', N'ru', N'Покупки', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Purchase, no VAT', N'ru', N'Покупки, без НДС', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Setoff', N'ru', N'Зачет', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'member_types_name', N'Withholding', N'ru', N'Удержание', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_total_types_name', N'Closing Balance', N'ru', N'Конечный баланс', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_total_types_name', N'Opening Balance', N'ru', N'Начальный баланс', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_total_types_name', N'Total', N'ru', N'Итого', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Administrative Expenses', N'ru', N'Административные расходы', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Cash at the Beginning (CF)', N'ru', N'Денежные средства на начало (CF)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Cash at the Beginning (DCF)', N'ru', N'Денежные средства на начало (DCF)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Cash at the End (CF)', N'ru', N'Денежные средства на конец (CF)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Cash at the End (DCF)', N'ru', N'Денежные средства на конец (DCF)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Cost of Revenue', N'ru', N'Себестоимость продаж', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Current Assets', N'ru', N'Оборотные активы', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Current Liabilities', N'ru', N'Текущие обязательства', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Depreciation (CF)', N'ru', N'Амортизация (CF)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Disabled', N'ru', N'Отключено', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Expense VAT', N'ru', N'НДС в расходах', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Financing Cash Flows (CF)', N'ru', N'Финансовые потоки', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Financing Cash Inflows', N'ru', N'Поступления от финансовой (CF)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Financing Cash Inflows (CF)', N'ru', N'Поступления от финансовой (CF)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Financing Cash Outflows (CF)', N'ru', N'Выплаты по финансовой (CF)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Financing Inflows', N'ru', N'Поступления от финансовой', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Financing Outflows', N'ru', N'Выплаты по финансовой', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'General Expenses', N'ru', N'Общие расходы', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Income Tax Expense', N'ru', N'Расходы по налогу на прибыль', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Income VAT', N'ru', N'НДС в доходах', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Interest Expenses', N'ru', N'Расходы на проценты', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Investing Cash Flows (CF)', N'ru', N'Инвестиционные потоки', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Investing Inflows', N'ru', N'Поступления от инвестиционной', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Investing Outflows', N'ru', N'Выплаты по инвестиционной', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Net Income (CF)', N'ru', N'Чистая прибыль (CF)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Non-Current Assets', N'ru', N'Внеоборотные активы', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Non-Current Liabilities', N'ru', N'Долгосрочные обязательства', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Operating Cash Flows (CF)', N'ru', N'Операционные потоки', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Operating Inflows', N'ru', N'Поступления от операционной', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Operating Outflows', N'ru', N'Выплаты по операционной', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Other Expenses', N'ru', N'Прочие расходы', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Other Income', N'ru', N'Прочие доходы', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'R&D Expenses', N'ru', N'Расходы R&D', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Revenue', N'ru', N'Выручка', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Selling Expenses', N'ru', N'Коммерческие расходы', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Stockholders'' Equity', N'ru', N'Собственный капитал', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'Stockholders'' Equity - Net Income', N'ru', N'Собственный капитал - Чистая прибыль', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'VAT Paid', N'ru', N'НДС уплаченный', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_types_name', N'VAT Set-Offs', N'ru', N'Зачет НДС', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_value_types_name', N'Balance', N'ru', N'Сальдо', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_value_types_name', N'Credit Balance', N'ru', N'Баланс по дебету', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_value_types_name', N'Debit Balance', N'ru', N'Баланс по кредиту', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_section_value_types_name', N'Flow', N'ru', N'Поток', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_code', N'BS', N'ru', N'БАЛАНС', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_code', N'CF', N'ru', N'ДП', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_code', N'DCF', N'ru', N'ДДС', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_code', N'PL', N'ru', N'ДР', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_code', N'VAT', N'ru', N'НДС', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_name', N'Balance Sheet', N'ru', N'Баланс', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_name', N'Cash Flow', N'ru', N'Денежные потоки', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_name', N'Direct Cash Flow', N'ru', N'ДДС', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_name', N'Income Statement', N'ru', N'Доходы и расходы', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'report_types_name', N'VAT', N'ru', N'Расчет НДС', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Access denied', N'ru', N'Доступ запрещен', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Cannot find member id %i', N'ru', N'Не удается найти идентификатор %i', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Cannot find member id %s', N'ru', N'Не удается найти идентификатор %s', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Cannot find member_id %i', N'ru', N'Не удается найти member_id %i', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Cannot find member_id %s', N'ru', N'Не удается найти member_id %s', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Cannot find the principal ''%s'', because it does not exist or you do not have permission.', N'ru', N'Не удается найти пользователя %s, так как он не существует или у вас нет разрешения.', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Invalid column name: %s', N'ru', N'Неверное имя столбца: %s', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Member %s cannot be editable as it has children', N'ru', N'Эдемент %s не является редактируемым, так как у него есть потомки', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Role ''%s'' does not exist', N'ru', N'Роль "%s" не существует', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Set 1 to add and 0 to remove a user from the role', N'ru', N'Установите 1 для добавления и 0 для удаления пользователя из роли', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'The code ''%s'' contains prohibited symbols (space, '', ", [ or ])', N'ru', N'Код ''%s'' содержит запрещенные символы (пробел, '', ", [или])', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'The column ''%s'' is not updatable', N'ru', N'Столбец ''%s'' не является обновляемым', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'The journal has operations on %s', N'ru', N'В журнале есть операции на %s', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'The period is closed for changes', N'ru', N'Период закрыт для изменений', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Unknown option: %i (Use 0 or 1)', N'ru', N'Неизвестная опция: %i (используйте 0 или 1)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Unknown option: %s (Use R, W, D)', N'ru', N'Неизвестная опция: %s (используйте R, W, D)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'Use TRANSLATED_NAME, TRANSLATED_DESC, or TRANSLATED_COMMENT', N'ru', N'Используйте TRANSLATED_NAME, TRANSLATED_DESC или TRANSLATED_COMMENT', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'dbo27', N'strings', N'User ''%s'' does not exist', N'ru', N'Пользователь "%s" не существует', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'account', N'ru', N'Счет', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'account_id', N'ru', N'Счет', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'account_type_id', N'ru', N'Тип счета', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'amount', N'ru', N'Сумма', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'amount$', N'ru', N'Сумма$', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'asset_sign', N'ru', N'Знак актива', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'assets', N'ru', N'Активы', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'auto_type_id', N'ru', N'Тип расчета', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance', N'ru', N'Сальдо', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance$', N'ru', N'Сальдо$', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance00', N'ru', N'Сальдо00', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance01', N'ru', N'Сальдо01', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance02', N'ru', N'Сальдо02', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance03', N'ru', N'Сальдо03', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance04', N'ru', N'Сальдо04', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance05', N'ru', N'Сальдо05', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance06', N'ru', N'Сальдо06', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance07', N'ru', N'Сальдо07', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance08', N'ru', N'Сальдо08', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance09', N'ru', N'Сальдо09', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance10', N'ru', N'Сальдо10', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance11', N'ru', N'Сальдо11', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'balance12', N'ru', N'Сальдо12', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'bs', N'ru', N'Баланс', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'bs_section', N'ru', N'Раздел баланса', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'bs_sign', N'ru', N'Знак баланса', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'category_id', N'ru', N'Категория', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'category_name', N'ru', N'Наименование категории', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'cf', N'ru', N'CF', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'cf_ref_number', N'ru', N'Номер строки CF', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'cf_section', N'ru', N'Раздел CF', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'cf_sign', N'ru', N'Знак CF', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charge_credit', N'ru', N'Кредит начислений', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charge_credit_id', N'ru', N'Кредит начислений', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charge_credit_type_id', N'ru', N'Тип кредита начислений', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charge_debit', N'ru', N'Дебет начислений', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charge_debit_id', N'ru', N'Дебет начислений', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charge_debit_type_id', N'ru', N'Тип дебета начислений', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges', N'ru', N'Начисления', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges01', N'ru', N'Начисления01', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges02', N'ru', N'Начисления02', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges03', N'ru', N'Начисления03', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges04', N'ru', N'Начисления04', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges05', N'ru', N'Начисления05', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges06', N'ru', N'Начисления06', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges07', N'ru', N'Начисления07', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges08', N'ru', N'Начисления08', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges09', N'ru', N'Начисления09', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges10', N'ru', N'Начисления10', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges11', N'ru', N'Начисления11', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'charges12', N'ru', N'Начисления12', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'closing_balance', N'ru', N'Конечное сальдо', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'closing_child_account_id', N'ru', N'Дочерний счет закрытия', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'closing_credit', N'ru', N'Конечное сальдо по кредиту', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'closing_credit_account_id', N'ru', N'Закрытие кредита', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'closing_debit', N'ru', N'Конечное сальдо по дебету', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'closing_debit_account_id', N'ru', N'Закрытие дебета', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'code', N'ru', N'Код', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'code1', N'ru', N'Код 1', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'code2', N'ru', N'Код 2', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'column_name', N'ru', N'Наименование колонки', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'company_id', N'ru', N'Компания', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'created_by', N'ru', N'Создан', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'created_on', N'ru', N'Дата создания', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'credit', N'ru', N'Кредит', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'credit$', N'ru', N'Кредит$', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'credit_account_id', N'ru', N'Счета кредита', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'credit_subsidiary_account_id', N'ru', N'Субсчет кредита', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'credit_turnover', N'ru', N'Обороты кредита', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'currency', N'ru', N'Валюта', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'currency_id', N'ru', N'Валюта', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data_format', N'ru', N'Формат данных', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data00', N'ru', N'Всего', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data01', N'ru', N'Янв', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data02', N'ru', N'Фев', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data03', N'ru', N'Мар', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data04', N'ru', N'Апр', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data05', N'ru', N'Май', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data06', N'ru', N'Июн', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data07', N'ru', N'Июл', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data08', N'ru', N'Авг', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data09', N'ru', N'Сен', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data10', N'ru', N'Окт', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data11', N'ru', N'Ноя', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'data12', N'ru', N'Дек', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'date', N'ru', N'Дата', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'debit', N'ru', N'Дебет', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'debit$', N'ru', N'Дебет$', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'debit_account_id', N'ru', N'Счет дебета', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'debit_subsidiary_account_id', N'ru', N'Субсчет дебета', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'debit_turnover', N'ru', N'Обороты дебета', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'default_language', N'ru', N'Язык по умолчанию', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'description', N'ru', N'Описание', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'dimension_id', N'ru', N'Измерение', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'end_day', N'ru', N'День окончания', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'end_month', N'ru', N'Месяц окончания', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'end_year', N'ru', N'Год окончания', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'entity_id', N'ru', N'Подразделение', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'entity_name', N'ru', N'Наименование подразделения', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'entry_side_id', N'ru', N'Сторона проводки', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'factor', N'ru', N'Фактор', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'field', N'ru', N'Поле', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'first_month', N'ru', N'Первый месяц', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'format_column', N'ru', N'Колонка формата', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'group_id', N'ru', N'Группа', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'group1', N'ru', N'Группа 1', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'group2', N'ru', N'Группа 2', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'group3', N'ru', N'Группа 3', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'hide', N'ru', N'Скрыть', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'hide_accounts', N'ru', N'Скрыть счета', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'hide_items', N'ru', N'Скрыть элементы', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'id', N'ru', N'ID', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'id1', N'ru', N'ID1', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'id2', N'ru', N'ID2', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'inverse_sign', N'ru', N'Обратный знак', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_active', N'ru', N'Активен', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_admin', N'ru', N'Админ', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_base_currency', N'ru', N'Базовая валюта', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_calc_date', N'ru', N'Дата расчета', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_charge_net', N'ru', N'Сумма без НДС', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_checked', N'ru', N'Проверено', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_closed', N'ru', N'Закрыто', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_complete', N'ru', N'Готово', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_credit_editable', N'ru', N'Кредит редактируемый', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_currency', N'ru', N'Валюта', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_da', N'ru', N'Амортизация', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_debit_editable', N'ru', N'Дебет редактируемый', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_default', N'ru', N'По умолчанию', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_draft', N'ru', N'Черновик', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_empty', N'ru', N'Пусто', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_functional_currency', N'ru', N'Функциональная валюта', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_in_budget', N'ru', N'В бюджет', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_in_budget_request', N'ru', N'Строка заявки', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_inherited', N'ru', N'Наследник', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_parent', N'ru', N'Расчетная', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_pl', N'ru', N'PL', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'is_translatable', N'ru', N'Перевод', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'language', N'ru', N'Язык', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'last_format_column', N'ru', N'Последняя колонка формата', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'last_month', N'ru', N'Прошлый месяц', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'level', N'ru', N'Уровень', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'line', N'ru', N'Строка', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'line_factor', N'ru', N'Множитель строки', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'member_dimension_id', N'ru', N'Измерение элемента', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'member_id', N'ru', N'Элемент', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'modified_by', N'ru', N'Изменен', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'modified_on', N'ru', N'Дата изменения', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'month', N'ru', N'Месяц', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'name', N'ru', N'Наименование', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'opening_balance', N'ru', N'Начальное сальдо', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'opening_credit', N'ru', N'Начальное сальдо по кредиту', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'opening_debit', N'ru', N'Начальное сальдо по дебету', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'page_break', N'ru', N'Разрыв страницы', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'page_break_before', N'ru', N'Разрыв страницы до', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'pair', N'ru', N'Валютная пара', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'pair_account_type_id', N'ru', N'Тип парного счета', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'parent_id', N'ru', N'Родитель', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'parent2_id', N'ru', N'Родитель2', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'partner_dimension_id', N'ru', N'Измерение партнера', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'partner_id', N'ru', N'Партнер', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payment_credit', N'ru', N'Кредит платежей', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payment_credit_id', N'ru', N'Кредит платежей', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payment_credit_type_id', N'ru', N'Тип кредита платежей', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payment_debit', N'ru', N'Дебет платежей', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payment_debit_id', N'ru', N'Дебет платежей', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payment_debit_type_id', N'ru', N'Тип дебета платежей', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments', N'ru', N'Платежи', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments01', N'ru', N'Платежи01', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments02', N'ru', N'Платежи02', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments03', N'ru', N'Платежи03', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments04', N'ru', N'Платежи04', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments05', N'ru', N'Платежи05', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments06', N'ru', N'Платежи06', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments07', N'ru', N'Платежи07', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments08', N'ru', N'Платежи08', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments09', N'ru', N'Платежи09', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments10', N'ru', N'Платежи10', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments11', N'ru', N'Платежи11', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'payments12', N'ru', N'Платежи12', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period_name', N'ru', N'Наименование периода', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period01', N'ru', N'Период01', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period02', N'ru', N'Период02', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period03', N'ru', N'Период03', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period04', N'ru', N'Период04', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period05', N'ru', N'Период05', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period06', N'ru', N'Период06', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period07', N'ru', N'Период07', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period08', N'ru', N'Период08', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period09', N'ru', N'Период09', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period10', N'ru', N'Период10', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period11', N'ru', N'Период11', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'period12', N'ru', N'Период12', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'permission', N'ru', N'Разрешение', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'pl', N'ru', N'PL', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'pl_ref_number', N'ru', N'Номер ссылки PL', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'pl_section', N'ru', N'Раздел PL', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'pl_section_id', N'ru', N'Раздел PL', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'pl_sign', N'ru', N'Знак PL', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'product_id', N'ru', N'Продукт', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'rate', N'ru', N'Курс валюты', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'ref_number', N'ru', N'Стр.', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'ref_record_id', N'ru', N'Стр.', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'region_id', N'ru', N'Регион', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'report', N'ru', N'Отчет', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'report_id', N'ru', N'Отчет', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'report_section_type_id', N'ru', N'Тип раздела отчета', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'report_type_id', N'ru', N'Тип отчета', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'row_comments', N'ru', N'Комментарии строки', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'row_format', N'ru', N'Формат строки', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'row_formulas', N'ru', N'Формулы строки', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'row_index', N'ru', N'Индекс строки', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'row_level', N'ru', N'Уровень строки', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'rows', N'ru', N'Кол-во строк', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'schema', N'ru', N'Схема', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'section', N'ru', N'Раздел', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'section_type_id', N'ru', N'Тип раздела', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'select_permission', N'ru', N'Разрешение SELECT', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'show_line', N'ru', N'Показать строку', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'show_line_after', N'ru', N'Показать строку после', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'show_line_before', N'ru', N'Показать строку до', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'sort_order', N'ru', N'Порядок сортировки', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'specific_type_id', N'ru', N'Специальный тип', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'start_day', N'ru', N'День начала', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'start_month', N'ru', N'Месяц начала', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'start_year', N'ru', N'Начальный год', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'subsidiary_account_id', N'ru', N'Субсчет', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'subsidiary_group_id', N'ru', N'Дочерняя группа', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'subsidiary_name', N'ru', N'Наименование субсчета', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'table_id', N'ru', N'ID таблицы', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'time_id', N'ru', N'Период', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'total_charges', N'ru', N'Всего начислений', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'total_payments', N'ru', N'Всего платежей', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'total_type_id', N'ru', N'Тип итогов', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'transaction_start_time', N'ru', N'Время начала транзакции', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'translated_name', N'ru', N'Переведенное имя', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'type', N'ru', N'Тип', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'type_id', N'ru', N'Тип', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'unit', N'ru', N'Единица изм.', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'unit_id', N'ru', N'Ед. изм.', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'update_permission', N'ru', N'Разрешение UPDATE', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'username', N'ru', N'Имя пользователя', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'value_sign', N'ru', N'Знак значения', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'value_type_id', N'ru', N'Тип значения', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'vat', N'ru', N'НДС', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'vat_credit', N'ru', N'Кредит НДС', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'vat_credit_id', N'ru', N'Кредит НДС', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'vat_credit_type_id', N'ru', N'Тип кредита НДС', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'vat_debit', N'ru', N'Дебет НДС', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'vat_debit_id', N'ru', N'Дебет НДС', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'vat_debit_type_id', N'ru', N'Тип дебета НДС', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'vat_rate_id', N'ru', N'Ставка НДС', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'vat_sign', N'ru', N'Знак НДС', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'year', N'ru', N'Год', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', NULL, N'zero', N'ru', N'Ноль', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_actual_balances', NULL, N'ru', N'Начальные остатки факта', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_actual_balances', N'account_id', N'ru', N'ID счета', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_actual_balances', N'subsidiary_account_id', N'ru', N'ID субсчета', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_actual_closed_periods', NULL, N'ru', N'Закрытые периоды факта', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_actual_currency_rates', NULL, N'ru', N'Курсы валют факта', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_actual_reports', NULL, N'ru', N'Отчеты по факту', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_balance_sheet_trial', NULL, N'ru', N'Оборотная ведомость', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_balances', NULL, N'ru', N'Начальные остатки бюджета', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_closed_periods', NULL, N'ru', N'Закрытые периоды бюджета', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_currency_rates', NULL, N'ru', N'Курсы валют бюджета', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_data', NULL, N'ru', N'Данные бюджета', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_journal', NULL, N'ru', N'Журнал проводок бюджета', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_reports', NULL, N'ru', N'Отчеты по бюджету', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_reports_raw', NULL, N'ru', N'Данные бюджета', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', NULL, N'ru', N'Бюджетный запрос 1', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', N'account', N'ru', N'Счет', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', N'account_id', N'ru', N'Счет', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', N'account_name', N'ru', N'Наименование счета', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', N'product', N'ru', N'Продукт', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', N'product_id', N'ru', N'Продукт', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', N'region', N'ru', N'Регион', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', N'region_id', N'ru', N'Регион', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', N'subsidiary_account', N'ru', N'Субсчет', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request1', N'subsidiary_account_id', N'ru', N'Субсчет', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', NULL, N'ru', N'Бюджетный запрос 2', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', N'account', N'ru', N'Счет', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', N'account_id', N'ru', N'Счет', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', N'account_name', N'ru', N'Наименование счета', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', N'product', N'ru', N'Продукт', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', N'product_id', N'ru', N'Продукт', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', N'region', N'ru', N'Регион', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', N'region_id', N'ru', N'Регион', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', N'subsidiary_account', N'ru', N'Субсчет', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_request2', N'subsidiary_account_id', N'ru', N'Субсчет', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_requests', NULL, N'ru', N'Бюджетные запросы', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budget_requests_totals', NULL, N'ru', N'Оборотная ведомость бюджета', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_budgeting_accounts', NULL, N'ru', N'Бюджетные счета', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_companies', NULL, N'ru', N'Компании', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_dimensions', NULL, N'ru', N'Измерения', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_entry_sides', NULL, N'ru', N'Стороны проводки', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_journal', NULL, N'ru', N'Журнал проводок по факту', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_ledger_account_special_types', NULL, N'ru', N'Типы специальных счетов', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_ledger_account_types', NULL, N'ru', N'Типы бухгалтерских счетов', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_ledger_accounts', NULL, N'ru', N'План счетов', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_member_permissions', NULL, N'ru', N'Разрешения для элементов', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_member_relations', NULL, N'ru', N'Отношения элементов измерений', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_member_types', NULL, N'ru', N'Типы элементов', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_members', NULL, N'ru', N'Элементы измерений', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_report_section_accounts', NULL, N'ru', N'Счета и разделы отчетов', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_report_section_total_types', NULL, N'ru', N'Типы итогов раздела отчета', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_report_section_types', NULL, N'ru', N'Типы разделов отчетов', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_report_section_value_types', NULL, N'ru', N'Типы значений разделов отчета', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_report_sections', NULL, N'ru', N'Разделы отчетов', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_report_types', NULL, N'ru', N'Типы отчетов', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_role_members', NULL, N'ru', N'Члены ролей', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_saved_report_types', NULL, N'ru', N'Типы сохраненных отчетов', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_saved_reports', NULL, N'ru', N'Сохраненные отчеты', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_subsidiary_accounts', NULL, N'ru', N'Субсчета', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_subsidiary_groups', NULL, N'ru', N'Группы субсчетов', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_translations', NULL, N'ru', N'Перевод элементов', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_translations_common', NULL, N'ru', N'Переводы (общие)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_translations_xls', NULL, N'ru', N'Переводы (xls)', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_units', NULL, N'ru', N'Единицы измерения', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_users', NULL, N'ru', N'Пользователи', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'usp_vat_rates', NULL, N'ru', N'Ставки НДС', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_actions_actual_report_cell_data', NULL, N'ru', N'Показать исходные данные ячейки', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_actions_add_language', NULL, N'ru', N'Добавить язык', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_actions_auto_calc_all', NULL, N'ru', N'Рассчитать все', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_actions_auto_close_accounts', NULL, N'ru', N'Рассчитать закрытые счетов', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_actions_auto_currency_transactions', NULL, N'ru', N'Рассчитать результаты валютных операций', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_actions_auto_currency_translation', NULL, N'ru', N'Рассчитать результаты переоценки валюты', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_actions_budget_report_cell_data', NULL, N'ru', N'Показать исходные данные ячейки', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_actions_select_members', NULL, N'ru', N'Показать элементы и счета учета', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_automatic_handlers', NULL, N'ru', N'Автоматические обработчики', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_online_help_handlers', NULL, N'ru', N'Обработчики интерактивной справки', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'April', N'ru', N'Aпрель', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'August', N'ru', N'Август', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'December', N'ru', N'Декабрь', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'February', N'ru', N'Февраль', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'January', N'ru', N'Январь', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'July', N'ru', N'Июль', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'June', N'ru', N'Июнь', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'March', N'ru', N'Март', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'May', N'ru', N'Май', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'November', N'ru', N'Ноябрь', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'October', N'ru', N'Октябрь', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_parameter_values_month_name', N'September', N'ru', N'Сентябрь', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_query_list_admin', NULL, N'ru', N'Список объектов администратора', NULL, NULL);
INSERT INTO xls.translations (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT) VALUES (N'xls27', N'xl_query_list_setup', NULL, N'ru', N'Список объектов настройки', NULL, NULL);
GO

INSERT INTO xls.workbooks (NAME, TEMPLATE, DEFINITION, TABLE_SCHEMA) VALUES (N'gBudgeting-A1-Setup.xlsx', N'https://www.savetodb.com/downloads/v10/gBudgeting-A1-Setup.xlsx', N'1a_units=xls27.usp_units,xls27.xl_query_list_setup,False,$B$3,,{"Parameters":{"company_id":1},"ListObjectName":"units","WorkbookLanguage":"en"}
1b_vat_rates=xls27.usp_vat_rates,xls27.xl_query_list_setup,False,$B$3,,{"Parameters":{"company_id":1},"ListObjectName":"vat_rates","WorkbookLanguage":"en"}
1c_subsidiary_groups=xls27.usp_subsidiary_groups,xls27.xl_query_list_setup,False,$B$3,,{"Parameters":{"company_id":1},"ListObjectName":"subsidiary_groups","WorkbookLanguage":"en"}
2a_budgeting_accounts=xls27.usp_budgeting_accounts,xls27.xl_query_list_setup,False,$B$3,,{"Parameters":{"company_id":1,"account_type_id":null,"is_in_budget":null,"is_active":null},"ListObjectName":"budgeting_accounts","WorkbookLanguage":"en"}
2b_ledger_accounts=xls27.usp_ledger_accounts,(Default),False,$B$3,,{"Parameters":{"company_id":1},"ListObjectName":"ledger_accounts","WorkbookLanguage":"en"}
2c_report_sections=xls27.usp_report_sections,xls27.xl_query_list_setup,False,$B$3,,{"Parameters":{"company_id":1,"report_type_id":null},"ListObjectName":"report_section_types","WorkbookLanguage":"en"}
3a_members=xls27.usp_members,xls27.xl_query_list_setup,False,$B$3,,{"Parameters":{"company_id":1,"dimension_id":4,"is_in_budget":null,"is_active":null},"ListObjectName":"members","WorkbookLanguage":"en"}
3b_subsidiary_accounts=xls27.usp_subsidiary_accounts,xls27.xl_query_list_setup,False,$B$3,,{"Parameters":{"company_id":1,"subsidiary_group_id":null},"ListObjectName":"subsidiary_accounts","WorkbookLanguage":"en"}
3c_member_relations=xls27.usp_member_relations,xls27.xl_query_list_setup,False,$B$3,,{"Parameters":{"company_id":1,"member_dimension_id":1,"partner_dimension_id":4},"ListObjectName":"member_relations","WorkbookLanguage":"en"}
3d_translations=xls27.usp_translations,xls27.xl_query_list_setup,False,$B$3,,{"Parameters":{"company_id":1,"is_translatable":1,"is_complete":null},"ListObjectName":"translations","WorkbookLanguage":"en"}
4a_budget_balances=xls27.usp_budget_balances,xls27.xl_query_list_setup,False,$B$3,,{"Parameters":{"company_id":1,"category_id":69,"time_id":67},"ListObjectName":"budget_balances","WorkbookLanguage":"en"}
4b_budget_rates=xls27.usp_budget_currency_rates,xls27.xl_query_list_setup,False,$B$3,,{"Parameters":{"company_id":1,"category_id":null,"time_id":null},"ListObjectName":"budget_currency_rates","WorkbookLanguage":"en"}
4c_budget_closed_periods=xls27.usp_budget_closed_periods,xls27.xl_query_list_setup,False,$B$3,,{"Parameters":{"company_id":1},"ListObjectName":"budget_closed_periods","WorkbookLanguage":"en"}
5a_actual_balances=xls27.usp_actual_balances,xls27.xl_query_list_setup,False,$B$3,,{"Parameters":{"company_id":1},"ListObjectName":"actual_balances","WorkbookLanguage":"en"}
5b_actual_rates=xls27.usp_actual_currency_rates,xls27.xl_query_list_setup,True,$B$3,,{"Parameters":{"company_id":1,"currency_id":null},"ListObjectName":"actual_currency_rates","WorkbookLanguage":"en"}
5c_actual_closed_periods=xls27.usp_actual_closed_periods,xls27.xl_query_list_setup,True,$B$3,,{"Parameters":{"company_id":1},"ListObjectName":"actual_closed_periods","WorkbookLanguage":"en"}
6a_saved_report_types=xls27.usp_saved_report_types,(Default),True,$B$3,,{"Parameters":{"company_id":1},"ListObjectName":"saved_report_types","WorkbookLanguage":"en"}', N'xls27');
INSERT INTO xls.workbooks (NAME, TEMPLATE, DEFINITION, TABLE_SCHEMA) VALUES (N'gBudgeting-B1-Admin.xlsx', N'https://www.savetodb.com/downloads/v10/gBudgeting-B1-Admin.xlsx', N'1_companies=xls27.usp_companies,xls27,False,$B$3,,{"Parameters":{},"ListObjectName":"companies","WorkbookLanguage":"en"}
2_users=xls27.usp_users,xls27,False,$B$3,,{"Parameters":{"company_id":1},"ListObjectName":"users","WorkbookLanguage":"en"}
3_role_members=xls27.usp_role_members,(Default),False,$B$3,,{"Parameters":{},"ListObjectName":"role_members","WorkbookLanguage":"en"}
member_permissions=xls27.usp_member_permissions,xls27,False,$B$3,,{"Parameters":{"company_id":1,"dimension_id":1,"username":null},"ListObjectName":"member_permissions","WorkbookLanguage":"en"}
actual_closed_periods=xls27.usp_actual_closed_periods,xls27,False,$B$3,,{"Parameters":{"company_id":1},"ListObjectName":"actual_closed_periods","WorkbookLanguage":"en"}
budget_closed_periods=xls27.usp_budget_closed_periods,xls27,False,$B$3,,{"Parameters":{"company_id":1},"ListObjectName":"budget_closed_periods","WorkbookLanguage":"en"}', N'xls27');
INSERT INTO xls.workbooks (NAME, TEMPLATE, DEFINITION, TABLE_SCHEMA) VALUES (N'gBudgeting-C1-Request-101.xlsx', N'https://www.savetodb.com/downloads/v10/gBudgeting-C1-Request-101.xlsx', N'Request1=xls27.usp_budget_request1,(Default),False,$B$8,,{"Parameters":{"company_id":1,"category_id":69,"time_id":67,"entity_id":71,"rows":26},"ListObjectName":"budget_request1","WorkbookLanguage":"en"}
Request2=xls27.usp_budget_request2,(Default),False,$B$8,,{"Parameters":{"company_id":1,"category_id":69,"time_id":67,"entity_id":71,"rows":26},"ListObjectName":"budget_request2","WorkbookLanguage":"en"}', N'xls27');
INSERT INTO xls.workbooks (NAME, TEMPLATE, DEFINITION, TABLE_SCHEMA) VALUES (N'gBudgeting-C1-Request-201.xlsx', N'https://www.savetodb.com/downloads/v10/gBudgeting-C1-Request-201.xlsx', N'Request1=xls27.usp_budget_request1,(Default),False,$B$8,,{"Parameters":{"company_id":1,"category_id":69,"time_id":67,"entity_id":72,"rows":26},"ListObjectName":"budget_request1","WorkbookLanguage":"en"}
Request2=xls27.usp_budget_request2,(Default),False,$B$8,,{"Parameters":{"company_id":1,"category_id":69,"time_id":67,"entity_id":72,"rows":26},"ListObjectName":"budget_request2","WorkbookLanguage":"en"}', N'xls27');
INSERT INTO xls.workbooks (NAME, TEMPLATE, DEFINITION, TABLE_SCHEMA) VALUES (N'gBudgeting-C1-Request-301.xlsx', N'https://www.savetodb.com/downloads/v10/gBudgeting-C1-Request-301.xlsx', N'Request1=xls27.usp_budget_request1,(Default),False,$B$8,,{"Parameters":{"company_id":1,"category_id":69,"time_id":67,"entity_id":73,"rows":26},"ListObjectName":"budget_request1","WorkbookLanguage":"en"}
Request2=xls27.usp_budget_request2,(Default),False,$B$8,,{"Parameters":{"company_id":1,"category_id":69,"time_id":67,"entity_id":73,"rows":26},"ListObjectName":"budget_request2","WorkbookLanguage":"en"}', N'xls27');
INSERT INTO xls.workbooks (NAME, TEMPLATE, DEFINITION, TABLE_SCHEMA) VALUES (N'gBudgeting-C1-Request-401.xlsx', N'https://www.savetodb.com/downloads/v10/gBudgeting-C1-Request-401.xlsx', N'Request1=xls27.usp_budget_request1,(Default),False,$B$8,,{"Parameters":{"company_id":1,"category_id":69,"time_id":67,"entity_id":74,"rows":26},"ListObjectName":"budget_request1","WorkbookLanguage":"en"}
Request2=xls27.usp_budget_request2,(Default),False,$B$8,,{"Parameters":{"company_id":1,"category_id":69,"time_id":67,"entity_id":74,"rows":26},"ListObjectName":"budget_request2","WorkbookLanguage":"en"}', N'xls27');
INSERT INTO xls.workbooks (NAME, TEMPLATE, DEFINITION, TABLE_SCHEMA) VALUES (N'gBudgeting-D1-Analyst.xlsx', N'https://www.savetodb.com/downloads/v10/gBudgeting-D1-Analyst.xlsx', N'Reports=xls27.usp_budget_reports,(Default),False,$B$3,,{"Parameters":{"company_id":1,"category_id":69,"time_id":67,"entity_id":null,"report_id":null,"unit":1},"ListObjectName":"budget_reports","WorkbookLanguage":"en"}
Totals=xls27.usp_budget_requests_totals,(Default),False,$B$3,,{"Parameters":{"company_id":1,"category_id":69,"time_id":67,"entity_id":null,"subsidiary_account_id":null,"region_id":null,"product_id":null,"first_month":1,"last_month":12,"unit":1},"ListObjectName":"budget_requests_totals","WorkbookLanguage":"en"}
Requests=xls27.usp_budget_requests,(Default),False,$B$3,,{"Parameters":{"company_id":1,"category_id":null,"time_id":null,"entity_id":null},"ListObjectName":"budget_requests","WorkbookLanguage":"en"}
Request1=xls27.usp_budget_request1,(Default),False,$B$8,,{"Parameters":{"company_id":1,"category_id":69,"time_id":67,"entity_id":71,"rows":26},"ListObjectName":"budget_request1","WorkbookLanguage":"en"}
Request2=xls27.usp_budget_request2,(Default),False,$B$8,,{"Parameters":{"company_id":1,"category_id":69,"time_id":67,"entity_id":74,"rows":26},"ListObjectName":"budget_request2","WorkbookLanguage":"en"}
OpeningBalances=xls27.usp_budget_balances,xls27.xl_query_list_setup,False,$B$3,,{"Parameters":{"company_id":1,"category_id":69,"time_id":67},"ListObjectName":"budget_balances","WorkbookLanguage":"en"}
CurrencyRates=xls27.usp_budget_currency_rates,xls27.xl_query_list_setup,False,$B$3,,{"Parameters":{"company_id":1,"category_id":null,"time_id":null},"ListObjectName":"budget_currency_rates","WorkbookLanguage":"en"}', N'xls27');
INSERT INTO xls.workbooks (NAME, TEMPLATE, DEFINITION, TABLE_SCHEMA) VALUES (N'gBudgeting-D2-Accounting.xlsx', N'https://www.savetodb.com/downloads/v10/gBudgeting-D2-Accounting.xlsx', N'BudgetJournal=xls27.usp_budget_journal,(Default),False,$B$3,,{"Parameters":{"company_id":1,"category_id":69,"time_id":67,"entity_id":null,"subsidiary_account_id":null,"region_id":null,"product_id":null,"first_month":1,"last_month":12},"ListObjectName":"budget_journal","WorkbookLanguage":"en"}
Journal=xls27.usp_journal,(Default),False,$B$3,,{"Parameters":{"start_year":2020,"start_month":1,"start_day":null,"end_year":2020,"end_month":12,"end_day":null,"company_id":1,"account_id":null,"subsidiary_account_id":null,"entity_id":null,"region_id":null,"product_id":null},"ListObjectName":"journal","WorkbookLanguage":"en"}
TrialBalance=xls27.usp_balance_sheet_trial,(Default),False,$B$3,,{"Parameters":{"start_year":2020,"start_month":1,"start_day":null,"end_year":2020,"end_month":12,"end_day":null,"company_id":1},"ListObjectName":"trial_balance","WorkbookLanguage":"en"}
Reports=xls27.usp_actual_reports,(Default),False,$B$3,,{"Parameters":{"company_id":1,"year":2020,"entity_id":null,"report_id":null,"unit":1},"ListObjectName":"actual_reports","WorkbookLanguage":"en"}
CurrencyRates=xls27.usp_actual_currency_rates,(Default),False,$B$3,,{"Parameters":{"company_id":1,"currency_id":null},"ListObjectName":"currency_rates","WorkbookLanguage":"en"}
OpeningBalances=xls27.usp_actual_balances,(Default),False,$B$3,,{"Parameters":{"company_id":1},"ListObjectName":"balances","WorkbookLanguage":"en"}
ClosedPeriods=xls27.usp_actual_closed_periods,(Default),True,$B$3,,{"Parameters":{"company_id":1},"ListObjectName":"closed_periods","WorkbookLanguage":"en"}
BudgetingAccounts=xls27.usp_budgeting_accounts,xls.queries,False,$B$3,,{"Parameters":{"company_id":1,"account_type_id":null,"is_in_budget":null,"is_active":null},"ListObjectName":"budgeting_accounts","WorkbookLanguage":"en"}
LedgerAccounts=xls27.usp_ledger_accounts,(Default),False,$B$3,,{"Parameters":{"company_id":1},"ListObjectName":"ledger_accounts","WorkbookLanguage":"en"}
Members=xls27.usp_members,xls.queries,False,$B$3,,{"Parameters":{"company_id":1,"dimension_id":7,"is_in_budget":null,"is_active":null},"ListObjectName":"members","WorkbookLanguage":"en"}
SubsidiaryAccounts=xls27.usp_subsidiary_accounts,xls27.xl_query_list_setup,False,$B$3,,{"Parameters":{"company_id":1,"subsidiary_group_id":null},"ListObjectName":"subsidiary_accounts","WorkbookLanguage":"en"}', N'xls27');
INSERT INTO xls.workbooks (NAME, TEMPLATE, DEFINITION, TABLE_SCHEMA) VALUES (N'gBudgeting-D3-CustomReports.xlsx', N'https://www.savetodb.com/downloads/v10/gBudgeting-D3-CustomReports.xlsx', N'Data=xls27.usp_budget_data,(Default),False,$B$3,,{"Parameters":{"company_id":1,"category_id":69,"time_id":67,"entity_id":null},"ListObjectName":"data","WorkbookLanguage":"en"}
SavedReports=xls27.usp_saved_reports,(Default),False,$B$3,,{"Parameters":{"company_id":1,"category_id":69,"time_id":67,"type_id":1},"ListObjectName":"report_data","WorkbookLanguage":"en"}
SavedReportTypes=xls27.usp_saved_report_types,(Default),False,$B$3,,{"Parameters":{"company_id":1},"ListObjectName":"saved_report_types","WorkbookLanguage":"en"}', N'xls27');
INSERT INTO xls.workbooks (NAME, TEMPLATE, DEFINITION, TABLE_SCHEMA) VALUES (N'gBudgeting-D4-ConsolidatedReports.xlsx', N'https://www.savetodb.com/downloads/v10/gBudgeting-D4-ConsolidatedReports.xlsx', N'BaseReport=xls27.usp_saved_reports,(Default),False,$B$3,,{"Parameters":{"company_id":1,"category_id":69,"time_id":67,"type_id":1},"ListObjectName":"base_report"}
CurrentReport=xls27.usp_saved_reports,(Default),False,$B$3,,{"Parameters":{"company_id":1,"category_id":69,"time_id":67,"type_id":1},"ListObjectName":"current_report"}', N'xls27');
INSERT INTO xls.workbooks (NAME, TEMPLATE, DEFINITION, TABLE_SCHEMA) VALUES (N'gBudgeting-F1-SystemTables.xlsx', N'https://www.savetodb.com/downloads/v10/gBudgeting-F1-SystemTables.xlsx', N'objects=xls.objects,(Default),False,$B$3,,{"Parameters":{},"ListObjectName":"objects","WorkbookLanguage":"en"}
handlers=xls.handlers,(Default),False,$B$3,,{"Parameters":{"TABLE_SCHEMA":"(N''dbo27'',N''xls27'')","TABLE_NAME":null,"EVENT_NAME":null},"ListObjectName":"handlers","WorkbookLanguage":"en"}
translations=xls.translations,(Default),False,$B$3,,{"Parameters":{"TABLE_SCHEMA":null,"TABLE_NAME":null,"LANGUAGE_NAME":null},"ListObjectName":"translations","WorkbookLanguage":"en"}
translations_xls=xls27.usp_translations_xls,xls27,False,$B$3,,{"Parameters":{"field":"TRANSLATED_NAME","schema":null,"is_complete":null},"ListObjectName":"translation_xls","WorkbookLanguage":"en"}
translations_common=xls27.usp_translations_common,xls27,False,$B$3,,{"Parameters":{"is_complete":null},"ListObjectName":"translation_common","WorkbookLanguage":"en"}
workbooks=xls.workbooks,(Default),False,$B$3,,{"Parameters":{},"ListObjectName":"workbooks","WorkbookLanguage":"en"}
dimensions=xls27.usp_dimensions,xls27,False,$B$3,,{"Parameters":{},"ListObjectName":"dimensions","WorkbookLanguage":"en"}
ledger_account_types=xls27.usp_ledger_account_types,xls27,False,$B$3,,{"Parameters":{},"ListObjectName":"ledger_account_types","WorkbookLanguage":"en"}
ledger_account_special_types=xls27.usp_ledger_account_special_types,xls27,False,$B$3,,{"Parameters":{},"ListObjectName":"ledger_account_special_types","WorkbookLanguage":"en"}
member_types=xls27.usp_member_types,xls27,False,$B$3,,{"Parameters":{},"ListObjectName":"member_types","WorkbookLanguage":"en"}
report_types=xls27.usp_report_types,xls27,False,$B$3,,{"Parameters":{},"ListObjectName":"report_types","WorkbookLanguage":"en"}
report_section_types=xls27.usp_report_section_types,xls27,False,$B$3,,{"Parameters":{},"ListObjectName":"report_section_types","WorkbookLanguage":"en"}
report_section_accounts=xls27.usp_report_section_accounts,xls27,False,$B$3,,{"Parameters":{"report_type_id":null,"is_pl":null,"entry_side_id":null},"ListObjectName":"report_section_accounts","WorkbookLanguage":"en"}
report_section_value_types=xls27.usp_report_section_value_types,xls27,False,$B$3,,{"Parameters":{},"ListObjectName":"report_section_value_types","WorkbookLanguage":"en"}
entry_sides=xls27.usp_entry_sides,(Default),False,$B$3,,{"Parameters":{},"ListObjectName":"entry_sides","WorkbookLanguage":"en"}', N'xls27');
GO

ALTER AUTHORIZATION ON SCHEMA::xls TO budgeting_app;
GO
CREATE ROLE budgeting_app_admins        AUTHORIZATION budgeting_app;
GO
CREATE ROLE budgeting_app_analysts      AUTHORIZATION budgeting_app;
GO
CREATE ROLE budgeting_app_accountants   AUTHORIZATION budgeting_app;
GO
CREATE ROLE budgeting_app_developers    AUTHORIZATION budgeting_app;
GO
CREATE ROLE budgeting_app_users         AUTHORIZATION budgeting_app;
GO

GRANT ALTER, VIEW DEFINITION ON ROLE::xls_users      TO budgeting_app WITH GRANT OPTION;
GRANT ALTER, VIEW DEFINITION ON ROLE::xls_formats    TO budgeting_app WITH GRANT OPTION;
GRANT ALTER, VIEW DEFINITION ON ROLE::xls_developers TO budgeting_app WITH GRANT OPTION;
GO

IF USER_ID('xls_admins') IS NOT NULL
    BEGIN
    GRANT ALTER, VIEW DEFINITION ON ROLE::xls_admins TO budgeting_app WITH GRANT OPTION;

    EXEC sp_addrolemember 'xls_admins', 'budgeting_app_admins';
    END

EXEC dbo27.xl_actions_set_role_permissions;
GO

EXEC xls.xl_actions_set_role_permissions 1;
GO

print 'Application installed';
